var Cq=Object.defineProperty;var wq=(s,e,t)=>e in s?Cq(s,e,{enumerable:!0,configurable:!0,writable:!0,value:t}):s[e]=t;var Ni=(s,e,t)=>(wq(s,typeof e!="symbol"?e+"":e,t),t);(function(){const e=document.createElement("link").relList;if(e&&e.supports&&e.supports("modulepreload"))return;for(const n of document.querySelectorAll('link[rel="modulepreload"]'))i(n);new MutationObserver(n=>{for(const o of n)if(o.type==="childList")for(const r of o.addedNodes)r.tagName==="LINK"&&r.rel==="modulepreload"&&i(r)}).observe(document,{childList:!0,subtree:!0});function t(n){const o={};return n.integrity&&(o.integrity=n.integrity),n.referrerPolicy&&(o.referrerPolicy=n.referrerPolicy),n.crossOrigin==="use-credentials"?o.credentials="include":n.crossOrigin==="anonymous"?o.credentials="omit":o.credentials="same-origin",o}function i(n){if(n.ep)return;n.ep=!0;const o=t(n);fetch(n.href,o)}})();function Sq(s,e,t){return e in s?Object.defineProperty(s,e,{value:t,enumerable:!0,configurable:!0,writable:!0}):s[e]=t,s}function iF(s,e){var t=Object.keys(s);if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(s);e&&(i=i.filter(function(n){return Object.getOwnPropertyDescriptor(s,n).enumerable})),t.push.apply(t,i)}return t}function nF(s){for(var e=1;e<arguments.length;e++){var t=arguments[e]!=null?arguments[e]:{};e%2?iF(Object(t),!0).forEach(function(i){Sq(s,i,t[i])}):Object.getOwnPropertyDescriptors?Object.defineProperties(s,Object.getOwnPropertyDescriptors(t)):iF(Object(t)).forEach(function(i){Object.defineProperty(s,i,Object.getOwnPropertyDescriptor(t,i))})}return s}function yq(s,e){if(s==null)return{};var t={},i=Object.keys(s),n,o;for(o=0;o<i.length;o++)n=i[o],!(e.indexOf(n)>=0)&&(t[n]=s[n]);return t}function Lq(s,e){if(s==null)return{};var t=yq(s,e),i,n;if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(s);for(n=0;n<o.length;n++)i=o[n],!(e.indexOf(i)>=0)&&Object.prototype.propertyIsEnumerable.call(s,i)&&(t[i]=s[i])}return t}function xq(s,e){return Dq(s)||kq(s,e)||Iq(s,e)||Eq()}function Dq(s){if(Array.isArray(s))return s}function kq(s,e){if(!(typeof Symbol>"u"||!(Symbol.iterator in Object(s)))){var t=[],i=!0,n=!1,o=void 0;try{for(var r=s[Symbol.iterator](),a;!(i=(a=r.next()).done)&&(t.push(a.value),!(e&&t.length===e));i=!0);}catch(l){n=!0,o=l}finally{try{!i&&r.return!=null&&r.return()}finally{if(n)throw o}}return t}}function Iq(s,e){if(s){if(typeof s=="string")return sF(s,e);var t=Object.prototype.toString.call(s).slice(8,-1);if(t==="Object"&&s.constructor&&(t=s.constructor.name),t==="Map"||t==="Set")return Array.from(s);if(t==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t))return sF(s,e)}}function sF(s,e){(e==null||e>s.length)&&(e=s.length);for(var t=0,i=new Array(e);t<e;t++)i[t]=s[t];return i}function Eq(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Nq(s,e,t){return e in s?Object.defineProperty(s,e,{value:t,enumerable:!0,configurable:!0,writable:!0}):s[e]=t,s}function oF(s,e){var t=Object.keys(s);if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(s);e&&(i=i.filter(function(n){return Object.getOwnPropertyDescriptor(s,n).enumerable})),t.push.apply(t,i)}return t}function rF(s){for(var e=1;e<arguments.length;e++){var t=arguments[e]!=null?arguments[e]:{};e%2?oF(Object(t),!0).forEach(function(i){Nq(s,i,t[i])}):Object.getOwnPropertyDescriptors?Object.defineProperties(s,Object.getOwnPropertyDescriptors(t)):oF(Object(t)).forEach(function(i){Object.defineProperty(s,i,Object.getOwnPropertyDescriptor(t,i))})}return s}function Tq(){for(var s=arguments.length,e=new Array(s),t=0;t<s;t++)e[t]=arguments[t];return function(i){return e.reduceRight(function(n,o){return o(n)},i)}}function tv(s){return function e(){for(var t=this,i=arguments.length,n=new Array(i),o=0;o<i;o++)n[o]=arguments[o];return n.length>=s.length?s.apply(this,n):function(){for(var r=arguments.length,a=new Array(r),l=0;l<r;l++)a[l]=arguments[l];return e.apply(t,[].concat(n,a))}}}function hS(s){return{}.toString.call(s).includes("Object")}function Mq(s){return!Object.keys(s).length}function u0(s){return typeof s=="function"}function Rq(s,e){return Object.prototype.hasOwnProperty.call(s,e)}function Aq(s,e){return hS(e)||tu("changeType"),Object.keys(e).some(function(t){return!Rq(s,t)})&&tu("changeField"),e}function Pq(s){u0(s)||tu("selectorType")}function Oq(s){u0(s)||hS(s)||tu("handlerType"),hS(s)&&Object.values(s).some(function(e){return!u0(e)})&&tu("handlersType")}function Fq(s){s||tu("initialIsRequired"),hS(s)||tu("initialType"),Mq(s)&&tu("initialContent")}function Bq(s,e){throw new Error(s[e]||s.default)}var Wq={initialIsRequired:"initial state is required",initialType:"initial state should be an object",initialContent:"initial state shouldn't be an empty object",handlerType:"handler should be an object or a function",handlersType:"all handlers should be a functions",selectorType:"selector should be a function",changeType:"provided value of changes should be an object",changeField:'it seams you want to change a field in the state which is not specified in the "initial" state',default:"an unknown error accured in `state-local` package"},tu=tv(Bq)(Wq),GC={changes:Aq,selector:Pq,handler:Oq,initial:Fq};function Vq(s){var e=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};GC.initial(s),GC.handler(e);var t={current:s},i=tv(Uq)(t,e),n=tv(zq)(t),o=tv(GC.changes)(s),r=tv(Hq)(t);function a(){var d=arguments.length>0&&arguments[0]!==void 0?arguments[0]:function(c){return c};return GC.selector(d),d(t.current)}function l(d){Tq(i,n,o,r)(d)}return[a,l]}function Hq(s,e){return u0(e)?e(s.current):e}function zq(s,e){return s.current=rF(rF({},s.current),e),e}function Uq(s,e,t){return u0(e)?e(s.current):Object.keys(t).forEach(function(i){var n;return(n=e[i])===null||n===void 0?void 0:n.call(e,s.current[i])}),t}var $q={create:Vq},jq={paths:{vs:"https://cdn.jsdelivr.net/npm/monaco-editor@0.43.0/min/vs"}};function Kq(s){return function e(){for(var t=this,i=arguments.length,n=new Array(i),o=0;o<i;o++)n[o]=arguments[o];return n.length>=s.length?s.apply(this,n):function(){for(var r=arguments.length,a=new Array(r),l=0;l<r;l++)a[l]=arguments[l];return e.apply(t,[].concat(n,a))}}}function qq(s){return{}.toString.call(s).includes("Object")}function Gq(s){return s||aF("configIsRequired"),qq(s)||aF("configType"),s.urls?(Zq(),{paths:{vs:s.urls.monacoBase}}):s}function Zq(){console.warn(e6.deprecation)}function Yq(s,e){throw new Error(s[e]||s.default)}var e6={configIsRequired:"the configuration object is required",configType:"the configuration object should be an object",default:"an unknown error accured in `@monaco-editor/loader` package",deprecation:`Deprecation warning!
    You are using deprecated way of configuration.

    Instead of using
      monaco.config({ urls: { monacoBase: '...' } })
    use
      monaco.config({ paths: { vs: '...' } })

    For more please check the link https://github.com/suren-atoyan/monaco-loader#config
  `},aF=Kq(Yq)(e6),Xq={config:Gq},Qq=function(){for(var e=arguments.length,t=new Array(e),i=0;i<e;i++)t[i]=arguments[i];return function(n){return t.reduceRight(function(o,r){return r(o)},n)}};function t6(s,e){return Object.keys(e).forEach(function(t){e[t]instanceof Object&&s[t]&&Object.assign(e[t],t6(s[t],e[t]))}),nF(nF({},s),e)}var Jq={type:"cancelation",msg:"operation is manually canceled"};function uk(s){var e=!1,t=new Promise(function(i,n){s.then(function(o){return e?n(Jq):i(o)}),s.catch(n)});return t.cancel=function(){return e=!0},t}var eG=$q.create({config:jq,isInitialized:!1,resolve:null,reject:null,monaco:null}),i6=xq(eG,2),Yb=i6[0],kL=i6[1];function tG(s){var e=Xq.config(s),t=e.monaco,i=Lq(e,["monaco"]);kL(function(n){return{config:t6(n.config,i),monaco:t}})}function iG(){var s=Yb(function(e){var t=e.monaco,i=e.isInitialized,n=e.resolve;return{monaco:t,isInitialized:i,resolve:n}});if(!s.isInitialized){if(kL({isInitialized:!0}),s.monaco)return s.resolve(s.monaco),uk(hk);if(window.monaco&&window.monaco.editor)return n6(window.monaco),s.resolve(window.monaco),uk(hk);Qq(nG,oG)(rG)}return uk(hk)}function nG(s){return document.body.appendChild(s)}function sG(s){var e=document.createElement("script");return s&&(e.src=s),e}function oG(s){var e=Yb(function(i){var n=i.config,o=i.reject;return{config:n,reject:o}}),t=sG("".concat(e.config.paths.vs,"/loader.js"));return t.onload=function(){return s()},t.onerror=e.reject,t}function rG(){var s=Yb(function(t){var i=t.config,n=t.resolve,o=t.reject;return{config:i,resolve:n,reject:o}}),e=window.require;e.config(s.config),e(["vs/editor/editor.main"],function(t){n6(t),s.resolve(t)},function(t){s.reject(t)})}function n6(s){Yb().monaco||kL({monaco:s})}function aG(){return Yb(function(s){var e=s.monaco;return e})}var hk=new Promise(function(s,e){return kL({resolve:s,reject:e})}),gS={config:tG,init:iG,__getMonacoInstance:aG};/**
* @vue/shared v3.4.15
* (c) 2018-present Yuxi (Evan) You and Vue contributors
* @license MIT
**/function sA(s,e){const t=new Set(s.split(","));return e?i=>t.has(i.toLowerCase()):i=>t.has(i)}const un={},kp=[],Vr=()=>{},lG=()=>!1,IL=s=>s.charCodeAt(0)===111&&s.charCodeAt(1)===110&&(s.charCodeAt(2)>122||s.charCodeAt(2)<97),oA=s=>s.startsWith("onUpdate:"),Fs=Object.assign,rA=(s,e)=>{const t=s.indexOf(e);t>-1&&s.splice(t,1)},dG=Object.prototype.hasOwnProperty,ci=(s,e)=>dG.call(s,e),Tt=Array.isArray,Ip=s=>EL(s)==="[object Map]",s6=s=>EL(s)==="[object Set]",Ht=s=>typeof s=="function",ls=s=>typeof s=="string",Zm=s=>typeof s=="symbol",fn=s=>s!==null&&typeof s=="object",o6=s=>(fn(s)||Ht(s))&&Ht(s.then)&&Ht(s.catch),r6=Object.prototype.toString,EL=s=>r6.call(s),cG=s=>EL(s).slice(8,-1),a6=s=>EL(s)==="[object Object]",aA=s=>ls(s)&&s!=="NaN"&&s[0]!=="-"&&""+parseInt(s,10)===s,yw=sA(",key,ref,ref_for,ref_key,onVnodeBeforeMount,onVnodeMounted,onVnodeBeforeUpdate,onVnodeUpdated,onVnodeBeforeUnmount,onVnodeUnmounted"),NL=s=>{const e=Object.create(null);return t=>e[t]||(e[t]=s(t))},uG=/-(\w)/g,$l=NL(s=>s.replace(uG,(e,t)=>t?t.toUpperCase():"")),hG=/\B([A-Z])/g,Ym=NL(s=>s.replace(hG,"-$1").toLowerCase()),TL=NL(s=>s.charAt(0).toUpperCase()+s.slice(1)),gk=NL(s=>s?`on${TL(s)}`:""),Su=(s,e)=>!Object.is(s,e),fk=(s,e)=>{for(let t=0;t<s.length;t++)s[t](e)},fS=(s,e,t)=>{Object.defineProperty(s,e,{configurable:!0,enumerable:!1,value:t})},gG=s=>{const e=parseFloat(s);return isNaN(e)?s:e};let lF;const l6=()=>lF||(lF=typeof globalThis<"u"?globalThis:typeof self<"u"?self:typeof window<"u"?window:typeof global<"u"?global:{});function ML(s){if(Tt(s)){const e={};for(let t=0;t<s.length;t++){const i=s[t],n=ls(i)?_G(i):ML(i);if(n)for(const o in n)e[o]=n[o]}return e}else if(ls(s)||fn(s))return s}const fG=/;(?![^(]*\))/g,pG=/:([^]+)/,mG=/\/\*[^]*?\*\//g;function _G(s){const e={};return s.replace(mG,"").split(fG).forEach(t=>{if(t){const i=t.split(pG);i.length>1&&(e[i[0].trim()]=i[1].trim())}}),e}function Ho(s){let e="";if(ls(s))e=s;else if(Tt(s))for(let t=0;t<s.length;t++){const i=Ho(s[t]);i&&(e+=i+" ")}else if(fn(s))for(const t in s)s[t]&&(e+=t+" ");return e.trim()}const vG="itemscope,allowfullscreen,formnovalidate,ismap,nomodule,novalidate,readonly",bG=sA(vG);function d6(s){return!!s||s===""}const jn=s=>ls(s)?s:s==null?"":Tt(s)||fn(s)&&(s.toString===r6||!Ht(s.toString))?JSON.stringify(s,c6,2):String(s),c6=(s,e)=>e&&e.__v_isRef?c6(s,e.value):Ip(e)?{[`Map(${e.size})`]:[...e.entries()].reduce((t,[i,n],o)=>(t[pk(i,o)+" =>"]=n,t),{})}:s6(e)?{[`Set(${e.size})`]:[...e.values()].map(t=>pk(t))}:Zm(e)?pk(e):fn(e)&&!Tt(e)&&!a6(e)?String(e):e,pk=(s,e="")=>{var t;return Zm(s)?`Symbol(${(t=s.description)!=null?t:e})`:s};/**
* @vue/reactivity v3.4.15
* (c) 2018-present Yuxi (Evan) You and Vue contributors
* @license MIT
**/let ur;class u6{constructor(e=!1){this.detached=e,this._active=!0,this.effects=[],this.cleanups=[],this.parent=ur,!e&&ur&&(this.index=(ur.scopes||(ur.scopes=[])).push(this)-1)}get active(){return this._active}run(e){if(this._active){const t=ur;try{return ur=this,e()}finally{ur=t}}}on(){ur=this}off(){ur=this.parent}stop(e){if(this._active){let t,i;for(t=0,i=this.effects.length;t<i;t++)this.effects[t].stop();for(t=0,i=this.cleanups.length;t<i;t++)this.cleanups[t]();if(this.scopes)for(t=0,i=this.scopes.length;t<i;t++)this.scopes[t].stop(!0);if(!this.detached&&this.parent&&!e){const n=this.parent.scopes.pop();n&&n!==this&&(this.parent.scopes[this.index]=n,n.index=this.index)}this.parent=void 0,this._active=!1}}}function h6(s){return new u6(s)}function CG(s,e=ur){e&&e.active&&e.effects.push(s)}function g6(){return ur}function wG(s){ur&&ur.cleanups.push(s)}let lg;class lA{constructor(e,t,i,n){this.fn=e,this.trigger=t,this.scheduler=i,this.active=!0,this.deps=[],this._dirtyLevel=2,this._trackId=0,this._runnings=0,this._shouldSchedule=!1,this._depsLength=0,CG(this,n)}get dirty(){if(this._dirtyLevel===1){sf();for(let e=0;e<this._depsLength;e++){const t=this.deps[e];if(t.computed&&(SG(t.computed),this._dirtyLevel>=2))break}this._dirtyLevel<2&&(this._dirtyLevel=0),of()}return this._dirtyLevel>=2}set dirty(e){this._dirtyLevel=e?2:0}run(){if(this._dirtyLevel=0,!this.active)return this.fn();let e=iu,t=lg;try{return iu=!0,lg=this,this._runnings++,dF(this),this.fn()}finally{cF(this),this._runnings--,lg=t,iu=e}}stop(){var e;this.active&&(dF(this),cF(this),(e=this.onStop)==null||e.call(this),this.active=!1)}}function SG(s){return s.value}function dF(s){s._trackId++,s._depsLength=0}function cF(s){if(s.deps&&s.deps.length>s._depsLength){for(let e=s._depsLength;e<s.deps.length;e++)f6(s.deps[e],s);s.deps.length=s._depsLength}}function f6(s,e){const t=s.get(e);t!==void 0&&e._trackId!==t&&(s.delete(e),s.size===0&&s.cleanup())}let iu=!0,TE=0;const p6=[];function sf(){p6.push(iu),iu=!1}function of(){const s=p6.pop();iu=s===void 0?!0:s}function dA(){TE++}function cA(){for(TE--;!TE&&ME.length;)ME.shift()()}function m6(s,e,t){if(e.get(s)!==s._trackId){e.set(s,s._trackId);const i=s.deps[s._depsLength];i!==e?(i&&f6(i,s),s.deps[s._depsLength++]=e):s._depsLength++}}const ME=[];function _6(s,e,t){dA();for(const i of s.keys())if(i._dirtyLevel<e&&s.get(i)===i._trackId){const n=i._dirtyLevel;i._dirtyLevel=e,n===0&&(i._shouldSchedule=!0,i.trigger())}v6(s),cA()}function v6(s){for(const e of s.keys())e.scheduler&&e._shouldSchedule&&(!e._runnings||e.allowRecurse)&&s.get(e)===e._trackId&&(e._shouldSchedule=!1,ME.push(e.scheduler))}const b6=(s,e)=>{const t=new Map;return t.cleanup=s,t.computed=e,t},pS=new WeakMap,dg=Symbol(""),RE=Symbol("");function tr(s,e,t){if(iu&&lg){let i=pS.get(s);i||pS.set(s,i=new Map);let n=i.get(t);n||i.set(t,n=b6(()=>i.delete(t))),m6(lg,n)}}function zd(s,e,t,i,n,o){const r=pS.get(s);if(!r)return;let a=[];if(e==="clear")a=[...r.values()];else if(t==="length"&&Tt(s)){const l=Number(i);r.forEach((d,c)=>{(c==="length"||!Zm(c)&&c>=l)&&a.push(d)})}else switch(t!==void 0&&a.push(r.get(t)),e){case"add":Tt(s)?aA(t)&&a.push(r.get("length")):(a.push(r.get(dg)),Ip(s)&&a.push(r.get(RE)));break;case"delete":Tt(s)||(a.push(r.get(dg)),Ip(s)&&a.push(r.get(RE)));break;case"set":Ip(s)&&a.push(r.get(dg));break}dA();for(const l of a)l&&_6(l,2);cA()}function yG(s,e){var t;return(t=pS.get(s))==null?void 0:t.get(e)}const LG=sA("__proto__,__v_isRef,__isVue"),C6=new Set(Object.getOwnPropertyNames(Symbol).filter(s=>s!=="arguments"&&s!=="caller").map(s=>Symbol[s]).filter(Zm)),uF=xG();function xG(){const s={};return["includes","indexOf","lastIndexOf"].forEach(e=>{s[e]=function(...t){const i=gi(this);for(let o=0,r=this.length;o<r;o++)tr(i,"get",o+"");const n=i[e](...t);return n===-1||n===!1?i[e](...t.map(gi)):n}}),["push","pop","shift","unshift","splice"].forEach(e=>{s[e]=function(...t){sf(),dA();const i=gi(this)[e].apply(this,t);return cA(),of(),i}}),s}function DG(s){const e=gi(this);return tr(e,"has",s),e.hasOwnProperty(s)}class w6{constructor(e=!1,t=!1){this._isReadonly=e,this._shallow=t}get(e,t,i){const n=this._isReadonly,o=this._shallow;if(t==="__v_isReactive")return!n;if(t==="__v_isReadonly")return n;if(t==="__v_isShallow")return o;if(t==="__v_raw")return i===(n?o?WG:x6:o?L6:y6).get(e)||Object.getPrototypeOf(e)===Object.getPrototypeOf(i)?e:void 0;const r=Tt(e);if(!n){if(r&&ci(uF,t))return Reflect.get(uF,t,i);if(t==="hasOwnProperty")return DG}const a=Reflect.get(e,t,i);return(Zm(t)?C6.has(t):LG(t))||(n||tr(e,"get",t),o)?a:ds(a)?r&&aA(t)?a:a.value:fn(a)?n?D6(a):AL(a):a}}class S6 extends w6{constructor(e=!1){super(!1,e)}set(e,t,i,n){let o=e[t];if(!this._shallow){const l=nm(o);if(!mS(i)&&!nm(i)&&(o=gi(o),i=gi(i)),!Tt(e)&&ds(o)&&!ds(i))return l?!1:(o.value=i,!0)}const r=Tt(e)&&aA(t)?Number(t)<e.length:ci(e,t),a=Reflect.set(e,t,i,n);return e===gi(n)&&(r?Su(i,o)&&zd(e,"set",t,i):zd(e,"add",t,i)),a}deleteProperty(e,t){const i=ci(e,t);e[t];const n=Reflect.deleteProperty(e,t);return n&&i&&zd(e,"delete",t,void 0),n}has(e,t){const i=Reflect.has(e,t);return(!Zm(t)||!C6.has(t))&&tr(e,"has",t),i}ownKeys(e){return tr(e,"iterate",Tt(e)?"length":dg),Reflect.ownKeys(e)}}class kG extends w6{constructor(e=!1){super(!0,e)}set(e,t){return!0}deleteProperty(e,t){return!0}}const IG=new S6,EG=new kG,NG=new S6(!0),uA=s=>s,RL=s=>Reflect.getPrototypeOf(s);function ZC(s,e,t=!1,i=!1){s=s.__v_raw;const n=gi(s),o=gi(e);t||(Su(e,o)&&tr(n,"get",e),tr(n,"get",o));const{has:r}=RL(n),a=i?uA:t?fA:h0;if(r.call(n,e))return a(s.get(e));if(r.call(n,o))return a(s.get(o));s!==n&&s.get(e)}function YC(s,e=!1){const t=this.__v_raw,i=gi(t),n=gi(s);return e||(Su(s,n)&&tr(i,"has",s),tr(i,"has",n)),s===n?t.has(s):t.has(s)||t.has(n)}function XC(s,e=!1){return s=s.__v_raw,!e&&tr(gi(s),"iterate",dg),Reflect.get(s,"size",s)}function hF(s){s=gi(s);const e=gi(this);return RL(e).has.call(e,s)||(e.add(s),zd(e,"add",s,s)),this}function gF(s,e){e=gi(e);const t=gi(this),{has:i,get:n}=RL(t);let o=i.call(t,s);o||(s=gi(s),o=i.call(t,s));const r=n.call(t,s);return t.set(s,e),o?Su(e,r)&&zd(t,"set",s,e):zd(t,"add",s,e),this}function fF(s){const e=gi(this),{has:t,get:i}=RL(e);let n=t.call(e,s);n||(s=gi(s),n=t.call(e,s)),i&&i.call(e,s);const o=e.delete(s);return n&&zd(e,"delete",s,void 0),o}function pF(){const s=gi(this),e=s.size!==0,t=s.clear();return e&&zd(s,"clear",void 0,void 0),t}function QC(s,e){return function(i,n){const o=this,r=o.__v_raw,a=gi(r),l=e?uA:s?fA:h0;return!s&&tr(a,"iterate",dg),r.forEach((d,c)=>i.call(n,l(d),l(c),o))}}function JC(s,e,t){return function(...i){const n=this.__v_raw,o=gi(n),r=Ip(o),a=s==="entries"||s===Symbol.iterator&&r,l=s==="keys"&&r,d=n[s](...i),c=t?uA:e?fA:h0;return!e&&tr(o,"iterate",l?RE:dg),{next(){const{value:u,done:h}=d.next();return h?{value:u,done:h}:{value:a?[c(u[0]),c(u[1])]:c(u),done:h}},[Symbol.iterator](){return this}}}}function gc(s){return function(...e){return s==="delete"?!1:s==="clear"?void 0:this}}function TG(){const s={get(o){return ZC(this,o)},get size(){return XC(this)},has:YC,add:hF,set:gF,delete:fF,clear:pF,forEach:QC(!1,!1)},e={get(o){return ZC(this,o,!1,!0)},get size(){return XC(this)},has:YC,add:hF,set:gF,delete:fF,clear:pF,forEach:QC(!1,!0)},t={get(o){return ZC(this,o,!0)},get size(){return XC(this,!0)},has(o){return YC.call(this,o,!0)},add:gc("add"),set:gc("set"),delete:gc("delete"),clear:gc("clear"),forEach:QC(!0,!1)},i={get(o){return ZC(this,o,!0,!0)},get size(){return XC(this,!0)},has(o){return YC.call(this,o,!0)},add:gc("add"),set:gc("set"),delete:gc("delete"),clear:gc("clear"),forEach:QC(!0,!0)};return["keys","values","entries",Symbol.iterator].forEach(o=>{s[o]=JC(o,!1,!1),t[o]=JC(o,!0,!1),e[o]=JC(o,!1,!0),i[o]=JC(o,!0,!0)}),[s,t,e,i]}const[MG,RG,AG,PG]=TG();function hA(s,e){const t=e?s?PG:AG:s?RG:MG;return(i,n,o)=>n==="__v_isReactive"?!s:n==="__v_isReadonly"?s:n==="__v_raw"?i:Reflect.get(ci(t,n)&&n in i?t:i,n,o)}const OG={get:hA(!1,!1)},FG={get:hA(!1,!0)},BG={get:hA(!0,!1)},y6=new WeakMap,L6=new WeakMap,x6=new WeakMap,WG=new WeakMap;function VG(s){switch(s){case"Object":case"Array":return 1;case"Map":case"Set":case"WeakMap":case"WeakSet":return 2;default:return 0}}function HG(s){return s.__v_skip||!Object.isExtensible(s)?0:VG(cG(s))}function AL(s){return nm(s)?s:gA(s,!1,IG,OG,y6)}function zG(s){return gA(s,!1,NG,FG,L6)}function D6(s){return gA(s,!0,EG,BG,x6)}function gA(s,e,t,i,n){if(!fn(s)||s.__v_raw&&!(e&&s.__v_isReactive))return s;const o=n.get(s);if(o)return o;const r=HG(s);if(r===0)return s;const a=new Proxy(s,r===2?i:t);return n.set(s,a),a}function nu(s){return nm(s)?nu(s.__v_raw):!!(s&&s.__v_isReactive)}function nm(s){return!!(s&&s.__v_isReadonly)}function mS(s){return!!(s&&s.__v_isShallow)}function k6(s){return nu(s)||nm(s)}function gi(s){const e=s&&s.__v_raw;return e?gi(e):s}function PL(s){return fS(s,"__v_skip",!0),s}const h0=s=>fn(s)?AL(s):s,fA=s=>fn(s)?D6(s):s;class I6{constructor(e,t,i,n){this._setter=t,this.dep=void 0,this.__v_isRef=!0,this.__v_isReadonly=!1,this.effect=new lA(()=>e(this._value),()=>Lw(this,1),()=>this.dep&&v6(this.dep)),this.effect.computed=this,this.effect.active=this._cacheable=!n,this.__v_isReadonly=i}get value(){const e=gi(this);return(!e._cacheable||e.effect.dirty)&&Su(e._value,e._value=e.effect.run())&&Lw(e,2),E6(e),e.effect._dirtyLevel>=1&&Lw(e,1),e._value}set value(e){this._setter(e)}get _dirty(){return this.effect.dirty}set _dirty(e){this.effect.dirty=e}}function UG(s,e,t=!1){let i,n;const o=Ht(s);return o?(i=s,n=Vr):(i=s.get,n=s.set),new I6(i,n,o||!n,t)}function E6(s){iu&&lg&&(s=gi(s),m6(lg,s.dep||(s.dep=b6(()=>s.dep=void 0,s instanceof I6?s:void 0))))}function Lw(s,e=2,t){s=gi(s);const i=s.dep;i&&_6(i,e)}function ds(s){return!!(s&&s.__v_isRef===!0)}function _o(s){return N6(s,!1)}function Xm(s){return N6(s,!0)}function N6(s,e){return ds(s)?s:new $G(s,e)}class $G{constructor(e,t){this.__v_isShallow=t,this.dep=void 0,this.__v_isRef=!0,this._rawValue=t?e:gi(e),this._value=t?e:h0(e)}get value(){return E6(this),this._value}set value(e){const t=this.__v_isShallow||mS(e)||nm(e);e=t?e:gi(e),Su(e,this._rawValue)&&(this._rawValue=e,this._value=t?e:h0(e),Lw(this,2))}}function Ue(s){return ds(s)?s.value:s}const jG={get:(s,e,t)=>Ue(Reflect.get(s,e,t)),set:(s,e,t,i)=>{const n=s[e];return ds(n)&&!ds(t)?(n.value=t,!0):Reflect.set(s,e,t,i)}};function T6(s){return nu(s)?s:new Proxy(s,jG)}function KG(s){const e=Tt(s)?new Array(s.length):{};for(const t in s)e[t]=GG(s,t);return e}class qG{constructor(e,t,i){this._object=e,this._key=t,this._defaultValue=i,this.__v_isRef=!0}get value(){const e=this._object[this._key];return e===void 0?this._defaultValue:e}set value(e){this._object[this._key]=e}get dep(){return yG(gi(this._object),this._key)}}function GG(s,e,t){const i=s[e];return ds(i)?i:new qG(s,e,t)}/**
* @vue/runtime-core v3.4.15
* (c) 2018-present Yuxi (Evan) You and Vue contributors
* @license MIT
**/function su(s,e,t,i){let n;try{n=i?s(...i):s()}catch(o){OL(o,e,t)}return n}function Ma(s,e,t,i){if(Ht(s)){const o=su(s,e,t,i);return o&&o6(o)&&o.catch(r=>{OL(r,e,t)}),o}const n=[];for(let o=0;o<s.length;o++)n.push(Ma(s[o],e,t,i));return n}function OL(s,e,t,i=!0){const n=e?e.vnode:null;if(e){let o=e.parent;const r=e.proxy,a=`https://vuejs.org/error-reference/#runtime-${t}`;for(;o;){const d=o.ec;if(d){for(let c=0;c<d.length;c++)if(d[c](s,r,a)===!1)return}o=o.parent}const l=e.appContext.config.errorHandler;if(l){su(l,null,10,[s,r,a]);return}}ZG(s,t,n,i)}function ZG(s,e,t,i=!0){console.error(s)}let g0=!1,AE=!1;const Zs=[];let ml=0;const Ep=[];let Ec=null,Wh=0;const M6=Promise.resolve();let pA=null;function Xb(s){const e=pA||M6;return s?e.then(this?s.bind(this):s):e}function YG(s){let e=ml+1,t=Zs.length;for(;e<t;){const i=e+t>>>1,n=Zs[i],o=f0(n);o<s||o===s&&n.pre?e=i+1:t=i}return e}function mA(s){(!Zs.length||!Zs.includes(s,g0&&s.allowRecurse?ml+1:ml))&&(s.id==null?Zs.push(s):Zs.splice(YG(s.id),0,s),R6())}function R6(){!g0&&!AE&&(AE=!0,pA=M6.then(P6))}function XG(s){const e=Zs.indexOf(s);e>ml&&Zs.splice(e,1)}function QG(s){Tt(s)?Ep.push(...s):(!Ec||!Ec.includes(s,s.allowRecurse?Wh+1:Wh))&&Ep.push(s),R6()}function mF(s,e,t=g0?ml+1:0){for(;t<Zs.length;t++){const i=Zs[t];if(i&&i.pre){if(s&&i.id!==s.uid)continue;Zs.splice(t,1),t--,i()}}}function A6(s){if(Ep.length){const e=[...new Set(Ep)].sort((t,i)=>f0(t)-f0(i));if(Ep.length=0,Ec){Ec.push(...e);return}for(Ec=e,Wh=0;Wh<Ec.length;Wh++)Ec[Wh]();Ec=null,Wh=0}}const f0=s=>s.id==null?1/0:s.id,JG=(s,e)=>{const t=f0(s)-f0(e);if(t===0){if(s.pre&&!e.pre)return-1;if(e.pre&&!s.pre)return 1}return t};function P6(s){AE=!1,g0=!0,Zs.sort(JG);try{for(ml=0;ml<Zs.length;ml++){const e=Zs[ml];e&&e.active!==!1&&su(e,null,14)}}finally{ml=0,Zs.length=0,A6(),g0=!1,pA=null,(Zs.length||Ep.length)&&P6()}}function eZ(s,e,...t){if(s.isUnmounted)return;const i=s.vnode.props||un;let n=t;const o=e.startsWith("update:"),r=o&&e.slice(7);if(r&&r in i){const c=`${r==="modelValue"?"model":r}Modifiers`,{number:u,trim:h}=i[c]||un;h&&(n=t.map(g=>ls(g)?g.trim():g)),u&&(n=t.map(gG))}let a,l=i[a=gk(e)]||i[a=gk($l(e))];!l&&o&&(l=i[a=gk(Ym(e))]),l&&Ma(l,s,6,n);const d=i[a+"Once"];if(d){if(!s.emitted)s.emitted={};else if(s.emitted[a])return;s.emitted[a]=!0,Ma(d,s,6,n)}}function O6(s,e,t=!1){const i=e.emitsCache,n=i.get(s);if(n!==void 0)return n;const o=s.emits;let r={},a=!1;if(!Ht(s)){const l=d=>{const c=O6(d,e,!0);c&&(a=!0,Fs(r,c))};!t&&e.mixins.length&&e.mixins.forEach(l),s.extends&&l(s.extends),s.mixins&&s.mixins.forEach(l)}return!o&&!a?(fn(s)&&i.set(s,null),null):(Tt(o)?o.forEach(l=>r[l]=null):Fs(r,o),fn(s)&&i.set(s,r),r)}function FL(s,e){return!s||!IL(e)?!1:(e=e.slice(2).replace(/Once$/,""),ci(s,e[0].toLowerCase()+e.slice(1))||ci(s,Ym(e))||ci(s,e))}let Ys=null,F6=null;function _S(s){const e=Ys;return Ys=s,F6=s&&s.type.__scopeId||null,e}function ts(s,e=Ys,t){if(!e||s._n)return s;const i=(...n)=>{i._d&&kF(-1);const o=_S(e);let r;try{r=s(...n)}finally{_S(o),i._d&&kF(1)}return r};return i._n=!0,i._c=!0,i._d=!0,i}function mk(s){const{type:e,vnode:t,proxy:i,withProxy:n,props:o,propsOptions:[r],slots:a,attrs:l,emit:d,render:c,renderCache:u,data:h,setupState:g,ctx:f,inheritAttrs:m}=s;let _,v;const b=_S(s);try{if(t.shapeFlag&4){const w=n||i,S=w;_=cl(c.call(S,w,u,o,g,h,f)),v=l}else{const w=e;_=cl(w.length>1?w(o,{attrs:l,slots:a,emit:d}):w(o,null)),v=e.props?l:tZ(l)}}catch(w){Nv.length=0,OL(w,s,1),_=Yt(yu)}let C=_;if(v&&m!==!1){const w=Object.keys(v),{shapeFlag:S}=C;w.length&&S&7&&(r&&w.some(oA)&&(v=iZ(v,r)),C=sm(C,v))}return t.dirs&&(C=sm(C),C.dirs=C.dirs?C.dirs.concat(t.dirs):t.dirs),t.transition&&(C.transition=t.transition),_=C,_S(b),_}const tZ=s=>{let e;for(const t in s)(t==="class"||t==="style"||IL(t))&&((e||(e={}))[t]=s[t]);return e},iZ=(s,e)=>{const t={};for(const i in s)(!oA(i)||!(i.slice(9)in e))&&(t[i]=s[i]);return t};function nZ(s,e,t){const{props:i,children:n,component:o}=s,{props:r,children:a,patchFlag:l}=e,d=o.emitsOptions;if(e.dirs||e.transition)return!0;if(t&&l>=0){if(l&1024)return!0;if(l&16)return i?_F(i,r,d):!!r;if(l&8){const c=e.dynamicProps;for(let u=0;u<c.length;u++){const h=c[u];if(r[h]!==i[h]&&!FL(d,h))return!0}}}else return(n||a)&&(!a||!a.$stable)?!0:i===r?!1:i?r?_F(i,r,d):!0:!!r;return!1}function _F(s,e,t){const i=Object.keys(e);if(i.length!==Object.keys(s).length)return!0;for(let n=0;n<i.length;n++){const o=i[n];if(e[o]!==s[o]&&!FL(t,o))return!0}return!1}function sZ({vnode:s,parent:e},t){for(;e;){const i=e.subTree;if(i.suspense&&i.suspense.activeBranch===s&&(i.el=s.el),i===s)(s=e.vnode).el=t,e=e.parent;else break}}const B6="components";function PE(s,e){return rZ(B6,s,!0,e)||s}const oZ=Symbol.for("v-ndc");function rZ(s,e,t=!0,i=!1){const n=Ys||Ns;if(n){const o=n.type;if(s===B6){const a=eY(o,!1);if(a&&(a===e||a===$l(e)||a===TL($l(e))))return o}const r=vF(n[s]||o[s],e)||vF(n.appContext[s],e);return!r&&i?o:r}}function vF(s,e){return s&&(s[e]||s[$l(e)]||s[TL($l(e))])}const aZ=s=>s.__isSuspense;function lZ(s,e){e&&e.pendingBranch?Tt(s)?e.effects.push(...s):e.effects.push(s):QG(s)}const dZ=Symbol.for("v-scx"),cZ=()=>Ev(dZ),e1={};function mn(s,e,t){return W6(s,e,t)}function W6(s,e,{immediate:t,deep:i,flush:n,once:o,onTrack:r,onTrigger:a}=un){if(e&&o){const x=e;e=(...L)=>{x(...L),S()}}const l=Ns,d=x=>i===!0?x:Jf(x,i===!1?1:void 0);let c,u=!1,h=!1;if(ds(s)?(c=()=>s.value,u=mS(s)):nu(s)?(c=()=>d(s),u=!0):Tt(s)?(h=!0,u=s.some(x=>nu(x)||mS(x)),c=()=>s.map(x=>{if(ds(x))return x.value;if(nu(x))return d(x);if(Ht(x))return su(x,l,2)})):Ht(s)?e?c=()=>su(s,l,2):c=()=>(g&&g(),Ma(s,l,3,[f])):c=Vr,e&&i){const x=c;c=()=>Jf(x())}let g,f=x=>{g=C.onStop=()=>{su(x,l,4),g=C.onStop=void 0}},m;if(UL)if(f=Vr,e?t&&Ma(e,l,3,[c(),h?[]:void 0,f]):c(),n==="sync"){const x=cZ();m=x.__watcherHandles||(x.__watcherHandles=[])}else return Vr;let _=h?new Array(s.length).fill(e1):e1;const v=()=>{if(!(!C.active||!C.dirty))if(e){const x=C.run();(i||u||(h?x.some((L,k)=>Su(L,_[k])):Su(x,_)))&&(g&&g(),Ma(e,l,3,[x,_===e1?void 0:h&&_[0]===e1?[]:_,f]),_=x)}else C.run()};v.allowRecurse=!!e;let b;n==="sync"?b=v:n==="post"?b=()=>Po(v,l&&l.suspense):(v.pre=!0,l&&(v.id=l.uid),b=()=>mA(v));const C=new lA(c,Vr,b),w=g6(),S=()=>{C.stop(),w&&rA(w.effects,C)};return e?t?v():_=C.run():n==="post"?Po(C.run.bind(C),l&&l.suspense):C.run(),m&&m.push(S),S}function uZ(s,e,t){const i=this.proxy,n=ls(s)?s.includes(".")?V6(i,s):()=>i[s]:s.bind(i,i);let o;Ht(e)?o=e:(o=e.handler,t=e);const r=Jb(this),a=W6(n,o.bind(i),t);return r(),a}function V6(s,e){const t=e.split(".");return()=>{let i=s;for(let n=0;n<t.length&&i;n++)i=i[t[n]];return i}}function Jf(s,e,t=0,i){if(!fn(s)||s.__v_skip)return s;if(e&&e>0){if(t>=e)return s;t++}if(i=i||new Set,i.has(s))return s;if(i.add(s),ds(s))Jf(s.value,e,t,i);else if(Tt(s))for(let n=0;n<s.length;n++)Jf(s[n],e,t,i);else if(s6(s)||Ip(s))s.forEach(n=>{Jf(n,e,t,i)});else if(a6(s))for(const n in s)Jf(s[n],e,t,i);return s}function vh(s,e,t,i){const n=s.dirs,o=e&&e.dirs;for(let r=0;r<n.length;r++){const a=n[r];o&&(a.oldValue=o[r].value);let l=a.dir[i];l&&(sf(),Ma(l,t,8,[s.el,a,s,e]),of())}}/*! #__NO_SIDE_EFFECTS__ */function Qm(s,e){return Ht(s)?Fs({name:s.name},e,{setup:s}):s}const kv=s=>!!s.type.__asyncLoader,H6=s=>s.type.__isKeepAlive;function hZ(s,e){z6(s,"a",e)}function gZ(s,e){z6(s,"da",e)}function z6(s,e,t=Ns){const i=s.__wdc||(s.__wdc=()=>{let n=t;for(;n;){if(n.isDeactivated)return;n=n.parent}return s()});if(BL(e,i,t),t){let n=t.parent;for(;n&&n.parent;)H6(n.parent.vnode)&&fZ(i,e,t,n),n=n.parent}}function fZ(s,e,t,i){const n=BL(e,s,i,!0);WL(()=>{rA(i[e],n)},t)}function BL(s,e,t=Ns,i=!1){if(t){const n=t[s]||(t[s]=[]),o=e.__weh||(e.__weh=(...r)=>{if(t.isUnmounted)return;sf();const a=Jb(t),l=Ma(e,t,s,r);return a(),of(),l});return i?n.unshift(o):n.push(o),o}}const sc=s=>(e,t=Ns)=>(!UL||s==="sp")&&BL(s,(...i)=>e(...i),t),pZ=sc("bm"),Qb=sc("m"),mZ=sc("bu"),_Z=sc("u"),vZ=sc("bum"),WL=sc("um"),bZ=sc("sp"),CZ=sc("rtg"),wZ=sc("rtc");function SZ(s,e=Ns){BL("ec",s,e)}function iv(s,e,t,i){let n;const o=t&&t[i];if(Tt(s)||ls(s)){n=new Array(s.length);for(let r=0,a=s.length;r<a;r++)n[r]=e(s[r],r,void 0,o&&o[r])}else if(typeof s=="number"){n=new Array(s);for(let r=0;r<s;r++)n[r]=e(r+1,r,void 0,o&&o[r])}else if(fn(s))if(s[Symbol.iterator])n=Array.from(s,(r,a)=>e(r,a,void 0,o&&o[a]));else{const r=Object.keys(s);n=new Array(r.length);for(let a=0,l=r.length;a<l;a++){const d=r[a];n[a]=e(s[d],d,a,o&&o[a])}}else n=[];return t&&(t[i]=n),n}function VL(s,e,t={},i,n){if(Ys.isCE||Ys.parent&&kv(Ys.parent)&&Ys.parent.isCE)return e!=="default"&&(t.name=e),Yt("slot",t,i&&i());let o=s[e];o&&o._c&&(o._d=!1),xt();const r=o&&U6(o(t)),a=ep(Ds,{key:t.key||r&&r.key||`_${e}`},r||(i?i():[]),r&&s._===1?64:-2);return!n&&a.scopeId&&(a.slotScopeIds=[a.scopeId+"-s"]),o&&o._c&&(o._d=!0),a}function U6(s){return s.some(e=>bS(e)?!(e.type===yu||e.type===Ds&&!U6(e.children)):!0)?s:null}const OE=s=>s?tW(s)?CA(s)||s.proxy:OE(s.parent):null,Iv=Fs(Object.create(null),{$:s=>s,$el:s=>s.vnode.el,$data:s=>s.data,$props:s=>s.props,$attrs:s=>s.attrs,$slots:s=>s.slots,$refs:s=>s.refs,$parent:s=>OE(s.parent),$root:s=>OE(s.root),$emit:s=>s.emit,$options:s=>_A(s),$forceUpdate:s=>s.f||(s.f=()=>{s.effect.dirty=!0,mA(s.update)}),$nextTick:s=>s.n||(s.n=Xb.bind(s.proxy)),$watch:s=>uZ.bind(s)}),_k=(s,e)=>s!==un&&!s.__isScriptSetup&&ci(s,e),yZ={get({_:s},e){const{ctx:t,setupState:i,data:n,props:o,accessCache:r,type:a,appContext:l}=s;let d;if(e[0]!=="$"){const g=r[e];if(g!==void 0)switch(g){case 1:return i[e];case 2:return n[e];case 4:return t[e];case 3:return o[e]}else{if(_k(i,e))return r[e]=1,i[e];if(n!==un&&ci(n,e))return r[e]=2,n[e];if((d=s.propsOptions[0])&&ci(d,e))return r[e]=3,o[e];if(t!==un&&ci(t,e))return r[e]=4,t[e];FE&&(r[e]=0)}}const c=Iv[e];let u,h;if(c)return e==="$attrs"&&tr(s,"get",e),c(s);if((u=a.__cssModules)&&(u=u[e]))return u;if(t!==un&&ci(t,e))return r[e]=4,t[e];if(h=l.config.globalProperties,ci(h,e))return h[e]},set({_:s},e,t){const{data:i,setupState:n,ctx:o}=s;return _k(n,e)?(n[e]=t,!0):i!==un&&ci(i,e)?(i[e]=t,!0):ci(s.props,e)||e[0]==="$"&&e.slice(1)in s?!1:(o[e]=t,!0)},has({_:{data:s,setupState:e,accessCache:t,ctx:i,appContext:n,propsOptions:o}},r){let a;return!!t[r]||s!==un&&ci(s,r)||_k(e,r)||(a=o[0])&&ci(a,r)||ci(i,r)||ci(Iv,r)||ci(n.config.globalProperties,r)},defineProperty(s,e,t){return t.get!=null?s._.accessCache[e]=0:ci(t,"value")&&this.set(s,e,t.value,null),Reflect.defineProperty(s,e,t)}};function bF(s){return Tt(s)?s.reduce((e,t)=>(e[t]=null,e),{}):s}let FE=!0;function LZ(s){const e=_A(s),t=s.proxy,i=s.ctx;FE=!1,e.beforeCreate&&CF(e.beforeCreate,s,"bc");const{data:n,computed:o,methods:r,watch:a,provide:l,inject:d,created:c,beforeMount:u,mounted:h,beforeUpdate:g,updated:f,activated:m,deactivated:_,beforeDestroy:v,beforeUnmount:b,destroyed:C,unmounted:w,render:S,renderTracked:x,renderTriggered:L,errorCaptured:k,serverPrefetch:I,expose:P,inheritAttrs:$,components:A,directives:z,filters:K}=e;if(d&&xZ(d,i,null),r)for(const fe in r){const ve=r[fe];Ht(ve)&&(i[fe]=ve.bind(t))}if(n){const fe=n.call(t,t);fn(fe)&&(s.data=AL(fe))}if(FE=!0,o)for(const fe in o){const ve=o[fe],ye=Ht(ve)?ve.bind(t,t):Ht(ve.get)?ve.get.bind(t,t):Vr,Be=!Ht(ve)&&Ht(ve.set)?ve.set.bind(t):Vr,Ve=An({get:ye,set:Be});Object.defineProperty(i,fe,{enumerable:!0,configurable:!0,get:()=>Ve.value,set:Ie=>Ve.value=Ie})}if(a)for(const fe in a)$6(a[fe],i,t,fe);if(l){const fe=Ht(l)?l.call(t):l;Reflect.ownKeys(fe).forEach(ve=>{TZ(ve,fe[ve])})}c&&CF(c,s,"c");function ne(fe,ve){Tt(ve)?ve.forEach(ye=>fe(ye.bind(t))):ve&&fe(ve.bind(t))}if(ne(pZ,u),ne(Qb,h),ne(mZ,g),ne(_Z,f),ne(hZ,m),ne(gZ,_),ne(SZ,k),ne(wZ,x),ne(CZ,L),ne(vZ,b),ne(WL,w),ne(bZ,I),Tt(P))if(P.length){const fe=s.exposed||(s.exposed={});P.forEach(ve=>{Object.defineProperty(fe,ve,{get:()=>t[ve],set:ye=>t[ve]=ye})})}else s.exposed||(s.exposed={});S&&s.render===Vr&&(s.render=S),$!=null&&(s.inheritAttrs=$),A&&(s.components=A),z&&(s.directives=z)}function xZ(s,e,t=Vr){Tt(s)&&(s=BE(s));for(const i in s){const n=s[i];let o;fn(n)?"default"in n?o=Ev(n.from||i,n.default,!0):o=Ev(n.from||i):o=Ev(n),ds(o)?Object.defineProperty(e,i,{enumerable:!0,configurable:!0,get:()=>o.value,set:r=>o.value=r}):e[i]=o}}function CF(s,e,t){Ma(Tt(s)?s.map(i=>i.bind(e.proxy)):s.bind(e.proxy),e,t)}function $6(s,e,t,i){const n=i.includes(".")?V6(t,i):()=>t[i];if(ls(s)){const o=e[s];Ht(o)&&mn(n,o)}else if(Ht(s))mn(n,s.bind(t));else if(fn(s))if(Tt(s))s.forEach(o=>$6(o,e,t,i));else{const o=Ht(s.handler)?s.handler.bind(t):e[s.handler];Ht(o)&&mn(n,o,s)}}function _A(s){const e=s.type,{mixins:t,extends:i}=e,{mixins:n,optionsCache:o,config:{optionMergeStrategies:r}}=s.appContext,a=o.get(e);let l;return a?l=a:!n.length&&!t&&!i?l=e:(l={},n.length&&n.forEach(d=>vS(l,d,r,!0)),vS(l,e,r)),fn(e)&&o.set(e,l),l}function vS(s,e,t,i=!1){const{mixins:n,extends:o}=e;o&&vS(s,o,t,!0),n&&n.forEach(r=>vS(s,r,t,!0));for(const r in e)if(!(i&&r==="expose")){const a=DZ[r]||t&&t[r];s[r]=a?a(s[r],e[r]):e[r]}return s}const DZ={data:wF,props:SF,emits:SF,methods:nv,computed:nv,beforeCreate:ao,created:ao,beforeMount:ao,mounted:ao,beforeUpdate:ao,updated:ao,beforeDestroy:ao,beforeUnmount:ao,destroyed:ao,unmounted:ao,activated:ao,deactivated:ao,errorCaptured:ao,serverPrefetch:ao,components:nv,directives:nv,watch:IZ,provide:wF,inject:kZ};function wF(s,e){return e?s?function(){return Fs(Ht(s)?s.call(this,this):s,Ht(e)?e.call(this,this):e)}:e:s}function kZ(s,e){return nv(BE(s),BE(e))}function BE(s){if(Tt(s)){const e={};for(let t=0;t<s.length;t++)e[s[t]]=s[t];return e}return s}function ao(s,e){return s?[...new Set([].concat(s,e))]:e}function nv(s,e){return s?Fs(Object.create(null),s,e):e}function SF(s,e){return s?Tt(s)&&Tt(e)?[...new Set([...s,...e])]:Fs(Object.create(null),bF(s),bF(e??{})):e}function IZ(s,e){if(!s)return e;if(!e)return s;const t=Fs(Object.create(null),s);for(const i in e)t[i]=ao(s[i],e[i]);return t}function j6(){return{app:null,config:{isNativeTag:lG,performance:!1,globalProperties:{},optionMergeStrategies:{},errorHandler:void 0,warnHandler:void 0,compilerOptions:{}},mixins:[],components:{},directives:{},provides:Object.create(null),optionsCache:new WeakMap,propsCache:new WeakMap,emitsCache:new WeakMap}}let EZ=0;function NZ(s,e){return function(i,n=null){Ht(i)||(i=Fs({},i)),n!=null&&!fn(n)&&(n=null);const o=j6(),r=new WeakSet;let a=!1;const l=o.app={_uid:EZ++,_component:i,_props:n,_container:null,_context:o,_instance:null,version:iY,get config(){return o.config},set config(d){},use(d,...c){return r.has(d)||(d&&Ht(d.install)?(r.add(d),d.install(l,...c)):Ht(d)&&(r.add(d),d(l,...c))),l},mixin(d){return o.mixins.includes(d)||o.mixins.push(d),l},component(d,c){return c?(o.components[d]=c,l):o.components[d]},directive(d,c){return c?(o.directives[d]=c,l):o.directives[d]},mount(d,c,u){if(!a){const h=Yt(i,n);return h.appContext=o,u===!0?u="svg":u===!1&&(u=void 0),c&&e?e(h,d):s(h,d,u),a=!0,l._container=d,d.__vue_app__=l,CA(h.component)||h.component.proxy}},unmount(){a&&(s(null,l._container),delete l._container.__vue_app__)},provide(d,c){return o.provides[d]=c,l},runWithContext(d){p0=l;try{return d()}finally{p0=null}}};return l}}let p0=null;function TZ(s,e){if(Ns){let t=Ns.provides;const i=Ns.parent&&Ns.parent.provides;i===t&&(t=Ns.provides=Object.create(i)),t[s]=e}}function Ev(s,e,t=!1){const i=Ns||Ys;if(i||p0){const n=i?i.parent==null?i.vnode.appContext&&i.vnode.appContext.provides:i.parent.provides:p0._context.provides;if(n&&s in n)return n[s];if(arguments.length>1)return t&&Ht(e)?e.call(i&&i.proxy):e}}function MZ(){return!!(Ns||Ys||p0)}function RZ(s,e,t,i=!1){const n={},o={};fS(o,zL,1),s.propsDefaults=Object.create(null),K6(s,e,n,o);for(const r in s.propsOptions[0])r in n||(n[r]=void 0);t?s.props=i?n:zG(n):s.type.props?s.props=n:s.props=o,s.attrs=o}function AZ(s,e,t,i){const{props:n,attrs:o,vnode:{patchFlag:r}}=s,a=gi(n),[l]=s.propsOptions;let d=!1;if((i||r>0)&&!(r&16)){if(r&8){const c=s.vnode.dynamicProps;for(let u=0;u<c.length;u++){let h=c[u];if(FL(s.emitsOptions,h))continue;const g=e[h];if(l)if(ci(o,h))g!==o[h]&&(o[h]=g,d=!0);else{const f=$l(h);n[f]=WE(l,a,f,g,s,!1)}else g!==o[h]&&(o[h]=g,d=!0)}}}else{K6(s,e,n,o)&&(d=!0);let c;for(const u in a)(!e||!ci(e,u)&&((c=Ym(u))===u||!ci(e,c)))&&(l?t&&(t[u]!==void 0||t[c]!==void 0)&&(n[u]=WE(l,a,u,void 0,s,!0)):delete n[u]);if(o!==a)for(const u in o)(!e||!ci(e,u))&&(delete o[u],d=!0)}d&&zd(s,"set","$attrs")}function K6(s,e,t,i){const[n,o]=s.propsOptions;let r=!1,a;if(e)for(let l in e){if(yw(l))continue;const d=e[l];let c;n&&ci(n,c=$l(l))?!o||!o.includes(c)?t[c]=d:(a||(a={}))[c]=d:FL(s.emitsOptions,l)||(!(l in i)||d!==i[l])&&(i[l]=d,r=!0)}if(o){const l=gi(t),d=a||un;for(let c=0;c<o.length;c++){const u=o[c];t[u]=WE(n,l,u,d[u],s,!ci(d,u))}}return r}function WE(s,e,t,i,n,o){const r=s[t];if(r!=null){const a=ci(r,"default");if(a&&i===void 0){const l=r.default;if(r.type!==Function&&!r.skipFactory&&Ht(l)){const{propsDefaults:d}=n;if(t in d)i=d[t];else{const c=Jb(n);i=d[t]=l.call(null,e),c()}}else i=l}r[0]&&(o&&!a?i=!1:r[1]&&(i===""||i===Ym(t))&&(i=!0))}return i}function q6(s,e,t=!1){const i=e.propsCache,n=i.get(s);if(n)return n;const o=s.props,r={},a=[];let l=!1;if(!Ht(s)){const c=u=>{l=!0;const[h,g]=q6(u,e,!0);Fs(r,h),g&&a.push(...g)};!t&&e.mixins.length&&e.mixins.forEach(c),s.extends&&c(s.extends),s.mixins&&s.mixins.forEach(c)}if(!o&&!l)return fn(s)&&i.set(s,kp),kp;if(Tt(o))for(let c=0;c<o.length;c++){const u=$l(o[c]);yF(u)&&(r[u]=un)}else if(o)for(const c in o){const u=$l(c);if(yF(u)){const h=o[c],g=r[u]=Tt(h)||Ht(h)?{type:h}:Fs({},h);if(g){const f=DF(Boolean,g.type),m=DF(String,g.type);g[0]=f>-1,g[1]=m<0||f<m,(f>-1||ci(g,"default"))&&a.push(u)}}}const d=[r,a];return fn(s)&&i.set(s,d),d}function yF(s){return s[0]!=="$"}function LF(s){const e=s&&s.toString().match(/^\s*(function|class) (\w+)/);return e?e[2]:s===null?"null":""}function xF(s,e){return LF(s)===LF(e)}function DF(s,e){return Tt(e)?e.findIndex(t=>xF(t,s)):Ht(e)&&xF(e,s)?0:-1}const G6=s=>s[0]==="_"||s==="$stable",vA=s=>Tt(s)?s.map(cl):[cl(s)],PZ=(s,e,t)=>{if(e._n)return e;const i=ts((...n)=>vA(e(...n)),t);return i._c=!1,i},Z6=(s,e,t)=>{const i=s._ctx;for(const n in s){if(G6(n))continue;const o=s[n];if(Ht(o))e[n]=PZ(n,o,i);else if(o!=null){const r=vA(o);e[n]=()=>r}}},Y6=(s,e)=>{const t=vA(e);s.slots.default=()=>t},OZ=(s,e)=>{if(s.vnode.shapeFlag&32){const t=e._;t?(s.slots=gi(e),fS(e,"_",t)):Z6(e,s.slots={})}else s.slots={},e&&Y6(s,e);fS(s.slots,zL,1)},FZ=(s,e,t)=>{const{vnode:i,slots:n}=s;let o=!0,r=un;if(i.shapeFlag&32){const a=e._;a?t&&a===1?o=!1:(Fs(n,e),!t&&a===1&&delete n._):(o=!e.$stable,Z6(e,n)),r=e}else e&&(Y6(s,e),r={default:1});if(o)for(const a in n)!G6(a)&&r[a]==null&&delete n[a]};function VE(s,e,t,i,n=!1){if(Tt(s)){s.forEach((h,g)=>VE(h,e&&(Tt(e)?e[g]:e),t,i,n));return}if(kv(i)&&!n)return;const o=i.shapeFlag&4?CA(i.component)||i.component.proxy:i.el,r=n?null:o,{i:a,r:l}=s,d=e&&e.r,c=a.refs===un?a.refs={}:a.refs,u=a.setupState;if(d!=null&&d!==l&&(ls(d)?(c[d]=null,ci(u,d)&&(u[d]=null)):ds(d)&&(d.value=null)),Ht(l))su(l,a,12,[r,c]);else{const h=ls(l),g=ds(l),f=s.f;if(h||g){const m=()=>{if(f){const _=h?ci(u,l)?u[l]:c[l]:l.value;n?Tt(_)&&rA(_,o):Tt(_)?_.includes(o)||_.push(o):h?(c[l]=[o],ci(u,l)&&(u[l]=c[l])):(l.value=[o],s.k&&(c[s.k]=l.value))}else h?(c[l]=r,ci(u,l)&&(u[l]=r)):g&&(l.value=r,s.k&&(c[s.k]=r))};n||f?m():(m.id=-1,Po(m,t))}}}const Po=lZ;function BZ(s){return WZ(s)}function WZ(s,e){const t=l6();t.__VUE__=!0;const{insert:i,remove:n,patchProp:o,createElement:r,createText:a,createComment:l,setText:d,setElementText:c,parentNode:u,nextSibling:h,setScopeId:g=Vr,insertStaticContent:f}=s,m=(q,Z,ae,be=null,Le=null,Re=null,ze=void 0,U=null,V=!!Z.dynamicChildren)=>{if(q===Z)return;q&&!D_(q,Z)&&(be=wt(q),Ie(q,Le,Re,!0),q=null),Z.patchFlag===-2&&(V=!1,Z.dynamicChildren=null);const{type:F,ref:E,shapeFlag:M}=Z;switch(F){case HL:_(q,Z,ae,be);break;case yu:v(q,Z,ae,be);break;case bk:q==null&&b(Z,ae,be,ze);break;case Ds:A(q,Z,ae,be,Le,Re,ze,U,V);break;default:M&1?S(q,Z,ae,be,Le,Re,ze,U,V):M&6?z(q,Z,ae,be,Le,Re,ze,U,V):(M&64||M&128)&&F.process(q,Z,ae,be,Le,Re,ze,U,V,ji)}E!=null&&Le&&VE(E,q&&q.ref,Re,Z||q,!Z)},_=(q,Z,ae,be)=>{if(q==null)i(Z.el=a(Z.children),ae,be);else{const Le=Z.el=q.el;Z.children!==q.children&&d(Le,Z.children)}},v=(q,Z,ae,be)=>{q==null?i(Z.el=l(Z.children||""),ae,be):Z.el=q.el},b=(q,Z,ae,be)=>{[q.el,q.anchor]=f(q.children,Z,ae,be,q.el,q.anchor)},C=({el:q,anchor:Z},ae,be)=>{let Le;for(;q&&q!==Z;)Le=h(q),i(q,ae,be),q=Le;i(Z,ae,be)},w=({el:q,anchor:Z})=>{let ae;for(;q&&q!==Z;)ae=h(q),n(q),q=ae;n(Z)},S=(q,Z,ae,be,Le,Re,ze,U,V)=>{Z.type==="svg"?ze="svg":Z.type==="math"&&(ze="mathml"),q==null?x(Z,ae,be,Le,Re,ze,U,V):I(q,Z,Le,Re,ze,U,V)},x=(q,Z,ae,be,Le,Re,ze,U)=>{let V,F;const{props:E,shapeFlag:M,transition:B,dirs:O}=q;if(V=q.el=r(q.type,Re,E&&E.is,E),M&8?c(V,q.children):M&16&&k(q.children,V,null,be,Le,vk(q,Re),ze,U),O&&vh(q,null,be,"created"),L(V,q,q.scopeId,ze,be),E){for(const ce in E)ce!=="value"&&!yw(ce)&&o(V,ce,null,E[ce],Re,q.children,be,Le,ni);"value"in E&&o(V,"value",null,E.value,Re),(F=E.onVnodeBeforeMount)&&el(F,be,q)}O&&vh(q,null,be,"beforeMount");const X=VZ(Le,B);X&&B.beforeEnter(V),i(V,Z,ae),((F=E&&E.onVnodeMounted)||X||O)&&Po(()=>{F&&el(F,be,q),X&&B.enter(V),O&&vh(q,null,be,"mounted")},Le)},L=(q,Z,ae,be,Le)=>{if(ae&&g(q,ae),be)for(let Re=0;Re<be.length;Re++)g(q,be[Re]);if(Le){let Re=Le.subTree;if(Z===Re){const ze=Le.vnode;L(q,ze,ze.scopeId,ze.slotScopeIds,Le.parent)}}},k=(q,Z,ae,be,Le,Re,ze,U,V=0)=>{for(let F=V;F<q.length;F++){const E=q[F]=U?Nc(q[F]):cl(q[F]);m(null,E,Z,ae,be,Le,Re,ze,U)}},I=(q,Z,ae,be,Le,Re,ze)=>{const U=Z.el=q.el;let{patchFlag:V,dynamicChildren:F,dirs:E}=Z;V|=q.patchFlag&16;const M=q.props||un,B=Z.props||un;let O;if(ae&&bh(ae,!1),(O=B.onVnodeBeforeUpdate)&&el(O,ae,Z,q),E&&vh(Z,q,ae,"beforeUpdate"),ae&&bh(ae,!0),F?P(q.dynamicChildren,F,U,ae,be,vk(Z,Le),Re):ze||ve(q,Z,U,null,ae,be,vk(Z,Le),Re,!1),V>0){if(V&16)$(U,Z,M,B,ae,be,Le);else if(V&2&&M.class!==B.class&&o(U,"class",null,B.class,Le),V&4&&o(U,"style",M.style,B.style,Le),V&8){const X=Z.dynamicProps;for(let ce=0;ce<X.length;ce++){const Se=X[ce],ke=M[Se],Ke=B[Se];(Ke!==ke||Se==="value")&&o(U,Se,ke,Ke,Le,q.children,ae,be,ni)}}V&1&&q.children!==Z.children&&c(U,Z.children)}else!ze&&F==null&&$(U,Z,M,B,ae,be,Le);((O=B.onVnodeUpdated)||E)&&Po(()=>{O&&el(O,ae,Z,q),E&&vh(Z,q,ae,"updated")},be)},P=(q,Z,ae,be,Le,Re,ze)=>{for(let U=0;U<Z.length;U++){const V=q[U],F=Z[U],E=V.el&&(V.type===Ds||!D_(V,F)||V.shapeFlag&70)?u(V.el):ae;m(V,F,E,null,be,Le,Re,ze,!0)}},$=(q,Z,ae,be,Le,Re,ze)=>{if(ae!==be){if(ae!==un)for(const U in ae)!yw(U)&&!(U in be)&&o(q,U,ae[U],null,ze,Z.children,Le,Re,ni);for(const U in be){if(yw(U))continue;const V=be[U],F=ae[U];V!==F&&U!=="value"&&o(q,U,F,V,ze,Z.children,Le,Re,ni)}"value"in be&&o(q,"value",ae.value,be.value,ze)}},A=(q,Z,ae,be,Le,Re,ze,U,V)=>{const F=Z.el=q?q.el:a(""),E=Z.anchor=q?q.anchor:a("");let{patchFlag:M,dynamicChildren:B,slotScopeIds:O}=Z;O&&(U=U?U.concat(O):O),q==null?(i(F,ae,be),i(E,ae,be),k(Z.children||[],ae,E,Le,Re,ze,U,V)):M>0&&M&64&&B&&q.dynamicChildren?(P(q.dynamicChildren,B,ae,Le,Re,ze,U),(Z.key!=null||Le&&Z===Le.subTree)&&X6(q,Z,!0)):ve(q,Z,ae,E,Le,Re,ze,U,V)},z=(q,Z,ae,be,Le,Re,ze,U,V)=>{Z.slotScopeIds=U,q==null?Z.shapeFlag&512?Le.ctx.activate(Z,ae,be,ze,V):K(Z,ae,be,Le,Re,ze,V):Q(q,Z,V)},K=(q,Z,ae,be,Le,Re,ze)=>{const U=q.component=ZZ(q,be,Le);if(H6(q)&&(U.ctx.renderer=ji),YZ(U),U.asyncDep){if(Le&&Le.registerDep(U,ne),!q.el){const V=U.subTree=Yt(yu);v(null,V,Z,ae)}}else ne(U,q,Z,ae,Le,Re,ze)},Q=(q,Z,ae)=>{const be=Z.component=q.component;if(nZ(q,Z,ae))if(be.asyncDep&&!be.asyncResolved){fe(be,Z,ae);return}else be.next=Z,XG(be.update),be.effect.dirty=!0,be.update();else Z.el=q.el,be.vnode=Z},ne=(q,Z,ae,be,Le,Re,ze)=>{const U=()=>{if(q.isMounted){let{next:E,bu:M,u:B,parent:O,vnode:X}=q;{const Ye=Q6(q);if(Ye){E&&(E.el=X.el,fe(q,E,ze)),Ye.asyncDep.then(()=>{q.isUnmounted||U()});return}}let ce=E,Se;bh(q,!1),E?(E.el=X.el,fe(q,E,ze)):E=X,M&&fk(M),(Se=E.props&&E.props.onVnodeBeforeUpdate)&&el(Se,O,E,X),bh(q,!0);const ke=mk(q),Ke=q.subTree;q.subTree=ke,m(Ke,ke,u(Ke.el),wt(Ke),q,Le,Re),E.el=ke.el,ce===null&&sZ(q,ke.el),B&&Po(B,Le),(Se=E.props&&E.props.onVnodeUpdated)&&Po(()=>el(Se,O,E,X),Le)}else{let E;const{el:M,props:B}=Z,{bm:O,m:X,parent:ce}=q,Se=kv(Z);if(bh(q,!1),O&&fk(O),!Se&&(E=B&&B.onVnodeBeforeMount)&&el(E,ce,Z),bh(q,!0),M&&zn){const ke=()=>{q.subTree=mk(q),zn(M,q.subTree,q,Le,null)};Se?Z.type.__asyncLoader().then(()=>!q.isUnmounted&&ke()):ke()}else{const ke=q.subTree=mk(q);m(null,ke,ae,be,q,Le,Re),Z.el=ke.el}if(X&&Po(X,Le),!Se&&(E=B&&B.onVnodeMounted)){const ke=Z;Po(()=>el(E,ce,ke),Le)}(Z.shapeFlag&256||ce&&kv(ce.vnode)&&ce.vnode.shapeFlag&256)&&q.a&&Po(q.a,Le),q.isMounted=!0,Z=ae=be=null}},V=q.effect=new lA(U,Vr,()=>mA(F),q.scope),F=q.update=()=>{V.dirty&&V.run()};F.id=q.uid,bh(q,!0),F()},fe=(q,Z,ae)=>{Z.component=q;const be=q.vnode.props;q.vnode=Z,q.next=null,AZ(q,Z.props,be,ae),FZ(q,Z.children,ae),sf(),mF(q),of()},ve=(q,Z,ae,be,Le,Re,ze,U,V=!1)=>{const F=q&&q.children,E=q?q.shapeFlag:0,M=Z.children,{patchFlag:B,shapeFlag:O}=Z;if(B>0){if(B&128){Be(F,M,ae,be,Le,Re,ze,U,V);return}else if(B&256){ye(F,M,ae,be,Le,Re,ze,U,V);return}}O&8?(E&16&&ni(F,Le,Re),M!==F&&c(ae,M)):E&16?O&16?Be(F,M,ae,be,Le,Re,ze,U,V):ni(F,Le,Re,!0):(E&8&&c(ae,""),O&16&&k(M,ae,be,Le,Re,ze,U,V))},ye=(q,Z,ae,be,Le,Re,ze,U,V)=>{q=q||kp,Z=Z||kp;const F=q.length,E=Z.length,M=Math.min(F,E);let B;for(B=0;B<M;B++){const O=Z[B]=V?Nc(Z[B]):cl(Z[B]);m(q[B],O,ae,null,Le,Re,ze,U,V)}F>E?ni(q,Le,Re,!0,!1,M):k(Z,ae,be,Le,Re,ze,U,V,M)},Be=(q,Z,ae,be,Le,Re,ze,U,V)=>{let F=0;const E=Z.length;let M=q.length-1,B=E-1;for(;F<=M&&F<=B;){const O=q[F],X=Z[F]=V?Nc(Z[F]):cl(Z[F]);if(D_(O,X))m(O,X,ae,null,Le,Re,ze,U,V);else break;F++}for(;F<=M&&F<=B;){const O=q[M],X=Z[B]=V?Nc(Z[B]):cl(Z[B]);if(D_(O,X))m(O,X,ae,null,Le,Re,ze,U,V);else break;M--,B--}if(F>M){if(F<=B){const O=B+1,X=O<E?Z[O].el:be;for(;F<=B;)m(null,Z[F]=V?Nc(Z[F]):cl(Z[F]),ae,X,Le,Re,ze,U,V),F++}}else if(F>B)for(;F<=M;)Ie(q[F],Le,Re,!0),F++;else{const O=F,X=F,ce=new Map;for(F=X;F<=B;F++){const Ot=Z[F]=V?Nc(Z[F]):cl(Z[F]);Ot.key!=null&&ce.set(Ot.key,F)}let Se,ke=0;const Ke=B-X+1;let Ye=!1,Kt=0;const At=new Array(Ke);for(F=0;F<Ke;F++)At[F]=0;for(F=O;F<=M;F++){const Ot=q[F];if(ke>=Ke){Ie(Ot,Le,Re,!0);continue}let $t;if(Ot.key!=null)$t=ce.get(Ot.key);else for(Se=X;Se<=B;Se++)if(At[Se-X]===0&&D_(Ot,Z[Se])){$t=Se;break}$t===void 0?Ie(Ot,Le,Re,!0):(At[$t-X]=F+1,$t>=Kt?Kt=$t:Ye=!0,m(Ot,Z[$t],ae,null,Le,Re,ze,U,V),ke++)}const qe=Ye?HZ(At):kp;for(Se=qe.length-1,F=Ke-1;F>=0;F--){const Ot=X+F,$t=Z[Ot],so=Ot+1<E?Z[Ot+1].el:be;At[F]===0?m(null,$t,ae,so,Le,Re,ze,U,V):Ye&&(Se<0||F!==qe[Se]?Ve($t,ae,so,2):Se--)}}},Ve=(q,Z,ae,be,Le=null)=>{const{el:Re,type:ze,transition:U,children:V,shapeFlag:F}=q;if(F&6){Ve(q.component.subTree,Z,ae,be);return}if(F&128){q.suspense.move(Z,ae,be);return}if(F&64){ze.move(q,Z,ae,ji);return}if(ze===Ds){i(Re,Z,ae);for(let M=0;M<V.length;M++)Ve(V[M],Z,ae,be);i(q.anchor,Z,ae);return}if(ze===bk){C(q,Z,ae);return}if(be!==2&&F&1&&U)if(be===0)U.beforeEnter(Re),i(Re,Z,ae),Po(()=>U.enter(Re),Le);else{const{leave:M,delayLeave:B,afterLeave:O}=U,X=()=>i(Re,Z,ae),ce=()=>{M(Re,()=>{X(),O&&O()})};B?B(Re,X,ce):ce()}else i(Re,Z,ae)},Ie=(q,Z,ae,be=!1,Le=!1)=>{const{type:Re,props:ze,ref:U,children:V,dynamicChildren:F,shapeFlag:E,patchFlag:M,dirs:B}=q;if(U!=null&&VE(U,null,ae,q,!0),E&256){Z.ctx.deactivate(q);return}const O=E&1&&B,X=!kv(q);let ce;if(X&&(ce=ze&&ze.onVnodeBeforeUnmount)&&el(ce,Z,q),E&6)wn(q.component,ae,be);else{if(E&128){q.suspense.unmount(ae,be);return}O&&vh(q,null,Z,"beforeUnmount"),E&64?q.type.remove(q,Z,ae,Le,ji,be):F&&(Re!==Ds||M>0&&M&64)?ni(F,Z,ae,!1,!0):(Re===Ds&&M&384||!Le&&E&16)&&ni(V,Z,ae),be&&pe(q)}(X&&(ce=ze&&ze.onVnodeUnmounted)||O)&&Po(()=>{ce&&el(ce,Z,q),O&&vh(q,null,Z,"unmounted")},ae)},pe=q=>{const{type:Z,el:ae,anchor:be,transition:Le}=q;if(Z===Ds){Ji(ae,be);return}if(Z===bk){w(q);return}const Re=()=>{n(ae),Le&&!Le.persisted&&Le.afterLeave&&Le.afterLeave()};if(q.shapeFlag&1&&Le&&!Le.persisted){const{leave:ze,delayLeave:U}=Le,V=()=>ze(ae,Re);U?U(q.el,Re,V):V()}else Re()},Ji=(q,Z)=>{let ae;for(;q!==Z;)ae=h(q),n(q),q=ae;n(Z)},wn=(q,Z,ae)=>{const{bum:be,scope:Le,update:Re,subTree:ze,um:U}=q;be&&fk(be),Le.stop(),Re&&(Re.active=!1,Ie(ze,q,Z,ae)),U&&Po(U,Z),Po(()=>{q.isUnmounted=!0},Z),Z&&Z.pendingBranch&&!Z.isUnmounted&&q.asyncDep&&!q.asyncResolved&&q.suspenseId===Z.pendingId&&(Z.deps--,Z.deps===0&&Z.resolve())},ni=(q,Z,ae,be=!1,Le=!1,Re=0)=>{for(let ze=Re;ze<q.length;ze++)Ie(q[ze],Z,ae,be,Le)},wt=q=>q.shapeFlag&6?wt(q.component.subTree):q.shapeFlag&128?q.suspense.next():h(q.anchor||q.el);let $i=!1;const no=(q,Z,ae)=>{q==null?Z._vnode&&Ie(Z._vnode,null,null,!0):m(Z._vnode||null,q,Z,null,null,null,ae),$i||($i=!0,mF(),A6(),$i=!1),Z._vnode=q},ji={p:m,um:Ie,m:Ve,r:pe,mt:K,mc:k,pc:ve,pbc:P,n:wt,o:s};let Ze,zn;return e&&([Ze,zn]=e(ji)),{render:no,hydrate:Ze,createApp:NZ(no,Ze)}}function vk({type:s,props:e},t){return t==="svg"&&s==="foreignObject"||t==="mathml"&&s==="annotation-xml"&&e&&e.encoding&&e.encoding.includes("html")?void 0:t}function bh({effect:s,update:e},t){s.allowRecurse=e.allowRecurse=t}function VZ(s,e){return(!s||s&&!s.pendingBranch)&&e&&!e.persisted}function X6(s,e,t=!1){const i=s.children,n=e.children;if(Tt(i)&&Tt(n))for(let o=0;o<i.length;o++){const r=i[o];let a=n[o];a.shapeFlag&1&&!a.dynamicChildren&&((a.patchFlag<=0||a.patchFlag===32)&&(a=n[o]=Nc(n[o]),a.el=r.el),t||X6(r,a)),a.type===HL&&(a.el=r.el)}}function HZ(s){const e=s.slice(),t=[0];let i,n,o,r,a;const l=s.length;for(i=0;i<l;i++){const d=s[i];if(d!==0){if(n=t[t.length-1],s[n]<d){e[i]=n,t.push(i);continue}for(o=0,r=t.length-1;o<r;)a=o+r>>1,s[t[a]]<d?o=a+1:r=a;d<s[t[o]]&&(o>0&&(e[i]=t[o-1]),t[o]=i)}}for(o=t.length,r=t[o-1];o-- >0;)t[o]=r,r=e[r];return t}function Q6(s){const e=s.subTree.component;if(e)return e.asyncDep&&!e.asyncResolved?e:Q6(e)}const zZ=s=>s.__isTeleport,Ds=Symbol.for("v-fgt"),HL=Symbol.for("v-txt"),yu=Symbol.for("v-cmt"),bk=Symbol.for("v-stc"),Nv=[];let Ia=null;function xt(s=!1){Nv.push(Ia=s?null:[])}function UZ(){Nv.pop(),Ia=Nv[Nv.length-1]||null}let m0=1;function kF(s){m0+=s}function J6(s){return s.dynamicChildren=m0>0?Ia||kp:null,UZ(),m0>0&&Ia&&Ia.push(s),s}function Vt(s,e,t,i,n,o){return J6(Ce(s,e,t,i,n,o,!0))}function ep(s,e,t,i,n){return J6(Yt(s,e,t,i,n,!0))}function bS(s){return s?s.__v_isVNode===!0:!1}function D_(s,e){return s.type===e.type&&s.key===e.key}const zL="__vInternal",eW=({key:s})=>s??null,xw=({ref:s,ref_key:e,ref_for:t})=>(typeof s=="number"&&(s=""+s),s!=null?ls(s)||ds(s)||Ht(s)?{i:Ys,r:s,k:e,f:!!t}:s:null);function Ce(s,e=null,t=null,i=0,n=null,o=s===Ds?0:1,r=!1,a=!1){const l={__v_isVNode:!0,__v_skip:!0,type:s,props:e,key:e&&eW(e),ref:e&&xw(e),scopeId:F6,slotScopeIds:null,children:t,component:null,suspense:null,ssContent:null,ssFallback:null,dirs:null,transition:null,el:null,anchor:null,target:null,targetAnchor:null,staticCount:0,shapeFlag:o,patchFlag:i,dynamicProps:n,dynamicChildren:null,appContext:null,ctx:Ys};return a?(bA(l,t),o&128&&s.normalize(l)):t&&(l.shapeFlag|=ls(t)?8:16),m0>0&&!r&&Ia&&(l.patchFlag>0||o&6)&&l.patchFlag!==32&&Ia.push(l),l}const Yt=$Z;function $Z(s,e=null,t=null,i=0,n=null,o=!1){if((!s||s===oZ)&&(s=yu),bS(s)){const a=sm(s,e,!0);return t&&bA(a,t),m0>0&&!o&&Ia&&(a.shapeFlag&6?Ia[Ia.indexOf(s)]=a:Ia.push(a)),a.patchFlag|=-2,a}if(tY(s)&&(s=s.__vccOpts),e){e=jZ(e);let{class:a,style:l}=e;a&&!ls(a)&&(e.class=Ho(a)),fn(l)&&(k6(l)&&!Tt(l)&&(l=Fs({},l)),e.style=ML(l))}const r=ls(s)?1:aZ(s)?128:zZ(s)?64:fn(s)?4:Ht(s)?2:0;return Ce(s,e,t,i,n,r,o,!0)}function jZ(s){return s?k6(s)||zL in s?Fs({},s):s:null}function sm(s,e,t=!1){const{props:i,ref:n,patchFlag:o,children:r}=s,a=e?KZ(i||{},e):i;return{__v_isVNode:!0,__v_skip:!0,type:s.type,props:a,key:a&&eW(a),ref:e&&e.ref?t&&n?Tt(n)?n.concat(xw(e)):[n,xw(e)]:xw(e):n,scopeId:s.scopeId,slotScopeIds:s.slotScopeIds,children:r,target:s.target,targetAnchor:s.targetAnchor,staticCount:s.staticCount,shapeFlag:s.shapeFlag,patchFlag:e&&s.type!==Ds?o===-1?16:o|16:o,dynamicProps:s.dynamicProps,dynamicChildren:s.dynamicChildren,appContext:s.appContext,dirs:s.dirs,transition:s.transition,component:s.component,suspense:s.suspense,ssContent:s.ssContent&&sm(s.ssContent),ssFallback:s.ssFallback&&sm(s.ssFallback),el:s.el,anchor:s.anchor,ctx:s.ctx,ce:s.ce}}function Vh(s=" ",e=0){return Yt(HL,null,s,e)}function _s(s="",e=!1){return e?(xt(),ep(yu,null,s)):Yt(yu,null,s)}function cl(s){return s==null||typeof s=="boolean"?Yt(yu):Tt(s)?Yt(Ds,null,s.slice()):typeof s=="object"?Nc(s):Yt(HL,null,String(s))}function Nc(s){return s.el===null&&s.patchFlag!==-1||s.memo?s:sm(s)}function bA(s,e){let t=0;const{shapeFlag:i}=s;if(e==null)e=null;else if(Tt(e))t=16;else if(typeof e=="object")if(i&65){const n=e.default;n&&(n._c&&(n._d=!1),bA(s,n()),n._c&&(n._d=!0));return}else{t=32;const n=e._;!n&&!(zL in e)?e._ctx=Ys:n===3&&Ys&&(Ys.slots._===1?e._=1:(e._=2,s.patchFlag|=1024))}else Ht(e)?(e={default:e,_ctx:Ys},t=32):(e=String(e),i&64?(t=16,e=[Vh(e)]):t=8);s.children=e,s.shapeFlag|=t}function KZ(...s){const e={};for(let t=0;t<s.length;t++){const i=s[t];for(const n in i)if(n==="class")e.class!==i.class&&(e.class=Ho([e.class,i.class]));else if(n==="style")e.style=ML([e.style,i.style]);else if(IL(n)){const o=e[n],r=i[n];r&&o!==r&&!(Tt(o)&&o.includes(r))&&(e[n]=o?[].concat(o,r):r)}else n!==""&&(e[n]=i[n])}return e}function el(s,e,t,i=null){Ma(s,e,7,[t,i])}const qZ=j6();let GZ=0;function ZZ(s,e,t){const i=s.type,n=(e?e.appContext:s.appContext)||qZ,o={uid:GZ++,vnode:s,type:i,parent:e,appContext:n,root:null,next:null,subTree:null,effect:null,update:null,scope:new u6(!0),render:null,proxy:null,exposed:null,exposeProxy:null,withProxy:null,provides:e?e.provides:Object.create(n.provides),accessCache:null,renderCache:[],components:null,directives:null,propsOptions:q6(i,n),emitsOptions:O6(i,n),emit:null,emitted:null,propsDefaults:un,inheritAttrs:i.inheritAttrs,ctx:un,data:un,props:un,attrs:un,slots:un,refs:un,setupState:un,setupContext:null,attrsProxy:null,slotsProxy:null,suspense:t,suspenseId:t?t.pendingId:0,asyncDep:null,asyncResolved:!1,isMounted:!1,isUnmounted:!1,isDeactivated:!1,bc:null,c:null,bm:null,m:null,bu:null,u:null,um:null,bum:null,da:null,a:null,rtg:null,rtc:null,ec:null,sp:null};return o.ctx={_:o},o.root=e?e.root:o,o.emit=eZ.bind(null,o),s.ce&&s.ce(o),o}let Ns=null,CS,HE;{const s=l6(),e=(t,i)=>{let n;return(n=s[t])||(n=s[t]=[]),n.push(i),o=>{n.length>1?n.forEach(r=>r(o)):n[0](o)}};CS=e("__VUE_INSTANCE_SETTERS__",t=>Ns=t),HE=e("__VUE_SSR_SETTERS__",t=>UL=t)}const Jb=s=>{const e=Ns;return CS(s),s.scope.on(),()=>{s.scope.off(),CS(e)}},IF=()=>{Ns&&Ns.scope.off(),CS(null)};function tW(s){return s.vnode.shapeFlag&4}let UL=!1;function YZ(s,e=!1){e&&HE(e);const{props:t,children:i}=s.vnode,n=tW(s);RZ(s,t,n,e),OZ(s,i);const o=n?XZ(s,e):void 0;return e&&HE(!1),o}function XZ(s,e){const t=s.type;s.accessCache=Object.create(null),s.proxy=PL(new Proxy(s.ctx,yZ));const{setup:i}=t;if(i){const n=s.setupContext=i.length>1?JZ(s):null,o=Jb(s);sf();const r=su(i,s,0,[s.props,n]);if(of(),o(),o6(r)){if(r.then(IF,IF),e)return r.then(a=>{EF(s,a,e)}).catch(a=>{OL(a,s,0)});s.asyncDep=r}else EF(s,r,e)}else iW(s,e)}function EF(s,e,t){Ht(e)?s.type.__ssrInlineRender?s.ssrRender=e:s.render=e:fn(e)&&(s.setupState=T6(e)),iW(s,t)}let NF;function iW(s,e,t){const i=s.type;if(!s.render){if(!e&&NF&&!i.render){const n=i.template||_A(s).template;if(n){const{isCustomElement:o,compilerOptions:r}=s.appContext.config,{delimiters:a,compilerOptions:l}=i,d=Fs(Fs({isCustomElement:o,delimiters:a},r),l);i.render=NF(n,d)}}s.render=i.render||Vr}{const n=Jb(s);sf();try{LZ(s)}finally{of(),n()}}}function QZ(s){return s.attrsProxy||(s.attrsProxy=new Proxy(s.attrs,{get(e,t){return tr(s,"get","$attrs"),e[t]}}))}function JZ(s){const e=t=>{s.exposed=t||{}};return{get attrs(){return QZ(s)},slots:s.slots,emit:s.emit,expose:e}}function CA(s){if(s.exposed)return s.exposeProxy||(s.exposeProxy=new Proxy(T6(PL(s.exposed)),{get(e,t){if(t in e)return e[t];if(t in Iv)return Iv[t](s)},has(e,t){return t in e||t in Iv}}))}function eY(s,e=!0){return Ht(s)?s.displayName||s.name:s.name||e&&s.__name}function tY(s){return Ht(s)&&"__vccOpts"in s}const An=(s,e)=>UG(s,e,UL);function cg(s,e,t){const i=arguments.length;return i===2?fn(e)&&!Tt(e)?bS(e)?Yt(s,null,[e]):Yt(s,e):Yt(s,null,e):(i>3?t=Array.prototype.slice.call(arguments,2):i===3&&bS(t)&&(t=[t]),Yt(s,e,t))}const iY="3.4.15";/**
* @vue/runtime-dom v3.4.15
* (c) 2018-present Yuxi (Evan) You and Vue contributors
* @license MIT
**/const nY="http://www.w3.org/2000/svg",sY="http://www.w3.org/1998/Math/MathML",Tc=typeof document<"u"?document:null,TF=Tc&&Tc.createElement("template"),oY={insert:(s,e,t)=>{e.insertBefore(s,t||null)},remove:s=>{const e=s.parentNode;e&&e.removeChild(s)},createElement:(s,e,t,i)=>{const n=e==="svg"?Tc.createElementNS(nY,s):e==="mathml"?Tc.createElementNS(sY,s):Tc.createElement(s,t?{is:t}:void 0);return s==="select"&&i&&i.multiple!=null&&n.setAttribute("multiple",i.multiple),n},createText:s=>Tc.createTextNode(s),createComment:s=>Tc.createComment(s),setText:(s,e)=>{s.nodeValue=e},setElementText:(s,e)=>{s.textContent=e},parentNode:s=>s.parentNode,nextSibling:s=>s.nextSibling,querySelector:s=>Tc.querySelector(s),setScopeId(s,e){s.setAttribute(e,"")},insertStaticContent(s,e,t,i,n,o){const r=t?t.previousSibling:e.lastChild;if(n&&(n===o||n.nextSibling))for(;e.insertBefore(n.cloneNode(!0),t),!(n===o||!(n=n.nextSibling)););else{TF.innerHTML=i==="svg"?`<svg>${s}</svg>`:i==="mathml"?`<math>${s}</math>`:s;const a=TF.content;if(i==="svg"||i==="mathml"){const l=a.firstChild;for(;l.firstChild;)a.appendChild(l.firstChild);a.removeChild(l)}e.insertBefore(a,t)}return[r?r.nextSibling:e.firstChild,t?t.previousSibling:e.lastChild]}},rY=Symbol("_vtc");function aY(s,e,t){const i=s[rY];i&&(e=(e?[e,...i]:[...i]).join(" ")),e==null?s.removeAttribute("class"):t?s.setAttribute("class",e):s.className=e}const lY=Symbol("_vod"),dY=Symbol("");function cY(s,e,t){const i=s.style,n=i.display,o=ls(t);if(t&&!o){if(e&&!ls(e))for(const r in e)t[r]==null&&zE(i,r,"");for(const r in t)zE(i,r,t[r])}else if(o){if(e!==t){const r=i[dY];r&&(t+=";"+r),i.cssText=t}}else e&&s.removeAttribute("style");lY in s&&(i.display=n)}const MF=/\s*!important$/;function zE(s,e,t){if(Tt(t))t.forEach(i=>zE(s,e,i));else if(t==null&&(t=""),e.startsWith("--"))s.setProperty(e,t);else{const i=uY(s,e);MF.test(t)?s.setProperty(Ym(i),t.replace(MF,""),"important"):s[i]=t}}const RF=["Webkit","Moz","ms"],Ck={};function uY(s,e){const t=Ck[e];if(t)return t;let i=$l(e);if(i!=="filter"&&i in s)return Ck[e]=i;i=TL(i);for(let n=0;n<RF.length;n++){const o=RF[n]+i;if(o in s)return Ck[e]=o}return e}const AF="http://www.w3.org/1999/xlink";function hY(s,e,t,i,n){if(i&&e.startsWith("xlink:"))t==null?s.removeAttributeNS(AF,e.slice(6,e.length)):s.setAttributeNS(AF,e,t);else{const o=bG(e);t==null||o&&!d6(t)?s.removeAttribute(e):s.setAttribute(e,o?"":t)}}function gY(s,e,t,i,n,o,r){if(e==="innerHTML"||e==="textContent"){i&&r(i,n,o),s[e]=t??"";return}const a=s.tagName;if(e==="value"&&a!=="PROGRESS"&&!a.includes("-")){s._value=t;const d=a==="OPTION"?s.getAttribute("value"):s.value,c=t??"";d!==c&&(s.value=c),t==null&&s.removeAttribute(e);return}let l=!1;if(t===""||t==null){const d=typeof s[e];d==="boolean"?t=d6(t):t==null&&d==="string"?(t="",l=!0):d==="number"&&(t=0,l=!0)}try{s[e]=t}catch{}l&&s.removeAttribute(e)}function fY(s,e,t,i){s.addEventListener(e,t,i)}function pY(s,e,t,i){s.removeEventListener(e,t,i)}const PF=Symbol("_vei");function mY(s,e,t,i,n=null){const o=s[PF]||(s[PF]={}),r=o[e];if(i&&r)r.value=i;else{const[a,l]=_Y(e);if(i){const d=o[e]=CY(i,n);fY(s,a,d,l)}else r&&(pY(s,a,r,l),o[e]=void 0)}}const OF=/(?:Once|Passive|Capture)$/;function _Y(s){let e;if(OF.test(s)){e={};let i;for(;i=s.match(OF);)s=s.slice(0,s.length-i[0].length),e[i[0].toLowerCase()]=!0}return[s[2]===":"?s.slice(3):Ym(s.slice(2)),e]}let wk=0;const vY=Promise.resolve(),bY=()=>wk||(vY.then(()=>wk=0),wk=Date.now());function CY(s,e){const t=i=>{if(!i._vts)i._vts=Date.now();else if(i._vts<=t.attached)return;Ma(wY(i,t.value),e,5,[i])};return t.value=s,t.attached=bY(),t}function wY(s,e){if(Tt(e)){const t=s.stopImmediatePropagation;return s.stopImmediatePropagation=()=>{t.call(s),s._stopped=!0},e.map(i=>n=>!n._stopped&&i&&i(n))}else return e}const FF=s=>s.charCodeAt(0)===111&&s.charCodeAt(1)===110&&s.charCodeAt(2)>96&&s.charCodeAt(2)<123,SY=(s,e,t,i,n,o,r,a,l)=>{const d=n==="svg";e==="class"?aY(s,i,d):e==="style"?cY(s,t,i):IL(e)?oA(e)||mY(s,e,t,i,r):(e[0]==="."?(e=e.slice(1),!0):e[0]==="^"?(e=e.slice(1),!1):yY(s,e,i,d))?gY(s,e,i,o,r,a,l):(e==="true-value"?s._trueValue=i:e==="false-value"&&(s._falseValue=i),hY(s,e,i,d))};function yY(s,e,t,i){if(i)return!!(e==="innerHTML"||e==="textContent"||e in s&&FF(e)&&Ht(t));if(e==="spellcheck"||e==="draggable"||e==="translate"||e==="form"||e==="list"&&s.tagName==="INPUT"||e==="type"&&s.tagName==="TEXTAREA")return!1;if(e==="width"||e==="height"){const n=s.tagName;if(n==="IMG"||n==="VIDEO"||n==="CANVAS"||n==="SOURCE")return!1}return FF(e)&&ls(t)?!1:e in s}const LY=Fs({patchProp:SY},oY);let BF;function xY(){return BF||(BF=BZ(LY))}const DY=(...s)=>{const e=xY().createApp(...s),{mount:t}=e;return e.mount=i=>{const n=IY(i);if(!n)return;const o=e._component;!Ht(o)&&!o.render&&!o.template&&(o.template=n.innerHTML),n.innerHTML="";const r=t(n,!1,kY(n));return n instanceof Element&&(n.removeAttribute("v-cloak"),n.setAttribute("data-v-app","")),r},e};function kY(s){if(s instanceof SVGElement)return"svg";if(typeof MathMLElement=="function"&&s instanceof MathMLElement)return"mathml"}function IY(s){return ls(s)?document.querySelector(s):s}var EY=Object.defineProperty,NY=Object.defineProperties,TY=Object.getOwnPropertyDescriptors,WF=Object.getOwnPropertySymbols,MY=Object.prototype.hasOwnProperty,RY=Object.prototype.propertyIsEnumerable,VF=(s,e,t)=>e in s?EY(s,e,{enumerable:!0,configurable:!0,writable:!0,value:t}):s[e]=t,Sk=(s,e)=>{for(var t in e||(e={}))MY.call(e,t)&&VF(s,t,e[t]);if(WF)for(var t of WF(e))RY.call(e,t)&&VF(s,t,e[t]);return s},AY=(s,e)=>NY(s,TY(e));const yk={wrapper:{display:"flex",position:"relative",textAlign:"initial"},fullWidth:{width:"100%"},hide:{display:"none"}};function nW(s,e){const t=An(()=>{const{width:n,height:o}=s;return AY(Sk({},yk.wrapper),{width:n,height:o})}),i=An(()=>Sk(Sk({},yk.fullWidth),!e.value&&yk.hide));return{wrapperStyle:t,containerStyle:i}}function sW(){const s=Xm(gS.__getMonacoInstance()),e=_o(!1);let t;return Qb(()=>{s.value||(t=gS.init(),t.then(n=>s.value=n).catch(n=>{(n==null?void 0:n.type)!=="cancelation"&&(e.value=!0,console.error("Monaco initialization error:",n))}))}),{monacoRef:s,unload:()=>t==null?void 0:t.cancel(),isLoadFailed:e}}function wS(s){return typeof s=="function"?s():s}function oW(s){return s===void 0}function om(s,e,t,i){return PY(s,i)||OY(s,e,t,i)}function PY(s,e){return s.editor.getModel(rW(s,e))}function OY(s,e,t,i){return s.editor.createModel(e,t,i?rW(s,i):void 0)}function rW(s,e){return s.Uri.parse(e)}var FY=Object.defineProperty,HF=Object.getOwnPropertySymbols,BY=Object.prototype.hasOwnProperty,WY=Object.prototype.propertyIsEnumerable,zF=(s,e,t)=>e in s?FY(s,e,{enumerable:!0,configurable:!0,writable:!0,value:t}):s[e]=t,VY=(s,e)=>{for(var t in e||(e={}))BY.call(e,t)&&zF(s,t,e[t]);if(HF)for(var t of HF(e))WY.call(e,t)&&zF(s,t,e[t]);return s};const HY={display:"flex",height:"100%",width:"100%",justifyContent:"center",alignItems:"center"};var UF=Qm({name:"VueMonacoEditor",model:{prop:"value",event:"update:value"},props:{defaultValue:String,defaultPath:String,defaultLanguage:String,value:String,language:String,path:String,theme:{type:String,default:"vs"},line:Number,options:{type:Object,default:()=>({})},overrideServices:{type:Object,default:()=>({})},saveViewState:{type:Boolean,default:!0},width:{type:[Number,String],default:"100%"},height:{type:[Number,String],default:"100%"},className:String},emits:["update:value","beforeMount","mount","change","validate"],setup(s,e){const t=new Map,i=Xm(null),{monacoRef:n,unload:o,isLoadFailed:r}=sW(),{editorRef:a}=zY(e,s,n,i),{disposeValidator:l}=UY(e,s,n,a),d=An(()=>!!n.value&&!!a.value),{wrapperStyle:c,containerStyle:u}=nW(s,d);return WL(()=>{var h,g;(h=l.value)==null||h.call(l),a.value?((g=a.value.getModel())==null||g.dispose(),a.value.dispose()):o()}),mn(()=>s.path,(h,g)=>{const f=om(n.value,s.value||s.defaultValue||"",s.language||s.defaultLanguage||"",h||s.defaultPath||"");f!==a.value.getModel()&&(s.saveViewState&&t.set(g,a.value.saveViewState()),a.value.setModel(f),s.saveViewState&&a.value.restoreViewState(t.get(h)))}),mn(()=>s.value,h=>{a.value&&a.value.getValue()!==h&&a.value.setValue(h)}),mn(()=>s.options,h=>a.value&&a.value.updateOptions(h),{deep:!0}),mn(()=>s.theme,h=>n.value&&n.value.editor.setTheme(h)),mn(()=>s.language,h=>d.value&&n.value.editor.setModelLanguage(a.value.getModel(),h)),mn(()=>s.line,h=>{a.value&&!oW(h)&&a.value.revealLine(h)}),{containerRef:i,isEditorReady:d,isLoadFailed:r,wrapperStyle:c,containerStyle:u}},render(){const{$slots:s,isEditorReady:e,isLoadFailed:t,wrapperStyle:i,containerStyle:n,className:o}=this;return cg("div",{style:i},[!e&&cg("div",{style:HY},t?s.failure?wS(s.failure):"load failed":s.default?wS(s.default):"loading..."),cg("div",{ref:"containerRef",key:"monaco_editor_container",style:n,class:o})])}});function zY({emit:s},e,t,i){const n=Xm(null);Qb(()=>{const r=mn(t,()=>{i.value&&t.value&&(Xb(()=>r()),o())},{immediate:!0})});function o(){var r;if(!i.value||!t.value||n.value)return;s("beforeMount",t.value);const a=e.path||e.defaultPath,l=om(t.value,e.value||e.defaultValue||"",e.language||e.defaultLanguage||"",a||"");n.value=t.value.editor.create(i.value,VY({model:l,theme:e.theme,automaticLayout:!0,autoIndent:"brackets",formatOnPaste:!0,formatOnType:!0},e.options),e.overrideServices),(r=n.value)==null||r.onDidChangeModelContent(d=>{const c=n.value.getValue();c!==e.value&&(s("update:value",c),s("change",c,d))}),n.value&&!oW(e.line)&&n.value.revealLine(e.line),s("mount",n.value,t.value)}return{editorRef:n}}function UY({emit:s},e,t,i){const n=_o(null),o=mn([t,i],()=>{if(t.value&&i.value){Xb(()=>o());const r=t.value.editor.onDidChangeMarkers(a=>{var l,d;const c=(d=(l=i.value)==null?void 0:l.getModel())==null?void 0:d.uri;if(c&&a.find(h=>h.path===c.path)){const h=t.value.editor.getModelMarkers({resource:c});s("validate",h)}});n.value=()=>r==null?void 0:r.dispose()}});return{disposeValidator:n}}var $Y=Object.defineProperty,$F=Object.getOwnPropertySymbols,jY=Object.prototype.hasOwnProperty,KY=Object.prototype.propertyIsEnumerable,jF=(s,e,t)=>e in s?$Y(s,e,{enumerable:!0,configurable:!0,writable:!0,value:t}):s[e]=t,qY=(s,e)=>{for(var t in e||(e={}))jY.call(e,t)&&jF(s,t,e[t]);if($F)for(var t of $F(e))KY.call(e,t)&&jF(s,t,e[t]);return s};const GY={display:"flex",height:"100%",width:"100%",justifyContent:"center",alignItems:"center"};var KF=Qm({name:"VueMonacoDiffEditor",props:{original:String,modified:String,language:String,originalLanguage:String,modifiedLanguage:String,originalModelPath:String,modifiedModelPath:String,theme:{type:String,default:"vs"},options:{type:Object,default:()=>({})},width:{type:[Number,String],default:"100%"},height:{type:[Number,String],default:"100%"},className:String},setup(s,e){const t=Xm(null),{monacoRef:i,unload:n,isLoadFailed:o}=sW(),{diffEditorRef:r}=ZY(e,s,i,t),a=An(()=>!!i.value&&!!r.value),{wrapperStyle:l,containerStyle:d}=nW(s,a);return WL(()=>{var c,u,h,g,f,m,_,v;!i.value&&n();const b=(u=(c=r.value)==null?void 0:c.getModel)==null?void 0:u.call(c);(g=(h=b==null?void 0:b.original)==null?void 0:h.dispose)==null||g.call(h),(m=(f=b==null?void 0:b.modified)==null?void 0:f.dispose)==null||m.call(f),(v=(_=r.value)==null?void 0:_.dispose)==null||v.call(_)}),mn(()=>s.originalModelPath,()=>{if(!i.value||!r.value)return;const c=r.value.getOriginalEditor(),u=om(i.value,s.original||"",s.originalLanguage||s.language||"text",s.originalModelPath||"");u!==c.getModel()&&c.setModel(u)}),mn(()=>s.modifiedModelPath,()=>{if(!i.value||!r.value)return;const c=r.value.getModifiedEditor(),u=om(i.value,s.modified||"",s.modifiedLanguage||s.language||"text",s.modifiedModelPath||"");u!==c.getModel()&&c.setModel(u)}),mn(()=>s.modified,()=>{if(!a.value)return;const c=r.value.getModifiedEditor();c.getOption(i.value.editor.EditorOption.readOnly)?c.setValue(s.modified||""):s.modified!==c.getValue()&&(c.executeEdits("",[{range:c.getModel().getFullModelRange(),text:s.modified||"",forceMoveMarkers:!0}]),c.pushUndoStop())}),mn(()=>s.original,()=>{var c,u;(u=(c=r.value)==null?void 0:c.getModel())==null||u.original.setValue((s==null?void 0:s.original)||"")}),mn(()=>[s.language,s.originalLanguage,s.modifiedLanguage],()=>{if(!a.value)return;const{original:c,modified:u}=r.value.getModel();i.value.editor.setModelLanguage(c,s.originalLanguage||s.language||"text"),i.value.editor.setModelLanguage(u,s.originalLanguage||s.language||"text")}),mn(()=>s.theme,()=>{var c;return(c=i.value)==null?void 0:c.editor.setTheme(s.theme)}),mn(()=>s.options,()=>{var c;return(c=r.value)==null?void 0:c.updateOptions(s.options)},{deep:!0}),{containerRef:t,isDiffEditorReady:a,isLoadFailed:o,wrapperStyle:l,containerStyle:d}},render(){const{$slots:s,isDiffEditorReady:e,isLoadFailed:t,wrapperStyle:i,containerStyle:n,className:o}=this;return cg("div",{style:i},[!e&&cg("div",{style:GY},t?s.failure?wS(s.failure):"load failed":s.default?wS(s.default):"loading..."),cg("div",{ref:"containerRef",key:"monaco_diff_editor_container",style:n,class:o})])}});function ZY({emit:s},e,t,i){const n=Xm(null);Qb(()=>{const r=mn(t,()=>{i.value&&t.value&&(Xb(()=>r()),o())},{immediate:!0})});function o(){var r;if(!i.value||!t.value||n.value)return;s("beforeMount",t.value),n.value=t.value.editor.createDiffEditor(i.value,qY({automaticLayout:!0,autoIndent:"brackets",theme:e.theme,formatOnPaste:!0,formatOnType:!0},e.options));const a=om(t.value,e.original||"",e.originalLanguage||e.language||"text",e.originalModelPath||""),l=om(t.value,e.modified||"",e.modifiedLanguage||e.language||"text",e.modifiedModelPath||"");(r=n.value)==null||r.setModel({original:a,modified:l}),s("mount",n.value,t.value)}return{diffEditorRef:n}}function YY(s,e){e&&gS.config(e),s.component(UF.name,UF),s.component(KF.name,KF)}function dr(s,e=0){return s[s.length-(1+e)]}function XY(s){if(s.length===0)throw new Error("Invalid tail call");return[s.slice(0,s.length-1),s[s.length-1]]}function Ai(s,e,t=(i,n)=>i===n){if(s===e)return!0;if(!s||!e||s.length!==e.length)return!1;for(let i=0,n=s.length;i<n;i++)if(!t(s[i],e[i]))return!1;return!0}function QY(s,e){const t=s.length-1;e<t&&(s[e]=s[t]),s.pop()}function _0(s,e,t){return JY(s.length,i=>t(s[i],e))}function JY(s,e){let t=0,i=s-1;for(;t<=i;){const n=(t+i)/2|0,o=e(n);if(o<0)t=n+1;else if(o>0)i=n-1;else return n}return-(t+1)}function UE(s,e,t){if(s=s|0,s>=e.length)throw new TypeError("invalid index");const i=e[Math.floor(e.length*Math.random())],n=[],o=[],r=[];for(const a of e){const l=t(a,i);l<0?n.push(a):l>0?o.push(a):r.push(a)}return s<n.length?UE(s,n,t):s<n.length+r.length?r[0]:UE(s-(n.length+r.length),o,t)}function qF(s,e){const t=[];let i;for(const n of s.slice(0).sort(e))!i||e(i[0],n)!==0?(i=[n],t.push(i)):i.push(n);return t}function*aW(s,e){let t,i;for(const n of s)i!==void 0&&e(i,n)?t.push(n):(t&&(yield t),t=[n]),i=n;t&&(yield t)}function lW(s,e){for(let t=0;t<=s.length;t++)e(t===0?void 0:s[t-1],t===s.length?void 0:s[t])}function eX(s,e){for(let t=0;t<s.length;t++)e(t===0?void 0:s[t-1],s[t],t+1===s.length?void 0:s[t+1])}function Ba(s){return s.filter(e=>!!e)}function GF(s){let e=0;for(let t=0;t<s.length;t++)s[t]&&(s[e]=s[t],e+=1);s.length=e}function dW(s){return!Array.isArray(s)||s.length===0}function as(s){return Array.isArray(s)&&s.length>0}function Lu(s,e=t=>t){const t=new Set;return s.filter(i=>{const n=e(i);return t.has(n)?!1:(t.add(n),!0)})}function wA(s,e){return s.length>0?s[0]:e}function Ls(s,e){let t=typeof e=="number"?s:0;typeof e=="number"?t=s:(t=0,e=s);const i=[];if(t<=e)for(let n=t;n<e;n++)i.push(n);else for(let n=t;n>e;n--)i.push(n);return i}function $L(s,e,t){const i=s.slice(0,e),n=s.slice(e);return i.concat(t,n)}function Lk(s,e){const t=s.indexOf(e);t>-1&&(s.splice(t,1),s.unshift(e))}function t1(s,e){const t=s.indexOf(e);t>-1&&(s.splice(t,1),s.push(e))}function $E(s,e){for(const t of e)s.push(t)}function SA(s){return Array.isArray(s)?s:[s]}function tX(s,e,t){const i=cW(s,e),n=s.length,o=t.length;s.length=n+o;for(let r=n-1;r>=i;r--)s[r+o]=s[r];for(let r=0;r<o;r++)s[r+i]=t[r]}function ZF(s,e,t,i){const n=cW(s,e);let o=s.splice(n,t);return o===void 0&&(o=[]),tX(s,n,i),o}function cW(s,e){return e<0?Math.max(e+s.length,0):Math.min(e,s.length)}var v0;(function(s){function e(o){return o<0}s.isLessThan=e;function t(o){return o<=0}s.isLessThanOrEqual=t;function i(o){return o>0}s.isGreaterThan=i;function n(o){return o===0}s.isNeitherLessOrGreaterThan=n,s.greaterThan=1,s.lessThan=-1,s.neitherLessOrGreaterThan=0})(v0||(v0={}));function br(s,e){return(t,i)=>e(s(t),s(i))}function iX(...s){return(e,t)=>{for(const i of s){const n=i(e,t);if(!v0.isNeitherLessOrGreaterThan(n))return n}return v0.neitherLessOrGreaterThan}}const Ud=(s,e)=>s-e,nX=(s,e)=>Ud(s?1:0,e?1:0);function uW(s){return(e,t)=>-s(e,t)}class Qd{constructor(e){this.items=e,this.firstIdx=0,this.lastIdx=this.items.length-1}get length(){return this.lastIdx-this.firstIdx+1}takeWhile(e){let t=this.firstIdx;for(;t<this.items.length&&e(this.items[t]);)t++;const i=t===this.firstIdx?null:this.items.slice(this.firstIdx,t);return this.firstIdx=t,i}takeFromEndWhile(e){let t=this.lastIdx;for(;t>=0&&e(this.items[t]);)t--;const i=t===this.lastIdx?null:this.items.slice(t+1,this.lastIdx+1);return this.lastIdx=t,i}peek(){if(this.length!==0)return this.items[this.firstIdx]}dequeue(){const e=this.items[this.firstIdx];return this.firstIdx++,e}takeCount(e){const t=this.items.slice(this.firstIdx,this.firstIdx+e);return this.firstIdx+=e,t}}class Fl{constructor(e){this.iterate=e}toArray(){const e=[];return this.iterate(t=>(e.push(t),!0)),e}filter(e){return new Fl(t=>this.iterate(i=>e(i)?t(i):!0))}map(e){return new Fl(t=>this.iterate(i=>t(e(i))))}findLast(e){let t;return this.iterate(i=>(e(i)&&(t=i),!0)),t}findLastMaxBy(e){let t,i=!0;return this.iterate(n=>((i||v0.isGreaterThan(e(n,t)))&&(i=!1,t=n),!0)),t}}Fl.empty=new Fl(s=>{});function Ps(s){return typeof s=="string"}function Ts(s){return typeof s=="object"&&s!==null&&!Array.isArray(s)&&!(s instanceof RegExp)&&!(s instanceof Date)}function sX(s){const e=Object.getPrototypeOf(Uint8Array);return typeof s=="object"&&s instanceof e}function xu(s){return typeof s=="number"&&!isNaN(s)}function YF(s){return!!s&&typeof s[Symbol.iterator]=="function"}function hW(s){return s===!0||s===!1}function fo(s){return typeof s>"u"}function b0(s){return!Uo(s)}function Uo(s){return fo(s)||s===null}function zt(s,e){if(!s)throw new Error(e?`Unexpected type, expected '${e}'`:"Unexpected type")}function Vc(s){if(Uo(s))throw new Error("Assertion Failed: argument is undefined or null");return s}function C0(s){return typeof s=="function"}function oX(s,e){const t=Math.min(s.length,e.length);for(let i=0;i<t;i++)rX(s[i],e[i])}function rX(s,e){if(Ps(e)){if(typeof s!==e)throw new Error(`argument does not match constraint: typeof ${e}`)}else if(C0(e)){try{if(s instanceof e)return}catch{}if(!Uo(s)&&s.constructor===e||e.length===1&&e.call(void 0,s)===!0)return;throw new Error("argument does not match one of these constraints: arg instanceof constraint, arg.constructor === constraint, nor constraint(arg) === true")}}function yd(s){if(!s||typeof s!="object"||s instanceof RegExp)return s;const e=Array.isArray(s)?[]:{};return Object.entries(s).forEach(([t,i])=>{e[t]=i&&typeof i=="object"?yd(i):i}),e}function aX(s){if(!s||typeof s!="object")return s;const e=[s];for(;e.length>0;){const t=e.shift();Object.freeze(t);for(const i in t)if(gW.call(t,i)){const n=t[i];typeof n=="object"&&!Object.isFrozen(n)&&!sX(n)&&e.push(n)}}return s}const gW=Object.prototype.hasOwnProperty;function fW(s,e){return jE(s,e,new Set)}function jE(s,e,t){if(Uo(s))return s;const i=e(s);if(typeof i<"u")return i;if(Array.isArray(s)){const n=[];for(const o of s)n.push(jE(o,e,t));return n}if(Ts(s)){if(t.has(s))throw new Error("Cannot clone recursive data-structure");t.add(s);const n={};for(const o in s)gW.call(s,o)&&(n[o]=jE(s[o],e,t));return t.delete(s),n}return s}function jL(s,e,t=!0){return Ts(s)?(Ts(e)&&Object.keys(e).forEach(i=>{i in s?t&&(Ts(s[i])&&Ts(e[i])?jL(s[i],e[i],t):s[i]=e[i]):s[i]=e[i]}),s):e}function Qo(s,e){if(s===e)return!0;if(s==null||e===null||e===void 0||typeof s!=typeof e||typeof s!="object"||Array.isArray(s)!==Array.isArray(e))return!1;let t,i;if(Array.isArray(s)){if(s.length!==e.length)return!1;for(t=0;t<s.length;t++)if(!Qo(s[t],e[t]))return!1}else{const n=[];for(i in s)n.push(i);n.sort();const o=[];for(i in e)o.push(i);if(o.sort(),!Qo(n,o))return!1;for(t=0;t<n.length;t++)if(!Qo(s[n[t]],e[n[t]]))return!1}return!0}function lX(s){let e=[];for(;Object.prototype!==s;)e=e.concat(Object.getOwnPropertyNames(s)),s=Object.getPrototypeOf(s);return e}function yA(s){const e=[];for(const t of lX(s))typeof s[t]=="function"&&e.push(t);return e}function dX(s,e){const t=n=>function(){const o=Array.prototype.slice.call(arguments,0);return e(n,o)},i={};for(const n of s)i[n]=t(n);return i}let cX=typeof document<"u"&&document.location&&document.location.hash.indexOf("pseudo=true")>=0;function pW(s,e){let t;return e.length===0?t=s:t=s.replace(/\{(\d+)\}/g,(i,n)=>{const o=n[0],r=e[o];let a=i;return typeof r=="string"?a=r:(typeof r=="number"||typeof r=="boolean"||r===void 0||r===null)&&(a=String(r)),a}),cX&&(t="［"+t.replace(/[aouei]/g,"$&$&")+"］"),t}function p(s,e,...t){return pW(e,t)}function uX(s,e,...t){const i=pW(e,t);return{value:i,original:i}}var xk;const tp="en";let SS=!1,yS=!1,Dw=!1,mW=!1,LA=!1,xA=!1,_W=!1,i1,kw=tp,XF=tp,hX,da;const $d=globalThis;let xs;typeof $d.vscode<"u"&&typeof $d.vscode.process<"u"?xs=$d.vscode.process:typeof process<"u"&&(xs=process);const gX=typeof((xk=xs==null?void 0:xs.versions)===null||xk===void 0?void 0:xk.electron)=="string",fX=gX&&(xs==null?void 0:xs.type)==="renderer";if(typeof navigator=="object"&&!fX)da=navigator.userAgent,SS=da.indexOf("Windows")>=0,yS=da.indexOf("Macintosh")>=0,xA=(da.indexOf("Macintosh")>=0||da.indexOf("iPad")>=0||da.indexOf("iPhone")>=0)&&!!navigator.maxTouchPoints&&navigator.maxTouchPoints>0,Dw=da.indexOf("Linux")>=0,_W=(da==null?void 0:da.indexOf("Mobi"))>=0,LA=!0,p({key:"ensureLoaderPluginIsLoaded",comment:["{Locked}"]},"_"),i1=tp,kw=i1,XF=navigator.language;else if(typeof xs=="object"){SS=xs.platform==="win32",yS=xs.platform==="darwin",Dw=xs.platform==="linux",Dw&&xs.env.SNAP&&xs.env.SNAP_REVISION,xs.env.CI||xs.env.BUILD_ARTIFACTSTAGINGDIRECTORY,i1=tp,kw=tp;const s=xs.env.VSCODE_NLS_CONFIG;if(s)try{const e=JSON.parse(s),t=e.availableLanguages["*"];i1=e.locale,XF=e.osLocale,kw=t||tp,hX=e._translationsConfigFile}catch{}mW=!0}else console.error("Unable to resolve platform.");const es=SS,bt=yS,Ss=Dw,Ra=mW,Ju=LA,pX=LA&&typeof $d.importScripts=="function",mX=pX?$d.origin:void 0,Wa=xA,_X=_W,jl=da,vX=kw,bX=typeof $d.postMessage=="function"&&!$d.importScripts,vW=(()=>{if(bX){const s=[];$d.addEventListener("message",t=>{if(t.data&&t.data.vscodeScheduleAsyncWork)for(let i=0,n=s.length;i<n;i++){const o=s[i];if(o.id===t.data.vscodeScheduleAsyncWork){s.splice(i,1),o.callback();return}}});let e=0;return t=>{const i=++e;s.push({id:i,callback:t}),$d.postMessage({vscodeScheduleAsyncWork:i},"*")}}return s=>setTimeout(s)})(),Go=yS||xA?2:SS?1:3;let QF=!0,JF=!1;function bW(){if(!JF){JF=!0;const s=new Uint8Array(2);s[0]=1,s[1]=2,QF=new Uint16Array(s.buffer)[0]===513}return QF}const CW=!!(jl&&jl.indexOf("Chrome")>=0),CX=!!(jl&&jl.indexOf("Firefox")>=0),wX=!!(!CW&&jl&&jl.indexOf("Safari")>=0),SX=!!(jl&&jl.indexOf("Edg/")>=0);jl&&jl.indexOf("Android")>=0;const os={tabSize:4,indentSize:4,insertSpaces:!0,detectIndentation:!0,trimAutoWhitespace:!0,largeFileOptimizations:!0,bracketPairColorizationOptions:{enabled:!0,independentColorPoolPerBracketType:!1}};var ht;(function(s){function e(b){return b&&typeof b=="object"&&typeof b[Symbol.iterator]=="function"}s.is=e;const t=Object.freeze([]);function i(){return t}s.empty=i;function*n(b){yield b}s.single=n;function o(b){return e(b)?b:n(b)}s.wrap=o;function r(b){return b||t}s.from=r;function*a(b){for(let C=b.length-1;C>=0;C--)yield b[C]}s.reverse=a;function l(b){return!b||b[Symbol.iterator]().next().done===!0}s.isEmpty=l;function d(b){return b[Symbol.iterator]().next().value}s.first=d;function c(b,C){for(const w of b)if(C(w))return!0;return!1}s.some=c;function u(b,C){for(const w of b)if(C(w))return w}s.find=u;function*h(b,C){for(const w of b)C(w)&&(yield w)}s.filter=h;function*g(b,C){let w=0;for(const S of b)yield C(S,w++)}s.map=g;function*f(...b){for(const C of b)yield*C}s.concat=f;function m(b,C,w){let S=w;for(const x of b)S=C(S,x);return S}s.reduce=m;function*_(b,C,w=b.length){for(C<0&&(C+=b.length),w<0?w+=b.length:w>b.length&&(w=b.length);C<w;C++)yield b[C]}s.slice=_;function v(b,C=Number.POSITIVE_INFINITY){const w=[];if(C===0)return[w,b];const S=b[Symbol.iterator]();for(let x=0;x<C;x++){const L=S.next();if(L.done)return[w,s.empty()];w.push(L.value)}return[w,{[Symbol.iterator](){return S}}]}s.consume=v})(ht||(ht={}));let on=class KE{constructor(e){this.element=e,this.next=KE.Undefined,this.prev=KE.Undefined}};on.Undefined=new on(void 0);class Ms{constructor(){this._first=on.Undefined,this._last=on.Undefined,this._size=0}get size(){return this._size}isEmpty(){return this._first===on.Undefined}clear(){let e=this._first;for(;e!==on.Undefined;){const t=e.next;e.prev=on.Undefined,e.next=on.Undefined,e=t}this._first=on.Undefined,this._last=on.Undefined,this._size=0}unshift(e){return this._insert(e,!1)}push(e){return this._insert(e,!0)}_insert(e,t){const i=new on(e);if(this._first===on.Undefined)this._first=i,this._last=i;else if(t){const o=this._last;this._last=i,i.prev=o,o.next=i}else{const o=this._first;this._first=i,i.next=o,o.prev=i}this._size+=1;let n=!1;return()=>{n||(n=!0,this._remove(i))}}shift(){if(this._first!==on.Undefined){const e=this._first.element;return this._remove(this._first),e}}pop(){if(this._last!==on.Undefined){const e=this._last.element;return this._remove(this._last),e}}_remove(e){if(e.prev!==on.Undefined&&e.next!==on.Undefined){const t=e.prev;t.next=e.next,e.next.prev=t}else e.prev===on.Undefined&&e.next===on.Undefined?(this._first=on.Undefined,this._last=on.Undefined):e.next===on.Undefined?(this._last=this._last.prev,this._last.next=on.Undefined):e.prev===on.Undefined&&(this._first=this._first.next,this._first.prev=on.Undefined);this._size-=1}*[Symbol.iterator](){let e=this._first;for(;e!==on.Undefined;)yield e.element,e=e.next}}const wW="`~!@#$%^&*()-=+[{]}\\|;:'\",.<>/?";function yX(s=""){let e="(-?\\d*\\.\\d\\w*)|([^";for(const t of wW)s.indexOf(t)>=0||(e+="\\"+t);return e+="\\s]+)",new RegExp(e,"g")}const DA=yX();function kA(s){let e=DA;if(s&&s instanceof RegExp)if(s.global)e=s;else{let t="g";s.ignoreCase&&(t+="i"),s.multiline&&(t+="m"),s.unicode&&(t+="u"),e=new RegExp(s.source,t)}return e.lastIndex=0,e}const SW=new Ms;SW.unshift({maxLen:1e3,windowSize:15,timeBudget:150});function w0(s,e,t,i,n){if(e=kA(e),n||(n=ht.first(SW)),t.length>n.maxLen){let d=s-n.maxLen/2;return d<0?d=0:i+=d,t=t.substring(d,s+n.maxLen/2),w0(s,e,t,i,n)}const o=Date.now(),r=s-1-i;let a=-1,l=null;for(let d=1;!(Date.now()-o>=n.timeBudget);d++){const c=r-n.windowSize*d;e.lastIndex=Math.max(0,c);const u=LX(e,t,r,a);if(!u&&l||(l=u,c<=0))break;a=c}if(l){const d={word:l[0],startColumn:i+1+l.index,endColumn:i+1+l.index+l[0].length};return e.lastIndex=0,d}return null}function LX(s,e,t,i){let n;for(;n=s.exec(e);){const o=n.index||0;if(o<=t&&s.lastIndex>=t)return n;if(i>0&&o>i)return null}return null}const Cc=8;class yW{constructor(e){this._values=e}hasChanged(e){return this._values[e]}}class LW{constructor(){this.stableMinimapLayoutInput=null,this.stableFitMaxMinimapScale=0,this.stableFitRemainingWidth=0}}class wi{constructor(e,t,i,n){this.id=e,this.name=t,this.defaultValue=i,this.schema=n}applyUpdate(e,t){return KL(e,t)}compute(e,t,i){return i}}class Tv{constructor(e,t){this.newValue=e,this.didChange=t}}function KL(s,e){if(typeof s!="object"||typeof e!="object"||!s||!e)return new Tv(e,s!==e);if(Array.isArray(s)||Array.isArray(e)){const i=Array.isArray(s)&&Array.isArray(e)&&Ai(s,e);return new Tv(e,!i)}let t=!1;for(const i in e)if(e.hasOwnProperty(i)){const n=KL(s[i],e[i]);n.didChange&&(s[i]=n.newValue,t=!0)}return new Tv(s,t)}class eC{constructor(e){this.schema=void 0,this.id=e,this.name="_never_",this.defaultValue=void 0}applyUpdate(e,t){return KL(e,t)}validate(e){return this.defaultValue}}class Jm{constructor(e,t,i,n){this.id=e,this.name=t,this.defaultValue=i,this.schema=n}applyUpdate(e,t){return KL(e,t)}validate(e){return typeof e>"u"?this.defaultValue:e}compute(e,t,i){return i}}function Te(s,e){return typeof s>"u"?e:s==="false"?!1:!!s}class St extends Jm{constructor(e,t,i,n=void 0){typeof n<"u"&&(n.type="boolean",n.default=i),super(e,t,i,n)}validate(e){return Te(e,this.defaultValue)}}function Nh(s,e,t,i){if(typeof s>"u")return e;let n=parseInt(s,10);return isNaN(n)?e:(n=Math.max(t,n),n=Math.min(i,n),n|0)}class Gt extends Jm{static clampedInt(e,t,i,n){return Nh(e,t,i,n)}constructor(e,t,i,n,o,r=void 0){typeof r<"u"&&(r.type="integer",r.default=i,r.minimum=n,r.maximum=o),super(e,t,i,r),this.minimum=n,this.maximum=o}validate(e){return Gt.clampedInt(e,this.defaultValue,this.minimum,this.maximum)}}function xX(s,e,t,i){if(typeof s>"u")return e;const n=Hr.float(s,e);return Hr.clamp(n,t,i)}class Hr extends Jm{static clamp(e,t,i){return e<t?t:e>i?i:e}static float(e,t){if(typeof e=="number")return e;if(typeof e>"u")return t;const i=parseFloat(e);return isNaN(i)?t:i}constructor(e,t,i,n,o){typeof o<"u"&&(o.type="number",o.default=i),super(e,t,i,o),this.validationFn=n}validate(e){return this.validationFn(Hr.float(e,this.defaultValue))}}class uo extends Jm{static string(e,t){return typeof e!="string"?t:e}constructor(e,t,i,n=void 0){typeof n<"u"&&(n.type="string",n.default=i),super(e,t,i,n)}validate(e){return uo.string(e,this.defaultValue)}}function Vi(s,e,t,i){return typeof s!="string"?e:i&&s in i?i[s]:t.indexOf(s)===-1?e:s}class yi extends Jm{constructor(e,t,i,n,o=void 0){typeof o<"u"&&(o.type="string",o.enum=n,o.default=i),super(e,t,i,o),this._allowedValues=n}validate(e){return Vi(e,this.defaultValue,this._allowedValues)}}class n1 extends wi{constructor(e,t,i,n,o,r,a=void 0){typeof a<"u"&&(a.type="string",a.enum=o,a.default=n),super(e,t,i,a),this._allowedValues=o,this._convert=r}validate(e){return typeof e!="string"?this.defaultValue:this._allowedValues.indexOf(e)===-1?this.defaultValue:this._convert(e)}}function DX(s){switch(s){case"none":return 0;case"keep":return 1;case"brackets":return 2;case"advanced":return 3;case"full":return 4}}class kX extends wi{constructor(){super(2,"accessibilitySupport",0,{type:"string",enum:["auto","on","off"],enumDescriptions:[p("accessibilitySupport.auto","Use platform APIs to detect when a Screen Reader is attached."),p("accessibilitySupport.on","Optimize for usage with a Screen Reader."),p("accessibilitySupport.off","Assume a screen reader is not attached.")],default:"auto",tags:["accessibility"],description:p("accessibilitySupport","Controls if the UI should run in a mode where it is optimized for screen readers.")})}validate(e){switch(e){case"auto":return 0;case"off":return 1;case"on":return 2}return this.defaultValue}compute(e,t,i){return i===0?e.accessibilitySupport:i}}class IX extends wi{constructor(){const e={insertSpace:!0,ignoreEmptyLines:!0};super(23,"comments",e,{"editor.comments.insertSpace":{type:"boolean",default:e.insertSpace,description:p("comments.insertSpace","Controls whether a space character is inserted when commenting.")},"editor.comments.ignoreEmptyLines":{type:"boolean",default:e.ignoreEmptyLines,description:p("comments.ignoreEmptyLines","Controls if empty lines should be ignored with toggle, add or remove actions for line comments.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{insertSpace:Te(t.insertSpace,this.defaultValue.insertSpace),ignoreEmptyLines:Te(t.ignoreEmptyLines,this.defaultValue.ignoreEmptyLines)}}}function EX(s){switch(s){case"blink":return 1;case"smooth":return 2;case"phase":return 3;case"expand":return 4;case"solid":return 5}}var Fn;(function(s){s[s.Line=1]="Line",s[s.Block=2]="Block",s[s.Underline=3]="Underline",s[s.LineThin=4]="LineThin",s[s.BlockOutline=5]="BlockOutline",s[s.UnderlineThin=6]="UnderlineThin"})(Fn||(Fn={}));function NX(s){switch(s){case"line":return Fn.Line;case"block":return Fn.Block;case"underline":return Fn.Underline;case"line-thin":return Fn.LineThin;case"block-outline":return Fn.BlockOutline;case"underline-thin":return Fn.UnderlineThin}}class TX extends eC{constructor(){super(140)}compute(e,t,i){const n=["monaco-editor"];return t.get(39)&&n.push(t.get(39)),e.extraEditorClassName&&n.push(e.extraEditorClassName),t.get(73)==="default"?n.push("mouse-default"):t.get(73)==="copy"&&n.push("mouse-copy"),t.get(110)&&n.push("showUnused"),t.get(138)&&n.push("showDeprecated"),n.join(" ")}}class MX extends St{constructor(){super(37,"emptySelectionClipboard",!0,{description:p("emptySelectionClipboard","Controls whether copying without a selection copies the current line.")})}compute(e,t,i){return i&&e.emptySelectionClipboard}}class RX extends wi{constructor(){const e={cursorMoveOnType:!0,seedSearchStringFromSelection:"always",autoFindInSelection:"never",globalFindClipboard:!1,addExtraSpaceOnTop:!0,loop:!0};super(41,"find",e,{"editor.find.cursorMoveOnType":{type:"boolean",default:e.cursorMoveOnType,description:p("find.cursorMoveOnType","Controls whether the cursor should jump to find matches while typing.")},"editor.find.seedSearchStringFromSelection":{type:"string",enum:["never","always","selection"],default:e.seedSearchStringFromSelection,enumDescriptions:[p("editor.find.seedSearchStringFromSelection.never","Never seed search string from the editor selection."),p("editor.find.seedSearchStringFromSelection.always","Always seed search string from the editor selection, including word at cursor position."),p("editor.find.seedSearchStringFromSelection.selection","Only seed search string from the editor selection.")],description:p("find.seedSearchStringFromSelection","Controls whether the search string in the Find Widget is seeded from the editor selection.")},"editor.find.autoFindInSelection":{type:"string",enum:["never","always","multiline"],default:e.autoFindInSelection,enumDescriptions:[p("editor.find.autoFindInSelection.never","Never turn on Find in Selection automatically (default)."),p("editor.find.autoFindInSelection.always","Always turn on Find in Selection automatically."),p("editor.find.autoFindInSelection.multiline","Turn on Find in Selection automatically when multiple lines of content are selected.")],description:p("find.autoFindInSelection","Controls the condition for turning on Find in Selection automatically.")},"editor.find.globalFindClipboard":{type:"boolean",default:e.globalFindClipboard,description:p("find.globalFindClipboard","Controls whether the Find Widget should read or modify the shared find clipboard on macOS."),included:bt},"editor.find.addExtraSpaceOnTop":{type:"boolean",default:e.addExtraSpaceOnTop,description:p("find.addExtraSpaceOnTop","Controls whether the Find Widget should add extra lines on top of the editor. When true, you can scroll beyond the first line when the Find Widget is visible.")},"editor.find.loop":{type:"boolean",default:e.loop,description:p("find.loop","Controls whether the search automatically restarts from the beginning (or the end) when no further matches can be found.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{cursorMoveOnType:Te(t.cursorMoveOnType,this.defaultValue.cursorMoveOnType),seedSearchStringFromSelection:typeof e.seedSearchStringFromSelection=="boolean"?e.seedSearchStringFromSelection?"always":"never":Vi(t.seedSearchStringFromSelection,this.defaultValue.seedSearchStringFromSelection,["never","always","selection"]),autoFindInSelection:typeof e.autoFindInSelection=="boolean"?e.autoFindInSelection?"always":"never":Vi(t.autoFindInSelection,this.defaultValue.autoFindInSelection,["never","always","multiline"]),globalFindClipboard:Te(t.globalFindClipboard,this.defaultValue.globalFindClipboard),addExtraSpaceOnTop:Te(t.addExtraSpaceOnTop,this.defaultValue.addExtraSpaceOnTop),loop:Te(t.loop,this.defaultValue.loop)}}}class $o extends wi{constructor(){super(51,"fontLigatures",$o.OFF,{anyOf:[{type:"boolean",description:p("fontLigatures","Enables/Disables font ligatures ('calt' and 'liga' font features). Change this to a string for fine-grained control of the 'font-feature-settings' CSS property.")},{type:"string",description:p("fontFeatureSettings","Explicit 'font-feature-settings' CSS property. A boolean can be passed instead if one only needs to turn on/off ligatures.")}],description:p("fontLigaturesGeneral","Configures font ligatures or font features. Can be either a boolean to enable/disable ligatures or a string for the value of the CSS 'font-feature-settings' property."),default:!1})}validate(e){return typeof e>"u"?this.defaultValue:typeof e=="string"?e==="false"?$o.OFF:e==="true"?$o.ON:e:e?$o.ON:$o.OFF}}$o.OFF='"liga" off, "calt" off';$o.ON='"liga" on, "calt" on';class La extends wi{constructor(){super(54,"fontVariations",La.OFF,{anyOf:[{type:"boolean",description:p("fontVariations","Enables/Disables the translation from font-weight to font-variation-settings. Change this to a string for fine-grained control of the 'font-variation-settings' CSS property.")},{type:"string",description:p("fontVariationSettings","Explicit 'font-variation-settings' CSS property. A boolean can be passed instead if one only needs to translate font-weight to font-variation-settings.")}],description:p("fontVariationsGeneral","Configures font variations. Can be either a boolean to enable/disable the translation from font-weight to font-variation-settings or a string for the value of the CSS 'font-variation-settings' property."),default:!1})}validate(e){return typeof e>"u"?this.defaultValue:typeof e=="string"?e==="false"?La.OFF:e==="true"?La.TRANSLATE:e:e?La.TRANSLATE:La.OFF}compute(e,t,i){return e.fontInfo.fontVariationSettings}}La.OFF="normal";La.TRANSLATE="translate";class AX extends eC{constructor(){super(50)}compute(e,t,i){return e.fontInfo}}class PX extends Jm{constructor(){super(52,"fontSize",vo.fontSize,{type:"number",minimum:6,maximum:100,default:vo.fontSize,description:p("fontSize","Controls the font size in pixels.")})}validate(e){const t=Hr.float(e,this.defaultValue);return t===0?vo.fontSize:Hr.clamp(t,6,100)}compute(e,t,i){return e.fontInfo.fontSize}}class _l extends wi{constructor(){super(53,"fontWeight",vo.fontWeight,{anyOf:[{type:"number",minimum:_l.MINIMUM_VALUE,maximum:_l.MAXIMUM_VALUE,errorMessage:p("fontWeightErrorMessage",'Only "normal" and "bold" keywords or numbers between 1 and 1000 are allowed.')},{type:"string",pattern:"^(normal|bold|1000|[1-9][0-9]{0,2})$"},{enum:_l.SUGGESTION_VALUES}],default:vo.fontWeight,description:p("fontWeight",'Controls the font weight. Accepts "normal" and "bold" keywords or numbers between 1 and 1000.')})}validate(e){return e==="normal"||e==="bold"?e:String(Gt.clampedInt(e,vo.fontWeight,_l.MINIMUM_VALUE,_l.MAXIMUM_VALUE))}}_l.SUGGESTION_VALUES=["normal","bold","100","200","300","400","500","600","700","800","900"];_l.MINIMUM_VALUE=1;_l.MAXIMUM_VALUE=1e3;class OX extends wi{constructor(){const e={multiple:"peek",multipleDefinitions:"peek",multipleTypeDefinitions:"peek",multipleDeclarations:"peek",multipleImplementations:"peek",multipleReferences:"peek",alternativeDefinitionCommand:"editor.action.goToReferences",alternativeTypeDefinitionCommand:"editor.action.goToReferences",alternativeDeclarationCommand:"editor.action.goToReferences",alternativeImplementationCommand:"",alternativeReferenceCommand:""},t={type:"string",enum:["peek","gotoAndPeek","goto"],default:e.multiple,enumDescriptions:[p("editor.gotoLocation.multiple.peek","Show Peek view of the results (default)"),p("editor.gotoLocation.multiple.gotoAndPeek","Go to the primary result and show a Peek view"),p("editor.gotoLocation.multiple.goto","Go to the primary result and enable Peek-less navigation to others")]},i=["","editor.action.referenceSearch.trigger","editor.action.goToReferences","editor.action.peekImplementation","editor.action.goToImplementation","editor.action.peekTypeDefinition","editor.action.goToTypeDefinition","editor.action.peekDeclaration","editor.action.revealDeclaration","editor.action.peekDefinition","editor.action.revealDefinitionAside","editor.action.revealDefinition"];super(58,"gotoLocation",e,{"editor.gotoLocation.multiple":{deprecationMessage:p("editor.gotoLocation.multiple.deprecated","This setting is deprecated, please use separate settings like 'editor.editor.gotoLocation.multipleDefinitions' or 'editor.editor.gotoLocation.multipleImplementations' instead.")},"editor.gotoLocation.multipleDefinitions":{description:p("editor.editor.gotoLocation.multipleDefinitions","Controls the behavior the 'Go to Definition'-command when multiple target locations exist."),...t},"editor.gotoLocation.multipleTypeDefinitions":{description:p("editor.editor.gotoLocation.multipleTypeDefinitions","Controls the behavior the 'Go to Type Definition'-command when multiple target locations exist."),...t},"editor.gotoLocation.multipleDeclarations":{description:p("editor.editor.gotoLocation.multipleDeclarations","Controls the behavior the 'Go to Declaration'-command when multiple target locations exist."),...t},"editor.gotoLocation.multipleImplementations":{description:p("editor.editor.gotoLocation.multipleImplemenattions","Controls the behavior the 'Go to Implementations'-command when multiple target locations exist."),...t},"editor.gotoLocation.multipleReferences":{description:p("editor.editor.gotoLocation.multipleReferences","Controls the behavior the 'Go to References'-command when multiple target locations exist."),...t},"editor.gotoLocation.alternativeDefinitionCommand":{type:"string",default:e.alternativeDefinitionCommand,enum:i,description:p("alternativeDefinitionCommand","Alternative command id that is being executed when the result of 'Go to Definition' is the current location.")},"editor.gotoLocation.alternativeTypeDefinitionCommand":{type:"string",default:e.alternativeTypeDefinitionCommand,enum:i,description:p("alternativeTypeDefinitionCommand","Alternative command id that is being executed when the result of 'Go to Type Definition' is the current location.")},"editor.gotoLocation.alternativeDeclarationCommand":{type:"string",default:e.alternativeDeclarationCommand,enum:i,description:p("alternativeDeclarationCommand","Alternative command id that is being executed when the result of 'Go to Declaration' is the current location.")},"editor.gotoLocation.alternativeImplementationCommand":{type:"string",default:e.alternativeImplementationCommand,enum:i,description:p("alternativeImplementationCommand","Alternative command id that is being executed when the result of 'Go to Implementation' is the current location.")},"editor.gotoLocation.alternativeReferenceCommand":{type:"string",default:e.alternativeReferenceCommand,enum:i,description:p("alternativeReferenceCommand","Alternative command id that is being executed when the result of 'Go to Reference' is the current location.")}})}validate(e){var t,i,n,o,r;if(!e||typeof e!="object")return this.defaultValue;const a=e;return{multiple:Vi(a.multiple,this.defaultValue.multiple,["peek","gotoAndPeek","goto"]),multipleDefinitions:(t=a.multipleDefinitions)!==null&&t!==void 0?t:Vi(a.multipleDefinitions,"peek",["peek","gotoAndPeek","goto"]),multipleTypeDefinitions:(i=a.multipleTypeDefinitions)!==null&&i!==void 0?i:Vi(a.multipleTypeDefinitions,"peek",["peek","gotoAndPeek","goto"]),multipleDeclarations:(n=a.multipleDeclarations)!==null&&n!==void 0?n:Vi(a.multipleDeclarations,"peek",["peek","gotoAndPeek","goto"]),multipleImplementations:(o=a.multipleImplementations)!==null&&o!==void 0?o:Vi(a.multipleImplementations,"peek",["peek","gotoAndPeek","goto"]),multipleReferences:(r=a.multipleReferences)!==null&&r!==void 0?r:Vi(a.multipleReferences,"peek",["peek","gotoAndPeek","goto"]),alternativeDefinitionCommand:uo.string(a.alternativeDefinitionCommand,this.defaultValue.alternativeDefinitionCommand),alternativeTypeDefinitionCommand:uo.string(a.alternativeTypeDefinitionCommand,this.defaultValue.alternativeTypeDefinitionCommand),alternativeDeclarationCommand:uo.string(a.alternativeDeclarationCommand,this.defaultValue.alternativeDeclarationCommand),alternativeImplementationCommand:uo.string(a.alternativeImplementationCommand,this.defaultValue.alternativeImplementationCommand),alternativeReferenceCommand:uo.string(a.alternativeReferenceCommand,this.defaultValue.alternativeReferenceCommand)}}}class FX extends wi{constructor(){const e={enabled:!0,delay:300,hidingDelay:300,sticky:!0,above:!0};super(60,"hover",e,{"editor.hover.enabled":{type:"boolean",default:e.enabled,description:p("hover.enabled","Controls whether the hover is shown.")},"editor.hover.delay":{type:"number",default:e.delay,minimum:0,maximum:1e4,description:p("hover.delay","Controls the delay in milliseconds after which the hover is shown.")},"editor.hover.sticky":{type:"boolean",default:e.sticky,description:p("hover.sticky","Controls whether the hover should remain visible when mouse is moved over it.")},"editor.hover.hidingDelay":{type:"integer",minimum:0,default:e.hidingDelay,description:p("hover.hidingDelay","Controls the delay in milliseconds after which the hover is hidden. Requires `editor.hover.sticky` to be enabled.")},"editor.hover.above":{type:"boolean",default:e.above,description:p("hover.above","Prefer showing hovers above the line, if there's space.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{enabled:Te(t.enabled,this.defaultValue.enabled),delay:Gt.clampedInt(t.delay,this.defaultValue.delay,0,1e4),sticky:Te(t.sticky,this.defaultValue.sticky),hidingDelay:Gt.clampedInt(t.hidingDelay,this.defaultValue.hidingDelay,0,6e5),above:Te(t.above,this.defaultValue.above)}}}class Np extends eC{constructor(){super(143)}compute(e,t,i){return Np.computeLayout(t,{memory:e.memory,outerWidth:e.outerWidth,outerHeight:e.outerHeight,isDominatedByLongLines:e.isDominatedByLongLines,lineHeight:e.fontInfo.lineHeight,viewLineCount:e.viewLineCount,lineNumbersDigitCount:e.lineNumbersDigitCount,typicalHalfwidthCharacterWidth:e.fontInfo.typicalHalfwidthCharacterWidth,maxDigitWidth:e.fontInfo.maxDigitWidth,pixelRatio:e.pixelRatio,glyphMarginDecorationLaneCount:e.glyphMarginDecorationLaneCount})}static computeContainedMinimapLineCount(e){const t=e.height/e.lineHeight,i=Math.floor(e.paddingTop/e.lineHeight);let n=Math.floor(e.paddingBottom/e.lineHeight);e.scrollBeyondLastLine&&(n=Math.max(n,t-1));const o=(i+e.viewLineCount+n)/(e.pixelRatio*e.height),r=Math.floor(e.viewLineCount/o);return{typicalViewportLineCount:t,extraLinesBeforeFirstLine:i,extraLinesBeyondLastLine:n,desiredRatio:o,minimapLineCount:r}}static _computeMinimapLayout(e,t){const i=e.outerWidth,n=e.outerHeight,o=e.pixelRatio;if(!e.minimap.enabled)return{renderMinimap:0,minimapLeft:0,minimapWidth:0,minimapHeightIsEditorHeight:!1,minimapIsSampling:!1,minimapScale:1,minimapLineHeight:1,minimapCanvasInnerWidth:0,minimapCanvasInnerHeight:Math.floor(o*n),minimapCanvasOuterWidth:0,minimapCanvasOuterHeight:n};const r=t.stableMinimapLayoutInput,a=r&&e.outerHeight===r.outerHeight&&e.lineHeight===r.lineHeight&&e.typicalHalfwidthCharacterWidth===r.typicalHalfwidthCharacterWidth&&e.pixelRatio===r.pixelRatio&&e.scrollBeyondLastLine===r.scrollBeyondLastLine&&e.paddingTop===r.paddingTop&&e.paddingBottom===r.paddingBottom&&e.minimap.enabled===r.minimap.enabled&&e.minimap.side===r.minimap.side&&e.minimap.size===r.minimap.size&&e.minimap.showSlider===r.minimap.showSlider&&e.minimap.renderCharacters===r.minimap.renderCharacters&&e.minimap.maxColumn===r.minimap.maxColumn&&e.minimap.scale===r.minimap.scale&&e.verticalScrollbarWidth===r.verticalScrollbarWidth&&e.isViewportWrapping===r.isViewportWrapping,l=e.lineHeight,d=e.typicalHalfwidthCharacterWidth,c=e.scrollBeyondLastLine,u=e.minimap.renderCharacters;let h=o>=2?Math.round(e.minimap.scale*2):e.minimap.scale;const g=e.minimap.maxColumn,f=e.minimap.size,m=e.minimap.side,_=e.verticalScrollbarWidth,v=e.viewLineCount,b=e.remainingWidth,C=e.isViewportWrapping,w=u?2:3;let S=Math.floor(o*n);const x=S/o;let L=!1,k=!1,I=w*h,P=h/o,$=1;if(f==="fill"||f==="fit"){const{typicalViewportLineCount:ve,extraLinesBeforeFirstLine:ye,extraLinesBeyondLastLine:Be,desiredRatio:Ve,minimapLineCount:Ie}=Np.computeContainedMinimapLineCount({viewLineCount:v,scrollBeyondLastLine:c,paddingTop:e.paddingTop,paddingBottom:e.paddingBottom,height:n,lineHeight:l,pixelRatio:o});if(v/Ie>1)L=!0,k=!0,h=1,I=1,P=h/o;else{let Ji=!1,wn=h+1;if(f==="fit"){const ni=Math.ceil((ye+v+Be)*I);C&&a&&b<=t.stableFitRemainingWidth?(Ji=!0,wn=t.stableFitMaxMinimapScale):Ji=ni>S}if(f==="fill"||Ji){L=!0;const ni=h;I=Math.min(l*o,Math.max(1,Math.floor(1/Ve))),C&&a&&b<=t.stableFitRemainingWidth&&(wn=t.stableFitMaxMinimapScale),h=Math.min(wn,Math.max(1,Math.floor(I/w))),h>ni&&($=Math.min(2,h/ni)),P=h/o/$,S=Math.ceil(Math.max(ve,ye+v+Be)*I),C?(t.stableMinimapLayoutInput=e,t.stableFitRemainingWidth=b,t.stableFitMaxMinimapScale=h):(t.stableMinimapLayoutInput=null,t.stableFitRemainingWidth=0)}}}const A=Math.floor(g*P),z=Math.min(A,Math.max(0,Math.floor((b-_-2)*P/(d+P)))+Cc);let K=Math.floor(o*z);const Q=K/o;K=Math.floor(K*$);const ne=u?1:2,fe=m==="left"?0:i-z-_;return{renderMinimap:ne,minimapLeft:fe,minimapWidth:z,minimapHeightIsEditorHeight:L,minimapIsSampling:k,minimapScale:h,minimapLineHeight:I,minimapCanvasInnerWidth:K,minimapCanvasInnerHeight:S,minimapCanvasOuterWidth:Q,minimapCanvasOuterHeight:x}}static computeLayout(e,t){const i=t.outerWidth|0,n=t.outerHeight|0,o=t.lineHeight|0,r=t.lineNumbersDigitCount|0,a=t.typicalHalfwidthCharacterWidth,l=t.maxDigitWidth,d=t.pixelRatio,c=t.viewLineCount,u=e.get(135),h=u==="inherit"?e.get(134):u,g=h==="inherit"?e.get(130):h,f=e.get(133),m=t.isDominatedByLongLines,_=e.get(57),v=e.get(67).renderType!==0,b=e.get(68),C=e.get(104),w=e.get(83),S=e.get(72),x=e.get(102),L=x.verticalScrollbarSize,k=x.verticalHasArrows,I=x.arrowSize,P=x.horizontalScrollbarSize,$=e.get(43),A=e.get(109)!=="never";let z=e.get(65);$&&A&&(z+=16);let K=0;if(v){const $i=Math.max(r,b);K=Math.round($i*l)}let Q=0;_&&(Q=o*t.glyphMarginDecorationLaneCount);let ne=0,fe=ne+Q,ve=fe+K,ye=ve+z;const Be=i-Q-K-z;let Ve=!1,Ie=!1,pe=-1;h==="inherit"&&m?(Ve=!0,Ie=!0):g==="on"||g==="bounded"?Ie=!0:g==="wordWrapColumn"&&(pe=f);const Ji=Np._computeMinimapLayout({outerWidth:i,outerHeight:n,lineHeight:o,typicalHalfwidthCharacterWidth:a,pixelRatio:d,scrollBeyondLastLine:C,paddingTop:w.top,paddingBottom:w.bottom,minimap:S,verticalScrollbarWidth:L,viewLineCount:c,remainingWidth:Be,isViewportWrapping:Ie},t.memory||new LW);Ji.renderMinimap!==0&&Ji.minimapLeft===0&&(ne+=Ji.minimapWidth,fe+=Ji.minimapWidth,ve+=Ji.minimapWidth,ye+=Ji.minimapWidth);const wn=Be-Ji.minimapWidth,ni=Math.max(1,Math.floor((wn-L-2)/a)),wt=k?I:0;return Ie&&(pe=Math.max(1,ni),g==="bounded"&&(pe=Math.min(pe,f))),{width:i,height:n,glyphMarginLeft:ne,glyphMarginWidth:Q,glyphMarginDecorationLaneCount:t.glyphMarginDecorationLaneCount,lineNumbersLeft:fe,lineNumbersWidth:K,decorationsLeft:ve,decorationsWidth:z,contentLeft:ye,contentWidth:wn,minimap:Ji,viewportColumn:ni,isWordWrapMinified:Ve,isViewportWrapping:Ie,wrappingColumn:pe,verticalScrollbarWidth:L,horizontalScrollbarHeight:P,overviewRuler:{top:wt,width:L,height:n-2*wt,right:0}}}}class BX extends wi{constructor(){super(137,"wrappingStrategy","simple",{"editor.wrappingStrategy":{enumDescriptions:[p("wrappingStrategy.simple","Assumes that all characters are of the same width. This is a fast algorithm that works correctly for monospace fonts and certain scripts (like Latin characters) where glyphs are of equal width."),p("wrappingStrategy.advanced","Delegates wrapping points computation to the browser. This is a slow algorithm, that might cause freezes for large files, but it works correctly in all cases.")],type:"string",enum:["simple","advanced"],default:"simple",description:p("wrappingStrategy","Controls the algorithm that computes wrapping points. Note that when in accessibility mode, advanced will be used for the best experience.")}})}validate(e){return Vi(e,"simple",["simple","advanced"])}compute(e,t,i){return t.get(2)===2?"advanced":i}}var ho;(function(s){s.Off="off",s.OnCode="onCode",s.On="on"})(ho||(ho={}));class WX extends wi{constructor(){const e={enabled:!0,experimental:{showAiIcon:ho.Off}};super(64,"lightbulb",e,{"editor.lightbulb.enabled":{type:"boolean",default:e.enabled,description:p("codeActions","Enables the Code Action lightbulb in the editor.")},"editor.lightbulb.experimental.showAiIcon":{type:"string",enum:[ho.Off,ho.OnCode,ho.On],default:e.experimental.showAiIcon,enumDescriptions:[p("editor.lightbulb.showAiIcon.off","Don not show the AI icon."),p("editor.lightbulb.showAiIcon.onCode","Show an AI icon when the code action menu contains an AI action, but only on code."),p("editor.lightbulb.showAiIcon.on","Show an AI icon when the code action menu contains an AI action, on code and empty lines.")],description:p("showAiIcons","Show an AI icon along with the lightbulb when the code action menu contains an AI action.")}})}validate(e){var t,i;if(!e||typeof e!="object")return this.defaultValue;const n=e;return{enabled:Te(n.enabled,this.defaultValue.enabled),experimental:{showAiIcon:Vi((t=n.experimental)===null||t===void 0?void 0:t.showAiIcon,(i=this.defaultValue.experimental)===null||i===void 0?void 0:i.showAiIcon,[ho.Off,ho.OnCode,ho.On])}}}}class VX extends wi{constructor(){const e={enabled:!1,maxLineCount:5,defaultModel:"outlineModel",scrollWithEditor:!0};super(114,"stickyScroll",e,{"editor.stickyScroll.enabled":{type:"boolean",default:e.enabled,description:p("editor.stickyScroll.enabled","Shows the nested current scopes during the scroll at the top of the editor.")},"editor.stickyScroll.maxLineCount":{type:"number",default:e.maxLineCount,minimum:1,maximum:10,description:p("editor.stickyScroll.maxLineCount","Defines the maximum number of sticky lines to show.")},"editor.stickyScroll.defaultModel":{type:"string",enum:["outlineModel","foldingProviderModel","indentationModel"],default:e.defaultModel,description:p("editor.stickyScroll.defaultModel","Defines the model to use for determining which lines to stick. If the outline model does not exist, it will fall back on the folding provider model which falls back on the indentation model. This order is respected in all three cases.")},"editor.stickyScroll.scrollWithEditor":{type:"boolean",default:e.scrollWithEditor,description:p("editor.stickyScroll.scrollWithEditor","Enable scrolling of Sticky Scroll with the editor's horizontal scrollbar.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{enabled:Te(t.enabled,this.defaultValue.enabled),maxLineCount:Gt.clampedInt(t.maxLineCount,this.defaultValue.maxLineCount,1,10),defaultModel:Vi(t.defaultModel,this.defaultValue.defaultModel,["outlineModel","foldingProviderModel","indentationModel"]),scrollWithEditor:Te(t.scrollWithEditor,this.defaultValue.scrollWithEditor)}}}class HX extends wi{constructor(){const e={enabled:"on",fontSize:0,fontFamily:"",padding:!1};super(139,"inlayHints",e,{"editor.inlayHints.enabled":{type:"string",default:e.enabled,description:p("inlayHints.enable","Enables the inlay hints in the editor."),enum:["on","onUnlessPressed","offUnlessPressed","off"],markdownEnumDescriptions:[p("editor.inlayHints.on","Inlay hints are enabled"),p("editor.inlayHints.onUnlessPressed","Inlay hints are showing by default and hide when holding {0}",bt?"Ctrl+Option":"Ctrl+Alt"),p("editor.inlayHints.offUnlessPressed","Inlay hints are hidden by default and show when holding {0}",bt?"Ctrl+Option":"Ctrl+Alt"),p("editor.inlayHints.off","Inlay hints are disabled")]},"editor.inlayHints.fontSize":{type:"number",default:e.fontSize,markdownDescription:p("inlayHints.fontSize","Controls font size of inlay hints in the editor. As default the {0} is used when the configured value is less than {1} or greater than the editor font size.","`#editor.fontSize#`","`5`")},"editor.inlayHints.fontFamily":{type:"string",default:e.fontFamily,markdownDescription:p("inlayHints.fontFamily","Controls font family of inlay hints in the editor. When set to empty, the {0} is used.","`#editor.fontFamily#`")},"editor.inlayHints.padding":{type:"boolean",default:e.padding,description:p("inlayHints.padding","Enables the padding around the inlay hints in the editor.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return typeof t.enabled=="boolean"&&(t.enabled=t.enabled?"on":"off"),{enabled:Vi(t.enabled,this.defaultValue.enabled,["on","off","offUnlessPressed","onUnlessPressed"]),fontSize:Gt.clampedInt(t.fontSize,this.defaultValue.fontSize,0,100),fontFamily:uo.string(t.fontFamily,this.defaultValue.fontFamily),padding:Te(t.padding,this.defaultValue.padding)}}}class zX extends wi{constructor(){super(65,"lineDecorationsWidth",10)}validate(e){return typeof e=="string"&&/^\d+(\.\d+)?ch$/.test(e)?-parseFloat(e.substring(0,e.length-2)):Gt.clampedInt(e,this.defaultValue,0,1e3)}compute(e,t,i){return i<0?Gt.clampedInt(-i*e.fontInfo.typicalHalfwidthCharacterWidth,this.defaultValue,0,1e3):i}}class UX extends Hr{constructor(){super(66,"lineHeight",vo.lineHeight,e=>Hr.clamp(e,0,150),{markdownDescription:p("lineHeight",`Controls the line height. 
 - Use 0 to automatically compute the line height from the font size.
 - Values between 0 and 8 will be used as a multiplier with the font size.
 - Values greater than or equal to 8 will be used as effective values.`)})}compute(e,t,i){return e.fontInfo.lineHeight}}class $X extends wi{constructor(){const e={enabled:!0,size:"proportional",side:"right",showSlider:"mouseover",autohide:!1,renderCharacters:!0,maxColumn:120,scale:1};super(72,"minimap",e,{"editor.minimap.enabled":{type:"boolean",default:e.enabled,description:p("minimap.enabled","Controls whether the minimap is shown.")},"editor.minimap.autohide":{type:"boolean",default:e.autohide,description:p("minimap.autohide","Controls whether the minimap is hidden automatically.")},"editor.minimap.size":{type:"string",enum:["proportional","fill","fit"],enumDescriptions:[p("minimap.size.proportional","The minimap has the same size as the editor contents (and might scroll)."),p("minimap.size.fill","The minimap will stretch or shrink as necessary to fill the height of the editor (no scrolling)."),p("minimap.size.fit","The minimap will shrink as necessary to never be larger than the editor (no scrolling).")],default:e.size,description:p("minimap.size","Controls the size of the minimap.")},"editor.minimap.side":{type:"string",enum:["left","right"],default:e.side,description:p("minimap.side","Controls the side where to render the minimap.")},"editor.minimap.showSlider":{type:"string",enum:["always","mouseover"],default:e.showSlider,description:p("minimap.showSlider","Controls when the minimap slider is shown.")},"editor.minimap.scale":{type:"number",default:e.scale,minimum:1,maximum:3,enum:[1,2,3],description:p("minimap.scale","Scale of content drawn in the minimap: 1, 2 or 3.")},"editor.minimap.renderCharacters":{type:"boolean",default:e.renderCharacters,description:p("minimap.renderCharacters","Render the actual characters on a line as opposed to color blocks.")},"editor.minimap.maxColumn":{type:"number",default:e.maxColumn,description:p("minimap.maxColumn","Limit the width of the minimap to render at most a certain number of columns.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{enabled:Te(t.enabled,this.defaultValue.enabled),autohide:Te(t.autohide,this.defaultValue.autohide),size:Vi(t.size,this.defaultValue.size,["proportional","fill","fit"]),side:Vi(t.side,this.defaultValue.side,["right","left"]),showSlider:Vi(t.showSlider,this.defaultValue.showSlider,["always","mouseover"]),renderCharacters:Te(t.renderCharacters,this.defaultValue.renderCharacters),scale:Gt.clampedInt(t.scale,1,1,3),maxColumn:Gt.clampedInt(t.maxColumn,this.defaultValue.maxColumn,1,1e4)}}}function jX(s){return s==="ctrlCmd"?bt?"metaKey":"ctrlKey":"altKey"}class KX extends wi{constructor(){super(83,"padding",{top:0,bottom:0},{"editor.padding.top":{type:"number",default:0,minimum:0,maximum:1e3,description:p("padding.top","Controls the amount of space between the top edge of the editor and the first line.")},"editor.padding.bottom":{type:"number",default:0,minimum:0,maximum:1e3,description:p("padding.bottom","Controls the amount of space between the bottom edge of the editor and the last line.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{top:Gt.clampedInt(t.top,0,0,1e3),bottom:Gt.clampedInt(t.bottom,0,0,1e3)}}}class qX extends wi{constructor(){const e={enabled:!0,cycle:!0};super(85,"parameterHints",e,{"editor.parameterHints.enabled":{type:"boolean",default:e.enabled,description:p("parameterHints.enabled","Enables a pop-up that shows parameter documentation and type information as you type.")},"editor.parameterHints.cycle":{type:"boolean",default:e.cycle,description:p("parameterHints.cycle","Controls whether the parameter hints menu cycles or closes when reaching the end of the list.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{enabled:Te(t.enabled,this.defaultValue.enabled),cycle:Te(t.cycle,this.defaultValue.cycle)}}}class GX extends eC{constructor(){super(141)}compute(e,t,i){return e.pixelRatio}}class ZX extends wi{constructor(){const e={other:"on",comments:"off",strings:"off"},t=[{type:"boolean"},{type:"string",enum:["on","inline","off"],enumDescriptions:[p("on","Quick suggestions show inside the suggest widget"),p("inline","Quick suggestions show as ghost text"),p("off","Quick suggestions are disabled")]}];super(88,"quickSuggestions",e,{type:"object",additionalProperties:!1,properties:{strings:{anyOf:t,default:e.strings,description:p("quickSuggestions.strings","Enable quick suggestions inside strings.")},comments:{anyOf:t,default:e.comments,description:p("quickSuggestions.comments","Enable quick suggestions inside comments.")},other:{anyOf:t,default:e.other,description:p("quickSuggestions.other","Enable quick suggestions outside of strings and comments.")}},default:e,markdownDescription:p("quickSuggestions","Controls whether suggestions should automatically show up while typing. This can be controlled for typing in comments, strings, and other code. Quick suggestion can be configured to show as ghost text or with the suggest widget. Also be aware of the '{0}'-setting which controls if suggestions are triggered by special characters.","#editor.suggestOnTriggerCharacters#")}),this.defaultValue=e}validate(e){if(typeof e=="boolean"){const d=e?"on":"off";return{comments:d,strings:d,other:d}}if(!e||typeof e!="object")return this.defaultValue;const{other:t,comments:i,strings:n}=e,o=["on","inline","off"];let r,a,l;return typeof t=="boolean"?r=t?"on":"off":r=Vi(t,this.defaultValue.other,o),typeof i=="boolean"?a=i?"on":"off":a=Vi(i,this.defaultValue.comments,o),typeof n=="boolean"?l=n?"on":"off":l=Vi(n,this.defaultValue.strings,o),{other:r,comments:a,strings:l}}}class YX extends wi{constructor(){super(67,"lineNumbers",{renderType:1,renderFn:null},{type:"string",enum:["off","on","relative","interval"],enumDescriptions:[p("lineNumbers.off","Line numbers are not rendered."),p("lineNumbers.on","Line numbers are rendered as absolute number."),p("lineNumbers.relative","Line numbers are rendered as distance in lines to cursor position."),p("lineNumbers.interval","Line numbers are rendered every 10 lines.")],default:"on",description:p("lineNumbers","Controls the display of line numbers.")})}validate(e){let t=this.defaultValue.renderType,i=this.defaultValue.renderFn;return typeof e<"u"&&(typeof e=="function"?(t=4,i=e):e==="interval"?t=3:e==="relative"?t=2:e==="on"?t=1:t=0),{renderType:t,renderFn:i}}}function LS(s){const e=s.get(97);return e==="editable"?s.get(90):e!=="on"}class XX extends wi{constructor(){const e=[],t={type:"number",description:p("rulers.size","Number of monospace characters at which this editor ruler will render.")};super(101,"rulers",e,{type:"array",items:{anyOf:[t,{type:["object"],properties:{column:t,color:{type:"string",description:p("rulers.color","Color of this editor ruler."),format:"color-hex"}}}]},default:e,description:p("rulers","Render vertical rulers after a certain number of monospace characters. Use multiple values for multiple rulers. No rulers are drawn if array is empty.")})}validate(e){if(Array.isArray(e)){const t=[];for(const i of e)if(typeof i=="number")t.push({column:Gt.clampedInt(i,0,0,1e4),color:null});else if(i&&typeof i=="object"){const n=i;t.push({column:Gt.clampedInt(n.column,0,0,1e4),color:n.color})}return t.sort((i,n)=>i.column-n.column),t}return this.defaultValue}}class QX extends wi{constructor(){super(91,"readOnlyMessage",void 0)}validate(e){return!e||typeof e!="object"?this.defaultValue:e}}function e5(s,e){if(typeof s!="string")return e;switch(s){case"hidden":return 2;case"visible":return 3;default:return 1}}let JX=class extends wi{constructor(){const e={vertical:1,horizontal:1,arrowSize:11,useShadows:!0,verticalHasArrows:!1,horizontalHasArrows:!1,horizontalScrollbarSize:12,horizontalSliderSize:12,verticalScrollbarSize:14,verticalSliderSize:14,handleMouseWheel:!0,alwaysConsumeMouseWheel:!0,scrollByPage:!1,ignoreHorizontalScrollbarInContentHeight:!1};super(102,"scrollbar",e,{"editor.scrollbar.vertical":{type:"string",enum:["auto","visible","hidden"],enumDescriptions:[p("scrollbar.vertical.auto","The vertical scrollbar will be visible only when necessary."),p("scrollbar.vertical.visible","The vertical scrollbar will always be visible."),p("scrollbar.vertical.fit","The vertical scrollbar will always be hidden.")],default:"auto",description:p("scrollbar.vertical","Controls the visibility of the vertical scrollbar.")},"editor.scrollbar.horizontal":{type:"string",enum:["auto","visible","hidden"],enumDescriptions:[p("scrollbar.horizontal.auto","The horizontal scrollbar will be visible only when necessary."),p("scrollbar.horizontal.visible","The horizontal scrollbar will always be visible."),p("scrollbar.horizontal.fit","The horizontal scrollbar will always be hidden.")],default:"auto",description:p("scrollbar.horizontal","Controls the visibility of the horizontal scrollbar.")},"editor.scrollbar.verticalScrollbarSize":{type:"number",default:e.verticalScrollbarSize,description:p("scrollbar.verticalScrollbarSize","The width of the vertical scrollbar.")},"editor.scrollbar.horizontalScrollbarSize":{type:"number",default:e.horizontalScrollbarSize,description:p("scrollbar.horizontalScrollbarSize","The height of the horizontal scrollbar.")},"editor.scrollbar.scrollByPage":{type:"boolean",default:e.scrollByPage,description:p("scrollbar.scrollByPage","Controls whether clicks scroll by page or jump to click position.")},"editor.scrollbar.ignoreHorizontalScrollbarInContentHeight":{type:"boolean",default:e.ignoreHorizontalScrollbarInContentHeight,description:p("scrollbar.ignoreHorizontalScrollbarInContentHeight","When set, the horizontal scrollbar will not increase the size of the editor's content.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e,i=Gt.clampedInt(t.horizontalScrollbarSize,this.defaultValue.horizontalScrollbarSize,0,1e3),n=Gt.clampedInt(t.verticalScrollbarSize,this.defaultValue.verticalScrollbarSize,0,1e3);return{arrowSize:Gt.clampedInt(t.arrowSize,this.defaultValue.arrowSize,0,1e3),vertical:e5(t.vertical,this.defaultValue.vertical),horizontal:e5(t.horizontal,this.defaultValue.horizontal),useShadows:Te(t.useShadows,this.defaultValue.useShadows),verticalHasArrows:Te(t.verticalHasArrows,this.defaultValue.verticalHasArrows),horizontalHasArrows:Te(t.horizontalHasArrows,this.defaultValue.horizontalHasArrows),handleMouseWheel:Te(t.handleMouseWheel,this.defaultValue.handleMouseWheel),alwaysConsumeMouseWheel:Te(t.alwaysConsumeMouseWheel,this.defaultValue.alwaysConsumeMouseWheel),horizontalScrollbarSize:i,horizontalSliderSize:Gt.clampedInt(t.horizontalSliderSize,i,0,1e3),verticalScrollbarSize:n,verticalSliderSize:Gt.clampedInt(t.verticalSliderSize,n,0,1e3),scrollByPage:Te(t.scrollByPage,this.defaultValue.scrollByPage),ignoreHorizontalScrollbarInContentHeight:Te(t.ignoreHorizontalScrollbarInContentHeight,this.defaultValue.ignoreHorizontalScrollbarInContentHeight)}}};const Oo="inUntrustedWorkspace",qs={allowedCharacters:"editor.unicodeHighlight.allowedCharacters",invisibleCharacters:"editor.unicodeHighlight.invisibleCharacters",nonBasicASCII:"editor.unicodeHighlight.nonBasicASCII",ambiguousCharacters:"editor.unicodeHighlight.ambiguousCharacters",includeComments:"editor.unicodeHighlight.includeComments",includeStrings:"editor.unicodeHighlight.includeStrings",allowedLocales:"editor.unicodeHighlight.allowedLocales"};class eQ extends wi{constructor(){const e={nonBasicASCII:Oo,invisibleCharacters:!0,ambiguousCharacters:!0,includeComments:Oo,includeStrings:!0,allowedCharacters:{},allowedLocales:{_os:!0,_vscode:!0}};super(124,"unicodeHighlight",e,{[qs.nonBasicASCII]:{restricted:!0,type:["boolean","string"],enum:[!0,!1,Oo],default:e.nonBasicASCII,description:p("unicodeHighlight.nonBasicASCII","Controls whether all non-basic ASCII characters are highlighted. Only characters between U+0020 and U+007E, tab, line-feed and carriage-return are considered basic ASCII.")},[qs.invisibleCharacters]:{restricted:!0,type:"boolean",default:e.invisibleCharacters,description:p("unicodeHighlight.invisibleCharacters","Controls whether characters that just reserve space or have no width at all are highlighted.")},[qs.ambiguousCharacters]:{restricted:!0,type:"boolean",default:e.ambiguousCharacters,description:p("unicodeHighlight.ambiguousCharacters","Controls whether characters are highlighted that can be confused with basic ASCII characters, except those that are common in the current user locale.")},[qs.includeComments]:{restricted:!0,type:["boolean","string"],enum:[!0,!1,Oo],default:e.includeComments,description:p("unicodeHighlight.includeComments","Controls whether characters in comments should also be subject to Unicode highlighting.")},[qs.includeStrings]:{restricted:!0,type:["boolean","string"],enum:[!0,!1,Oo],default:e.includeStrings,description:p("unicodeHighlight.includeStrings","Controls whether characters in strings should also be subject to Unicode highlighting.")},[qs.allowedCharacters]:{restricted:!0,type:"object",default:e.allowedCharacters,description:p("unicodeHighlight.allowedCharacters","Defines allowed characters that are not being highlighted."),additionalProperties:{type:"boolean"}},[qs.allowedLocales]:{restricted:!0,type:"object",additionalProperties:{type:"boolean"},default:e.allowedLocales,description:p("unicodeHighlight.allowedLocales","Unicode characters that are common in allowed locales are not being highlighted.")}})}applyUpdate(e,t){let i=!1;t.allowedCharacters&&e&&(Qo(e.allowedCharacters,t.allowedCharacters)||(e={...e,allowedCharacters:t.allowedCharacters},i=!0)),t.allowedLocales&&e&&(Qo(e.allowedLocales,t.allowedLocales)||(e={...e,allowedLocales:t.allowedLocales},i=!0));const n=super.applyUpdate(e,t);return i?new Tv(n.newValue,!0):n}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{nonBasicASCII:Tp(t.nonBasicASCII,Oo,[!0,!1,Oo]),invisibleCharacters:Te(t.invisibleCharacters,this.defaultValue.invisibleCharacters),ambiguousCharacters:Te(t.ambiguousCharacters,this.defaultValue.ambiguousCharacters),includeComments:Tp(t.includeComments,Oo,[!0,!1,Oo]),includeStrings:Tp(t.includeStrings,Oo,[!0,!1,Oo]),allowedCharacters:this.validateBooleanMap(e.allowedCharacters,this.defaultValue.allowedCharacters),allowedLocales:this.validateBooleanMap(e.allowedLocales,this.defaultValue.allowedLocales)}}validateBooleanMap(e,t){if(typeof e!="object"||!e)return t;const i={};for(const[n,o]of Object.entries(e))o===!0&&(i[n]=!0);return i}}class tQ extends wi{constructor(){const e={enabled:!0,mode:"subwordSmart",showToolbar:"onHover",suppressSuggestions:!1,keepOnBlur:!1};super(62,"inlineSuggest",e,{"editor.inlineSuggest.enabled":{type:"boolean",default:e.enabled,description:p("inlineSuggest.enabled","Controls whether to automatically show inline suggestions in the editor.")},"editor.inlineSuggest.showToolbar":{type:"string",default:e.showToolbar,enum:["always","onHover","never"],enumDescriptions:[p("inlineSuggest.showToolbar.always","Show the inline suggestion toolbar whenever an inline suggestion is shown."),p("inlineSuggest.showToolbar.onHover","Show the inline suggestion toolbar when hovering over an inline suggestion."),p("inlineSuggest.showToolbar.never","Never show the inline suggestion toolbar.")],description:p("inlineSuggest.showToolbar","Controls when to show the inline suggestion toolbar.")},"editor.inlineSuggest.suppressSuggestions":{type:"boolean",default:e.suppressSuggestions,description:p("inlineSuggest.suppressSuggestions","Controls how inline suggestions interact with the suggest widget. If enabled, the suggest widget is not shown automatically when inline suggestions are available.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{enabled:Te(t.enabled,this.defaultValue.enabled),mode:Vi(t.mode,this.defaultValue.mode,["prefix","subword","subwordSmart"]),showToolbar:Vi(t.showToolbar,this.defaultValue.showToolbar,["always","onHover","never"]),suppressSuggestions:Te(t.suppressSuggestions,this.defaultValue.suppressSuggestions),keepOnBlur:Te(t.keepOnBlur,this.defaultValue.keepOnBlur)}}}class iQ extends wi{constructor(){const e={enabled:os.bracketPairColorizationOptions.enabled,independentColorPoolPerBracketType:os.bracketPairColorizationOptions.independentColorPoolPerBracketType};super(15,"bracketPairColorization",e,{"editor.bracketPairColorization.enabled":{type:"boolean",default:e.enabled,markdownDescription:p("bracketPairColorization.enabled","Controls whether bracket pair colorization is enabled or not. Use {0} to override the bracket highlight colors.","`#workbench.colorCustomizations#`")},"editor.bracketPairColorization.independentColorPoolPerBracketType":{type:"boolean",default:e.independentColorPoolPerBracketType,description:p("bracketPairColorization.independentColorPoolPerBracketType","Controls whether each bracket type has its own independent color pool.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{enabled:Te(t.enabled,this.defaultValue.enabled),independentColorPoolPerBracketType:Te(t.independentColorPoolPerBracketType,this.defaultValue.independentColorPoolPerBracketType)}}}class nQ extends wi{constructor(){const e={bracketPairs:!1,bracketPairsHorizontal:"active",highlightActiveBracketPair:!0,indentation:!0,highlightActiveIndentation:!0};super(16,"guides",e,{"editor.guides.bracketPairs":{type:["boolean","string"],enum:[!0,"active",!1],enumDescriptions:[p("editor.guides.bracketPairs.true","Enables bracket pair guides."),p("editor.guides.bracketPairs.active","Enables bracket pair guides only for the active bracket pair."),p("editor.guides.bracketPairs.false","Disables bracket pair guides.")],default:e.bracketPairs,description:p("editor.guides.bracketPairs","Controls whether bracket pair guides are enabled or not.")},"editor.guides.bracketPairsHorizontal":{type:["boolean","string"],enum:[!0,"active",!1],enumDescriptions:[p("editor.guides.bracketPairsHorizontal.true","Enables horizontal guides as addition to vertical bracket pair guides."),p("editor.guides.bracketPairsHorizontal.active","Enables horizontal guides only for the active bracket pair."),p("editor.guides.bracketPairsHorizontal.false","Disables horizontal bracket pair guides.")],default:e.bracketPairsHorizontal,description:p("editor.guides.bracketPairsHorizontal","Controls whether horizontal bracket pair guides are enabled or not.")},"editor.guides.highlightActiveBracketPair":{type:"boolean",default:e.highlightActiveBracketPair,description:p("editor.guides.highlightActiveBracketPair","Controls whether the editor should highlight the active bracket pair.")},"editor.guides.indentation":{type:"boolean",default:e.indentation,description:p("editor.guides.indentation","Controls whether the editor should render indent guides.")},"editor.guides.highlightActiveIndentation":{type:["boolean","string"],enum:[!0,"always",!1],enumDescriptions:[p("editor.guides.highlightActiveIndentation.true","Highlights the active indent guide."),p("editor.guides.highlightActiveIndentation.always","Highlights the active indent guide even if bracket guides are highlighted."),p("editor.guides.highlightActiveIndentation.false","Do not highlight the active indent guide.")],default:e.highlightActiveIndentation,description:p("editor.guides.highlightActiveIndentation","Controls whether the editor should highlight the active indent guide.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{bracketPairs:Tp(t.bracketPairs,this.defaultValue.bracketPairs,[!0,!1,"active"]),bracketPairsHorizontal:Tp(t.bracketPairsHorizontal,this.defaultValue.bracketPairsHorizontal,[!0,!1,"active"]),highlightActiveBracketPair:Te(t.highlightActiveBracketPair,this.defaultValue.highlightActiveBracketPair),indentation:Te(t.indentation,this.defaultValue.indentation),highlightActiveIndentation:Tp(t.highlightActiveIndentation,this.defaultValue.highlightActiveIndentation,[!0,!1,"always"])}}}function Tp(s,e,t){const i=t.indexOf(s);return i===-1?e:t[i]}class sQ extends wi{constructor(){const e={insertMode:"insert",filterGraceful:!0,snippetsPreventQuickSuggestions:!1,localityBonus:!1,shareSuggestSelections:!1,selectionMode:"always",showIcons:!0,showStatusBar:!1,preview:!1,previewMode:"subwordSmart",showInlineDetails:!0,showMethods:!0,showFunctions:!0,showConstructors:!0,showDeprecated:!0,matchOnWordStartOnly:!0,showFields:!0,showVariables:!0,showClasses:!0,showStructs:!0,showInterfaces:!0,showModules:!0,showProperties:!0,showEvents:!0,showOperators:!0,showUnits:!0,showValues:!0,showConstants:!0,showEnums:!0,showEnumMembers:!0,showKeywords:!0,showWords:!0,showColors:!0,showFiles:!0,showReferences:!0,showFolders:!0,showTypeParameters:!0,showSnippets:!0,showUsers:!0,showIssues:!0};super(117,"suggest",e,{"editor.suggest.insertMode":{type:"string",enum:["insert","replace"],enumDescriptions:[p("suggest.insertMode.insert","Insert suggestion without overwriting text right of the cursor."),p("suggest.insertMode.replace","Insert suggestion and overwrite text right of the cursor.")],default:e.insertMode,description:p("suggest.insertMode","Controls whether words are overwritten when accepting completions. Note that this depends on extensions opting into this feature.")},"editor.suggest.filterGraceful":{type:"boolean",default:e.filterGraceful,description:p("suggest.filterGraceful","Controls whether filtering and sorting suggestions accounts for small typos.")},"editor.suggest.localityBonus":{type:"boolean",default:e.localityBonus,description:p("suggest.localityBonus","Controls whether sorting favors words that appear close to the cursor.")},"editor.suggest.shareSuggestSelections":{type:"boolean",default:e.shareSuggestSelections,markdownDescription:p("suggest.shareSuggestSelections","Controls whether remembered suggestion selections are shared between multiple workspaces and windows (needs `#editor.suggestSelection#`).")},"editor.suggest.selectionMode":{type:"string",enum:["always","never","whenTriggerCharacter","whenQuickSuggestion"],enumDescriptions:[p("suggest.insertMode.always","Always select a suggestion when automatically triggering IntelliSense."),p("suggest.insertMode.never","Never select a suggestion when automatically triggering IntelliSense."),p("suggest.insertMode.whenTriggerCharacter","Select a suggestion only when triggering IntelliSense from a trigger character."),p("suggest.insertMode.whenQuickSuggestion","Select a suggestion only when triggering IntelliSense as you type.")],default:e.selectionMode,markdownDescription:p("suggest.selectionMode","Controls whether a suggestion is selected when the widget shows. Note that this only applies to automatically triggered suggestions (`#editor.quickSuggestions#` and `#editor.suggestOnTriggerCharacters#`) and that a suggestion is always selected when explicitly invoked, e.g via `Ctrl+Space`.")},"editor.suggest.snippetsPreventQuickSuggestions":{type:"boolean",default:e.snippetsPreventQuickSuggestions,description:p("suggest.snippetsPreventQuickSuggestions","Controls whether an active snippet prevents quick suggestions.")},"editor.suggest.showIcons":{type:"boolean",default:e.showIcons,description:p("suggest.showIcons","Controls whether to show or hide icons in suggestions.")},"editor.suggest.showStatusBar":{type:"boolean",default:e.showStatusBar,description:p("suggest.showStatusBar","Controls the visibility of the status bar at the bottom of the suggest widget.")},"editor.suggest.preview":{type:"boolean",default:e.preview,description:p("suggest.preview","Controls whether to preview the suggestion outcome in the editor.")},"editor.suggest.showInlineDetails":{type:"boolean",default:e.showInlineDetails,description:p("suggest.showInlineDetails","Controls whether suggest details show inline with the label or only in the details widget.")},"editor.suggest.maxVisibleSuggestions":{type:"number",deprecationMessage:p("suggest.maxVisibleSuggestions.dep","This setting is deprecated. The suggest widget can now be resized.")},"editor.suggest.filteredTypes":{type:"object",deprecationMessage:p("deprecated","This setting is deprecated, please use separate settings like 'editor.suggest.showKeywords' or 'editor.suggest.showSnippets' instead.")},"editor.suggest.showMethods":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showMethods","When enabled IntelliSense shows `method`-suggestions.")},"editor.suggest.showFunctions":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showFunctions","When enabled IntelliSense shows `function`-suggestions.")},"editor.suggest.showConstructors":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showConstructors","When enabled IntelliSense shows `constructor`-suggestions.")},"editor.suggest.showDeprecated":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showDeprecated","When enabled IntelliSense shows `deprecated`-suggestions.")},"editor.suggest.matchOnWordStartOnly":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.matchOnWordStartOnly","When enabled IntelliSense filtering requires that the first character matches on a word start. For example, `c` on `Console` or `WebContext` but _not_ on `description`. When disabled IntelliSense will show more results but still sorts them by match quality.")},"editor.suggest.showFields":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showFields","When enabled IntelliSense shows `field`-suggestions.")},"editor.suggest.showVariables":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showVariables","When enabled IntelliSense shows `variable`-suggestions.")},"editor.suggest.showClasses":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showClasss","When enabled IntelliSense shows `class`-suggestions.")},"editor.suggest.showStructs":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showStructs","When enabled IntelliSense shows `struct`-suggestions.")},"editor.suggest.showInterfaces":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showInterfaces","When enabled IntelliSense shows `interface`-suggestions.")},"editor.suggest.showModules":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showModules","When enabled IntelliSense shows `module`-suggestions.")},"editor.suggest.showProperties":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showPropertys","When enabled IntelliSense shows `property`-suggestions.")},"editor.suggest.showEvents":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showEvents","When enabled IntelliSense shows `event`-suggestions.")},"editor.suggest.showOperators":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showOperators","When enabled IntelliSense shows `operator`-suggestions.")},"editor.suggest.showUnits":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showUnits","When enabled IntelliSense shows `unit`-suggestions.")},"editor.suggest.showValues":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showValues","When enabled IntelliSense shows `value`-suggestions.")},"editor.suggest.showConstants":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showConstants","When enabled IntelliSense shows `constant`-suggestions.")},"editor.suggest.showEnums":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showEnums","When enabled IntelliSense shows `enum`-suggestions.")},"editor.suggest.showEnumMembers":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showEnumMembers","When enabled IntelliSense shows `enumMember`-suggestions.")},"editor.suggest.showKeywords":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showKeywords","When enabled IntelliSense shows `keyword`-suggestions.")},"editor.suggest.showWords":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showTexts","When enabled IntelliSense shows `text`-suggestions.")},"editor.suggest.showColors":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showColors","When enabled IntelliSense shows `color`-suggestions.")},"editor.suggest.showFiles":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showFiles","When enabled IntelliSense shows `file`-suggestions.")},"editor.suggest.showReferences":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showReferences","When enabled IntelliSense shows `reference`-suggestions.")},"editor.suggest.showCustomcolors":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showCustomcolors","When enabled IntelliSense shows `customcolor`-suggestions.")},"editor.suggest.showFolders":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showFolders","When enabled IntelliSense shows `folder`-suggestions.")},"editor.suggest.showTypeParameters":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showTypeParameters","When enabled IntelliSense shows `typeParameter`-suggestions.")},"editor.suggest.showSnippets":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showSnippets","When enabled IntelliSense shows `snippet`-suggestions.")},"editor.suggest.showUsers":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showUsers","When enabled IntelliSense shows `user`-suggestions.")},"editor.suggest.showIssues":{type:"boolean",default:!0,markdownDescription:p("editor.suggest.showIssues","When enabled IntelliSense shows `issues`-suggestions.")}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{insertMode:Vi(t.insertMode,this.defaultValue.insertMode,["insert","replace"]),filterGraceful:Te(t.filterGraceful,this.defaultValue.filterGraceful),snippetsPreventQuickSuggestions:Te(t.snippetsPreventQuickSuggestions,this.defaultValue.filterGraceful),localityBonus:Te(t.localityBonus,this.defaultValue.localityBonus),shareSuggestSelections:Te(t.shareSuggestSelections,this.defaultValue.shareSuggestSelections),selectionMode:Vi(t.selectionMode,this.defaultValue.selectionMode,["always","never","whenQuickSuggestion","whenTriggerCharacter"]),showIcons:Te(t.showIcons,this.defaultValue.showIcons),showStatusBar:Te(t.showStatusBar,this.defaultValue.showStatusBar),preview:Te(t.preview,this.defaultValue.preview),previewMode:Vi(t.previewMode,this.defaultValue.previewMode,["prefix","subword","subwordSmart"]),showInlineDetails:Te(t.showInlineDetails,this.defaultValue.showInlineDetails),showMethods:Te(t.showMethods,this.defaultValue.showMethods),showFunctions:Te(t.showFunctions,this.defaultValue.showFunctions),showConstructors:Te(t.showConstructors,this.defaultValue.showConstructors),showDeprecated:Te(t.showDeprecated,this.defaultValue.showDeprecated),matchOnWordStartOnly:Te(t.matchOnWordStartOnly,this.defaultValue.matchOnWordStartOnly),showFields:Te(t.showFields,this.defaultValue.showFields),showVariables:Te(t.showVariables,this.defaultValue.showVariables),showClasses:Te(t.showClasses,this.defaultValue.showClasses),showStructs:Te(t.showStructs,this.defaultValue.showStructs),showInterfaces:Te(t.showInterfaces,this.defaultValue.showInterfaces),showModules:Te(t.showModules,this.defaultValue.showModules),showProperties:Te(t.showProperties,this.defaultValue.showProperties),showEvents:Te(t.showEvents,this.defaultValue.showEvents),showOperators:Te(t.showOperators,this.defaultValue.showOperators),showUnits:Te(t.showUnits,this.defaultValue.showUnits),showValues:Te(t.showValues,this.defaultValue.showValues),showConstants:Te(t.showConstants,this.defaultValue.showConstants),showEnums:Te(t.showEnums,this.defaultValue.showEnums),showEnumMembers:Te(t.showEnumMembers,this.defaultValue.showEnumMembers),showKeywords:Te(t.showKeywords,this.defaultValue.showKeywords),showWords:Te(t.showWords,this.defaultValue.showWords),showColors:Te(t.showColors,this.defaultValue.showColors),showFiles:Te(t.showFiles,this.defaultValue.showFiles),showReferences:Te(t.showReferences,this.defaultValue.showReferences),showFolders:Te(t.showFolders,this.defaultValue.showFolders),showTypeParameters:Te(t.showTypeParameters,this.defaultValue.showTypeParameters),showSnippets:Te(t.showSnippets,this.defaultValue.showSnippets),showUsers:Te(t.showUsers,this.defaultValue.showUsers),showIssues:Te(t.showIssues,this.defaultValue.showIssues)}}}class oQ extends wi{constructor(){super(112,"smartSelect",{selectLeadingAndTrailingWhitespace:!0,selectSubwords:!0},{"editor.smartSelect.selectLeadingAndTrailingWhitespace":{description:p("selectLeadingAndTrailingWhitespace","Whether leading and trailing whitespace should always be selected."),default:!0,type:"boolean"},"editor.smartSelect.selectSubwords":{description:p("selectSubwords","Whether subwords (like 'foo' in 'fooBar' or 'foo_bar') should be selected."),default:!0,type:"boolean"}})}validate(e){return!e||typeof e!="object"?this.defaultValue:{selectLeadingAndTrailingWhitespace:Te(e.selectLeadingAndTrailingWhitespace,this.defaultValue.selectLeadingAndTrailingWhitespace),selectSubwords:Te(e.selectSubwords,this.defaultValue.selectSubwords)}}}class rQ extends wi{constructor(){super(136,"wrappingIndent",1,{"editor.wrappingIndent":{type:"string",enum:["none","same","indent","deepIndent"],enumDescriptions:[p("wrappingIndent.none","No indentation. Wrapped lines begin at column 1."),p("wrappingIndent.same","Wrapped lines get the same indentation as the parent."),p("wrappingIndent.indent","Wrapped lines get +1 indentation toward the parent."),p("wrappingIndent.deepIndent","Wrapped lines get +2 indentation toward the parent.")],description:p("wrappingIndent","Controls the indentation of wrapped lines."),default:"same"}})}validate(e){switch(e){case"none":return 0;case"same":return 1;case"indent":return 2;case"deepIndent":return 3}return 1}compute(e,t,i){return t.get(2)===2?0:i}}class aQ extends eC{constructor(){super(144)}compute(e,t,i){const n=t.get(143);return{isDominatedByLongLines:e.isDominatedByLongLines,isWordWrapMinified:n.isWordWrapMinified,isViewportWrapping:n.isViewportWrapping,wrappingColumn:n.wrappingColumn}}}class lQ extends wi{constructor(){const e={enabled:!0,showDropSelector:"afterDrop"};super(36,"dropIntoEditor",e,{"editor.dropIntoEditor.enabled":{type:"boolean",default:e.enabled,markdownDescription:p("dropIntoEditor.enabled","Controls whether you can drag and drop a file into a text editor by holding down `Shift`-key (instead of opening the file in an editor).")},"editor.dropIntoEditor.showDropSelector":{type:"string",markdownDescription:p("dropIntoEditor.showDropSelector","Controls if a widget is shown when dropping files into the editor. This widget lets you control how the file is dropped."),enum:["afterDrop","never"],enumDescriptions:[p("dropIntoEditor.showDropSelector.afterDrop","Show the drop selector widget after a file is dropped into the editor."),p("dropIntoEditor.showDropSelector.never","Never show the drop selector widget. Instead the default drop provider is always used.")],default:"afterDrop"}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{enabled:Te(t.enabled,this.defaultValue.enabled),showDropSelector:Vi(t.showDropSelector,this.defaultValue.showDropSelector,["afterDrop","never"])}}}class dQ extends wi{constructor(){const e={enabled:!0,showPasteSelector:"afterPaste"};super(84,"pasteAs",e,{"editor.pasteAs.enabled":{type:"boolean",default:e.enabled,markdownDescription:p("pasteAs.enabled","Controls whether you can paste content in different ways.")},"editor.pasteAs.showPasteSelector":{type:"string",markdownDescription:p("pasteAs.showPasteSelector","Controls if a widget is shown when pasting content in to the editor. This widget lets you control how the file is pasted."),enum:["afterPaste","never"],enumDescriptions:[p("pasteAs.showPasteSelector.afterPaste","Show the paste selector widget after content is pasted into the editor."),p("pasteAs.showPasteSelector.never","Never show the paste selector widget. Instead the default pasting behavior is always used.")],default:"afterPaste"}})}validate(e){if(!e||typeof e!="object")return this.defaultValue;const t=e;return{enabled:Te(t.enabled,this.defaultValue.enabled),showPasteSelector:Vi(t.showPasteSelector,this.defaultValue.showPasteSelector,["afterPaste","never"])}}}const cQ="Consolas, 'Courier New', monospace",uQ="Menlo, Monaco, 'Courier New', monospace",hQ="'Droid Sans Mono', 'monospace', monospace",vo={fontFamily:bt?uQ:Ss?hQ:cQ,fontWeight:"normal",fontSize:bt?12:14,lineHeight:0,letterSpacing:0},ip=[];function oe(s){return ip[s.id]=s,s}const ja={acceptSuggestionOnCommitCharacter:oe(new St(0,"acceptSuggestionOnCommitCharacter",!0,{markdownDescription:p("acceptSuggestionOnCommitCharacter","Controls whether suggestions should be accepted on commit characters. For example, in JavaScript, the semi-colon (`;`) can be a commit character that accepts a suggestion and types that character.")})),acceptSuggestionOnEnter:oe(new yi(1,"acceptSuggestionOnEnter","on",["on","smart","off"],{markdownEnumDescriptions:["",p("acceptSuggestionOnEnterSmart","Only accept a suggestion with `Enter` when it makes a textual change."),""],markdownDescription:p("acceptSuggestionOnEnter","Controls whether suggestions should be accepted on `Enter`, in addition to `Tab`. Helps to avoid ambiguity between inserting new lines or accepting suggestions.")})),accessibilitySupport:oe(new kX),accessibilityPageSize:oe(new Gt(3,"accessibilityPageSize",10,1,1073741824,{description:p("accessibilityPageSize","Controls the number of lines in the editor that can be read out by a screen reader at once. When we detect a screen reader we automatically set the default to be 500. Warning: this has a performance implication for numbers larger than the default."),tags:["accessibility"]})),ariaLabel:oe(new uo(4,"ariaLabel",p("editorViewAccessibleLabel","Editor content"))),ariaRequired:oe(new St(5,"ariaRequired",!1,void 0)),screenReaderAnnounceInlineSuggestion:oe(new St(8,"screenReaderAnnounceInlineSuggestion",!0,{description:p("screenReaderAnnounceInlineSuggestion","Control whether inline suggestions are announced by a screen reader."),tags:["accessibility"]})),autoClosingBrackets:oe(new yi(6,"autoClosingBrackets","languageDefined",["always","languageDefined","beforeWhitespace","never"],{enumDescriptions:["",p("editor.autoClosingBrackets.languageDefined","Use language configurations to determine when to autoclose brackets."),p("editor.autoClosingBrackets.beforeWhitespace","Autoclose brackets only when the cursor is to the left of whitespace."),""],description:p("autoClosingBrackets","Controls whether the editor should automatically close brackets after the user adds an opening bracket.")})),autoClosingComments:oe(new yi(7,"autoClosingComments","languageDefined",["always","languageDefined","beforeWhitespace","never"],{enumDescriptions:["",p("editor.autoClosingComments.languageDefined","Use language configurations to determine when to autoclose comments."),p("editor.autoClosingComments.beforeWhitespace","Autoclose comments only when the cursor is to the left of whitespace."),""],description:p("autoClosingComments","Controls whether the editor should automatically close comments after the user adds an opening comment.")})),autoClosingDelete:oe(new yi(9,"autoClosingDelete","auto",["always","auto","never"],{enumDescriptions:["",p("editor.autoClosingDelete.auto","Remove adjacent closing quotes or brackets only if they were automatically inserted."),""],description:p("autoClosingDelete","Controls whether the editor should remove adjacent closing quotes or brackets when deleting.")})),autoClosingOvertype:oe(new yi(10,"autoClosingOvertype","auto",["always","auto","never"],{enumDescriptions:["",p("editor.autoClosingOvertype.auto","Type over closing quotes or brackets only if they were automatically inserted."),""],description:p("autoClosingOvertype","Controls whether the editor should type over closing quotes or brackets.")})),autoClosingQuotes:oe(new yi(11,"autoClosingQuotes","languageDefined",["always","languageDefined","beforeWhitespace","never"],{enumDescriptions:["",p("editor.autoClosingQuotes.languageDefined","Use language configurations to determine when to autoclose quotes."),p("editor.autoClosingQuotes.beforeWhitespace","Autoclose quotes only when the cursor is to the left of whitespace."),""],description:p("autoClosingQuotes","Controls whether the editor should automatically close quotes after the user adds an opening quote.")})),autoIndent:oe(new n1(12,"autoIndent",4,"full",["none","keep","brackets","advanced","full"],DX,{enumDescriptions:[p("editor.autoIndent.none","The editor will not insert indentation automatically."),p("editor.autoIndent.keep","The editor will keep the current line's indentation."),p("editor.autoIndent.brackets","The editor will keep the current line's indentation and honor language defined brackets."),p("editor.autoIndent.advanced","The editor will keep the current line's indentation, honor language defined brackets and invoke special onEnterRules defined by languages."),p("editor.autoIndent.full","The editor will keep the current line's indentation, honor language defined brackets, invoke special onEnterRules defined by languages, and honor indentationRules defined by languages.")],description:p("autoIndent","Controls whether the editor should automatically adjust the indentation when users type, paste, move or indent lines.")})),automaticLayout:oe(new St(13,"automaticLayout",!1)),autoSurround:oe(new yi(14,"autoSurround","languageDefined",["languageDefined","quotes","brackets","never"],{enumDescriptions:[p("editor.autoSurround.languageDefined","Use language configurations to determine when to automatically surround selections."),p("editor.autoSurround.quotes","Surround with quotes but not brackets."),p("editor.autoSurround.brackets","Surround with brackets but not quotes."),""],description:p("autoSurround","Controls whether the editor should automatically surround selections when typing quotes or brackets.")})),bracketPairColorization:oe(new iQ),bracketPairGuides:oe(new nQ),stickyTabStops:oe(new St(115,"stickyTabStops",!1,{description:p("stickyTabStops","Emulate selection behavior of tab characters when using spaces for indentation. Selection will stick to tab stops.")})),codeLens:oe(new St(17,"codeLens",!0,{description:p("codeLens","Controls whether the editor shows CodeLens.")})),codeLensFontFamily:oe(new uo(18,"codeLensFontFamily","",{description:p("codeLensFontFamily","Controls the font family for CodeLens.")})),codeLensFontSize:oe(new Gt(19,"codeLensFontSize",0,0,100,{type:"number",default:0,minimum:0,maximum:100,markdownDescription:p("codeLensFontSize","Controls the font size in pixels for CodeLens. When set to 0, 90% of `#editor.fontSize#` is used.")})),colorDecorators:oe(new St(20,"colorDecorators",!0,{description:p("colorDecorators","Controls whether the editor should render the inline color decorators and color picker.")})),colorDecoratorActivatedOn:oe(new yi(146,"colorDecoratorsActivatedOn","clickAndHover",["clickAndHover","hover","click"],{enumDescriptions:[p("editor.colorDecoratorActivatedOn.clickAndHover","Make the color picker appear both on click and hover of the color decorator"),p("editor.colorDecoratorActivatedOn.hover","Make the color picker appear on hover of the color decorator"),p("editor.colorDecoratorActivatedOn.click","Make the color picker appear on click of the color decorator")],description:p("colorDecoratorActivatedOn","Controls the condition to make a color picker appear from a color decorator")})),colorDecoratorsLimit:oe(new Gt(21,"colorDecoratorsLimit",500,1,1e6,{markdownDescription:p("colorDecoratorsLimit","Controls the max number of color decorators that can be rendered in an editor at once.")})),columnSelection:oe(new St(22,"columnSelection",!1,{description:p("columnSelection","Enable that the selection with the mouse and keys is doing column selection.")})),comments:oe(new IX),contextmenu:oe(new St(24,"contextmenu",!0)),copyWithSyntaxHighlighting:oe(new St(25,"copyWithSyntaxHighlighting",!0,{description:p("copyWithSyntaxHighlighting","Controls whether syntax highlighting should be copied into the clipboard.")})),cursorBlinking:oe(new n1(26,"cursorBlinking",1,"blink",["blink","smooth","phase","expand","solid"],EX,{description:p("cursorBlinking","Control the cursor animation style.")})),cursorSmoothCaretAnimation:oe(new yi(27,"cursorSmoothCaretAnimation","off",["off","explicit","on"],{enumDescriptions:[p("cursorSmoothCaretAnimation.off","Smooth caret animation is disabled."),p("cursorSmoothCaretAnimation.explicit","Smooth caret animation is enabled only when the user moves the cursor with an explicit gesture."),p("cursorSmoothCaretAnimation.on","Smooth caret animation is always enabled.")],description:p("cursorSmoothCaretAnimation","Controls whether the smooth caret animation should be enabled.")})),cursorStyle:oe(new n1(28,"cursorStyle",Fn.Line,"line",["line","block","underline","line-thin","block-outline","underline-thin"],NX,{description:p("cursorStyle","Controls the cursor style.")})),cursorSurroundingLines:oe(new Gt(29,"cursorSurroundingLines",0,0,1073741824,{description:p("cursorSurroundingLines","Controls the minimal number of visible leading lines (minimum 0) and trailing lines (minimum 1) surrounding the cursor. Known as 'scrollOff' or 'scrollOffset' in some other editors.")})),cursorSurroundingLinesStyle:oe(new yi(30,"cursorSurroundingLinesStyle","default",["default","all"],{enumDescriptions:[p("cursorSurroundingLinesStyle.default","`cursorSurroundingLines` is enforced only when triggered via the keyboard or API."),p("cursorSurroundingLinesStyle.all","`cursorSurroundingLines` is enforced always.")],markdownDescription:p("cursorSurroundingLinesStyle","Controls when `#cursorSurroundingLines#` should be enforced.")})),cursorWidth:oe(new Gt(31,"cursorWidth",0,0,1073741824,{markdownDescription:p("cursorWidth","Controls the width of the cursor when `#editor.cursorStyle#` is set to `line`.")})),disableLayerHinting:oe(new St(32,"disableLayerHinting",!1)),disableMonospaceOptimizations:oe(new St(33,"disableMonospaceOptimizations",!1)),domReadOnly:oe(new St(34,"domReadOnly",!1)),dragAndDrop:oe(new St(35,"dragAndDrop",!0,{description:p("dragAndDrop","Controls whether the editor should allow moving selections via drag and drop.")})),emptySelectionClipboard:oe(new MX),dropIntoEditor:oe(new lQ),stickyScroll:oe(new VX),experimentalWhitespaceRendering:oe(new yi(38,"experimentalWhitespaceRendering","svg",["svg","font","off"],{enumDescriptions:[p("experimentalWhitespaceRendering.svg","Use a new rendering method with svgs."),p("experimentalWhitespaceRendering.font","Use a new rendering method with font characters."),p("experimentalWhitespaceRendering.off","Use the stable rendering method.")],description:p("experimentalWhitespaceRendering","Controls whether whitespace is rendered with a new, experimental method.")})),extraEditorClassName:oe(new uo(39,"extraEditorClassName","")),fastScrollSensitivity:oe(new Hr(40,"fastScrollSensitivity",5,s=>s<=0?5:s,{markdownDescription:p("fastScrollSensitivity","Scrolling speed multiplier when pressing `Alt`.")})),find:oe(new RX),fixedOverflowWidgets:oe(new St(42,"fixedOverflowWidgets",!1)),folding:oe(new St(43,"folding",!0,{description:p("folding","Controls whether the editor has code folding enabled.")})),foldingStrategy:oe(new yi(44,"foldingStrategy","auto",["auto","indentation"],{enumDescriptions:[p("foldingStrategy.auto","Use a language-specific folding strategy if available, else the indentation-based one."),p("foldingStrategy.indentation","Use the indentation-based folding strategy.")],description:p("foldingStrategy","Controls the strategy for computing folding ranges.")})),foldingHighlight:oe(new St(45,"foldingHighlight",!0,{description:p("foldingHighlight","Controls whether the editor should highlight folded ranges.")})),foldingImportsByDefault:oe(new St(46,"foldingImportsByDefault",!1,{description:p("foldingImportsByDefault","Controls whether the editor automatically collapses import ranges.")})),foldingMaximumRegions:oe(new Gt(47,"foldingMaximumRegions",5e3,10,65e3,{description:p("foldingMaximumRegions","The maximum number of foldable regions. Increasing this value may result in the editor becoming less responsive when the current source has a large number of foldable regions.")})),unfoldOnClickAfterEndOfLine:oe(new St(48,"unfoldOnClickAfterEndOfLine",!1,{description:p("unfoldOnClickAfterEndOfLine","Controls whether clicking on the empty content after a folded line will unfold the line.")})),fontFamily:oe(new uo(49,"fontFamily",vo.fontFamily,{description:p("fontFamily","Controls the font family.")})),fontInfo:oe(new AX),fontLigatures2:oe(new $o),fontSize:oe(new PX),fontWeight:oe(new _l),fontVariations:oe(new La),formatOnPaste:oe(new St(55,"formatOnPaste",!1,{description:p("formatOnPaste","Controls whether the editor should automatically format the pasted content. A formatter must be available and the formatter should be able to format a range in a document.")})),formatOnType:oe(new St(56,"formatOnType",!1,{description:p("formatOnType","Controls whether the editor should automatically format the line after typing.")})),glyphMargin:oe(new St(57,"glyphMargin",!0,{description:p("glyphMargin","Controls whether the editor should render the vertical glyph margin. Glyph margin is mostly used for debugging.")})),gotoLocation:oe(new OX),hideCursorInOverviewRuler:oe(new St(59,"hideCursorInOverviewRuler",!1,{description:p("hideCursorInOverviewRuler","Controls whether the cursor should be hidden in the overview ruler.")})),hover:oe(new FX),inDiffEditor:oe(new St(61,"inDiffEditor",!1)),letterSpacing:oe(new Hr(63,"letterSpacing",vo.letterSpacing,s=>Hr.clamp(s,-5,20),{description:p("letterSpacing","Controls the letter spacing in pixels.")})),lightbulb:oe(new WX),lineDecorationsWidth:oe(new zX),lineHeight:oe(new UX),lineNumbers:oe(new YX),lineNumbersMinChars:oe(new Gt(68,"lineNumbersMinChars",5,1,300)),linkedEditing:oe(new St(69,"linkedEditing",!1,{description:p("linkedEditing","Controls whether the editor has linked editing enabled. Depending on the language, related symbols such as HTML tags, are updated while editing.")})),links:oe(new St(70,"links",!0,{description:p("links","Controls whether the editor should detect links and make them clickable.")})),matchBrackets:oe(new yi(71,"matchBrackets","always",["always","near","never"],{description:p("matchBrackets","Highlight matching brackets.")})),minimap:oe(new $X),mouseStyle:oe(new yi(73,"mouseStyle","text",["text","default","copy"])),mouseWheelScrollSensitivity:oe(new Hr(74,"mouseWheelScrollSensitivity",1,s=>s===0?1:s,{markdownDescription:p("mouseWheelScrollSensitivity","A multiplier to be used on the `deltaX` and `deltaY` of mouse wheel scroll events.")})),mouseWheelZoom:oe(new St(75,"mouseWheelZoom",!1,{markdownDescription:p("mouseWheelZoom","Zoom the font of the editor when using mouse wheel and holding `Ctrl`.")})),multiCursorMergeOverlapping:oe(new St(76,"multiCursorMergeOverlapping",!0,{description:p("multiCursorMergeOverlapping","Merge multiple cursors when they are overlapping.")})),multiCursorModifier:oe(new n1(77,"multiCursorModifier","altKey","alt",["ctrlCmd","alt"],jX,{markdownEnumDescriptions:[p("multiCursorModifier.ctrlCmd","Maps to `Control` on Windows and Linux and to `Command` on macOS."),p("multiCursorModifier.alt","Maps to `Alt` on Windows and Linux and to `Option` on macOS.")],markdownDescription:p({key:"multiCursorModifier",comment:["- `ctrlCmd` refers to a value the setting can take and should not be localized.","- `Control` and `Command` refer to the modifier keys Ctrl or Cmd on the keyboard and can be localized."]},"The modifier to be used to add multiple cursors with the mouse. The Go to Definition and Open Link mouse gestures will adapt such that they do not conflict with the [multicursor modifier](https://code.visualstudio.com/docs/editor/codebasics#_multicursor-modifier).")})),multiCursorPaste:oe(new yi(78,"multiCursorPaste","spread",["spread","full"],{markdownEnumDescriptions:[p("multiCursorPaste.spread","Each cursor pastes a single line of the text."),p("multiCursorPaste.full","Each cursor pastes the full text.")],markdownDescription:p("multiCursorPaste","Controls pasting when the line count of the pasted text matches the cursor count.")})),multiCursorLimit:oe(new Gt(79,"multiCursorLimit",1e4,1,1e5,{markdownDescription:p("multiCursorLimit","Controls the max number of cursors that can be in an active editor at once.")})),occurrencesHighlight:oe(new yi(80,"occurrencesHighlight","singleFile",["off","singleFile","multiFile"],{markdownEnumDescriptions:[p("occurrencesHighlight.off","Does not highlight occurrences."),p("occurrencesHighlight.singleFile","Highlights occurrences only in the current file."),p("occurrencesHighlight.multiFile","Experimental: Highlights occurrences across all valid open files.")],markdownDescription:p("occurrencesHighlight","Controls whether occurrences should be highlighted across open files.")})),overviewRulerBorder:oe(new St(81,"overviewRulerBorder",!0,{description:p("overviewRulerBorder","Controls whether a border should be drawn around the overview ruler.")})),overviewRulerLanes:oe(new Gt(82,"overviewRulerLanes",3,0,3)),padding:oe(new KX),pasteAs:oe(new dQ),parameterHints:oe(new qX),peekWidgetDefaultFocus:oe(new yi(86,"peekWidgetDefaultFocus","tree",["tree","editor"],{enumDescriptions:[p("peekWidgetDefaultFocus.tree","Focus the tree when opening peek"),p("peekWidgetDefaultFocus.editor","Focus the editor when opening peek")],description:p("peekWidgetDefaultFocus","Controls whether to focus the inline editor or the tree in the peek widget.")})),definitionLinkOpensInPeek:oe(new St(87,"definitionLinkOpensInPeek",!1,{description:p("definitionLinkOpensInPeek","Controls whether the Go to Definition mouse gesture always opens the peek widget.")})),quickSuggestions:oe(new ZX),quickSuggestionsDelay:oe(new Gt(89,"quickSuggestionsDelay",10,0,1073741824,{description:p("quickSuggestionsDelay","Controls the delay in milliseconds after which quick suggestions will show up.")})),readOnly:oe(new St(90,"readOnly",!1)),readOnlyMessage:oe(new QX),renameOnType:oe(new St(92,"renameOnType",!1,{description:p("renameOnType","Controls whether the editor auto renames on type."),markdownDeprecationMessage:p("renameOnTypeDeprecate","Deprecated, use `editor.linkedEditing` instead.")})),renderControlCharacters:oe(new St(93,"renderControlCharacters",!0,{description:p("renderControlCharacters","Controls whether the editor should render control characters."),restricted:!0})),renderFinalNewline:oe(new yi(94,"renderFinalNewline",Ss?"dimmed":"on",["off","on","dimmed"],{description:p("renderFinalNewline","Render last line number when the file ends with a newline.")})),renderLineHighlight:oe(new yi(95,"renderLineHighlight","line",["none","gutter","line","all"],{enumDescriptions:["","","",p("renderLineHighlight.all","Highlights both the gutter and the current line.")],description:p("renderLineHighlight","Controls how the editor should render the current line highlight.")})),renderLineHighlightOnlyWhenFocus:oe(new St(96,"renderLineHighlightOnlyWhenFocus",!1,{description:p("renderLineHighlightOnlyWhenFocus","Controls if the editor should render the current line highlight only when the editor is focused.")})),renderValidationDecorations:oe(new yi(97,"renderValidationDecorations","editable",["editable","on","off"])),renderWhitespace:oe(new yi(98,"renderWhitespace","selection",["none","boundary","selection","trailing","all"],{enumDescriptions:["",p("renderWhitespace.boundary","Render whitespace characters except for single spaces between words."),p("renderWhitespace.selection","Render whitespace characters only on selected text."),p("renderWhitespace.trailing","Render only trailing whitespace characters."),""],description:p("renderWhitespace","Controls how the editor should render whitespace characters.")})),revealHorizontalRightPadding:oe(new Gt(99,"revealHorizontalRightPadding",15,0,1e3)),roundedSelection:oe(new St(100,"roundedSelection",!0,{description:p("roundedSelection","Controls whether selections should have rounded corners.")})),rulers:oe(new XX),scrollbar:oe(new JX),scrollBeyondLastColumn:oe(new Gt(103,"scrollBeyondLastColumn",4,0,1073741824,{description:p("scrollBeyondLastColumn","Controls the number of extra characters beyond which the editor will scroll horizontally.")})),scrollBeyondLastLine:oe(new St(104,"scrollBeyondLastLine",!0,{description:p("scrollBeyondLastLine","Controls whether the editor will scroll beyond the last line.")})),scrollPredominantAxis:oe(new St(105,"scrollPredominantAxis",!0,{description:p("scrollPredominantAxis","Scroll only along the predominant axis when scrolling both vertically and horizontally at the same time. Prevents horizontal drift when scrolling vertically on a trackpad.")})),selectionClipboard:oe(new St(106,"selectionClipboard",!0,{description:p("selectionClipboard","Controls whether the Linux primary clipboard should be supported."),included:Ss})),selectionHighlight:oe(new St(107,"selectionHighlight",!0,{description:p("selectionHighlight","Controls whether the editor should highlight matches similar to the selection.")})),selectOnLineNumbers:oe(new St(108,"selectOnLineNumbers",!0)),showFoldingControls:oe(new yi(109,"showFoldingControls","mouseover",["always","never","mouseover"],{enumDescriptions:[p("showFoldingControls.always","Always show the folding controls."),p("showFoldingControls.never","Never show the folding controls and reduce the gutter size."),p("showFoldingControls.mouseover","Only show the folding controls when the mouse is over the gutter.")],description:p("showFoldingControls","Controls when the folding controls on the gutter are shown.")})),showUnused:oe(new St(110,"showUnused",!0,{description:p("showUnused","Controls fading out of unused code.")})),showDeprecated:oe(new St(138,"showDeprecated",!0,{description:p("showDeprecated","Controls strikethrough deprecated variables.")})),inlayHints:oe(new HX),snippetSuggestions:oe(new yi(111,"snippetSuggestions","inline",["top","bottom","inline","none"],{enumDescriptions:[p("snippetSuggestions.top","Show snippet suggestions on top of other suggestions."),p("snippetSuggestions.bottom","Show snippet suggestions below other suggestions."),p("snippetSuggestions.inline","Show snippets suggestions with other suggestions."),p("snippetSuggestions.none","Do not show snippet suggestions.")],description:p("snippetSuggestions","Controls whether snippets are shown with other suggestions and how they are sorted.")})),smartSelect:oe(new oQ),smoothScrolling:oe(new St(113,"smoothScrolling",!1,{description:p("smoothScrolling","Controls whether the editor will scroll using an animation.")})),stopRenderingLineAfter:oe(new Gt(116,"stopRenderingLineAfter",1e4,-1,1073741824)),suggest:oe(new sQ),inlineSuggest:oe(new tQ),inlineCompletionsAccessibilityVerbose:oe(new St(147,"inlineCompletionsAccessibilityVerbose",!1,{description:p("inlineCompletionsAccessibilityVerbose","Controls whether the accessibility hint should be provided to screen reader users when an inline completion is shown.")})),suggestFontSize:oe(new Gt(118,"suggestFontSize",0,0,1e3,{markdownDescription:p("suggestFontSize","Font size for the suggest widget. When set to {0}, the value of {1} is used.","`0`","`#editor.fontSize#`")})),suggestLineHeight:oe(new Gt(119,"suggestLineHeight",0,0,1e3,{markdownDescription:p("suggestLineHeight","Line height for the suggest widget. When set to {0}, the value of {1} is used. The minimum value is 8.","`0`","`#editor.lineHeight#`")})),suggestOnTriggerCharacters:oe(new St(120,"suggestOnTriggerCharacters",!0,{description:p("suggestOnTriggerCharacters","Controls whether suggestions should automatically show up when typing trigger characters.")})),suggestSelection:oe(new yi(121,"suggestSelection","first",["first","recentlyUsed","recentlyUsedByPrefix"],{markdownEnumDescriptions:[p("suggestSelection.first","Always select the first suggestion."),p("suggestSelection.recentlyUsed","Select recent suggestions unless further typing selects one, e.g. `console.| -> console.log` because `log` has been completed recently."),p("suggestSelection.recentlyUsedByPrefix","Select suggestions based on previous prefixes that have completed those suggestions, e.g. `co -> console` and `con -> const`.")],description:p("suggestSelection","Controls how suggestions are pre-selected when showing the suggest list.")})),tabCompletion:oe(new yi(122,"tabCompletion","off",["on","off","onlySnippets"],{enumDescriptions:[p("tabCompletion.on","Tab complete will insert the best matching suggestion when pressing tab."),p("tabCompletion.off","Disable tab completions."),p("tabCompletion.onlySnippets","Tab complete snippets when their prefix match. Works best when 'quickSuggestions' aren't enabled.")],description:p("tabCompletion","Enables tab completions.")})),tabIndex:oe(new Gt(123,"tabIndex",0,-1,1073741824)),unicodeHighlight:oe(new eQ),unusualLineTerminators:oe(new yi(125,"unusualLineTerminators","prompt",["auto","off","prompt"],{enumDescriptions:[p("unusualLineTerminators.auto","Unusual line terminators are automatically removed."),p("unusualLineTerminators.off","Unusual line terminators are ignored."),p("unusualLineTerminators.prompt","Unusual line terminators prompt to be removed.")],description:p("unusualLineTerminators","Remove unusual line terminators that might cause problems.")})),useShadowDOM:oe(new St(126,"useShadowDOM",!0)),useTabStops:oe(new St(127,"useTabStops",!0,{description:p("useTabStops","Inserting and deleting whitespace follows tab stops.")})),wordBreak:oe(new yi(128,"wordBreak","normal",["normal","keepAll"],{markdownEnumDescriptions:[p("wordBreak.normal","Use the default line break rule."),p("wordBreak.keepAll","Word breaks should not be used for Chinese/Japanese/Korean (CJK) text. Non-CJK text behavior is the same as for normal.")],description:p("wordBreak","Controls the word break rules used for Chinese/Japanese/Korean (CJK) text.")})),wordSeparators:oe(new uo(129,"wordSeparators",wW,{description:p("wordSeparators","Characters that will be used as word separators when doing word related navigations or operations.")})),wordWrap:oe(new yi(130,"wordWrap","off",["off","on","wordWrapColumn","bounded"],{markdownEnumDescriptions:[p("wordWrap.off","Lines will never wrap."),p("wordWrap.on","Lines will wrap at the viewport width."),p({key:"wordWrap.wordWrapColumn",comment:["- `editor.wordWrapColumn` refers to a different setting and should not be localized."]},"Lines will wrap at `#editor.wordWrapColumn#`."),p({key:"wordWrap.bounded",comment:["- viewport means the edge of the visible window size.","- `editor.wordWrapColumn` refers to a different setting and should not be localized."]},"Lines will wrap at the minimum of viewport and `#editor.wordWrapColumn#`.")],description:p({key:"wordWrap",comment:["- 'off', 'on', 'wordWrapColumn' and 'bounded' refer to values the setting can take and should not be localized.","- `editor.wordWrapColumn` refers to a different setting and should not be localized."]},"Controls how lines should wrap.")})),wordWrapBreakAfterCharacters:oe(new uo(131,"wordWrapBreakAfterCharacters"," 	})]?|/&.,;¢°′″‰℃、。｡､￠，．：；？！％・･ゝゞヽヾーァィゥェォッャュョヮヵヶぁぃぅぇぉっゃゅょゎゕゖㇰㇱㇲㇳㇴㇵㇶㇷㇸㇹㇺㇻㇼㇽㇾㇿ々〻ｧｨｩｪｫｬｭｮｯｰ”〉》」』】〕）］｝｣")),wordWrapBreakBeforeCharacters:oe(new uo(132,"wordWrapBreakBeforeCharacters","([{‘“〈《「『【〔（［｛｢£¥＄￡￥+＋")),wordWrapColumn:oe(new Gt(133,"wordWrapColumn",80,1,1073741824,{markdownDescription:p({key:"wordWrapColumn",comment:["- `editor.wordWrap` refers to a different setting and should not be localized.","- 'wordWrapColumn' and 'bounded' refer to values the different setting can take and should not be localized."]},"Controls the wrapping column of the editor when `#editor.wordWrap#` is `wordWrapColumn` or `bounded`.")})),wordWrapOverride1:oe(new yi(134,"wordWrapOverride1","inherit",["off","on","inherit"])),wordWrapOverride2:oe(new yi(135,"wordWrapOverride2","inherit",["off","on","inherit"])),editorClassName:oe(new TX),defaultColorDecorators:oe(new St(145,"defaultColorDecorators",!1,{markdownDescription:p("defaultColorDecorators","Controls whether inline color decorations should be shown using the default document color provider")})),pixelRatio:oe(new GX),tabFocusMode:oe(new St(142,"tabFocusMode",!1,{markdownDescription:p("tabFocusMode","Controls whether the editor receives tabs or defers them to the workbench for navigation.")})),layoutInfo:oe(new Np),wrappingInfo:oe(new aQ),wrappingIndent:oe(new rQ),wrappingStrategy:oe(new BX)};class gQ{constructor(){this.listeners=[],this.unexpectedErrorHandler=function(e){setTimeout(()=>{throw e.stack?rm.isErrorNoTelemetry(e)?new rm(e.message+`

`+e.stack):new Error(e.message+`

`+e.stack):e},0)}}emit(e){this.listeners.forEach(t=>{t(e)})}onUnexpectedError(e){this.unexpectedErrorHandler(e),this.emit(e)}onUnexpectedExternalError(e){this.unexpectedErrorHandler(e)}}const xW=new gQ;function et(s){Ka(s)||xW.onUnexpectedError(s)}function Zi(s){Ka(s)||xW.onUnexpectedExternalError(s)}function t5(s){if(s instanceof Error){const{name:e,message:t}=s,i=s.stacktrace||s.stack;return{$isError:!0,name:e,message:t,stack:i,noTelemetry:rm.isErrorNoTelemetry(s)}}return s}const xS="Canceled";function Ka(s){return s instanceof eh?!0:s instanceof Error&&s.name===xS&&s.message===xS}class eh extends Error{constructor(){super(xS),this.name=this.message}}function fQ(){const s=new Error(xS);return s.name=s.message,s}function Cr(s){return s?new Error(`Illegal argument: ${s}`):new Error("Illegal argument")}function IA(s){return s?new Error(`Illegal state: ${s}`):new Error("Illegal state")}class pQ extends Error{constructor(e){super("NotSupported"),e&&(this.message=e)}}class rm extends Error{constructor(e){super(e),this.name="CodeExpectedError"}static fromError(e){if(e instanceof rm)return e;const t=new rm;return t.message=e.message,t.stack=e.stack,t}static isErrorNoTelemetry(e){return e.name==="CodeExpectedError"}}class pi extends Error{constructor(e){super(e||"An unexpected bug occurred."),Object.setPrototypeOf(this,pi.prototype)}}function Du(s,e){const t=this;let i=!1,n;return function(){if(i)return n;if(i=!0,e)try{n=s.apply(t,arguments)}finally{e()}else n=s.apply(t,arguments);return n}}function EA(s){return typeof s.dispose=="function"&&s.dispose.length===0}function Bt(s){if(ht.is(s)){const e=[];for(const t of s)if(t)try{t.dispose()}catch(i){e.push(i)}if(e.length===1)throw e[0];if(e.length>1)throw new AggregateError(e,"Encountered errors while disposing of store");return Array.isArray(s)?[]:s}else if(s)return s.dispose(),s}function Gr(...s){return Fe(()=>Bt(s))}function Fe(s){return{dispose:Du(()=>{s()})}}class ie{constructor(){this._toDispose=new Set,this._isDisposed=!1}dispose(){this._isDisposed||(this._isDisposed=!0,this.clear())}get isDisposed(){return this._isDisposed}clear(){if(this._toDispose.size!==0)try{Bt(this._toDispose)}finally{this._toDispose.clear()}}add(e){if(!e)return e;if(e===this)throw new Error("Cannot register a disposable on itself!");return this._isDisposed?ie.DISABLE_DISPOSED_WARNING||console.warn(new Error("Trying to add a disposable to a DisposableStore that has already been disposed of. The added object will be leaked!").stack):this._toDispose.add(e),e}deleteAndLeak(e){e&&this._toDispose.has(e)&&this._toDispose.delete(e)}}ie.DISABLE_DISPOSED_WARNING=!1;class j{constructor(){this._store=new ie,this._store}dispose(){this._store.dispose()}_register(e){if(e===this)throw new Error("Cannot register a disposable on itself!");return this._store.add(e)}}j.None=Object.freeze({dispose(){}});class En{constructor(){this._isDisposed=!1}get value(){return this._isDisposed?void 0:this._value}set value(e){var t;this._isDisposed||e===this._value||((t=this._value)===null||t===void 0||t.dispose(),this._value=e)}clear(){this.value=void 0}dispose(){var e;this._isDisposed=!0,(e=this._value)===null||e===void 0||e.dispose(),this._value=void 0}}class mQ{constructor(e){this._disposable=e,this._counter=1}acquire(){return this._counter++,this}release(){return--this._counter===0&&this._disposable.dispose(),this}}class _Q{constructor(e){this.object=e}dispose(){}}class NA{constructor(){this._store=new Map,this._isDisposed=!1}dispose(){this._isDisposed=!0,this.clearAndDisposeAll()}clearAndDisposeAll(){if(this._store.size)try{Bt(this._store.values())}finally{this._store.clear()}}get(e){return this._store.get(e)}set(e,t,i=!1){var n;this._isDisposed&&console.warn(new Error("Trying to add a disposable to a DisposableMap that has already been disposed of. The added object will be leaked!").stack),i||(n=this._store.get(e))===null||n===void 0||n.dispose(),this._store.set(e,t)}deleteAndDispose(e){var t;(t=this._store.get(e))===null||t===void 0||t.dispose(),this._store.delete(e)}[Symbol.iterator](){return this._store[Symbol.iterator]()}}const vQ=globalThis.performance&&typeof globalThis.performance.now=="function";class cs{static create(e){return new cs(e)}constructor(e){this._now=vQ&&e===!1?Date.now:globalThis.performance.now.bind(globalThis.performance),this._startTime=this._now(),this._stopTime=-1}stop(){this._stopTime=this._now()}elapsed(){return this._stopTime!==-1?this._stopTime-this._startTime:this._now()-this._startTime}}var ge;(function(s){s.None=()=>j.None;function e(A,z){return u(A,()=>{},0,void 0,!0,void 0,z)}s.defer=e;function t(A){return(z,K=null,Q)=>{let ne=!1,fe;return fe=A(ve=>{if(!ne)return fe?fe.dispose():ne=!0,z.call(K,ve)},null,Q),ne&&fe.dispose(),fe}}s.once=t;function i(A,z,K){return d((Q,ne=null,fe)=>A(ve=>Q.call(ne,z(ve)),null,fe),K)}s.map=i;function n(A,z,K){return d((Q,ne=null,fe)=>A(ve=>{z(ve),Q.call(ne,ve)},null,fe),K)}s.forEach=n;function o(A,z,K){return d((Q,ne=null,fe)=>A(ve=>z(ve)&&Q.call(ne,ve),null,fe),K)}s.filter=o;function r(A){return A}s.signal=r;function a(...A){return(z,K=null,Q)=>{const ne=Gr(...A.map(fe=>fe(ve=>z.call(K,ve))));return c(ne,Q)}}s.any=a;function l(A,z,K,Q){let ne=K;return i(A,fe=>(ne=z(ne,fe),ne),Q)}s.reduce=l;function d(A,z){let K;const Q={onWillAddFirstListener(){K=A(ne.fire,ne)},onDidRemoveLastListener(){K==null||K.dispose()}},ne=new W(Q);return z==null||z.add(ne),ne.event}function c(A,z){return z instanceof Array?z.push(A):z&&z.add(A),A}function u(A,z,K=100,Q=!1,ne=!1,fe,ve){let ye,Be,Ve,Ie=0,pe;const Ji={leakWarningThreshold:fe,onWillAddFirstListener(){ye=A(ni=>{Ie++,Be=z(Be,ni),Q&&!Ve&&(wn.fire(Be),Be=void 0),pe=()=>{const wt=Be;Be=void 0,Ve=void 0,(!Q||Ie>1)&&wn.fire(wt),Ie=0},typeof K=="number"?(clearTimeout(Ve),Ve=setTimeout(pe,K)):Ve===void 0&&(Ve=0,queueMicrotask(pe))})},onWillRemoveListener(){ne&&Ie>0&&(pe==null||pe())},onDidRemoveLastListener(){pe=void 0,ye.dispose()}},wn=new W(Ji);return ve==null||ve.add(wn),wn.event}s.debounce=u;function h(A,z=0,K){return s.debounce(A,(Q,ne)=>Q?(Q.push(ne),Q):[ne],z,void 0,!0,void 0,K)}s.accumulate=h;function g(A,z=(Q,ne)=>Q===ne,K){let Q=!0,ne;return o(A,fe=>{const ve=Q||!z(fe,ne);return Q=!1,ne=fe,ve},K)}s.latch=g;function f(A,z,K){return[s.filter(A,z,K),s.filter(A,Q=>!z(Q),K)]}s.split=f;function m(A,z=!1,K=[],Q){let ne=K.slice(),fe=A(Be=>{ne?ne.push(Be):ye.fire(Be)});Q&&Q.add(fe);const ve=()=>{ne==null||ne.forEach(Be=>ye.fire(Be)),ne=null},ye=new W({onWillAddFirstListener(){fe||(fe=A(Be=>ye.fire(Be)),Q&&Q.add(fe))},onDidAddFirstListener(){ne&&(z?setTimeout(ve):ve())},onDidRemoveLastListener(){fe&&fe.dispose(),fe=null}});return Q&&Q.add(ye),ye.event}s.buffer=m;function _(A,z){return(Q,ne,fe)=>{const ve=z(new b);return A(function(ye){const Be=ve.evaluate(ye);Be!==v&&Q.call(ne,Be)},void 0,fe)}}s.chain=_;const v=Symbol("HaltChainable");class b{constructor(){this.steps=[]}map(z){return this.steps.push(z),this}forEach(z){return this.steps.push(K=>(z(K),K)),this}filter(z){return this.steps.push(K=>z(K)?K:v),this}reduce(z,K){let Q=K;return this.steps.push(ne=>(Q=z(Q,ne),Q)),this}latch(z=(K,Q)=>K===Q){let K=!0,Q;return this.steps.push(ne=>{const fe=K||!z(ne,Q);return K=!1,Q=ne,fe?ne:v}),this}evaluate(z){for(const K of this.steps)if(z=K(z),z===v)break;return z}}function C(A,z,K=Q=>Q){const Q=(...ye)=>ve.fire(K(...ye)),ne=()=>A.on(z,Q),fe=()=>A.removeListener(z,Q),ve=new W({onWillAddFirstListener:ne,onDidRemoveLastListener:fe});return ve.event}s.fromNodeEventEmitter=C;function w(A,z,K=Q=>Q){const Q=(...ye)=>ve.fire(K(...ye)),ne=()=>A.addEventListener(z,Q),fe=()=>A.removeEventListener(z,Q),ve=new W({onWillAddFirstListener:ne,onDidRemoveLastListener:fe});return ve.event}s.fromDOMEventEmitter=w;function S(A){return new Promise(z=>t(A)(z))}s.toPromise=S;function x(A){const z=new W;return A.then(K=>{z.fire(K)},()=>{z.fire(void 0)}).finally(()=>{z.dispose()}),z.event}s.fromPromise=x;function L(A,z,K){return z(K),A(Q=>z(Q))}s.runAndSubscribe=L;function k(A,z){let K=null;function Q(fe){K==null||K.dispose(),K=new ie,z(fe,K)}Q(void 0);const ne=A(fe=>Q(fe));return Fe(()=>{ne.dispose(),K==null||K.dispose()})}s.runAndSubscribeWithStore=k;class I{constructor(z,K){this._observable=z,this._counter=0,this._hasChanged=!1;const Q={onWillAddFirstListener:()=>{z.addObserver(this)},onDidRemoveLastListener:()=>{z.removeObserver(this)}};this.emitter=new W(Q),K&&K.add(this.emitter)}beginUpdate(z){this._counter++}handlePossibleChange(z){}handleChange(z,K){this._hasChanged=!0}endUpdate(z){this._counter--,this._counter===0&&(this._observable.reportChanges(),this._hasChanged&&(this._hasChanged=!1,this.emitter.fire(this._observable.get())))}}function P(A,z){return new I(A,z).emitter.event}s.fromObservable=P;function $(A){return(z,K,Q)=>{let ne=0,fe=!1;const ve={beginUpdate(){ne++},endUpdate(){ne--,ne===0&&(A.reportChanges(),fe&&(fe=!1,z.call(K)))},handlePossibleChange(){},handleChange(){fe=!0}};A.addObserver(ve),A.reportChanges();const ye={dispose(){A.removeObserver(ve)}};return Q instanceof ie?Q.add(ye):Array.isArray(Q)&&Q.push(ye),ye}}s.fromObservableLight=$})(ge||(ge={}));class am{constructor(e){this.listenerCount=0,this.invocationCount=0,this.elapsedOverall=0,this.durations=[],this.name=`${e}_${am._idPool++}`,am.all.add(this)}start(e){this._stopWatch=new cs,this.listenerCount=e}stop(){if(this._stopWatch){const e=this._stopWatch.elapsed();this.durations.push(e),this.elapsedOverall+=e,this.invocationCount+=1,this._stopWatch=void 0}}}am.all=new Set;am._idPool=0;let bQ=-1;class CQ{constructor(e,t=Math.random().toString(18).slice(2,5)){this.threshold=e,this.name=t,this._warnCountdown=0}dispose(){var e;(e=this._stacks)===null||e===void 0||e.clear()}check(e,t){const i=this.threshold;if(i<=0||t<i)return;this._stacks||(this._stacks=new Map);const n=this._stacks.get(e.value)||0;if(this._stacks.set(e.value,n+1),this._warnCountdown-=1,this._warnCountdown<=0){this._warnCountdown=i*.5;let o,r=0;for(const[a,l]of this._stacks)(!o||r<l)&&(o=a,r=l);console.warn(`[${this.name}] potential listener LEAK detected, having ${t} listeners already. MOST frequent listener (${r}):`),console.warn(o)}return()=>{const o=this._stacks.get(e.value)||0;this._stacks.set(e.value,o-1)}}}class TA{static create(){var e;return new TA((e=new Error().stack)!==null&&e!==void 0?e:"")}constructor(e){this.value=e}print(){console.warn(this.value.split(`
`).slice(2).join(`
`))}}class Dk{constructor(e){this.value=e}}const wQ=2;let W=class{constructor(e){var t,i,n,o,r;this._size=0,this._options=e,this._leakageMon=!((t=this._options)===null||t===void 0)&&t.leakWarningThreshold?new CQ((n=(i=this._options)===null||i===void 0?void 0:i.leakWarningThreshold)!==null&&n!==void 0?n:bQ):void 0,this._perfMon=!((o=this._options)===null||o===void 0)&&o._profName?new am(this._options._profName):void 0,this._deliveryQueue=(r=this._options)===null||r===void 0?void 0:r.deliveryQueue}dispose(){var e,t,i,n;this._disposed||(this._disposed=!0,((e=this._deliveryQueue)===null||e===void 0?void 0:e.current)===this&&this._deliveryQueue.reset(),this._listeners&&(this._listeners=void 0,this._size=0),(i=(t=this._options)===null||t===void 0?void 0:t.onDidRemoveLastListener)===null||i===void 0||i.call(t),(n=this._leakageMon)===null||n===void 0||n.dispose())}get event(){var e;return(e=this._event)!==null&&e!==void 0||(this._event=(t,i,n)=>{var o,r,a,l,d;if(this._leakageMon&&this._size>this._leakageMon.threshold*3)return console.warn(`[${this._leakageMon.name}] REFUSES to accept new listeners because it exceeded its threshold by far`),j.None;if(this._disposed)return j.None;i&&(t=t.bind(i));const c=new Dk(t);let u;this._leakageMon&&this._size>=Math.ceil(this._leakageMon.threshold*.2)&&(c.stack=TA.create(),u=this._leakageMon.check(c.stack,this._size+1)),this._listeners?this._listeners instanceof Dk?((d=this._deliveryQueue)!==null&&d!==void 0||(this._deliveryQueue=new DW),this._listeners=[this._listeners,c]):this._listeners.push(c):((r=(o=this._options)===null||o===void 0?void 0:o.onWillAddFirstListener)===null||r===void 0||r.call(o,this),this._listeners=c,(l=(a=this._options)===null||a===void 0?void 0:a.onDidAddFirstListener)===null||l===void 0||l.call(a,this)),this._size++;const h=Fe(()=>{u==null||u(),this._removeListener(c)});return n instanceof ie?n.add(h):Array.isArray(n)&&n.push(h),h}),this._event}_removeListener(e){var t,i,n,o;if((i=(t=this._options)===null||t===void 0?void 0:t.onWillRemoveListener)===null||i===void 0||i.call(t,this),!this._listeners)return;if(this._size===1){this._listeners=void 0,(o=(n=this._options)===null||n===void 0?void 0:n.onDidRemoveLastListener)===null||o===void 0||o.call(n,this),this._size=0;return}const r=this._listeners,a=r.indexOf(e);if(a===-1)throw console.log("disposed?",this._disposed),console.log("size?",this._size),console.log("arr?",JSON.stringify(this._listeners)),new Error("Attempted to dispose unknown listener");this._size--,r[a]=void 0;const l=this._deliveryQueue.current===this;if(this._size*wQ<=r.length){let d=0;for(let c=0;c<r.length;c++)r[c]?r[d++]=r[c]:l&&(this._deliveryQueue.end--,d<this._deliveryQueue.i&&this._deliveryQueue.i--);r.length=d}}_deliver(e,t){var i;if(!e)return;const n=((i=this._options)===null||i===void 0?void 0:i.onListenerError)||et;if(!n){e.value(t);return}try{e.value(t)}catch(o){n(o)}}_deliverQueue(e){const t=e.current._listeners;for(;e.i<e.end;)this._deliver(t[e.i++],e.value);e.reset()}fire(e){var t,i,n,o;if(!((t=this._deliveryQueue)===null||t===void 0)&&t.current&&(this._deliverQueue(this._deliveryQueue),(i=this._perfMon)===null||i===void 0||i.stop()),(n=this._perfMon)===null||n===void 0||n.start(this._size),this._listeners)if(this._listeners instanceof Dk)this._deliver(this._listeners,e);else{const r=this._deliveryQueue;r.enqueue(this,e,this._listeners.length),this._deliverQueue(r)}(o=this._perfMon)===null||o===void 0||o.stop()}hasListeners(){return this._size>0}};const SQ=()=>new DW;class DW{constructor(){this.i=-1,this.end=0}enqueue(e,t,i){this.i=0,this.end=i,this.current=e,this.value=t}reset(){this.i=this.end,this.current=void 0,this.value=void 0}}class Lg extends W{constructor(e){super(e),this._isPaused=0,this._eventQueue=new Ms,this._mergeFn=e==null?void 0:e.merge}pause(){this._isPaused++}resume(){if(this._isPaused!==0&&--this._isPaused===0)if(this._mergeFn){if(this._eventQueue.size>0){const e=Array.from(this._eventQueue);this._eventQueue.clear(),super.fire(this._mergeFn(e))}}else for(;!this._isPaused&&this._eventQueue.size!==0;)super.fire(this._eventQueue.shift())}fire(e){this._size&&(this._isPaused!==0?this._eventQueue.push(e):super.fire(e))}}class kW extends Lg{constructor(e){var t;super(e),this._delay=(t=e.delay)!==null&&t!==void 0?t:100}fire(e){this._handle||(this.pause(),this._handle=setTimeout(()=>{this._handle=void 0,this.resume()},this._delay)),super.fire(e)}}class yQ extends W{constructor(e){super(e),this._queuedEvents=[],this._mergeFn=e==null?void 0:e.merge}fire(e){this.hasListeners()&&(this._queuedEvents.push(e),this._queuedEvents.length===1&&queueMicrotask(()=>{this._mergeFn?super.fire(this._mergeFn(this._queuedEvents)):this._queuedEvents.forEach(t=>super.fire(t)),this._queuedEvents=[]}))}}class LQ{constructor(){this.hasListeners=!1,this.events=[],this.emitter=new W({onWillAddFirstListener:()=>this.onFirstListenerAdd(),onDidRemoveLastListener:()=>this.onLastListenerRemove()})}get event(){return this.emitter.event}add(e){const t={event:e,listener:null};return this.events.push(t),this.hasListeners&&this.hook(t),Fe(Du(()=>{this.hasListeners&&this.unhook(t);const n=this.events.indexOf(t);this.events.splice(n,1)}))}onFirstListenerAdd(){this.hasListeners=!0,this.events.forEach(e=>this.hook(e))}onLastListenerRemove(){this.hasListeners=!1,this.events.forEach(e=>this.unhook(e))}hook(e){e.listener=e.event(t=>this.emitter.fire(t))}unhook(e){e.listener&&e.listener.dispose(),e.listener=null}dispose(){this.emitter.dispose()}}class MA{constructor(){this.buffers=[]}wrapEvent(e){return(t,i,n)=>e(o=>{const r=this.buffers[this.buffers.length-1];r?r.push(()=>t.call(i,o)):t.call(i,o)},void 0,n)}bufferEvents(e){const t=[];this.buffers.push(t);const i=e();return this.buffers.pop(),t.forEach(n=>n()),i}}class i5{constructor(){this.listening=!1,this.inputEvent=ge.None,this.inputEventListener=j.None,this.emitter=new W({onDidAddFirstListener:()=>{this.listening=!0,this.inputEventListener=this.inputEvent(this.emitter.fire,this.emitter)},onDidRemoveLastListener:()=>{this.listening=!1,this.inputEventListener.dispose()}}),this.event=this.emitter.event}set input(e){this.inputEvent=e,this.listening&&(this.inputEventListener.dispose(),this.inputEventListener=e(this.emitter.fire,this.emitter))}dispose(){this.inputEventListener.dispose(),this.emitter.dispose()}}const IW=Object.freeze(function(s,e){const t=setTimeout(s.bind(e),0);return{dispose(){clearTimeout(t)}}});var ct;(function(s){function e(t){return t===s.None||t===s.Cancelled||t instanceof Iw?!0:!t||typeof t!="object"?!1:typeof t.isCancellationRequested=="boolean"&&typeof t.onCancellationRequested=="function"}s.isCancellationToken=e,s.None=Object.freeze({isCancellationRequested:!1,onCancellationRequested:ge.None}),s.Cancelled=Object.freeze({isCancellationRequested:!0,onCancellationRequested:IW})})(ct||(ct={}));class Iw{constructor(){this._isCancelled=!1,this._emitter=null}cancel(){this._isCancelled||(this._isCancelled=!0,this._emitter&&(this._emitter.fire(void 0),this.dispose()))}get isCancellationRequested(){return this._isCancelled}get onCancellationRequested(){return this._isCancelled?IW:(this._emitter||(this._emitter=new W),this._emitter.event)}dispose(){this._emitter&&(this._emitter.dispose(),this._emitter=null)}}let Yi=class{constructor(e){this._token=void 0,this._parentListener=void 0,this._parentListener=e&&e.onCancellationRequested(this.cancel,this)}get token(){return this._token||(this._token=new Iw),this._token}cancel(){this._token?this._token instanceof Iw&&this._token.cancel():this._token=ct.Cancelled}dispose(e=!1){var t;e&&this.cancel(),(t=this._parentListener)===null||t===void 0||t.dispose(),this._token?this._token instanceof Iw&&this._token.dispose():this._token=ct.None}};class RA{constructor(){this._keyCodeToStr=[],this._strToKeyCode=Object.create(null)}define(e,t){this._keyCodeToStr[e]=t,this._strToKeyCode[t.toLowerCase()]=e}keyCodeToStr(e){return this._keyCodeToStr[e]}strToKeyCode(e){return this._strToKeyCode[e.toLowerCase()]||0}}const Ew=new RA,qE=new RA,GE=new RA,EW=new Array(230),xQ=Object.create(null),DQ=Object.create(null),AA=[];for(let s=0;s<=193;s++)AA[s]=-1;(function(){const s="",e=[[1,0,"None",0,"unknown",0,"VK_UNKNOWN",s,s],[1,1,"Hyper",0,s,0,s,s,s],[1,2,"Super",0,s,0,s,s,s],[1,3,"Fn",0,s,0,s,s,s],[1,4,"FnLock",0,s,0,s,s,s],[1,5,"Suspend",0,s,0,s,s,s],[1,6,"Resume",0,s,0,s,s,s],[1,7,"Turbo",0,s,0,s,s,s],[1,8,"Sleep",0,s,0,"VK_SLEEP",s,s],[1,9,"WakeUp",0,s,0,s,s,s],[0,10,"KeyA",31,"A",65,"VK_A",s,s],[0,11,"KeyB",32,"B",66,"VK_B",s,s],[0,12,"KeyC",33,"C",67,"VK_C",s,s],[0,13,"KeyD",34,"D",68,"VK_D",s,s],[0,14,"KeyE",35,"E",69,"VK_E",s,s],[0,15,"KeyF",36,"F",70,"VK_F",s,s],[0,16,"KeyG",37,"G",71,"VK_G",s,s],[0,17,"KeyH",38,"H",72,"VK_H",s,s],[0,18,"KeyI",39,"I",73,"VK_I",s,s],[0,19,"KeyJ",40,"J",74,"VK_J",s,s],[0,20,"KeyK",41,"K",75,"VK_K",s,s],[0,21,"KeyL",42,"L",76,"VK_L",s,s],[0,22,"KeyM",43,"M",77,"VK_M",s,s],[0,23,"KeyN",44,"N",78,"VK_N",s,s],[0,24,"KeyO",45,"O",79,"VK_O",s,s],[0,25,"KeyP",46,"P",80,"VK_P",s,s],[0,26,"KeyQ",47,"Q",81,"VK_Q",s,s],[0,27,"KeyR",48,"R",82,"VK_R",s,s],[0,28,"KeyS",49,"S",83,"VK_S",s,s],[0,29,"KeyT",50,"T",84,"VK_T",s,s],[0,30,"KeyU",51,"U",85,"VK_U",s,s],[0,31,"KeyV",52,"V",86,"VK_V",s,s],[0,32,"KeyW",53,"W",87,"VK_W",s,s],[0,33,"KeyX",54,"X",88,"VK_X",s,s],[0,34,"KeyY",55,"Y",89,"VK_Y",s,s],[0,35,"KeyZ",56,"Z",90,"VK_Z",s,s],[0,36,"Digit1",22,"1",49,"VK_1",s,s],[0,37,"Digit2",23,"2",50,"VK_2",s,s],[0,38,"Digit3",24,"3",51,"VK_3",s,s],[0,39,"Digit4",25,"4",52,"VK_4",s,s],[0,40,"Digit5",26,"5",53,"VK_5",s,s],[0,41,"Digit6",27,"6",54,"VK_6",s,s],[0,42,"Digit7",28,"7",55,"VK_7",s,s],[0,43,"Digit8",29,"8",56,"VK_8",s,s],[0,44,"Digit9",30,"9",57,"VK_9",s,s],[0,45,"Digit0",21,"0",48,"VK_0",s,s],[1,46,"Enter",3,"Enter",13,"VK_RETURN",s,s],[1,47,"Escape",9,"Escape",27,"VK_ESCAPE",s,s],[1,48,"Backspace",1,"Backspace",8,"VK_BACK",s,s],[1,49,"Tab",2,"Tab",9,"VK_TAB",s,s],[1,50,"Space",10,"Space",32,"VK_SPACE",s,s],[0,51,"Minus",88,"-",189,"VK_OEM_MINUS","-","OEM_MINUS"],[0,52,"Equal",86,"=",187,"VK_OEM_PLUS","=","OEM_PLUS"],[0,53,"BracketLeft",92,"[",219,"VK_OEM_4","[","OEM_4"],[0,54,"BracketRight",94,"]",221,"VK_OEM_6","]","OEM_6"],[0,55,"Backslash",93,"\\",220,"VK_OEM_5","\\","OEM_5"],[0,56,"IntlHash",0,s,0,s,s,s],[0,57,"Semicolon",85,";",186,"VK_OEM_1",";","OEM_1"],[0,58,"Quote",95,"'",222,"VK_OEM_7","'","OEM_7"],[0,59,"Backquote",91,"`",192,"VK_OEM_3","`","OEM_3"],[0,60,"Comma",87,",",188,"VK_OEM_COMMA",",","OEM_COMMA"],[0,61,"Period",89,".",190,"VK_OEM_PERIOD",".","OEM_PERIOD"],[0,62,"Slash",90,"/",191,"VK_OEM_2","/","OEM_2"],[1,63,"CapsLock",8,"CapsLock",20,"VK_CAPITAL",s,s],[1,64,"F1",59,"F1",112,"VK_F1",s,s],[1,65,"F2",60,"F2",113,"VK_F2",s,s],[1,66,"F3",61,"F3",114,"VK_F3",s,s],[1,67,"F4",62,"F4",115,"VK_F4",s,s],[1,68,"F5",63,"F5",116,"VK_F5",s,s],[1,69,"F6",64,"F6",117,"VK_F6",s,s],[1,70,"F7",65,"F7",118,"VK_F7",s,s],[1,71,"F8",66,"F8",119,"VK_F8",s,s],[1,72,"F9",67,"F9",120,"VK_F9",s,s],[1,73,"F10",68,"F10",121,"VK_F10",s,s],[1,74,"F11",69,"F11",122,"VK_F11",s,s],[1,75,"F12",70,"F12",123,"VK_F12",s,s],[1,76,"PrintScreen",0,s,0,s,s,s],[1,77,"ScrollLock",84,"ScrollLock",145,"VK_SCROLL",s,s],[1,78,"Pause",7,"PauseBreak",19,"VK_PAUSE",s,s],[1,79,"Insert",19,"Insert",45,"VK_INSERT",s,s],[1,80,"Home",14,"Home",36,"VK_HOME",s,s],[1,81,"PageUp",11,"PageUp",33,"VK_PRIOR",s,s],[1,82,"Delete",20,"Delete",46,"VK_DELETE",s,s],[1,83,"End",13,"End",35,"VK_END",s,s],[1,84,"PageDown",12,"PageDown",34,"VK_NEXT",s,s],[1,85,"ArrowRight",17,"RightArrow",39,"VK_RIGHT","Right",s],[1,86,"ArrowLeft",15,"LeftArrow",37,"VK_LEFT","Left",s],[1,87,"ArrowDown",18,"DownArrow",40,"VK_DOWN","Down",s],[1,88,"ArrowUp",16,"UpArrow",38,"VK_UP","Up",s],[1,89,"NumLock",83,"NumLock",144,"VK_NUMLOCK",s,s],[1,90,"NumpadDivide",113,"NumPad_Divide",111,"VK_DIVIDE",s,s],[1,91,"NumpadMultiply",108,"NumPad_Multiply",106,"VK_MULTIPLY",s,s],[1,92,"NumpadSubtract",111,"NumPad_Subtract",109,"VK_SUBTRACT",s,s],[1,93,"NumpadAdd",109,"NumPad_Add",107,"VK_ADD",s,s],[1,94,"NumpadEnter",3,s,0,s,s,s],[1,95,"Numpad1",99,"NumPad1",97,"VK_NUMPAD1",s,s],[1,96,"Numpad2",100,"NumPad2",98,"VK_NUMPAD2",s,s],[1,97,"Numpad3",101,"NumPad3",99,"VK_NUMPAD3",s,s],[1,98,"Numpad4",102,"NumPad4",100,"VK_NUMPAD4",s,s],[1,99,"Numpad5",103,"NumPad5",101,"VK_NUMPAD5",s,s],[1,100,"Numpad6",104,"NumPad6",102,"VK_NUMPAD6",s,s],[1,101,"Numpad7",105,"NumPad7",103,"VK_NUMPAD7",s,s],[1,102,"Numpad8",106,"NumPad8",104,"VK_NUMPAD8",s,s],[1,103,"Numpad9",107,"NumPad9",105,"VK_NUMPAD9",s,s],[1,104,"Numpad0",98,"NumPad0",96,"VK_NUMPAD0",s,s],[1,105,"NumpadDecimal",112,"NumPad_Decimal",110,"VK_DECIMAL",s,s],[0,106,"IntlBackslash",97,"OEM_102",226,"VK_OEM_102",s,s],[1,107,"ContextMenu",58,"ContextMenu",93,s,s,s],[1,108,"Power",0,s,0,s,s,s],[1,109,"NumpadEqual",0,s,0,s,s,s],[1,110,"F13",71,"F13",124,"VK_F13",s,s],[1,111,"F14",72,"F14",125,"VK_F14",s,s],[1,112,"F15",73,"F15",126,"VK_F15",s,s],[1,113,"F16",74,"F16",127,"VK_F16",s,s],[1,114,"F17",75,"F17",128,"VK_F17",s,s],[1,115,"F18",76,"F18",129,"VK_F18",s,s],[1,116,"F19",77,"F19",130,"VK_F19",s,s],[1,117,"F20",78,"F20",131,"VK_F20",s,s],[1,118,"F21",79,"F21",132,"VK_F21",s,s],[1,119,"F22",80,"F22",133,"VK_F22",s,s],[1,120,"F23",81,"F23",134,"VK_F23",s,s],[1,121,"F24",82,"F24",135,"VK_F24",s,s],[1,122,"Open",0,s,0,s,s,s],[1,123,"Help",0,s,0,s,s,s],[1,124,"Select",0,s,0,s,s,s],[1,125,"Again",0,s,0,s,s,s],[1,126,"Undo",0,s,0,s,s,s],[1,127,"Cut",0,s,0,s,s,s],[1,128,"Copy",0,s,0,s,s,s],[1,129,"Paste",0,s,0,s,s,s],[1,130,"Find",0,s,0,s,s,s],[1,131,"AudioVolumeMute",117,"AudioVolumeMute",173,"VK_VOLUME_MUTE",s,s],[1,132,"AudioVolumeUp",118,"AudioVolumeUp",175,"VK_VOLUME_UP",s,s],[1,133,"AudioVolumeDown",119,"AudioVolumeDown",174,"VK_VOLUME_DOWN",s,s],[1,134,"NumpadComma",110,"NumPad_Separator",108,"VK_SEPARATOR",s,s],[0,135,"IntlRo",115,"ABNT_C1",193,"VK_ABNT_C1",s,s],[1,136,"KanaMode",0,s,0,s,s,s],[0,137,"IntlYen",0,s,0,s,s,s],[1,138,"Convert",0,s,0,s,s,s],[1,139,"NonConvert",0,s,0,s,s,s],[1,140,"Lang1",0,s,0,s,s,s],[1,141,"Lang2",0,s,0,s,s,s],[1,142,"Lang3",0,s,0,s,s,s],[1,143,"Lang4",0,s,0,s,s,s],[1,144,"Lang5",0,s,0,s,s,s],[1,145,"Abort",0,s,0,s,s,s],[1,146,"Props",0,s,0,s,s,s],[1,147,"NumpadParenLeft",0,s,0,s,s,s],[1,148,"NumpadParenRight",0,s,0,s,s,s],[1,149,"NumpadBackspace",0,s,0,s,s,s],[1,150,"NumpadMemoryStore",0,s,0,s,s,s],[1,151,"NumpadMemoryRecall",0,s,0,s,s,s],[1,152,"NumpadMemoryClear",0,s,0,s,s,s],[1,153,"NumpadMemoryAdd",0,s,0,s,s,s],[1,154,"NumpadMemorySubtract",0,s,0,s,s,s],[1,155,"NumpadClear",131,"Clear",12,"VK_CLEAR",s,s],[1,156,"NumpadClearEntry",0,s,0,s,s,s],[1,0,s,5,"Ctrl",17,"VK_CONTROL",s,s],[1,0,s,4,"Shift",16,"VK_SHIFT",s,s],[1,0,s,6,"Alt",18,"VK_MENU",s,s],[1,0,s,57,"Meta",91,"VK_COMMAND",s,s],[1,157,"ControlLeft",5,s,0,"VK_LCONTROL",s,s],[1,158,"ShiftLeft",4,s,0,"VK_LSHIFT",s,s],[1,159,"AltLeft",6,s,0,"VK_LMENU",s,s],[1,160,"MetaLeft",57,s,0,"VK_LWIN",s,s],[1,161,"ControlRight",5,s,0,"VK_RCONTROL",s,s],[1,162,"ShiftRight",4,s,0,"VK_RSHIFT",s,s],[1,163,"AltRight",6,s,0,"VK_RMENU",s,s],[1,164,"MetaRight",57,s,0,"VK_RWIN",s,s],[1,165,"BrightnessUp",0,s,0,s,s,s],[1,166,"BrightnessDown",0,s,0,s,s,s],[1,167,"MediaPlay",0,s,0,s,s,s],[1,168,"MediaRecord",0,s,0,s,s,s],[1,169,"MediaFastForward",0,s,0,s,s,s],[1,170,"MediaRewind",0,s,0,s,s,s],[1,171,"MediaTrackNext",124,"MediaTrackNext",176,"VK_MEDIA_NEXT_TRACK",s,s],[1,172,"MediaTrackPrevious",125,"MediaTrackPrevious",177,"VK_MEDIA_PREV_TRACK",s,s],[1,173,"MediaStop",126,"MediaStop",178,"VK_MEDIA_STOP",s,s],[1,174,"Eject",0,s,0,s,s,s],[1,175,"MediaPlayPause",127,"MediaPlayPause",179,"VK_MEDIA_PLAY_PAUSE",s,s],[1,176,"MediaSelect",128,"LaunchMediaPlayer",181,"VK_MEDIA_LAUNCH_MEDIA_SELECT",s,s],[1,177,"LaunchMail",129,"LaunchMail",180,"VK_MEDIA_LAUNCH_MAIL",s,s],[1,178,"LaunchApp2",130,"LaunchApp2",183,"VK_MEDIA_LAUNCH_APP2",s,s],[1,179,"LaunchApp1",0,s,0,"VK_MEDIA_LAUNCH_APP1",s,s],[1,180,"SelectTask",0,s,0,s,s,s],[1,181,"LaunchScreenSaver",0,s,0,s,s,s],[1,182,"BrowserSearch",120,"BrowserSearch",170,"VK_BROWSER_SEARCH",s,s],[1,183,"BrowserHome",121,"BrowserHome",172,"VK_BROWSER_HOME",s,s],[1,184,"BrowserBack",122,"BrowserBack",166,"VK_BROWSER_BACK",s,s],[1,185,"BrowserForward",123,"BrowserForward",167,"VK_BROWSER_FORWARD",s,s],[1,186,"BrowserStop",0,s,0,"VK_BROWSER_STOP",s,s],[1,187,"BrowserRefresh",0,s,0,"VK_BROWSER_REFRESH",s,s],[1,188,"BrowserFavorites",0,s,0,"VK_BROWSER_FAVORITES",s,s],[1,189,"ZoomToggle",0,s,0,s,s,s],[1,190,"MailReply",0,s,0,s,s,s],[1,191,"MailForward",0,s,0,s,s,s],[1,192,"MailSend",0,s,0,s,s,s],[1,0,s,114,"KeyInComposition",229,s,s,s],[1,0,s,116,"ABNT_C2",194,"VK_ABNT_C2",s,s],[1,0,s,96,"OEM_8",223,"VK_OEM_8",s,s],[1,0,s,0,s,0,"VK_KANA",s,s],[1,0,s,0,s,0,"VK_HANGUL",s,s],[1,0,s,0,s,0,"VK_JUNJA",s,s],[1,0,s,0,s,0,"VK_FINAL",s,s],[1,0,s,0,s,0,"VK_HANJA",s,s],[1,0,s,0,s,0,"VK_KANJI",s,s],[1,0,s,0,s,0,"VK_CONVERT",s,s],[1,0,s,0,s,0,"VK_NONCONVERT",s,s],[1,0,s,0,s,0,"VK_ACCEPT",s,s],[1,0,s,0,s,0,"VK_MODECHANGE",s,s],[1,0,s,0,s,0,"VK_SELECT",s,s],[1,0,s,0,s,0,"VK_PRINT",s,s],[1,0,s,0,s,0,"VK_EXECUTE",s,s],[1,0,s,0,s,0,"VK_SNAPSHOT",s,s],[1,0,s,0,s,0,"VK_HELP",s,s],[1,0,s,0,s,0,"VK_APPS",s,s],[1,0,s,0,s,0,"VK_PROCESSKEY",s,s],[1,0,s,0,s,0,"VK_PACKET",s,s],[1,0,s,0,s,0,"VK_DBE_SBCSCHAR",s,s],[1,0,s,0,s,0,"VK_DBE_DBCSCHAR",s,s],[1,0,s,0,s,0,"VK_ATTN",s,s],[1,0,s,0,s,0,"VK_CRSEL",s,s],[1,0,s,0,s,0,"VK_EXSEL",s,s],[1,0,s,0,s,0,"VK_EREOF",s,s],[1,0,s,0,s,0,"VK_PLAY",s,s],[1,0,s,0,s,0,"VK_ZOOM",s,s],[1,0,s,0,s,0,"VK_NONAME",s,s],[1,0,s,0,s,0,"VK_PA1",s,s],[1,0,s,0,s,0,"VK_OEM_CLEAR",s,s]],t=[],i=[];for(const n of e){const[o,r,a,l,d,c,u,h,g]=n;if(i[r]||(i[r]=!0,xQ[a]=r,DQ[a.toLowerCase()]=r,o&&(AA[r]=l)),!t[l]){if(t[l]=!0,!d)throw new Error(`String representation missing for key code ${l} around scan code ${a}`);Ew.define(l,d),qE.define(l,h||d),GE.define(l,g||h||d)}c&&(EW[c]=l)}})();var Id;(function(s){function e(a){return Ew.keyCodeToStr(a)}s.toString=e;function t(a){return Ew.strToKeyCode(a)}s.fromString=t;function i(a){return qE.keyCodeToStr(a)}s.toUserSettingsUS=i;function n(a){return GE.keyCodeToStr(a)}s.toUserSettingsGeneral=n;function o(a){return qE.strToKeyCode(a)||GE.strToKeyCode(a)}s.fromUserSettings=o;function r(a){if(a>=98&&a<=113)return null;switch(a){case 16:return"Up";case 18:return"Down";case 15:return"Left";case 17:return"Right"}return Ew.keyCodeToStr(a)}s.toElectronAccelerator=r})(Id||(Id={}));function dn(s,e){const t=(e&65535)<<16>>>0;return(s|t)>>>0}var n5={};let Mp;const kk=globalThis.vscode;if(typeof kk<"u"&&typeof kk.process<"u"){const s=kk.process;Mp={get platform(){return s.platform},get arch(){return s.arch},get env(){return s.env},cwd(){return s.cwd()}}}else typeof process<"u"?Mp={get platform(){return process.platform},get arch(){return process.arch},get env(){return n5},cwd(){return n5.VSCODE_CWD||process.cwd()}}:Mp={get platform(){return es?"win32":bt?"darwin":"linux"},get arch(){},get env(){return{}},cwd(){return"/"}};const DS=Mp.cwd,kS=Mp.env,kQ=Mp.platform,IQ=65,EQ=97,NQ=90,TQ=122,ou=46,ms=47,Ro=92,fc=58,MQ=63;class NW extends Error{constructor(e,t,i){let n;typeof t=="string"&&t.indexOf("not ")===0?(n="must not be",t=t.replace(/^not /,"")):n="must be";const o=e.indexOf(".")!==-1?"property":"argument";let r=`The "${e}" ${o} ${n} of type ${t}`;r+=`. Received type ${typeof i}`,super(r),this.code="ERR_INVALID_ARG_TYPE"}}function RQ(s,e){if(s===null||typeof s!="object")throw new NW(e,"Object",s)}function Ln(s,e){if(typeof s!="string")throw new NW(e,"string",s)}const th=kQ==="win32";function Wt(s){return s===ms||s===Ro}function ZE(s){return s===ms}function pc(s){return s>=IQ&&s<=NQ||s>=EQ&&s<=TQ}function IS(s,e,t,i){let n="",o=0,r=-1,a=0,l=0;for(let d=0;d<=s.length;++d){if(d<s.length)l=s.charCodeAt(d);else{if(i(l))break;l=ms}if(i(l)){if(!(r===d-1||a===1))if(a===2){if(n.length<2||o!==2||n.charCodeAt(n.length-1)!==ou||n.charCodeAt(n.length-2)!==ou){if(n.length>2){const c=n.lastIndexOf(t);c===-1?(n="",o=0):(n=n.slice(0,c),o=n.length-1-n.lastIndexOf(t)),r=d,a=0;continue}else if(n.length!==0){n="",o=0,r=d,a=0;continue}}e&&(n+=n.length>0?`${t}..`:"..",o=2)}else n.length>0?n+=`${t}${s.slice(r+1,d)}`:n=s.slice(r+1,d),o=d-r-1;r=d,a=0}else l===ou&&a!==-1?++a:a=-1}return n}function TW(s,e){RQ(e,"pathObject");const t=e.dir||e.root,i=e.base||`${e.name||""}${e.ext||""}`;return t?t===e.root?`${t}${i}`:`${t}${s}${i}`:i}const po={resolve(...s){let e="",t="",i=!1;for(let n=s.length-1;n>=-1;n--){let o;if(n>=0){if(o=s[n],Ln(o,"path"),o.length===0)continue}else e.length===0?o=DS():(o=kS[`=${e}`]||DS(),(o===void 0||o.slice(0,2).toLowerCase()!==e.toLowerCase()&&o.charCodeAt(2)===Ro)&&(o=`${e}\\`));const r=o.length;let a=0,l="",d=!1;const c=o.charCodeAt(0);if(r===1)Wt(c)&&(a=1,d=!0);else if(Wt(c))if(d=!0,Wt(o.charCodeAt(1))){let u=2,h=u;for(;u<r&&!Wt(o.charCodeAt(u));)u++;if(u<r&&u!==h){const g=o.slice(h,u);for(h=u;u<r&&Wt(o.charCodeAt(u));)u++;if(u<r&&u!==h){for(h=u;u<r&&!Wt(o.charCodeAt(u));)u++;(u===r||u!==h)&&(l=`\\\\${g}\\${o.slice(h,u)}`,a=u)}}}else a=1;else pc(c)&&o.charCodeAt(1)===fc&&(l=o.slice(0,2),a=2,r>2&&Wt(o.charCodeAt(2))&&(d=!0,a=3));if(l.length>0)if(e.length>0){if(l.toLowerCase()!==e.toLowerCase())continue}else e=l;if(i){if(e.length>0)break}else if(t=`${o.slice(a)}\\${t}`,i=d,d&&e.length>0)break}return t=IS(t,!i,"\\",Wt),i?`${e}\\${t}`:`${e}${t}`||"."},normalize(s){Ln(s,"path");const e=s.length;if(e===0)return".";let t=0,i,n=!1;const o=s.charCodeAt(0);if(e===1)return ZE(o)?"\\":s;if(Wt(o))if(n=!0,Wt(s.charCodeAt(1))){let a=2,l=a;for(;a<e&&!Wt(s.charCodeAt(a));)a++;if(a<e&&a!==l){const d=s.slice(l,a);for(l=a;a<e&&Wt(s.charCodeAt(a));)a++;if(a<e&&a!==l){for(l=a;a<e&&!Wt(s.charCodeAt(a));)a++;if(a===e)return`\\\\${d}\\${s.slice(l)}\\`;a!==l&&(i=`\\\\${d}\\${s.slice(l,a)}`,t=a)}}}else t=1;else pc(o)&&s.charCodeAt(1)===fc&&(i=s.slice(0,2),t=2,e>2&&Wt(s.charCodeAt(2))&&(n=!0,t=3));let r=t<e?IS(s.slice(t),!n,"\\",Wt):"";return r.length===0&&!n&&(r="."),r.length>0&&Wt(s.charCodeAt(e-1))&&(r+="\\"),i===void 0?n?`\\${r}`:r:n?`${i}\\${r}`:`${i}${r}`},isAbsolute(s){Ln(s,"path");const e=s.length;if(e===0)return!1;const t=s.charCodeAt(0);return Wt(t)||e>2&&pc(t)&&s.charCodeAt(1)===fc&&Wt(s.charCodeAt(2))},join(...s){if(s.length===0)return".";let e,t;for(let o=0;o<s.length;++o){const r=s[o];Ln(r,"path"),r.length>0&&(e===void 0?e=t=r:e+=`\\${r}`)}if(e===void 0)return".";let i=!0,n=0;if(typeof t=="string"&&Wt(t.charCodeAt(0))){++n;const o=t.length;o>1&&Wt(t.charCodeAt(1))&&(++n,o>2&&(Wt(t.charCodeAt(2))?++n:i=!1))}if(i){for(;n<e.length&&Wt(e.charCodeAt(n));)n++;n>=2&&(e=`\\${e.slice(n)}`)}return po.normalize(e)},relative(s,e){if(Ln(s,"from"),Ln(e,"to"),s===e)return"";const t=po.resolve(s),i=po.resolve(e);if(t===i||(s=t.toLowerCase(),e=i.toLowerCase(),s===e))return"";let n=0;for(;n<s.length&&s.charCodeAt(n)===Ro;)n++;let o=s.length;for(;o-1>n&&s.charCodeAt(o-1)===Ro;)o--;const r=o-n;let a=0;for(;a<e.length&&e.charCodeAt(a)===Ro;)a++;let l=e.length;for(;l-1>a&&e.charCodeAt(l-1)===Ro;)l--;const d=l-a,c=r<d?r:d;let u=-1,h=0;for(;h<c;h++){const f=s.charCodeAt(n+h);if(f!==e.charCodeAt(a+h))break;f===Ro&&(u=h)}if(h!==c){if(u===-1)return i}else{if(d>c){if(e.charCodeAt(a+h)===Ro)return i.slice(a+h+1);if(h===2)return i.slice(a+h)}r>c&&(s.charCodeAt(n+h)===Ro?u=h:h===2&&(u=3)),u===-1&&(u=0)}let g="";for(h=n+u+1;h<=o;++h)(h===o||s.charCodeAt(h)===Ro)&&(g+=g.length===0?"..":"\\..");return a+=u,g.length>0?`${g}${i.slice(a,l)}`:(i.charCodeAt(a)===Ro&&++a,i.slice(a,l))},toNamespacedPath(s){if(typeof s!="string"||s.length===0)return s;const e=po.resolve(s);if(e.length<=2)return s;if(e.charCodeAt(0)===Ro){if(e.charCodeAt(1)===Ro){const t=e.charCodeAt(2);if(t!==MQ&&t!==ou)return`\\\\?\\UNC\\${e.slice(2)}`}}else if(pc(e.charCodeAt(0))&&e.charCodeAt(1)===fc&&e.charCodeAt(2)===Ro)return`\\\\?\\${e}`;return s},dirname(s){Ln(s,"path");const e=s.length;if(e===0)return".";let t=-1,i=0;const n=s.charCodeAt(0);if(e===1)return Wt(n)?s:".";if(Wt(n)){if(t=i=1,Wt(s.charCodeAt(1))){let a=2,l=a;for(;a<e&&!Wt(s.charCodeAt(a));)a++;if(a<e&&a!==l){for(l=a;a<e&&Wt(s.charCodeAt(a));)a++;if(a<e&&a!==l){for(l=a;a<e&&!Wt(s.charCodeAt(a));)a++;if(a===e)return s;a!==l&&(t=i=a+1)}}}}else pc(n)&&s.charCodeAt(1)===fc&&(t=e>2&&Wt(s.charCodeAt(2))?3:2,i=t);let o=-1,r=!0;for(let a=e-1;a>=i;--a)if(Wt(s.charCodeAt(a))){if(!r){o=a;break}}else r=!1;if(o===-1){if(t===-1)return".";o=t}return s.slice(0,o)},basename(s,e){e!==void 0&&Ln(e,"ext"),Ln(s,"path");let t=0,i=-1,n=!0,o;if(s.length>=2&&pc(s.charCodeAt(0))&&s.charCodeAt(1)===fc&&(t=2),e!==void 0&&e.length>0&&e.length<=s.length){if(e===s)return"";let r=e.length-1,a=-1;for(o=s.length-1;o>=t;--o){const l=s.charCodeAt(o);if(Wt(l)){if(!n){t=o+1;break}}else a===-1&&(n=!1,a=o+1),r>=0&&(l===e.charCodeAt(r)?--r===-1&&(i=o):(r=-1,i=a))}return t===i?i=a:i===-1&&(i=s.length),s.slice(t,i)}for(o=s.length-1;o>=t;--o)if(Wt(s.charCodeAt(o))){if(!n){t=o+1;break}}else i===-1&&(n=!1,i=o+1);return i===-1?"":s.slice(t,i)},extname(s){Ln(s,"path");let e=0,t=-1,i=0,n=-1,o=!0,r=0;s.length>=2&&s.charCodeAt(1)===fc&&pc(s.charCodeAt(0))&&(e=i=2);for(let a=s.length-1;a>=e;--a){const l=s.charCodeAt(a);if(Wt(l)){if(!o){i=a+1;break}continue}n===-1&&(o=!1,n=a+1),l===ou?t===-1?t=a:r!==1&&(r=1):t!==-1&&(r=-1)}return t===-1||n===-1||r===0||r===1&&t===n-1&&t===i+1?"":s.slice(t,n)},format:TW.bind(null,"\\"),parse(s){Ln(s,"path");const e={root:"",dir:"",base:"",ext:"",name:""};if(s.length===0)return e;const t=s.length;let i=0,n=s.charCodeAt(0);if(t===1)return Wt(n)?(e.root=e.dir=s,e):(e.base=e.name=s,e);if(Wt(n)){if(i=1,Wt(s.charCodeAt(1))){let u=2,h=u;for(;u<t&&!Wt(s.charCodeAt(u));)u++;if(u<t&&u!==h){for(h=u;u<t&&Wt(s.charCodeAt(u));)u++;if(u<t&&u!==h){for(h=u;u<t&&!Wt(s.charCodeAt(u));)u++;u===t?i=u:u!==h&&(i=u+1)}}}}else if(pc(n)&&s.charCodeAt(1)===fc){if(t<=2)return e.root=e.dir=s,e;if(i=2,Wt(s.charCodeAt(2))){if(t===3)return e.root=e.dir=s,e;i=3}}i>0&&(e.root=s.slice(0,i));let o=-1,r=i,a=-1,l=!0,d=s.length-1,c=0;for(;d>=i;--d){if(n=s.charCodeAt(d),Wt(n)){if(!l){r=d+1;break}continue}a===-1&&(l=!1,a=d+1),n===ou?o===-1?o=d:c!==1&&(c=1):o!==-1&&(c=-1)}return a!==-1&&(o===-1||c===0||c===1&&o===a-1&&o===r+1?e.base=e.name=s.slice(r,a):(e.name=s.slice(r,o),e.base=s.slice(r,a),e.ext=s.slice(o,a))),r>0&&r!==i?e.dir=s.slice(0,r-1):e.dir=e.root,e},sep:"\\",delimiter:";",win32:null,posix:null},AQ=(()=>{if(th){const s=/\\/g;return()=>{const e=DS().replace(s,"/");return e.slice(e.indexOf("/"))}}return()=>DS()})(),an={resolve(...s){let e="",t=!1;for(let i=s.length-1;i>=-1&&!t;i--){const n=i>=0?s[i]:AQ();Ln(n,"path"),n.length!==0&&(e=`${n}/${e}`,t=n.charCodeAt(0)===ms)}return e=IS(e,!t,"/",ZE),t?`/${e}`:e.length>0?e:"."},normalize(s){if(Ln(s,"path"),s.length===0)return".";const e=s.charCodeAt(0)===ms,t=s.charCodeAt(s.length-1)===ms;return s=IS(s,!e,"/",ZE),s.length===0?e?"/":t?"./":".":(t&&(s+="/"),e?`/${s}`:s)},isAbsolute(s){return Ln(s,"path"),s.length>0&&s.charCodeAt(0)===ms},join(...s){if(s.length===0)return".";let e;for(let t=0;t<s.length;++t){const i=s[t];Ln(i,"path"),i.length>0&&(e===void 0?e=i:e+=`/${i}`)}return e===void 0?".":an.normalize(e)},relative(s,e){if(Ln(s,"from"),Ln(e,"to"),s===e||(s=an.resolve(s),e=an.resolve(e),s===e))return"";const t=1,i=s.length,n=i-t,o=1,r=e.length-o,a=n<r?n:r;let l=-1,d=0;for(;d<a;d++){const u=s.charCodeAt(t+d);if(u!==e.charCodeAt(o+d))break;u===ms&&(l=d)}if(d===a)if(r>a){if(e.charCodeAt(o+d)===ms)return e.slice(o+d+1);if(d===0)return e.slice(o+d)}else n>a&&(s.charCodeAt(t+d)===ms?l=d:d===0&&(l=0));let c="";for(d=t+l+1;d<=i;++d)(d===i||s.charCodeAt(d)===ms)&&(c+=c.length===0?"..":"/..");return`${c}${e.slice(o+l)}`},toNamespacedPath(s){return s},dirname(s){if(Ln(s,"path"),s.length===0)return".";const e=s.charCodeAt(0)===ms;let t=-1,i=!0;for(let n=s.length-1;n>=1;--n)if(s.charCodeAt(n)===ms){if(!i){t=n;break}}else i=!1;return t===-1?e?"/":".":e&&t===1?"//":s.slice(0,t)},basename(s,e){e!==void 0&&Ln(e,"ext"),Ln(s,"path");let t=0,i=-1,n=!0,o;if(e!==void 0&&e.length>0&&e.length<=s.length){if(e===s)return"";let r=e.length-1,a=-1;for(o=s.length-1;o>=0;--o){const l=s.charCodeAt(o);if(l===ms){if(!n){t=o+1;break}}else a===-1&&(n=!1,a=o+1),r>=0&&(l===e.charCodeAt(r)?--r===-1&&(i=o):(r=-1,i=a))}return t===i?i=a:i===-1&&(i=s.length),s.slice(t,i)}for(o=s.length-1;o>=0;--o)if(s.charCodeAt(o)===ms){if(!n){t=o+1;break}}else i===-1&&(n=!1,i=o+1);return i===-1?"":s.slice(t,i)},extname(s){Ln(s,"path");let e=-1,t=0,i=-1,n=!0,o=0;for(let r=s.length-1;r>=0;--r){const a=s.charCodeAt(r);if(a===ms){if(!n){t=r+1;break}continue}i===-1&&(n=!1,i=r+1),a===ou?e===-1?e=r:o!==1&&(o=1):e!==-1&&(o=-1)}return e===-1||i===-1||o===0||o===1&&e===i-1&&e===t+1?"":s.slice(e,i)},format:TW.bind(null,"/"),parse(s){Ln(s,"path");const e={root:"",dir:"",base:"",ext:"",name:""};if(s.length===0)return e;const t=s.charCodeAt(0)===ms;let i;t?(e.root="/",i=1):i=0;let n=-1,o=0,r=-1,a=!0,l=s.length-1,d=0;for(;l>=i;--l){const c=s.charCodeAt(l);if(c===ms){if(!a){o=l+1;break}continue}r===-1&&(a=!1,r=l+1),c===ou?n===-1?n=l:d!==1&&(d=1):n!==-1&&(d=-1)}if(r!==-1){const c=o===0&&t?1:o;n===-1||d===0||d===1&&n===r-1&&n===o+1?e.base=e.name=s.slice(c,r):(e.name=s.slice(c,n),e.base=s.slice(c,r),e.ext=s.slice(n,r))}return o>0?e.dir=s.slice(0,o-1):t&&(e.dir="/"),e},sep:"/",delimiter:":",win32:null,posix:null};an.win32=po.win32=po;an.posix=po.posix=an;const MW=th?po.normalize:an.normalize,PQ=th?po.resolve:an.resolve,OQ=th?po.relative:an.relative,RW=th?po.dirname:an.dirname,ru=th?po.basename:an.basename,FQ=th?po.extname:an.extname,Aa=th?po.sep:an.sep,BQ=/^\w[\w\d+.-]*$/,WQ=/^\//,VQ=/^\/\//;function HQ(s,e){if(!s.scheme&&e)throw new Error(`[UriError]: Scheme is missing: {scheme: "", authority: "${s.authority}", path: "${s.path}", query: "${s.query}", fragment: "${s.fragment}"}`);if(s.scheme&&!BQ.test(s.scheme))throw new Error("[UriError]: Scheme contains illegal characters.");if(s.path){if(s.authority){if(!WQ.test(s.path))throw new Error('[UriError]: If a URI contains an authority component, then the path component must either be empty or begin with a slash ("/") character')}else if(VQ.test(s.path))throw new Error('[UriError]: If a URI does not contain an authority component, then the path cannot begin with two slash characters ("//")')}}function zQ(s,e){return!s&&!e?"file":s}function UQ(s,e){switch(s){case"https":case"http":case"file":e?e[0]!==Ca&&(e=Ca+e):e=Ca;break}return e}const Ki="",Ca="/",$Q=/^(([^:/?#]+?):)?(\/\/([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?/;class Pe{static isUri(e){return e instanceof Pe?!0:e?typeof e.authority=="string"&&typeof e.fragment=="string"&&typeof e.path=="string"&&typeof e.query=="string"&&typeof e.scheme=="string"&&typeof e.fsPath=="string"&&typeof e.with=="function"&&typeof e.toString=="function":!1}constructor(e,t,i,n,o,r=!1){typeof e=="object"?(this.scheme=e.scheme||Ki,this.authority=e.authority||Ki,this.path=e.path||Ki,this.query=e.query||Ki,this.fragment=e.fragment||Ki):(this.scheme=zQ(e,r),this.authority=t||Ki,this.path=UQ(this.scheme,i||Ki),this.query=n||Ki,this.fragment=o||Ki,HQ(this,r))}get fsPath(){return ES(this,!1)}with(e){if(!e)return this;let{scheme:t,authority:i,path:n,query:o,fragment:r}=e;return t===void 0?t=this.scheme:t===null&&(t=Ki),i===void 0?i=this.authority:i===null&&(i=Ki),n===void 0?n=this.path:n===null&&(n=Ki),o===void 0?o=this.query:o===null&&(o=Ki),r===void 0?r=this.fragment:r===null&&(r=Ki),t===this.scheme&&i===this.authority&&n===this.path&&o===this.query&&r===this.fragment?this:new Lf(t,i,n,o,r)}static parse(e,t=!1){const i=$Q.exec(e);return i?new Lf(i[2]||Ki,s1(i[4]||Ki),s1(i[5]||Ki),s1(i[7]||Ki),s1(i[9]||Ki),t):new Lf(Ki,Ki,Ki,Ki,Ki)}static file(e){let t=Ki;if(es&&(e=e.replace(/\\/g,Ca)),e[0]===Ca&&e[1]===Ca){const i=e.indexOf(Ca,2);i===-1?(t=e.substring(2),e=Ca):(t=e.substring(2,i),e=e.substring(i)||Ca)}return new Lf("file",t,e,Ki,Ki)}static from(e,t){return new Lf(e.scheme,e.authority,e.path,e.query,e.fragment,t)}static joinPath(e,...t){if(!e.path)throw new Error("[UriError]: cannot call joinPath on URI without path");let i;return es&&e.scheme==="file"?i=Pe.file(po.join(ES(e,!0),...t)).path:i=an.join(e.path,...t),e.with({path:i})}toString(e=!1){return YE(this,e)}toJSON(){return this}static revive(e){var t,i;if(e){if(e instanceof Pe)return e;{const n=new Lf(e);return n._formatted=(t=e.external)!==null&&t!==void 0?t:null,n._fsPath=e._sep===AW&&(i=e.fsPath)!==null&&i!==void 0?i:null,n}}else return e}}const AW=es?1:void 0;let Lf=class extends Pe{constructor(){super(...arguments),this._formatted=null,this._fsPath=null}get fsPath(){return this._fsPath||(this._fsPath=ES(this,!1)),this._fsPath}toString(e=!1){return e?YE(this,!0):(this._formatted||(this._formatted=YE(this,!1)),this._formatted)}toJSON(){const e={$mid:1};return this._fsPath&&(e.fsPath=this._fsPath,e._sep=AW),this._formatted&&(e.external=this._formatted),this.path&&(e.path=this.path),this.scheme&&(e.scheme=this.scheme),this.authority&&(e.authority=this.authority),this.query&&(e.query=this.query),this.fragment&&(e.fragment=this.fragment),e}};const PW={58:"%3A",47:"%2F",63:"%3F",35:"%23",91:"%5B",93:"%5D",64:"%40",33:"%21",36:"%24",38:"%26",39:"%27",40:"%28",41:"%29",42:"%2A",43:"%2B",44:"%2C",59:"%3B",61:"%3D",32:"%20"};function s5(s,e,t){let i,n=-1;for(let o=0;o<s.length;o++){const r=s.charCodeAt(o);if(r>=97&&r<=122||r>=65&&r<=90||r>=48&&r<=57||r===45||r===46||r===95||r===126||e&&r===47||t&&r===91||t&&r===93||t&&r===58)n!==-1&&(i+=encodeURIComponent(s.substring(n,o)),n=-1),i!==void 0&&(i+=s.charAt(o));else{i===void 0&&(i=s.substr(0,o));const a=PW[r];a!==void 0?(n!==-1&&(i+=encodeURIComponent(s.substring(n,o)),n=-1),i+=a):n===-1&&(n=o)}}return n!==-1&&(i+=encodeURIComponent(s.substring(n))),i!==void 0?i:s}function jQ(s){let e;for(let t=0;t<s.length;t++){const i=s.charCodeAt(t);i===35||i===63?(e===void 0&&(e=s.substr(0,t)),e+=PW[i]):e!==void 0&&(e+=s[t])}return e!==void 0?e:s}function ES(s,e){let t;return s.authority&&s.path.length>1&&s.scheme==="file"?t=`//${s.authority}${s.path}`:s.path.charCodeAt(0)===47&&(s.path.charCodeAt(1)>=65&&s.path.charCodeAt(1)<=90||s.path.charCodeAt(1)>=97&&s.path.charCodeAt(1)<=122)&&s.path.charCodeAt(2)===58?e?t=s.path.substr(1):t=s.path[1].toLowerCase()+s.path.substr(2):t=s.path,es&&(t=t.replace(/\//g,"\\")),t}function YE(s,e){const t=e?jQ:s5;let i="",{scheme:n,authority:o,path:r,query:a,fragment:l}=s;if(n&&(i+=n,i+=":"),(o||n==="file")&&(i+=Ca,i+=Ca),o){let d=o.indexOf("@");if(d!==-1){const c=o.substr(0,d);o=o.substr(d+1),d=c.lastIndexOf(":"),d===-1?i+=t(c,!1,!1):(i+=t(c.substr(0,d),!1,!1),i+=":",i+=t(c.substr(d+1),!1,!0)),i+="@"}o=o.toLowerCase(),d=o.lastIndexOf(":"),d===-1?i+=t(o,!1,!0):(i+=t(o.substr(0,d),!1,!0),i+=o.substr(d))}if(r){if(r.length>=3&&r.charCodeAt(0)===47&&r.charCodeAt(2)===58){const d=r.charCodeAt(1);d>=65&&d<=90&&(r=`/${String.fromCharCode(d+32)}:${r.substr(3)}`)}else if(r.length>=2&&r.charCodeAt(1)===58){const d=r.charCodeAt(0);d>=65&&d<=90&&(r=`${String.fromCharCode(d+32)}:${r.substr(2)}`)}i+=t(r,!0,!1)}return a&&(i+="?",i+=t(a,!1,!1)),l&&(i+="#",i+=e?l:s5(l,!1,!1)),i}function OW(s){try{return decodeURIComponent(s)}catch{return s.length>3?s.substr(0,3)+OW(s.substr(3)):s}}const o5=/(%[0-9A-Za-z][0-9A-Za-z])+/g;function s1(s){return s.match(o5)?s.replace(o5,e=>OW(e)):s}let H=class Th{constructor(e,t){this.lineNumber=e,this.column=t}with(e=this.lineNumber,t=this.column){return e===this.lineNumber&&t===this.column?this:new Th(e,t)}delta(e=0,t=0){return this.with(this.lineNumber+e,this.column+t)}equals(e){return Th.equals(this,e)}static equals(e,t){return!e&&!t?!0:!!e&&!!t&&e.lineNumber===t.lineNumber&&e.column===t.column}isBefore(e){return Th.isBefore(this,e)}static isBefore(e,t){return e.lineNumber<t.lineNumber?!0:t.lineNumber<e.lineNumber?!1:e.column<t.column}isBeforeOrEqual(e){return Th.isBeforeOrEqual(this,e)}static isBeforeOrEqual(e,t){return e.lineNumber<t.lineNumber?!0:t.lineNumber<e.lineNumber?!1:e.column<=t.column}static compare(e,t){const i=e.lineNumber|0,n=t.lineNumber|0;if(i===n){const o=e.column|0,r=t.column|0;return o-r}return i-n}clone(){return new Th(this.lineNumber,this.column)}toString(){return"("+this.lineNumber+","+this.column+")"}static lift(e){return new Th(e.lineNumber,e.column)}static isIPosition(e){return e&&typeof e.lineNumber=="number"&&typeof e.column=="number"}toJSON(){return{lineNumber:this.lineNumber,column:this.column}}},D=class Tn{constructor(e,t,i,n){e>i||e===i&&t>n?(this.startLineNumber=i,this.startColumn=n,this.endLineNumber=e,this.endColumn=t):(this.startLineNumber=e,this.startColumn=t,this.endLineNumber=i,this.endColumn=n)}isEmpty(){return Tn.isEmpty(this)}static isEmpty(e){return e.startLineNumber===e.endLineNumber&&e.startColumn===e.endColumn}containsPosition(e){return Tn.containsPosition(this,e)}static containsPosition(e,t){return!(t.lineNumber<e.startLineNumber||t.lineNumber>e.endLineNumber||t.lineNumber===e.startLineNumber&&t.column<e.startColumn||t.lineNumber===e.endLineNumber&&t.column>e.endColumn)}static strictContainsPosition(e,t){return!(t.lineNumber<e.startLineNumber||t.lineNumber>e.endLineNumber||t.lineNumber===e.startLineNumber&&t.column<=e.startColumn||t.lineNumber===e.endLineNumber&&t.column>=e.endColumn)}containsRange(e){return Tn.containsRange(this,e)}static containsRange(e,t){return!(t.startLineNumber<e.startLineNumber||t.endLineNumber<e.startLineNumber||t.startLineNumber>e.endLineNumber||t.endLineNumber>e.endLineNumber||t.startLineNumber===e.startLineNumber&&t.startColumn<e.startColumn||t.endLineNumber===e.endLineNumber&&t.endColumn>e.endColumn)}strictContainsRange(e){return Tn.strictContainsRange(this,e)}static strictContainsRange(e,t){return!(t.startLineNumber<e.startLineNumber||t.endLineNumber<e.startLineNumber||t.startLineNumber>e.endLineNumber||t.endLineNumber>e.endLineNumber||t.startLineNumber===e.startLineNumber&&t.startColumn<=e.startColumn||t.endLineNumber===e.endLineNumber&&t.endColumn>=e.endColumn)}plusRange(e){return Tn.plusRange(this,e)}static plusRange(e,t){let i,n,o,r;return t.startLineNumber<e.startLineNumber?(i=t.startLineNumber,n=t.startColumn):t.startLineNumber===e.startLineNumber?(i=t.startLineNumber,n=Math.min(t.startColumn,e.startColumn)):(i=e.startLineNumber,n=e.startColumn),t.endLineNumber>e.endLineNumber?(o=t.endLineNumber,r=t.endColumn):t.endLineNumber===e.endLineNumber?(o=t.endLineNumber,r=Math.max(t.endColumn,e.endColumn)):(o=e.endLineNumber,r=e.endColumn),new Tn(i,n,o,r)}intersectRanges(e){return Tn.intersectRanges(this,e)}static intersectRanges(e,t){let i=e.startLineNumber,n=e.startColumn,o=e.endLineNumber,r=e.endColumn;const a=t.startLineNumber,l=t.startColumn,d=t.endLineNumber,c=t.endColumn;return i<a?(i=a,n=l):i===a&&(n=Math.max(n,l)),o>d?(o=d,r=c):o===d&&(r=Math.min(r,c)),i>o||i===o&&n>r?null:new Tn(i,n,o,r)}equalsRange(e){return Tn.equalsRange(this,e)}static equalsRange(e,t){return!e&&!t?!0:!!e&&!!t&&e.startLineNumber===t.startLineNumber&&e.startColumn===t.startColumn&&e.endLineNumber===t.endLineNumber&&e.endColumn===t.endColumn}getEndPosition(){return Tn.getEndPosition(this)}static getEndPosition(e){return new H(e.endLineNumber,e.endColumn)}getStartPosition(){return Tn.getStartPosition(this)}static getStartPosition(e){return new H(e.startLineNumber,e.startColumn)}toString(){return"["+this.startLineNumber+","+this.startColumn+" -> "+this.endLineNumber+","+this.endColumn+"]"}setEndPosition(e,t){return new Tn(this.startLineNumber,this.startColumn,e,t)}setStartPosition(e,t){return new Tn(e,t,this.endLineNumber,this.endColumn)}collapseToStart(){return Tn.collapseToStart(this)}static collapseToStart(e){return new Tn(e.startLineNumber,e.startColumn,e.startLineNumber,e.startColumn)}collapseToEnd(){return Tn.collapseToEnd(this)}static collapseToEnd(e){return new Tn(e.endLineNumber,e.endColumn,e.endLineNumber,e.endColumn)}delta(e){return new Tn(this.startLineNumber+e,this.startColumn,this.endLineNumber+e,this.endColumn)}static fromPositions(e,t=e){return new Tn(e.lineNumber,e.column,t.lineNumber,t.column)}static lift(e){return e?new Tn(e.startLineNumber,e.startColumn,e.endLineNumber,e.endColumn):null}static isIRange(e){return e&&typeof e.startLineNumber=="number"&&typeof e.startColumn=="number"&&typeof e.endLineNumber=="number"&&typeof e.endColumn=="number"}static areIntersectingOrTouching(e,t){return!(e.endLineNumber<t.startLineNumber||e.endLineNumber===t.startLineNumber&&e.endColumn<t.startColumn||t.endLineNumber<e.startLineNumber||t.endLineNumber===e.startLineNumber&&t.endColumn<e.startColumn)}static areIntersecting(e,t){return!(e.endLineNumber<t.startLineNumber||e.endLineNumber===t.startLineNumber&&e.endColumn<=t.startColumn||t.endLineNumber<e.startLineNumber||t.endLineNumber===e.startLineNumber&&t.endColumn<=e.startColumn)}static compareRangesUsingStarts(e,t){if(e&&t){const o=e.startLineNumber|0,r=t.startLineNumber|0;if(o===r){const a=e.startColumn|0,l=t.startColumn|0;if(a===l){const d=e.endLineNumber|0,c=t.endLineNumber|0;if(d===c){const u=e.endColumn|0,h=t.endColumn|0;return u-h}return d-c}return a-l}return o-r}return(e?1:0)-(t?1:0)}static compareRangesUsingEnds(e,t){return e.endLineNumber===t.endLineNumber?e.endColumn===t.endColumn?e.startLineNumber===t.startLineNumber?e.startColumn-t.startColumn:e.startLineNumber-t.startLineNumber:e.endColumn-t.endColumn:e.endLineNumber-t.endLineNumber}static spansMultipleLines(e){return e.endLineNumber>e.startLineNumber}toJSON(){return this}},De=class Pr extends D{constructor(e,t,i,n){super(e,t,i,n),this.selectionStartLineNumber=e,this.selectionStartColumn=t,this.positionLineNumber=i,this.positionColumn=n}toString(){return"["+this.selectionStartLineNumber+","+this.selectionStartColumn+" -> "+this.positionLineNumber+","+this.positionColumn+"]"}equalsSelection(e){return Pr.selectionsEqual(this,e)}static selectionsEqual(e,t){return e.selectionStartLineNumber===t.selectionStartLineNumber&&e.selectionStartColumn===t.selectionStartColumn&&e.positionLineNumber===t.positionLineNumber&&e.positionColumn===t.positionColumn}getDirection(){return this.selectionStartLineNumber===this.startLineNumber&&this.selectionStartColumn===this.startColumn?0:1}setEndPosition(e,t){return this.getDirection()===0?new Pr(this.startLineNumber,this.startColumn,e,t):new Pr(e,t,this.startLineNumber,this.startColumn)}getPosition(){return new H(this.positionLineNumber,this.positionColumn)}getSelectionStart(){return new H(this.selectionStartLineNumber,this.selectionStartColumn)}setStartPosition(e,t){return this.getDirection()===0?new Pr(e,t,this.endLineNumber,this.endColumn):new Pr(this.endLineNumber,this.endColumn,e,t)}static fromPositions(e,t=e){return new Pr(e.lineNumber,e.column,t.lineNumber,t.column)}static fromRange(e,t){return t===0?new Pr(e.startLineNumber,e.startColumn,e.endLineNumber,e.endColumn):new Pr(e.endLineNumber,e.endColumn,e.startLineNumber,e.startColumn)}static liftSelection(e){return new Pr(e.selectionStartLineNumber,e.selectionStartColumn,e.positionLineNumber,e.positionColumn)}static selectionsArrEqual(e,t){if(e&&!t||!e&&t)return!1;if(!e&&!t)return!0;if(e.length!==t.length)return!1;for(let i=0,n=e.length;i<n;i++)if(!this.selectionsEqual(e[i],t[i]))return!1;return!0}static isISelection(e){return e&&typeof e.selectionStartLineNumber=="number"&&typeof e.selectionStartColumn=="number"&&typeof e.positionLineNumber=="number"&&typeof e.positionColumn=="number"}static createWithDirection(e,t,i,n,o){return o===0?new Pr(e,t,i,n):new Pr(i,n,e,t)}};const XE=Object.create(null);function y(s,e){if(Ps(e)){const t=XE[e];if(t===void 0)throw new Error(`${s} references an unknown codicon: ${e}`);e=t}return XE[s]=e,{id:s}}function FW(){return XE}const le={add:y("add",6e4),plus:y("plus",6e4),gistNew:y("gist-new",6e4),repoCreate:y("repo-create",6e4),lightbulb:y("lightbulb",60001),lightBulb:y("light-bulb",60001),repo:y("repo",60002),repoDelete:y("repo-delete",60002),gistFork:y("gist-fork",60003),repoForked:y("repo-forked",60003),gitPullRequest:y("git-pull-request",60004),gitPullRequestAbandoned:y("git-pull-request-abandoned",60004),recordKeys:y("record-keys",60005),keyboard:y("keyboard",60005),tag:y("tag",60006),tagAdd:y("tag-add",60006),tagRemove:y("tag-remove",60006),gitPullRequestLabel:y("git-pull-request-label",60006),person:y("person",60007),personFollow:y("person-follow",60007),personOutline:y("person-outline",60007),personFilled:y("person-filled",60007),gitBranch:y("git-branch",60008),gitBranchCreate:y("git-branch-create",60008),gitBranchDelete:y("git-branch-delete",60008),sourceControl:y("source-control",60008),mirror:y("mirror",60009),mirrorPublic:y("mirror-public",60009),star:y("star",60010),starAdd:y("star-add",60010),starDelete:y("star-delete",60010),starEmpty:y("star-empty",60010),comment:y("comment",60011),commentAdd:y("comment-add",60011),alert:y("alert",60012),warning:y("warning",60012),search:y("search",60013),searchSave:y("search-save",60013),logOut:y("log-out",60014),signOut:y("sign-out",60014),logIn:y("log-in",60015),signIn:y("sign-in",60015),eye:y("eye",60016),eyeUnwatch:y("eye-unwatch",60016),eyeWatch:y("eye-watch",60016),circleFilled:y("circle-filled",60017),primitiveDot:y("primitive-dot",60017),closeDirty:y("close-dirty",60017),debugBreakpoint:y("debug-breakpoint",60017),debugBreakpointDisabled:y("debug-breakpoint-disabled",60017),debugHint:y("debug-hint",60017),primitiveSquare:y("primitive-square",60018),edit:y("edit",60019),pencil:y("pencil",60019),info:y("info",60020),issueOpened:y("issue-opened",60020),gistPrivate:y("gist-private",60021),gitForkPrivate:y("git-fork-private",60021),lock:y("lock",60021),mirrorPrivate:y("mirror-private",60021),close:y("close",60022),removeClose:y("remove-close",60022),x:y("x",60022),repoSync:y("repo-sync",60023),sync:y("sync",60023),clone:y("clone",60024),desktopDownload:y("desktop-download",60024),beaker:y("beaker",60025),microscope:y("microscope",60025),vm:y("vm",60026),deviceDesktop:y("device-desktop",60026),file:y("file",60027),fileText:y("file-text",60027),more:y("more",60028),ellipsis:y("ellipsis",60028),kebabHorizontal:y("kebab-horizontal",60028),mailReply:y("mail-reply",60029),reply:y("reply",60029),organization:y("organization",60030),organizationFilled:y("organization-filled",60030),organizationOutline:y("organization-outline",60030),newFile:y("new-file",60031),fileAdd:y("file-add",60031),newFolder:y("new-folder",60032),fileDirectoryCreate:y("file-directory-create",60032),trash:y("trash",60033),trashcan:y("trashcan",60033),history:y("history",60034),clock:y("clock",60034),folder:y("folder",60035),fileDirectory:y("file-directory",60035),symbolFolder:y("symbol-folder",60035),logoGithub:y("logo-github",60036),markGithub:y("mark-github",60036),github:y("github",60036),terminal:y("terminal",60037),console:y("console",60037),repl:y("repl",60037),zap:y("zap",60038),symbolEvent:y("symbol-event",60038),error:y("error",60039),stop:y("stop",60039),variable:y("variable",60040),symbolVariable:y("symbol-variable",60040),array:y("array",60042),symbolArray:y("symbol-array",60042),symbolModule:y("symbol-module",60043),symbolPackage:y("symbol-package",60043),symbolNamespace:y("symbol-namespace",60043),symbolObject:y("symbol-object",60043),symbolMethod:y("symbol-method",60044),symbolFunction:y("symbol-function",60044),symbolConstructor:y("symbol-constructor",60044),symbolBoolean:y("symbol-boolean",60047),symbolNull:y("symbol-null",60047),symbolNumeric:y("symbol-numeric",60048),symbolNumber:y("symbol-number",60048),symbolStructure:y("symbol-structure",60049),symbolStruct:y("symbol-struct",60049),symbolParameter:y("symbol-parameter",60050),symbolTypeParameter:y("symbol-type-parameter",60050),symbolKey:y("symbol-key",60051),symbolText:y("symbol-text",60051),symbolReference:y("symbol-reference",60052),goToFile:y("go-to-file",60052),symbolEnum:y("symbol-enum",60053),symbolValue:y("symbol-value",60053),symbolRuler:y("symbol-ruler",60054),symbolUnit:y("symbol-unit",60054),activateBreakpoints:y("activate-breakpoints",60055),archive:y("archive",60056),arrowBoth:y("arrow-both",60057),arrowDown:y("arrow-down",60058),arrowLeft:y("arrow-left",60059),arrowRight:y("arrow-right",60060),arrowSmallDown:y("arrow-small-down",60061),arrowSmallLeft:y("arrow-small-left",60062),arrowSmallRight:y("arrow-small-right",60063),arrowSmallUp:y("arrow-small-up",60064),arrowUp:y("arrow-up",60065),bell:y("bell",60066),bold:y("bold",60067),book:y("book",60068),bookmark:y("bookmark",60069),debugBreakpointConditionalUnverified:y("debug-breakpoint-conditional-unverified",60070),debugBreakpointConditional:y("debug-breakpoint-conditional",60071),debugBreakpointConditionalDisabled:y("debug-breakpoint-conditional-disabled",60071),debugBreakpointDataUnverified:y("debug-breakpoint-data-unverified",60072),debugBreakpointData:y("debug-breakpoint-data",60073),debugBreakpointDataDisabled:y("debug-breakpoint-data-disabled",60073),debugBreakpointLogUnverified:y("debug-breakpoint-log-unverified",60074),debugBreakpointLog:y("debug-breakpoint-log",60075),debugBreakpointLogDisabled:y("debug-breakpoint-log-disabled",60075),briefcase:y("briefcase",60076),broadcast:y("broadcast",60077),browser:y("browser",60078),bug:y("bug",60079),calendar:y("calendar",60080),caseSensitive:y("case-sensitive",60081),check:y("check",60082),checklist:y("checklist",60083),chevronDown:y("chevron-down",60084),dropDownButton:y("drop-down-button",60084),chevronLeft:y("chevron-left",60085),chevronRight:y("chevron-right",60086),chevronUp:y("chevron-up",60087),chromeClose:y("chrome-close",60088),chromeMaximize:y("chrome-maximize",60089),chromeMinimize:y("chrome-minimize",60090),chromeRestore:y("chrome-restore",60091),circle:y("circle",60092),circleOutline:y("circle-outline",60092),debugBreakpointUnverified:y("debug-breakpoint-unverified",60092),circleSlash:y("circle-slash",60093),circuitBoard:y("circuit-board",60094),clearAll:y("clear-all",60095),clippy:y("clippy",60096),closeAll:y("close-all",60097),cloudDownload:y("cloud-download",60098),cloudUpload:y("cloud-upload",60099),code:y("code",60100),collapseAll:y("collapse-all",60101),colorMode:y("color-mode",60102),commentDiscussion:y("comment-discussion",60103),compareChanges:y("compare-changes",60157),creditCard:y("credit-card",60105),dash:y("dash",60108),dashboard:y("dashboard",60109),database:y("database",60110),debugContinue:y("debug-continue",60111),debugDisconnect:y("debug-disconnect",60112),debugPause:y("debug-pause",60113),debugRestart:y("debug-restart",60114),debugStart:y("debug-start",60115),debugStepInto:y("debug-step-into",60116),debugStepOut:y("debug-step-out",60117),debugStepOver:y("debug-step-over",60118),debugStop:y("debug-stop",60119),debug:y("debug",60120),deviceCameraVideo:y("device-camera-video",60121),deviceCamera:y("device-camera",60122),deviceMobile:y("device-mobile",60123),diffAdded:y("diff-added",60124),diffIgnored:y("diff-ignored",60125),diffModified:y("diff-modified",60126),diffRemoved:y("diff-removed",60127),diffRenamed:y("diff-renamed",60128),diff:y("diff",60129),discard:y("discard",60130),editorLayout:y("editor-layout",60131),emptyWindow:y("empty-window",60132),exclude:y("exclude",60133),extensions:y("extensions",60134),eyeClosed:y("eye-closed",60135),fileBinary:y("file-binary",60136),fileCode:y("file-code",60137),fileMedia:y("file-media",60138),filePdf:y("file-pdf",60139),fileSubmodule:y("file-submodule",60140),fileSymlinkDirectory:y("file-symlink-directory",60141),fileSymlinkFile:y("file-symlink-file",60142),fileZip:y("file-zip",60143),files:y("files",60144),filter:y("filter",60145),flame:y("flame",60146),foldDown:y("fold-down",60147),foldUp:y("fold-up",60148),fold:y("fold",60149),folderActive:y("folder-active",60150),folderOpened:y("folder-opened",60151),gear:y("gear",60152),gift:y("gift",60153),gistSecret:y("gist-secret",60154),gist:y("gist",60155),gitCommit:y("git-commit",60156),gitCompare:y("git-compare",60157),gitMerge:y("git-merge",60158),githubAction:y("github-action",60159),githubAlt:y("github-alt",60160),globe:y("globe",60161),grabber:y("grabber",60162),graph:y("graph",60163),gripper:y("gripper",60164),heart:y("heart",60165),home:y("home",60166),horizontalRule:y("horizontal-rule",60167),hubot:y("hubot",60168),inbox:y("inbox",60169),issueClosed:y("issue-closed",60324),issueReopened:y("issue-reopened",60171),issues:y("issues",60172),italic:y("italic",60173),jersey:y("jersey",60174),json:y("json",60175),bracket:y("bracket",60175),kebabVertical:y("kebab-vertical",60176),key:y("key",60177),law:y("law",60178),lightbulbAutofix:y("lightbulb-autofix",60179),linkExternal:y("link-external",60180),link:y("link",60181),listOrdered:y("list-ordered",60182),listUnordered:y("list-unordered",60183),liveShare:y("live-share",60184),loading:y("loading",60185),location:y("location",60186),mailRead:y("mail-read",60187),mail:y("mail",60188),markdown:y("markdown",60189),megaphone:y("megaphone",60190),mention:y("mention",60191),milestone:y("milestone",60192),gitPullRequestMilestone:y("git-pull-request-milestone",60192),mortarBoard:y("mortar-board",60193),move:y("move",60194),multipleWindows:y("multiple-windows",60195),mute:y("mute",60196),noNewline:y("no-newline",60197),note:y("note",60198),octoface:y("octoface",60199),openPreview:y("open-preview",60200),package:y("package",60201),paintcan:y("paintcan",60202),pin:y("pin",60203),play:y("play",60204),run:y("run",60204),plug:y("plug",60205),preserveCase:y("preserve-case",60206),preview:y("preview",60207),project:y("project",60208),pulse:y("pulse",60209),question:y("question",60210),quote:y("quote",60211),radioTower:y("radio-tower",60212),reactions:y("reactions",60213),references:y("references",60214),refresh:y("refresh",60215),regex:y("regex",60216),remoteExplorer:y("remote-explorer",60217),remote:y("remote",60218),remove:y("remove",60219),replaceAll:y("replace-all",60220),replace:y("replace",60221),repoClone:y("repo-clone",60222),repoForcePush:y("repo-force-push",60223),repoPull:y("repo-pull",60224),repoPush:y("repo-push",60225),report:y("report",60226),requestChanges:y("request-changes",60227),rocket:y("rocket",60228),rootFolderOpened:y("root-folder-opened",60229),rootFolder:y("root-folder",60230),rss:y("rss",60231),ruby:y("ruby",60232),saveAll:y("save-all",60233),saveAs:y("save-as",60234),save:y("save",60235),screenFull:y("screen-full",60236),screenNormal:y("screen-normal",60237),searchStop:y("search-stop",60238),server:y("server",60240),settingsGear:y("settings-gear",60241),settings:y("settings",60242),shield:y("shield",60243),smiley:y("smiley",60244),sortPrecedence:y("sort-precedence",60245),splitHorizontal:y("split-horizontal",60246),splitVertical:y("split-vertical",60247),squirrel:y("squirrel",60248),starFull:y("star-full",60249),starHalf:y("star-half",60250),symbolClass:y("symbol-class",60251),symbolColor:y("symbol-color",60252),symbolCustomColor:y("symbol-customcolor",60252),symbolConstant:y("symbol-constant",60253),symbolEnumMember:y("symbol-enum-member",60254),symbolField:y("symbol-field",60255),symbolFile:y("symbol-file",60256),symbolInterface:y("symbol-interface",60257),symbolKeyword:y("symbol-keyword",60258),symbolMisc:y("symbol-misc",60259),symbolOperator:y("symbol-operator",60260),symbolProperty:y("symbol-property",60261),wrench:y("wrench",60261),wrenchSubaction:y("wrench-subaction",60261),symbolSnippet:y("symbol-snippet",60262),tasklist:y("tasklist",60263),telescope:y("telescope",60264),textSize:y("text-size",60265),threeBars:y("three-bars",60266),thumbsdown:y("thumbsdown",60267),thumbsup:y("thumbsup",60268),tools:y("tools",60269),triangleDown:y("triangle-down",60270),triangleLeft:y("triangle-left",60271),triangleRight:y("triangle-right",60272),triangleUp:y("triangle-up",60273),twitter:y("twitter",60274),unfold:y("unfold",60275),unlock:y("unlock",60276),unmute:y("unmute",60277),unverified:y("unverified",60278),verified:y("verified",60279),versions:y("versions",60280),vmActive:y("vm-active",60281),vmOutline:y("vm-outline",60282),vmRunning:y("vm-running",60283),watch:y("watch",60284),whitespace:y("whitespace",60285),wholeWord:y("whole-word",60286),window:y("window",60287),wordWrap:y("word-wrap",60288),zoomIn:y("zoom-in",60289),zoomOut:y("zoom-out",60290),listFilter:y("list-filter",60291),listFlat:y("list-flat",60292),listSelection:y("list-selection",60293),selection:y("selection",60293),listTree:y("list-tree",60294),debugBreakpointFunctionUnverified:y("debug-breakpoint-function-unverified",60295),debugBreakpointFunction:y("debug-breakpoint-function",60296),debugBreakpointFunctionDisabled:y("debug-breakpoint-function-disabled",60296),debugStackframeActive:y("debug-stackframe-active",60297),circleSmallFilled:y("circle-small-filled",60298),debugStackframeDot:y("debug-stackframe-dot",60298),debugStackframe:y("debug-stackframe",60299),debugStackframeFocused:y("debug-stackframe-focused",60299),debugBreakpointUnsupported:y("debug-breakpoint-unsupported",60300),symbolString:y("symbol-string",60301),debugReverseContinue:y("debug-reverse-continue",60302),debugStepBack:y("debug-step-back",60303),debugRestartFrame:y("debug-restart-frame",60304),callIncoming:y("call-incoming",60306),callOutgoing:y("call-outgoing",60307),menu:y("menu",60308),expandAll:y("expand-all",60309),feedback:y("feedback",60310),gitPullRequestReviewer:y("git-pull-request-reviewer",60310),groupByRefType:y("group-by-ref-type",60311),ungroupByRefType:y("ungroup-by-ref-type",60312),account:y("account",60313),gitPullRequestAssignee:y("git-pull-request-assignee",60313),bellDot:y("bell-dot",60314),debugConsole:y("debug-console",60315),library:y("library",60316),output:y("output",60317),runAll:y("run-all",60318),syncIgnored:y("sync-ignored",60319),pinned:y("pinned",60320),githubInverted:y("github-inverted",60321),debugAlt:y("debug-alt",60305),serverProcess:y("server-process",60322),serverEnvironment:y("server-environment",60323),pass:y("pass",60324),stopCircle:y("stop-circle",60325),playCircle:y("play-circle",60326),record:y("record",60327),debugAltSmall:y("debug-alt-small",60328),vmConnect:y("vm-connect",60329),cloud:y("cloud",60330),merge:y("merge",60331),exportIcon:y("export",60332),graphLeft:y("graph-left",60333),magnet:y("magnet",60334),notebook:y("notebook",60335),redo:y("redo",60336),checkAll:y("check-all",60337),pinnedDirty:y("pinned-dirty",60338),passFilled:y("pass-filled",60339),circleLargeFilled:y("circle-large-filled",60340),circleLarge:y("circle-large",60341),circleLargeOutline:y("circle-large-outline",60341),combine:y("combine",60342),gather:y("gather",60342),table:y("table",60343),variableGroup:y("variable-group",60344),typeHierarchy:y("type-hierarchy",60345),typeHierarchySub:y("type-hierarchy-sub",60346),typeHierarchySuper:y("type-hierarchy-super",60347),gitPullRequestCreate:y("git-pull-request-create",60348),runAbove:y("run-above",60349),runBelow:y("run-below",60350),notebookTemplate:y("notebook-template",60351),debugRerun:y("debug-rerun",60352),workspaceTrusted:y("workspace-trusted",60353),workspaceUntrusted:y("workspace-untrusted",60354),workspaceUnspecified:y("workspace-unspecified",60355),terminalCmd:y("terminal-cmd",60356),terminalDebian:y("terminal-debian",60357),terminalLinux:y("terminal-linux",60358),terminalPowershell:y("terminal-powershell",60359),terminalTmux:y("terminal-tmux",60360),terminalUbuntu:y("terminal-ubuntu",60361),terminalBash:y("terminal-bash",60362),arrowSwap:y("arrow-swap",60363),copy:y("copy",60364),personAdd:y("person-add",60365),filterFilled:y("filter-filled",60366),wand:y("wand",60367),debugLineByLine:y("debug-line-by-line",60368),inspect:y("inspect",60369),layers:y("layers",60370),layersDot:y("layers-dot",60371),layersActive:y("layers-active",60372),compass:y("compass",60373),compassDot:y("compass-dot",60374),compassActive:y("compass-active",60375),azure:y("azure",60376),issueDraft:y("issue-draft",60377),gitPullRequestClosed:y("git-pull-request-closed",60378),gitPullRequestDraft:y("git-pull-request-draft",60379),debugAll:y("debug-all",60380),debugCoverage:y("debug-coverage",60381),runErrors:y("run-errors",60382),folderLibrary:y("folder-library",60383),debugContinueSmall:y("debug-continue-small",60384),beakerStop:y("beaker-stop",60385),graphLine:y("graph-line",60386),graphScatter:y("graph-scatter",60387),pieChart:y("pie-chart",60388),bracketDot:y("bracket-dot",60389),bracketError:y("bracket-error",60390),lockSmall:y("lock-small",60391),azureDevops:y("azure-devops",60392),verifiedFilled:y("verified-filled",60393),newLine:y("newline",60394),layout:y("layout",60395),layoutActivitybarLeft:y("layout-activitybar-left",60396),layoutActivitybarRight:y("layout-activitybar-right",60397),layoutPanelLeft:y("layout-panel-left",60398),layoutPanelCenter:y("layout-panel-center",60399),layoutPanelJustify:y("layout-panel-justify",60400),layoutPanelRight:y("layout-panel-right",60401),layoutPanel:y("layout-panel",60402),layoutSidebarLeft:y("layout-sidebar-left",60403),layoutSidebarRight:y("layout-sidebar-right",60404),layoutStatusbar:y("layout-statusbar",60405),layoutMenubar:y("layout-menubar",60406),layoutCentered:y("layout-centered",60407),layoutSidebarRightOff:y("layout-sidebar-right-off",60416),layoutPanelOff:y("layout-panel-off",60417),layoutSidebarLeftOff:y("layout-sidebar-left-off",60418),target:y("target",60408),indent:y("indent",60409),recordSmall:y("record-small",60410),errorSmall:y("error-small",60411),arrowCircleDown:y("arrow-circle-down",60412),arrowCircleLeft:y("arrow-circle-left",60413),arrowCircleRight:y("arrow-circle-right",60414),arrowCircleUp:y("arrow-circle-up",60415),heartFilled:y("heart-filled",60420),map:y("map",60421),mapFilled:y("map-filled",60422),circleSmall:y("circle-small",60423),bellSlash:y("bell-slash",60424),bellSlashDot:y("bell-slash-dot",60425),commentUnresolved:y("comment-unresolved",60426),gitPullRequestGoToChanges:y("git-pull-request-go-to-changes",60427),gitPullRequestNewChanges:y("git-pull-request-new-changes",60428),searchFuzzy:y("search-fuzzy",60429),commentDraft:y("comment-draft",60430),send:y("send",60431),sparkle:y("sparkle",60432),insert:y("insert",60433),mic:y("mic",60434),thumbsDownFilled:y("thumbsdown-filled",60435),thumbsUpFilled:y("thumbsup-filled",60436),coffee:y("coffee",60437),snake:y("snake",60438),game:y("game",60439),vr:y("vr",60440),chip:y("chip",60441),piano:y("piano",60442),music:y("music",60443),micFilled:y("mic-filled",60444),gitFetch:y("git-fetch",60445),copilot:y("copilot",60446),lightbulbSparkle:y("lightbulb-sparkle",60447),lightbulbSparkleAutofix:y("lightbulb-sparkle-autofix",60447),robot:y("robot",60448),sparkleFilled:y("sparkle-filled",60449),diffSingle:y("diff-single",60450),diffMultiple:y("diff-multiple",60451),dialogError:y("dialog-error","error"),dialogWarning:y("dialog-warning","warning"),dialogInfo:y("dialog-info","info"),dialogClose:y("dialog-close","close"),treeItemExpanded:y("tree-item-expanded","chevron-down"),treeFilterOnTypeOn:y("tree-filter-on-type-on","list-filter"),treeFilterOnTypeOff:y("tree-filter-on-type-off","list-selection"),treeFilterClear:y("tree-filter-clear","close"),treeItemLoading:y("tree-item-loading","loading"),menuSelection:y("menu-selection","check"),menuSubmenu:y("menu-submenu","chevron-right"),menuBarMore:y("menubar-more","more"),scrollbarButtonLeft:y("scrollbar-button-left","triangle-left"),scrollbarButtonRight:y("scrollbar-button-right","triangle-right"),scrollbarButtonUp:y("scrollbar-button-up","triangle-up"),scrollbarButtonDown:y("scrollbar-button-down","triangle-down"),toolBarMore:y("toolbar-more","more"),quickInputBack:y("quick-input-back","arrow-left")};let KQ=class{constructor(){this._tokenizationSupports=new Map,this._factories=new Map,this._onDidChange=new W,this.onDidChange=this._onDidChange.event,this._colorMap=null}handleChange(e){this._onDidChange.fire({changedLanguages:e,changedColorMap:!1})}register(e,t){return this._tokenizationSupports.set(e,t),this.handleChange([e]),Fe(()=>{this._tokenizationSupports.get(e)===t&&(this._tokenizationSupports.delete(e),this.handleChange([e]))})}get(e){return this._tokenizationSupports.get(e)||null}registerFactory(e,t){var i;(i=this._factories.get(e))===null||i===void 0||i.dispose();const n=new qQ(this,e,t);return this._factories.set(e,n),Fe(()=>{const o=this._factories.get(e);!o||o!==n||(this._factories.delete(e),o.dispose())})}async getOrCreate(e){const t=this.get(e);if(t)return t;const i=this._factories.get(e);return!i||i.isResolved?null:(await i.resolve(),this.get(e))}isResolved(e){if(this.get(e))return!0;const i=this._factories.get(e);return!!(!i||i.isResolved)}setColorMap(e){this._colorMap=e,this._onDidChange.fire({changedLanguages:Array.from(this._tokenizationSupports.keys()),changedColorMap:!0})}getColorMap(){return this._colorMap}getDefaultBackground(){return this._colorMap&&this._colorMap.length>2?this._colorMap[2]:null}};class qQ extends j{get isResolved(){return this._isResolved}constructor(e,t,i){super(),this._registry=e,this._languageId=t,this._factory=i,this._isDisposed=!1,this._resolvePromise=null,this._isResolved=!1}dispose(){this._isDisposed=!0,super.dispose()}async resolve(){return this._resolvePromise||(this._resolvePromise=this._create()),this._resolvePromise}async _create(){const e=await this._factory.tokenizationSupport;this._isResolved=!0,e&&!this._isDisposed&&this._register(this._registry.register(this._languageId,e))}}let S0=class{constructor(e,t,i){this.offset=e,this.type=t,this.language=i,this._tokenBrand=void 0}toString(){return"("+this.offset+", "+this.type+")"}};class PA{constructor(e,t){this.tokens=e,this.endState=t,this._tokenizationResultBrand=void 0}}class qL{constructor(e,t){this.tokens=e,this.endState=t,this._encodedTokenizationResultBrand=void 0}}var y0;(function(s){const e=new Map;e.set(0,le.symbolMethod),e.set(1,le.symbolFunction),e.set(2,le.symbolConstructor),e.set(3,le.symbolField),e.set(4,le.symbolVariable),e.set(5,le.symbolClass),e.set(6,le.symbolStruct),e.set(7,le.symbolInterface),e.set(8,le.symbolModule),e.set(9,le.symbolProperty),e.set(10,le.symbolEvent),e.set(11,le.symbolOperator),e.set(12,le.symbolUnit),e.set(13,le.symbolValue),e.set(15,le.symbolEnum),e.set(14,le.symbolConstant),e.set(15,le.symbolEnum),e.set(16,le.symbolEnumMember),e.set(17,le.symbolKeyword),e.set(27,le.symbolSnippet),e.set(18,le.symbolText),e.set(19,le.symbolColor),e.set(20,le.symbolFile),e.set(21,le.symbolReference),e.set(22,le.symbolCustomColor),e.set(23,le.symbolFolder),e.set(24,le.symbolTypeParameter),e.set(25,le.account),e.set(26,le.issues);function t(o){let r=e.get(o);return r||(console.info("No codicon found for CompletionItemKind "+o),r=le.symbolProperty),r}s.toIcon=t;const i=new Map;i.set("method",0),i.set("function",1),i.set("constructor",2),i.set("field",3),i.set("variable",4),i.set("class",5),i.set("struct",6),i.set("interface",7),i.set("module",8),i.set("property",9),i.set("event",10),i.set("operator",11),i.set("unit",12),i.set("value",13),i.set("constant",14),i.set("enum",15),i.set("enum-member",16),i.set("enumMember",16),i.set("keyword",17),i.set("snippet",27),i.set("text",18),i.set("color",19),i.set("file",20),i.set("reference",21),i.set("customcolor",22),i.set("folder",23),i.set("type-parameter",24),i.set("typeParameter",24),i.set("account",25),i.set("issue",26);function n(o,r){let a=i.get(o);return typeof a>"u"&&!r&&(a=9),a}s.fromString=n})(y0||(y0={}));var jd;(function(s){s[s.Automatic=0]="Automatic",s[s.Explicit=1]="Explicit"})(jd||(jd={}));class BW{constructor(e,t,i,n){this.range=e,this.text=t,this.completionKind=i,this.isSnippetText=n}equals(e){return D.lift(this.range).equalsRange(e.range)&&this.text===e.text&&this.completionKind===e.completionKind&&this.isSnippetText===e.isSnippetText}}var Bl;(function(s){s[s.Invoke=1]="Invoke",s[s.TriggerCharacter=2]="TriggerCharacter",s[s.ContentChange=3]="ContentChange"})(Bl||(Bl={}));var L0;(function(s){s[s.Text=0]="Text",s[s.Read=1]="Read",s[s.Write=2]="Write"})(L0||(L0={}));function GQ(s){return s&&Pe.isUri(s.uri)&&D.isIRange(s.range)&&(D.isIRange(s.originSelectionRange)||D.isIRange(s.targetSelectionRange))}const ZQ={17:p("Array","array"),16:p("Boolean","boolean"),4:p("Class","class"),13:p("Constant","constant"),8:p("Constructor","constructor"),9:p("Enum","enumeration"),21:p("EnumMember","enumeration member"),23:p("Event","event"),7:p("Field","field"),0:p("File","file"),11:p("Function","function"),10:p("Interface","interface"),19:p("Key","key"),5:p("Method","method"),1:p("Module","module"),2:p("Namespace","namespace"),20:p("Null","null"),15:p("Number","number"),18:p("Object","object"),24:p("Operator","operator"),3:p("Package","package"),6:p("Property","property"),14:p("String","string"),22:p("Struct","struct"),25:p("TypeParameter","type parameter"),12:p("Variable","variable")};function YQ(s,e){return p("symbolAriaLabel","{0} ({1})",s,ZQ[e])}var NS;(function(s){const e=new Map;e.set(0,le.symbolFile),e.set(1,le.symbolModule),e.set(2,le.symbolNamespace),e.set(3,le.symbolPackage),e.set(4,le.symbolClass),e.set(5,le.symbolMethod),e.set(6,le.symbolProperty),e.set(7,le.symbolField),e.set(8,le.symbolConstructor),e.set(9,le.symbolEnum),e.set(10,le.symbolInterface),e.set(11,le.symbolFunction),e.set(12,le.symbolVariable),e.set(13,le.symbolConstant),e.set(14,le.symbolString),e.set(15,le.symbolNumber),e.set(16,le.symbolBoolean),e.set(17,le.symbolArray),e.set(18,le.symbolObject),e.set(19,le.symbolKey),e.set(20,le.symbolNull),e.set(21,le.symbolEnumMember),e.set(22,le.symbolStruct),e.set(23,le.symbolEvent),e.set(24,le.symbolOperator),e.set(25,le.symbolTypeParameter);function t(i){let n=e.get(i);return n||(console.info("No codicon found for SymbolKind "+i),n=le.symbolProperty),n}s.toIcon=t})(NS||(NS={}));class Rs{static fromValue(e){switch(e){case"comment":return Rs.Comment;case"imports":return Rs.Imports;case"region":return Rs.Region}return new Rs(e)}constructor(e){this.value=e}}Rs.Comment=new Rs("comment");Rs.Imports=new Rs("imports");Rs.Region=new Rs("region");var QE;(function(s){function e(t){return!t||typeof t!="object"?!1:typeof t.id=="string"&&typeof t.title=="string"}s.is=e})(QE||(QE={}));var TS;(function(s){s[s.Type=1]="Type",s[s.Parameter=2]="Parameter"})(TS||(TS={}));class XQ{constructor(e){this.createSupport=e,this._tokenizationSupport=null}dispose(){this._tokenizationSupport&&this._tokenizationSupport.then(e=>{e&&e.dispose()})}get tokenizationSupport(){return this._tokenizationSupport||(this._tokenizationSupport=this.createSupport()),this._tokenizationSupport}}const xi=new KQ;var JE;(function(s){s[s.Unknown=0]="Unknown",s[s.Disabled=1]="Disabled",s[s.Enabled=2]="Enabled"})(JE||(JE={}));var eN;(function(s){s[s.Invoke=1]="Invoke",s[s.Auto=2]="Auto"})(eN||(eN={}));var tN;(function(s){s[s.None=0]="None",s[s.KeepWhitespace=1]="KeepWhitespace",s[s.InsertAsSnippet=4]="InsertAsSnippet"})(tN||(tN={}));var iN;(function(s){s[s.Method=0]="Method",s[s.Function=1]="Function",s[s.Constructor=2]="Constructor",s[s.Field=3]="Field",s[s.Variable=4]="Variable",s[s.Class=5]="Class",s[s.Struct=6]="Struct",s[s.Interface=7]="Interface",s[s.Module=8]="Module",s[s.Property=9]="Property",s[s.Event=10]="Event",s[s.Operator=11]="Operator",s[s.Unit=12]="Unit",s[s.Value=13]="Value",s[s.Constant=14]="Constant",s[s.Enum=15]="Enum",s[s.EnumMember=16]="EnumMember",s[s.Keyword=17]="Keyword",s[s.Text=18]="Text",s[s.Color=19]="Color",s[s.File=20]="File",s[s.Reference=21]="Reference",s[s.Customcolor=22]="Customcolor",s[s.Folder=23]="Folder",s[s.TypeParameter=24]="TypeParameter",s[s.User=25]="User",s[s.Issue=26]="Issue",s[s.Snippet=27]="Snippet"})(iN||(iN={}));var nN;(function(s){s[s.Deprecated=1]="Deprecated"})(nN||(nN={}));var sN;(function(s){s[s.Invoke=0]="Invoke",s[s.TriggerCharacter=1]="TriggerCharacter",s[s.TriggerForIncompleteCompletions=2]="TriggerForIncompleteCompletions"})(sN||(sN={}));var oN;(function(s){s[s.EXACT=0]="EXACT",s[s.ABOVE=1]="ABOVE",s[s.BELOW=2]="BELOW"})(oN||(oN={}));var rN;(function(s){s[s.NotSet=0]="NotSet",s[s.ContentFlush=1]="ContentFlush",s[s.RecoverFromMarkers=2]="RecoverFromMarkers",s[s.Explicit=3]="Explicit",s[s.Paste=4]="Paste",s[s.Undo=5]="Undo",s[s.Redo=6]="Redo"})(rN||(rN={}));var aN;(function(s){s[s.LF=1]="LF",s[s.CRLF=2]="CRLF"})(aN||(aN={}));var lN;(function(s){s[s.Text=0]="Text",s[s.Read=1]="Read",s[s.Write=2]="Write"})(lN||(lN={}));var dN;(function(s){s[s.None=0]="None",s[s.Keep=1]="Keep",s[s.Brackets=2]="Brackets",s[s.Advanced=3]="Advanced",s[s.Full=4]="Full"})(dN||(dN={}));var cN;(function(s){s[s.acceptSuggestionOnCommitCharacter=0]="acceptSuggestionOnCommitCharacter",s[s.acceptSuggestionOnEnter=1]="acceptSuggestionOnEnter",s[s.accessibilitySupport=2]="accessibilitySupport",s[s.accessibilityPageSize=3]="accessibilityPageSize",s[s.ariaLabel=4]="ariaLabel",s[s.ariaRequired=5]="ariaRequired",s[s.autoClosingBrackets=6]="autoClosingBrackets",s[s.autoClosingComments=7]="autoClosingComments",s[s.screenReaderAnnounceInlineSuggestion=8]="screenReaderAnnounceInlineSuggestion",s[s.autoClosingDelete=9]="autoClosingDelete",s[s.autoClosingOvertype=10]="autoClosingOvertype",s[s.autoClosingQuotes=11]="autoClosingQuotes",s[s.autoIndent=12]="autoIndent",s[s.automaticLayout=13]="automaticLayout",s[s.autoSurround=14]="autoSurround",s[s.bracketPairColorization=15]="bracketPairColorization",s[s.guides=16]="guides",s[s.codeLens=17]="codeLens",s[s.codeLensFontFamily=18]="codeLensFontFamily",s[s.codeLensFontSize=19]="codeLensFontSize",s[s.colorDecorators=20]="colorDecorators",s[s.colorDecoratorsLimit=21]="colorDecoratorsLimit",s[s.columnSelection=22]="columnSelection",s[s.comments=23]="comments",s[s.contextmenu=24]="contextmenu",s[s.copyWithSyntaxHighlighting=25]="copyWithSyntaxHighlighting",s[s.cursorBlinking=26]="cursorBlinking",s[s.cursorSmoothCaretAnimation=27]="cursorSmoothCaretAnimation",s[s.cursorStyle=28]="cursorStyle",s[s.cursorSurroundingLines=29]="cursorSurroundingLines",s[s.cursorSurroundingLinesStyle=30]="cursorSurroundingLinesStyle",s[s.cursorWidth=31]="cursorWidth",s[s.disableLayerHinting=32]="disableLayerHinting",s[s.disableMonospaceOptimizations=33]="disableMonospaceOptimizations",s[s.domReadOnly=34]="domReadOnly",s[s.dragAndDrop=35]="dragAndDrop",s[s.dropIntoEditor=36]="dropIntoEditor",s[s.emptySelectionClipboard=37]="emptySelectionClipboard",s[s.experimentalWhitespaceRendering=38]="experimentalWhitespaceRendering",s[s.extraEditorClassName=39]="extraEditorClassName",s[s.fastScrollSensitivity=40]="fastScrollSensitivity",s[s.find=41]="find",s[s.fixedOverflowWidgets=42]="fixedOverflowWidgets",s[s.folding=43]="folding",s[s.foldingStrategy=44]="foldingStrategy",s[s.foldingHighlight=45]="foldingHighlight",s[s.foldingImportsByDefault=46]="foldingImportsByDefault",s[s.foldingMaximumRegions=47]="foldingMaximumRegions",s[s.unfoldOnClickAfterEndOfLine=48]="unfoldOnClickAfterEndOfLine",s[s.fontFamily=49]="fontFamily",s[s.fontInfo=50]="fontInfo",s[s.fontLigatures=51]="fontLigatures",s[s.fontSize=52]="fontSize",s[s.fontWeight=53]="fontWeight",s[s.fontVariations=54]="fontVariations",s[s.formatOnPaste=55]="formatOnPaste",s[s.formatOnType=56]="formatOnType",s[s.glyphMargin=57]="glyphMargin",s[s.gotoLocation=58]="gotoLocation",s[s.hideCursorInOverviewRuler=59]="hideCursorInOverviewRuler",s[s.hover=60]="hover",s[s.inDiffEditor=61]="inDiffEditor",s[s.inlineSuggest=62]="inlineSuggest",s[s.letterSpacing=63]="letterSpacing",s[s.lightbulb=64]="lightbulb",s[s.lineDecorationsWidth=65]="lineDecorationsWidth",s[s.lineHeight=66]="lineHeight",s[s.lineNumbers=67]="lineNumbers",s[s.lineNumbersMinChars=68]="lineNumbersMinChars",s[s.linkedEditing=69]="linkedEditing",s[s.links=70]="links",s[s.matchBrackets=71]="matchBrackets",s[s.minimap=72]="minimap",s[s.mouseStyle=73]="mouseStyle",s[s.mouseWheelScrollSensitivity=74]="mouseWheelScrollSensitivity",s[s.mouseWheelZoom=75]="mouseWheelZoom",s[s.multiCursorMergeOverlapping=76]="multiCursorMergeOverlapping",s[s.multiCursorModifier=77]="multiCursorModifier",s[s.multiCursorPaste=78]="multiCursorPaste",s[s.multiCursorLimit=79]="multiCursorLimit",s[s.occurrencesHighlight=80]="occurrencesHighlight",s[s.overviewRulerBorder=81]="overviewRulerBorder",s[s.overviewRulerLanes=82]="overviewRulerLanes",s[s.padding=83]="padding",s[s.pasteAs=84]="pasteAs",s[s.parameterHints=85]="parameterHints",s[s.peekWidgetDefaultFocus=86]="peekWidgetDefaultFocus",s[s.definitionLinkOpensInPeek=87]="definitionLinkOpensInPeek",s[s.quickSuggestions=88]="quickSuggestions",s[s.quickSuggestionsDelay=89]="quickSuggestionsDelay",s[s.readOnly=90]="readOnly",s[s.readOnlyMessage=91]="readOnlyMessage",s[s.renameOnType=92]="renameOnType",s[s.renderControlCharacters=93]="renderControlCharacters",s[s.renderFinalNewline=94]="renderFinalNewline",s[s.renderLineHighlight=95]="renderLineHighlight",s[s.renderLineHighlightOnlyWhenFocus=96]="renderLineHighlightOnlyWhenFocus",s[s.renderValidationDecorations=97]="renderValidationDecorations",s[s.renderWhitespace=98]="renderWhitespace",s[s.revealHorizontalRightPadding=99]="revealHorizontalRightPadding",s[s.roundedSelection=100]="roundedSelection",s[s.rulers=101]="rulers",s[s.scrollbar=102]="scrollbar",s[s.scrollBeyondLastColumn=103]="scrollBeyondLastColumn",s[s.scrollBeyondLastLine=104]="scrollBeyondLastLine",s[s.scrollPredominantAxis=105]="scrollPredominantAxis",s[s.selectionClipboard=106]="selectionClipboard",s[s.selectionHighlight=107]="selectionHighlight",s[s.selectOnLineNumbers=108]="selectOnLineNumbers",s[s.showFoldingControls=109]="showFoldingControls",s[s.showUnused=110]="showUnused",s[s.snippetSuggestions=111]="snippetSuggestions",s[s.smartSelect=112]="smartSelect",s[s.smoothScrolling=113]="smoothScrolling",s[s.stickyScroll=114]="stickyScroll",s[s.stickyTabStops=115]="stickyTabStops",s[s.stopRenderingLineAfter=116]="stopRenderingLineAfter",s[s.suggest=117]="suggest",s[s.suggestFontSize=118]="suggestFontSize",s[s.suggestLineHeight=119]="suggestLineHeight",s[s.suggestOnTriggerCharacters=120]="suggestOnTriggerCharacters",s[s.suggestSelection=121]="suggestSelection",s[s.tabCompletion=122]="tabCompletion",s[s.tabIndex=123]="tabIndex",s[s.unicodeHighlighting=124]="unicodeHighlighting",s[s.unusualLineTerminators=125]="unusualLineTerminators",s[s.useShadowDOM=126]="useShadowDOM",s[s.useTabStops=127]="useTabStops",s[s.wordBreak=128]="wordBreak",s[s.wordSeparators=129]="wordSeparators",s[s.wordWrap=130]="wordWrap",s[s.wordWrapBreakAfterCharacters=131]="wordWrapBreakAfterCharacters",s[s.wordWrapBreakBeforeCharacters=132]="wordWrapBreakBeforeCharacters",s[s.wordWrapColumn=133]="wordWrapColumn",s[s.wordWrapOverride1=134]="wordWrapOverride1",s[s.wordWrapOverride2=135]="wordWrapOverride2",s[s.wrappingIndent=136]="wrappingIndent",s[s.wrappingStrategy=137]="wrappingStrategy",s[s.showDeprecated=138]="showDeprecated",s[s.inlayHints=139]="inlayHints",s[s.editorClassName=140]="editorClassName",s[s.pixelRatio=141]="pixelRatio",s[s.tabFocusMode=142]="tabFocusMode",s[s.layoutInfo=143]="layoutInfo",s[s.wrappingInfo=144]="wrappingInfo",s[s.defaultColorDecorators=145]="defaultColorDecorators",s[s.colorDecoratorsActivatedOn=146]="colorDecoratorsActivatedOn",s[s.inlineCompletionsAccessibilityVerbose=147]="inlineCompletionsAccessibilityVerbose"})(cN||(cN={}));var uN;(function(s){s[s.TextDefined=0]="TextDefined",s[s.LF=1]="LF",s[s.CRLF=2]="CRLF"})(uN||(uN={}));var hN;(function(s){s[s.LF=0]="LF",s[s.CRLF=1]="CRLF"})(hN||(hN={}));var gN;(function(s){s[s.Left=1]="Left",s[s.Right=2]="Right"})(gN||(gN={}));var fN;(function(s){s[s.None=0]="None",s[s.Indent=1]="Indent",s[s.IndentOutdent=2]="IndentOutdent",s[s.Outdent=3]="Outdent"})(fN||(fN={}));var pN;(function(s){s[s.Both=0]="Both",s[s.Right=1]="Right",s[s.Left=2]="Left",s[s.None=3]="None"})(pN||(pN={}));var mN;(function(s){s[s.Type=1]="Type",s[s.Parameter=2]="Parameter"})(mN||(mN={}));var _N;(function(s){s[s.Automatic=0]="Automatic",s[s.Explicit=1]="Explicit"})(_N||(_N={}));var vN;(function(s){s[s.DependsOnKbLayout=-1]="DependsOnKbLayout",s[s.Unknown=0]="Unknown",s[s.Backspace=1]="Backspace",s[s.Tab=2]="Tab",s[s.Enter=3]="Enter",s[s.Shift=4]="Shift",s[s.Ctrl=5]="Ctrl",s[s.Alt=6]="Alt",s[s.PauseBreak=7]="PauseBreak",s[s.CapsLock=8]="CapsLock",s[s.Escape=9]="Escape",s[s.Space=10]="Space",s[s.PageUp=11]="PageUp",s[s.PageDown=12]="PageDown",s[s.End=13]="End",s[s.Home=14]="Home",s[s.LeftArrow=15]="LeftArrow",s[s.UpArrow=16]="UpArrow",s[s.RightArrow=17]="RightArrow",s[s.DownArrow=18]="DownArrow",s[s.Insert=19]="Insert",s[s.Delete=20]="Delete",s[s.Digit0=21]="Digit0",s[s.Digit1=22]="Digit1",s[s.Digit2=23]="Digit2",s[s.Digit3=24]="Digit3",s[s.Digit4=25]="Digit4",s[s.Digit5=26]="Digit5",s[s.Digit6=27]="Digit6",s[s.Digit7=28]="Digit7",s[s.Digit8=29]="Digit8",s[s.Digit9=30]="Digit9",s[s.KeyA=31]="KeyA",s[s.KeyB=32]="KeyB",s[s.KeyC=33]="KeyC",s[s.KeyD=34]="KeyD",s[s.KeyE=35]="KeyE",s[s.KeyF=36]="KeyF",s[s.KeyG=37]="KeyG",s[s.KeyH=38]="KeyH",s[s.KeyI=39]="KeyI",s[s.KeyJ=40]="KeyJ",s[s.KeyK=41]="KeyK",s[s.KeyL=42]="KeyL",s[s.KeyM=43]="KeyM",s[s.KeyN=44]="KeyN",s[s.KeyO=45]="KeyO",s[s.KeyP=46]="KeyP",s[s.KeyQ=47]="KeyQ",s[s.KeyR=48]="KeyR",s[s.KeyS=49]="KeyS",s[s.KeyT=50]="KeyT",s[s.KeyU=51]="KeyU",s[s.KeyV=52]="KeyV",s[s.KeyW=53]="KeyW",s[s.KeyX=54]="KeyX",s[s.KeyY=55]="KeyY",s[s.KeyZ=56]="KeyZ",s[s.Meta=57]="Meta",s[s.ContextMenu=58]="ContextMenu",s[s.F1=59]="F1",s[s.F2=60]="F2",s[s.F3=61]="F3",s[s.F4=62]="F4",s[s.F5=63]="F5",s[s.F6=64]="F6",s[s.F7=65]="F7",s[s.F8=66]="F8",s[s.F9=67]="F9",s[s.F10=68]="F10",s[s.F11=69]="F11",s[s.F12=70]="F12",s[s.F13=71]="F13",s[s.F14=72]="F14",s[s.F15=73]="F15",s[s.F16=74]="F16",s[s.F17=75]="F17",s[s.F18=76]="F18",s[s.F19=77]="F19",s[s.F20=78]="F20",s[s.F21=79]="F21",s[s.F22=80]="F22",s[s.F23=81]="F23",s[s.F24=82]="F24",s[s.NumLock=83]="NumLock",s[s.ScrollLock=84]="ScrollLock",s[s.Semicolon=85]="Semicolon",s[s.Equal=86]="Equal",s[s.Comma=87]="Comma",s[s.Minus=88]="Minus",s[s.Period=89]="Period",s[s.Slash=90]="Slash",s[s.Backquote=91]="Backquote",s[s.BracketLeft=92]="BracketLeft",s[s.Backslash=93]="Backslash",s[s.BracketRight=94]="BracketRight",s[s.Quote=95]="Quote",s[s.OEM_8=96]="OEM_8",s[s.IntlBackslash=97]="IntlBackslash",s[s.Numpad0=98]="Numpad0",s[s.Numpad1=99]="Numpad1",s[s.Numpad2=100]="Numpad2",s[s.Numpad3=101]="Numpad3",s[s.Numpad4=102]="Numpad4",s[s.Numpad5=103]="Numpad5",s[s.Numpad6=104]="Numpad6",s[s.Numpad7=105]="Numpad7",s[s.Numpad8=106]="Numpad8",s[s.Numpad9=107]="Numpad9",s[s.NumpadMultiply=108]="NumpadMultiply",s[s.NumpadAdd=109]="NumpadAdd",s[s.NUMPAD_SEPARATOR=110]="NUMPAD_SEPARATOR",s[s.NumpadSubtract=111]="NumpadSubtract",s[s.NumpadDecimal=112]="NumpadDecimal",s[s.NumpadDivide=113]="NumpadDivide",s[s.KEY_IN_COMPOSITION=114]="KEY_IN_COMPOSITION",s[s.ABNT_C1=115]="ABNT_C1",s[s.ABNT_C2=116]="ABNT_C2",s[s.AudioVolumeMute=117]="AudioVolumeMute",s[s.AudioVolumeUp=118]="AudioVolumeUp",s[s.AudioVolumeDown=119]="AudioVolumeDown",s[s.BrowserSearch=120]="BrowserSearch",s[s.BrowserHome=121]="BrowserHome",s[s.BrowserBack=122]="BrowserBack",s[s.BrowserForward=123]="BrowserForward",s[s.MediaTrackNext=124]="MediaTrackNext",s[s.MediaTrackPrevious=125]="MediaTrackPrevious",s[s.MediaStop=126]="MediaStop",s[s.MediaPlayPause=127]="MediaPlayPause",s[s.LaunchMediaPlayer=128]="LaunchMediaPlayer",s[s.LaunchMail=129]="LaunchMail",s[s.LaunchApp2=130]="LaunchApp2",s[s.Clear=131]="Clear",s[s.MAX_VALUE=132]="MAX_VALUE"})(vN||(vN={}));var bN;(function(s){s[s.Hint=1]="Hint",s[s.Info=2]="Info",s[s.Warning=4]="Warning",s[s.Error=8]="Error"})(bN||(bN={}));var CN;(function(s){s[s.Unnecessary=1]="Unnecessary",s[s.Deprecated=2]="Deprecated"})(CN||(CN={}));var wN;(function(s){s[s.Inline=1]="Inline",s[s.Gutter=2]="Gutter"})(wN||(wN={}));var SN;(function(s){s[s.UNKNOWN=0]="UNKNOWN",s[s.TEXTAREA=1]="TEXTAREA",s[s.GUTTER_GLYPH_MARGIN=2]="GUTTER_GLYPH_MARGIN",s[s.GUTTER_LINE_NUMBERS=3]="GUTTER_LINE_NUMBERS",s[s.GUTTER_LINE_DECORATIONS=4]="GUTTER_LINE_DECORATIONS",s[s.GUTTER_VIEW_ZONE=5]="GUTTER_VIEW_ZONE",s[s.CONTENT_TEXT=6]="CONTENT_TEXT",s[s.CONTENT_EMPTY=7]="CONTENT_EMPTY",s[s.CONTENT_VIEW_ZONE=8]="CONTENT_VIEW_ZONE",s[s.CONTENT_WIDGET=9]="CONTENT_WIDGET",s[s.OVERVIEW_RULER=10]="OVERVIEW_RULER",s[s.SCROLLBAR=11]="SCROLLBAR",s[s.OVERLAY_WIDGET=12]="OVERLAY_WIDGET",s[s.OUTSIDE_EDITOR=13]="OUTSIDE_EDITOR"})(SN||(SN={}));var yN;(function(s){s[s.TOP_RIGHT_CORNER=0]="TOP_RIGHT_CORNER",s[s.BOTTOM_RIGHT_CORNER=1]="BOTTOM_RIGHT_CORNER",s[s.TOP_CENTER=2]="TOP_CENTER"})(yN||(yN={}));var LN;(function(s){s[s.Left=1]="Left",s[s.Center=2]="Center",s[s.Right=4]="Right",s[s.Full=7]="Full"})(LN||(LN={}));var xN;(function(s){s[s.Left=0]="Left",s[s.Right=1]="Right",s[s.None=2]="None",s[s.LeftOfInjectedText=3]="LeftOfInjectedText",s[s.RightOfInjectedText=4]="RightOfInjectedText"})(xN||(xN={}));var DN;(function(s){s[s.Off=0]="Off",s[s.On=1]="On",s[s.Relative=2]="Relative",s[s.Interval=3]="Interval",s[s.Custom=4]="Custom"})(DN||(DN={}));var kN;(function(s){s[s.None=0]="None",s[s.Text=1]="Text",s[s.Blocks=2]="Blocks"})(kN||(kN={}));var IN;(function(s){s[s.Smooth=0]="Smooth",s[s.Immediate=1]="Immediate"})(IN||(IN={}));var EN;(function(s){s[s.Auto=1]="Auto",s[s.Hidden=2]="Hidden",s[s.Visible=3]="Visible"})(EN||(EN={}));var NN;(function(s){s[s.LTR=0]="LTR",s[s.RTL=1]="RTL"})(NN||(NN={}));var TN;(function(s){s.Off="off",s.OnCode="onCode",s.On="on"})(TN||(TN={}));var MN;(function(s){s[s.Invoke=1]="Invoke",s[s.TriggerCharacter=2]="TriggerCharacter",s[s.ContentChange=3]="ContentChange"})(MN||(MN={}));var RN;(function(s){s[s.File=0]="File",s[s.Module=1]="Module",s[s.Namespace=2]="Namespace",s[s.Package=3]="Package",s[s.Class=4]="Class",s[s.Method=5]="Method",s[s.Property=6]="Property",s[s.Field=7]="Field",s[s.Constructor=8]="Constructor",s[s.Enum=9]="Enum",s[s.Interface=10]="Interface",s[s.Function=11]="Function",s[s.Variable=12]="Variable",s[s.Constant=13]="Constant",s[s.String=14]="String",s[s.Number=15]="Number",s[s.Boolean=16]="Boolean",s[s.Array=17]="Array",s[s.Object=18]="Object",s[s.Key=19]="Key",s[s.Null=20]="Null",s[s.EnumMember=21]="EnumMember",s[s.Struct=22]="Struct",s[s.Event=23]="Event",s[s.Operator=24]="Operator",s[s.TypeParameter=25]="TypeParameter"})(RN||(RN={}));var AN;(function(s){s[s.Deprecated=1]="Deprecated"})(AN||(AN={}));var PN;(function(s){s[s.Hidden=0]="Hidden",s[s.Blink=1]="Blink",s[s.Smooth=2]="Smooth",s[s.Phase=3]="Phase",s[s.Expand=4]="Expand",s[s.Solid=5]="Solid"})(PN||(PN={}));var ON;(function(s){s[s.Line=1]="Line",s[s.Block=2]="Block",s[s.Underline=3]="Underline",s[s.LineThin=4]="LineThin",s[s.BlockOutline=5]="BlockOutline",s[s.UnderlineThin=6]="UnderlineThin"})(ON||(ON={}));var FN;(function(s){s[s.AlwaysGrowsWhenTypingAtEdges=0]="AlwaysGrowsWhenTypingAtEdges",s[s.NeverGrowsWhenTypingAtEdges=1]="NeverGrowsWhenTypingAtEdges",s[s.GrowsOnlyWhenTypingBefore=2]="GrowsOnlyWhenTypingBefore",s[s.GrowsOnlyWhenTypingAfter=3]="GrowsOnlyWhenTypingAfter"})(FN||(FN={}));var BN;(function(s){s[s.None=0]="None",s[s.Same=1]="Same",s[s.Indent=2]="Indent",s[s.DeepIndent=3]="DeepIndent"})(BN||(BN={}));let tC=class{static chord(e,t){return dn(e,t)}};tC.CtrlCmd=2048;tC.Shift=1024;tC.Alt=512;tC.WinCtrl=256;function WW(){return{editor:void 0,languages:void 0,CancellationTokenSource:Yi,Emitter:W,KeyCode:vN,KeyMod:tC,Position:H,Range:D,Selection:De,SelectionDirection:NN,MarkerSeverity:bN,MarkerTag:CN,Uri:Pe,Token:S0}}function QQ(s,e){const t=s;typeof t.vscodeWindowId!="number"&&Object.defineProperty(t,"vscodeWindowId",{get:()=>e})}const Ci=window,Wl=Ci;class JQ{constructor(e){this.fn=e,this.lastCache=void 0,this.lastArgKey=void 0}get(e){const t=JSON.stringify(e);return this.lastArgKey!==t&&(this.lastArgKey=t,this.lastCache=this.fn(e)),this.lastCache}}class r5{get cachedValues(){return this._map}constructor(e){this.fn=e,this._map=new Map}get(e){if(this._map.has(e))return this._map.get(e);const t=this.fn(e);return this._map.set(e,t),t}}class ih{constructor(e){this.executor=e,this._didRun=!1}get value(){if(!this._didRun)try{this._value=this.executor()}catch(e){this._error=e}finally{this._didRun=!0}if(this._error)throw this._error;return this._value}get rawValue(){return this._value}}var lm;function VW(s){return!s||typeof s!="string"?!0:s.trim().length===0}const eJ=/{(\d+)}/g;function xg(s,...e){return e.length===0?s:s.replace(eJ,function(t,i){const n=parseInt(i,10);return isNaN(n)||n<0||n>=e.length?t:e[n]})}function MS(s){return s.replace(/[<>&]/g,function(e){switch(e){case"<":return"&lt;";case">":return"&gt;";case"&":return"&amp;";default:return e}})}function ir(s){return s.replace(/[\\\{\}\*\+\?\|\^\$\.\[\]\(\)]/g,"\\$&")}function tJ(s,e=" "){const t=iC(s,e);return HW(t,e)}function iC(s,e){if(!s||!e)return s;const t=e.length;if(t===0||s.length===0)return s;let i=0;for(;s.indexOf(e,i)===i;)i=i+t;return s.substring(i)}function HW(s,e){if(!s||!e)return s;const t=e.length,i=s.length;if(t===0||i===0)return s;let n=i,o=-1;for(;o=s.lastIndexOf(e,n-1),!(o===-1||o+t!==n);){if(o===0)return"";n=o}return s.substring(0,n)}function iJ(s){return s.replace(/[\-\\\{\}\+\?\|\^\$\.\,\[\]\(\)\#\s]/g,"\\$&").replace(/[\*]/g,".*")}function nJ(s){return s.replace(/\*/g,"")}function zW(s,e,t={}){if(!s)throw new Error("Cannot create regex from empty string");e||(s=ir(s)),t.wholeWord&&(/\B/.test(s.charAt(0))||(s="\\b"+s),/\B/.test(s.charAt(s.length-1))||(s=s+"\\b"));let i="";return t.global&&(i+="g"),t.matchCase||(i+="i"),t.multiline&&(i+="m"),t.unicode&&(i+="u"),new RegExp(s,i)}function sJ(s){return s.source==="^"||s.source==="^$"||s.source==="$"||s.source==="^\\s*$"?!1:!!(s.exec("")&&s.lastIndex===0)}function Kl(s){return s.split(/\r\n|\r|\n/)}function ws(s){for(let e=0,t=s.length;e<t;e++){const i=s.charCodeAt(e);if(i!==32&&i!==9)return e}return-1}function Zt(s,e=0,t=s.length){for(let i=e;i<t;i++){const n=s.charCodeAt(i);if(n!==32&&n!==9)return s.substring(e,i)}return s.substring(e,t)}function Pa(s,e=s.length-1){for(let t=e;t>=0;t--){const i=s.charCodeAt(t);if(i!==32&&i!==9)return t}return-1}function x0(s,e){return s<e?-1:s>e?1:0}function OA(s,e,t=0,i=s.length,n=0,o=e.length){for(;t<i&&n<o;t++,n++){const l=s.charCodeAt(t),d=e.charCodeAt(n);if(l<d)return-1;if(l>d)return 1}const r=i-t,a=o-n;return r<a?-1:r>a?1:0}function WN(s,e){return nC(s,e,0,s.length,0,e.length)}function nC(s,e,t=0,i=s.length,n=0,o=e.length){for(;t<i&&n<o;t++,n++){let l=s.charCodeAt(t),d=e.charCodeAt(n);if(l===d)continue;if(l>=128||d>=128)return OA(s.toLowerCase(),e.toLowerCase(),t,i,n,o);Hc(l)&&(l-=32),Hc(d)&&(d-=32);const c=l-d;if(c!==0)return c}const r=i-t,a=o-n;return r<a?-1:r>a?1:0}function o1(s){return s>=48&&s<=57}function Hc(s){return s>=97&&s<=122}function ul(s){return s>=65&&s<=90}function np(s,e){return s.length===e.length&&nC(s,e)===0}function FA(s,e){const t=e.length;return e.length>s.length?!1:nC(s,e,0,t)===0}function Dg(s,e){const t=Math.min(s.length,e.length);let i;for(i=0;i<t;i++)if(s.charCodeAt(i)!==e.charCodeAt(i))return i;return t}function RS(s,e){const t=Math.min(s.length,e.length);let i;const n=s.length-1,o=e.length-1;for(i=0;i<t;i++)if(s.charCodeAt(n-i)!==e.charCodeAt(o-i))return i;return t}function _n(s){return 55296<=s&&s<=56319}function kg(s){return 56320<=s&&s<=57343}function BA(s,e){return(s-55296<<10)+(e-56320)+65536}function AS(s,e,t){const i=s.charCodeAt(t);if(_n(i)&&t+1<e){const n=s.charCodeAt(t+1);if(kg(n))return BA(i,n)}return i}function oJ(s,e){const t=s.charCodeAt(e-1);if(kg(t)&&e>1){const i=s.charCodeAt(e-2);if(_n(i))return BA(i,t)}return t}class WA{get offset(){return this._offset}constructor(e,t=0){this._str=e,this._len=e.length,this._offset=t}setOffset(e){this._offset=e}prevCodePoint(){const e=oJ(this._str,this._offset);return this._offset-=e>=65536?2:1,e}nextCodePoint(){const e=AS(this._str,this._len,this._offset);return this._offset+=e>=65536?2:1,e}eol(){return this._offset>=this._len}}class PS{get offset(){return this._iterator.offset}constructor(e,t=0){this._iterator=new WA(e,t)}nextGraphemeLength(){const e=zc.getInstance(),t=this._iterator,i=t.offset;let n=e.getGraphemeBreakType(t.nextCodePoint());for(;!t.eol();){const o=t.offset,r=e.getGraphemeBreakType(t.nextCodePoint());if(a5(n,r)){t.setOffset(o);break}n=r}return t.offset-i}prevGraphemeLength(){const e=zc.getInstance(),t=this._iterator,i=t.offset;let n=e.getGraphemeBreakType(t.prevCodePoint());for(;t.offset>0;){const o=t.offset,r=e.getGraphemeBreakType(t.prevCodePoint());if(a5(r,n)){t.setOffset(o);break}n=r}return i-t.offset}eol(){return this._iterator.eol()}}function VA(s,e){return new PS(s,e).nextGraphemeLength()}function UW(s,e){return new PS(s,e).prevGraphemeLength()}function rJ(s,e){e>0&&kg(s.charCodeAt(e))&&e--;const t=e+VA(s,e);return[t-UW(s,t),t]}let Ik;function aJ(){return/(?:[\u05BE\u05C0\u05C3\u05C6\u05D0-\u05F4\u0608\u060B\u060D\u061B-\u064A\u066D-\u066F\u0671-\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u0710\u0712-\u072F\u074D-\u07A5\u07B1-\u07EA\u07F4\u07F5\u07FA\u07FE-\u0815\u081A\u0824\u0828\u0830-\u0858\u085E-\u088E\u08A0-\u08C9\u200F\uFB1D\uFB1F-\uFB28\uFB2A-\uFD3D\uFD50-\uFDC7\uFDF0-\uFDFC\uFE70-\uFEFC]|\uD802[\uDC00-\uDD1B\uDD20-\uDE00\uDE10-\uDE35\uDE40-\uDEE4\uDEEB-\uDF35\uDF40-\uDFFF]|\uD803[\uDC00-\uDD23\uDE80-\uDEA9\uDEAD-\uDF45\uDF51-\uDF81\uDF86-\uDFF6]|\uD83A[\uDC00-\uDCCF\uDD00-\uDD43\uDD4B-\uDFFF]|\uD83B[\uDC00-\uDEBB])/}function dm(s){return Ik||(Ik=aJ()),Ik.test(s)}const lJ=/^[\t\n\r\x20-\x7E]*$/;function sC(s){return lJ.test(s)}const $W=/[\u2028\u2029]/;function jW(s){return $W.test(s)}function ku(s){return s>=11904&&s<=55215||s>=63744&&s<=64255||s>=65281&&s<=65374}function HA(s){return s>=127462&&s<=127487||s===8986||s===8987||s===9200||s===9203||s>=9728&&s<=10175||s===11088||s===11093||s>=127744&&s<=128591||s>=128640&&s<=128764||s>=128992&&s<=129008||s>=129280&&s<=129535||s>=129648&&s<=129782}const dJ="\uFEFF";function zA(s){return!!(s&&s.length>0&&s.charCodeAt(0)===65279)}function cJ(s,e=!1){return s?(e&&(s=s.replace(/\\./g,"")),s.toLowerCase()!==s):!1}function KW(s){return s=s%(2*26),s<26?String.fromCharCode(97+s):String.fromCharCode(65+s-26)}function a5(s,e){return s===0?e!==5&&e!==7:s===2&&e===3?!1:s===4||s===2||s===3||e===4||e===2||e===3?!0:!(s===8&&(e===8||e===9||e===11||e===12)||(s===11||s===9)&&(e===9||e===10)||(s===12||s===10)&&e===10||e===5||e===13||e===7||s===1||s===13&&e===14||s===6&&e===6)}class zc{static getInstance(){return zc._INSTANCE||(zc._INSTANCE=new zc),zc._INSTANCE}constructor(){this._data=uJ()}getGraphemeBreakType(e){if(e<32)return e===10?3:e===13?2:4;if(e<127)return 0;const t=this._data,i=t.length/3;let n=1;for(;n<=i;)if(e<t[3*n])n=2*n;else if(e>t[3*n+1])n=2*n+1;else return t[3*n+2];return 0}}zc._INSTANCE=null;function uJ(){return JSON.parse("[0,0,0,51229,51255,12,44061,44087,12,127462,127487,6,7083,7085,5,47645,47671,12,54813,54839,12,128678,128678,14,3270,3270,5,9919,9923,14,45853,45879,12,49437,49463,12,53021,53047,12,71216,71218,7,128398,128399,14,129360,129374,14,2519,2519,5,4448,4519,9,9742,9742,14,12336,12336,14,44957,44983,12,46749,46775,12,48541,48567,12,50333,50359,12,52125,52151,12,53917,53943,12,69888,69890,5,73018,73018,5,127990,127990,14,128558,128559,14,128759,128760,14,129653,129655,14,2027,2035,5,2891,2892,7,3761,3761,5,6683,6683,5,8293,8293,4,9825,9826,14,9999,9999,14,43452,43453,5,44509,44535,12,45405,45431,12,46301,46327,12,47197,47223,12,48093,48119,12,48989,49015,12,49885,49911,12,50781,50807,12,51677,51703,12,52573,52599,12,53469,53495,12,54365,54391,12,65279,65279,4,70471,70472,7,72145,72147,7,119173,119179,5,127799,127818,14,128240,128244,14,128512,128512,14,128652,128652,14,128721,128722,14,129292,129292,14,129445,129450,14,129734,129743,14,1476,1477,5,2366,2368,7,2750,2752,7,3076,3076,5,3415,3415,5,4141,4144,5,6109,6109,5,6964,6964,5,7394,7400,5,9197,9198,14,9770,9770,14,9877,9877,14,9968,9969,14,10084,10084,14,43052,43052,5,43713,43713,5,44285,44311,12,44733,44759,12,45181,45207,12,45629,45655,12,46077,46103,12,46525,46551,12,46973,46999,12,47421,47447,12,47869,47895,12,48317,48343,12,48765,48791,12,49213,49239,12,49661,49687,12,50109,50135,12,50557,50583,12,51005,51031,12,51453,51479,12,51901,51927,12,52349,52375,12,52797,52823,12,53245,53271,12,53693,53719,12,54141,54167,12,54589,54615,12,55037,55063,12,69506,69509,5,70191,70193,5,70841,70841,7,71463,71467,5,72330,72342,5,94031,94031,5,123628,123631,5,127763,127765,14,127941,127941,14,128043,128062,14,128302,128317,14,128465,128467,14,128539,128539,14,128640,128640,14,128662,128662,14,128703,128703,14,128745,128745,14,129004,129007,14,129329,129330,14,129402,129402,14,129483,129483,14,129686,129704,14,130048,131069,14,173,173,4,1757,1757,1,2200,2207,5,2434,2435,7,2631,2632,5,2817,2817,5,3008,3008,5,3201,3201,5,3387,3388,5,3542,3542,5,3902,3903,7,4190,4192,5,6002,6003,5,6439,6440,5,6765,6770,7,7019,7027,5,7154,7155,7,8205,8205,13,8505,8505,14,9654,9654,14,9757,9757,14,9792,9792,14,9852,9853,14,9890,9894,14,9937,9937,14,9981,9981,14,10035,10036,14,11035,11036,14,42654,42655,5,43346,43347,7,43587,43587,5,44006,44007,7,44173,44199,12,44397,44423,12,44621,44647,12,44845,44871,12,45069,45095,12,45293,45319,12,45517,45543,12,45741,45767,12,45965,45991,12,46189,46215,12,46413,46439,12,46637,46663,12,46861,46887,12,47085,47111,12,47309,47335,12,47533,47559,12,47757,47783,12,47981,48007,12,48205,48231,12,48429,48455,12,48653,48679,12,48877,48903,12,49101,49127,12,49325,49351,12,49549,49575,12,49773,49799,12,49997,50023,12,50221,50247,12,50445,50471,12,50669,50695,12,50893,50919,12,51117,51143,12,51341,51367,12,51565,51591,12,51789,51815,12,52013,52039,12,52237,52263,12,52461,52487,12,52685,52711,12,52909,52935,12,53133,53159,12,53357,53383,12,53581,53607,12,53805,53831,12,54029,54055,12,54253,54279,12,54477,54503,12,54701,54727,12,54925,54951,12,55149,55175,12,68101,68102,5,69762,69762,7,70067,70069,7,70371,70378,5,70720,70721,7,71087,71087,5,71341,71341,5,71995,71996,5,72249,72249,7,72850,72871,5,73109,73109,5,118576,118598,5,121505,121519,5,127245,127247,14,127568,127569,14,127777,127777,14,127872,127891,14,127956,127967,14,128015,128016,14,128110,128172,14,128259,128259,14,128367,128368,14,128424,128424,14,128488,128488,14,128530,128532,14,128550,128551,14,128566,128566,14,128647,128647,14,128656,128656,14,128667,128673,14,128691,128693,14,128715,128715,14,128728,128732,14,128752,128752,14,128765,128767,14,129096,129103,14,129311,129311,14,129344,129349,14,129394,129394,14,129413,129425,14,129466,129471,14,129511,129535,14,129664,129666,14,129719,129722,14,129760,129767,14,917536,917631,5,13,13,2,1160,1161,5,1564,1564,4,1807,1807,1,2085,2087,5,2307,2307,7,2382,2383,7,2497,2500,5,2563,2563,7,2677,2677,5,2763,2764,7,2879,2879,5,2914,2915,5,3021,3021,5,3142,3144,5,3263,3263,5,3285,3286,5,3398,3400,7,3530,3530,5,3633,3633,5,3864,3865,5,3974,3975,5,4155,4156,7,4229,4230,5,5909,5909,7,6078,6085,7,6277,6278,5,6451,6456,7,6744,6750,5,6846,6846,5,6972,6972,5,7074,7077,5,7146,7148,7,7222,7223,5,7416,7417,5,8234,8238,4,8417,8417,5,9000,9000,14,9203,9203,14,9730,9731,14,9748,9749,14,9762,9763,14,9776,9783,14,9800,9811,14,9831,9831,14,9872,9873,14,9882,9882,14,9900,9903,14,9929,9933,14,9941,9960,14,9974,9974,14,9989,9989,14,10006,10006,14,10062,10062,14,10160,10160,14,11647,11647,5,12953,12953,14,43019,43019,5,43232,43249,5,43443,43443,5,43567,43568,7,43696,43696,5,43765,43765,7,44013,44013,5,44117,44143,12,44229,44255,12,44341,44367,12,44453,44479,12,44565,44591,12,44677,44703,12,44789,44815,12,44901,44927,12,45013,45039,12,45125,45151,12,45237,45263,12,45349,45375,12,45461,45487,12,45573,45599,12,45685,45711,12,45797,45823,12,45909,45935,12,46021,46047,12,46133,46159,12,46245,46271,12,46357,46383,12,46469,46495,12,46581,46607,12,46693,46719,12,46805,46831,12,46917,46943,12,47029,47055,12,47141,47167,12,47253,47279,12,47365,47391,12,47477,47503,12,47589,47615,12,47701,47727,12,47813,47839,12,47925,47951,12,48037,48063,12,48149,48175,12,48261,48287,12,48373,48399,12,48485,48511,12,48597,48623,12,48709,48735,12,48821,48847,12,48933,48959,12,49045,49071,12,49157,49183,12,49269,49295,12,49381,49407,12,49493,49519,12,49605,49631,12,49717,49743,12,49829,49855,12,49941,49967,12,50053,50079,12,50165,50191,12,50277,50303,12,50389,50415,12,50501,50527,12,50613,50639,12,50725,50751,12,50837,50863,12,50949,50975,12,51061,51087,12,51173,51199,12,51285,51311,12,51397,51423,12,51509,51535,12,51621,51647,12,51733,51759,12,51845,51871,12,51957,51983,12,52069,52095,12,52181,52207,12,52293,52319,12,52405,52431,12,52517,52543,12,52629,52655,12,52741,52767,12,52853,52879,12,52965,52991,12,53077,53103,12,53189,53215,12,53301,53327,12,53413,53439,12,53525,53551,12,53637,53663,12,53749,53775,12,53861,53887,12,53973,53999,12,54085,54111,12,54197,54223,12,54309,54335,12,54421,54447,12,54533,54559,12,54645,54671,12,54757,54783,12,54869,54895,12,54981,55007,12,55093,55119,12,55243,55291,10,66045,66045,5,68325,68326,5,69688,69702,5,69817,69818,5,69957,69958,7,70089,70092,5,70198,70199,5,70462,70462,5,70502,70508,5,70750,70750,5,70846,70846,7,71100,71101,5,71230,71230,7,71351,71351,5,71737,71738,5,72000,72000,7,72160,72160,5,72273,72278,5,72752,72758,5,72882,72883,5,73031,73031,5,73461,73462,7,94192,94193,7,119149,119149,7,121403,121452,5,122915,122916,5,126980,126980,14,127358,127359,14,127535,127535,14,127759,127759,14,127771,127771,14,127792,127793,14,127825,127867,14,127897,127899,14,127945,127945,14,127985,127986,14,128000,128007,14,128021,128021,14,128066,128100,14,128184,128235,14,128249,128252,14,128266,128276,14,128335,128335,14,128379,128390,14,128407,128419,14,128444,128444,14,128481,128481,14,128499,128499,14,128526,128526,14,128536,128536,14,128543,128543,14,128556,128556,14,128564,128564,14,128577,128580,14,128643,128645,14,128649,128649,14,128654,128654,14,128660,128660,14,128664,128664,14,128675,128675,14,128686,128689,14,128695,128696,14,128705,128709,14,128717,128719,14,128725,128725,14,128736,128741,14,128747,128748,14,128755,128755,14,128762,128762,14,128981,128991,14,129009,129023,14,129160,129167,14,129296,129304,14,129320,129327,14,129340,129342,14,129356,129356,14,129388,129392,14,129399,129400,14,129404,129407,14,129432,129442,14,129454,129455,14,129473,129474,14,129485,129487,14,129648,129651,14,129659,129660,14,129671,129679,14,129709,129711,14,129728,129730,14,129751,129753,14,129776,129782,14,917505,917505,4,917760,917999,5,10,10,3,127,159,4,768,879,5,1471,1471,5,1536,1541,1,1648,1648,5,1767,1768,5,1840,1866,5,2070,2073,5,2137,2139,5,2274,2274,1,2363,2363,7,2377,2380,7,2402,2403,5,2494,2494,5,2507,2508,7,2558,2558,5,2622,2624,7,2641,2641,5,2691,2691,7,2759,2760,5,2786,2787,5,2876,2876,5,2881,2884,5,2901,2902,5,3006,3006,5,3014,3016,7,3072,3072,5,3134,3136,5,3157,3158,5,3260,3260,5,3266,3266,5,3274,3275,7,3328,3329,5,3391,3392,7,3405,3405,5,3457,3457,5,3536,3537,7,3551,3551,5,3636,3642,5,3764,3772,5,3895,3895,5,3967,3967,7,3993,4028,5,4146,4151,5,4182,4183,7,4226,4226,5,4253,4253,5,4957,4959,5,5940,5940,7,6070,6070,7,6087,6088,7,6158,6158,4,6432,6434,5,6448,6449,7,6679,6680,5,6742,6742,5,6754,6754,5,6783,6783,5,6912,6915,5,6966,6970,5,6978,6978,5,7042,7042,7,7080,7081,5,7143,7143,7,7150,7150,7,7212,7219,5,7380,7392,5,7412,7412,5,8203,8203,4,8232,8232,4,8265,8265,14,8400,8412,5,8421,8432,5,8617,8618,14,9167,9167,14,9200,9200,14,9410,9410,14,9723,9726,14,9733,9733,14,9745,9745,14,9752,9752,14,9760,9760,14,9766,9766,14,9774,9774,14,9786,9786,14,9794,9794,14,9823,9823,14,9828,9828,14,9833,9850,14,9855,9855,14,9875,9875,14,9880,9880,14,9885,9887,14,9896,9897,14,9906,9916,14,9926,9927,14,9935,9935,14,9939,9939,14,9962,9962,14,9972,9972,14,9978,9978,14,9986,9986,14,9997,9997,14,10002,10002,14,10017,10017,14,10055,10055,14,10071,10071,14,10133,10135,14,10548,10549,14,11093,11093,14,12330,12333,5,12441,12442,5,42608,42610,5,43010,43010,5,43045,43046,5,43188,43203,7,43302,43309,5,43392,43394,5,43446,43449,5,43493,43493,5,43571,43572,7,43597,43597,7,43703,43704,5,43756,43757,5,44003,44004,7,44009,44010,7,44033,44059,12,44089,44115,12,44145,44171,12,44201,44227,12,44257,44283,12,44313,44339,12,44369,44395,12,44425,44451,12,44481,44507,12,44537,44563,12,44593,44619,12,44649,44675,12,44705,44731,12,44761,44787,12,44817,44843,12,44873,44899,12,44929,44955,12,44985,45011,12,45041,45067,12,45097,45123,12,45153,45179,12,45209,45235,12,45265,45291,12,45321,45347,12,45377,45403,12,45433,45459,12,45489,45515,12,45545,45571,12,45601,45627,12,45657,45683,12,45713,45739,12,45769,45795,12,45825,45851,12,45881,45907,12,45937,45963,12,45993,46019,12,46049,46075,12,46105,46131,12,46161,46187,12,46217,46243,12,46273,46299,12,46329,46355,12,46385,46411,12,46441,46467,12,46497,46523,12,46553,46579,12,46609,46635,12,46665,46691,12,46721,46747,12,46777,46803,12,46833,46859,12,46889,46915,12,46945,46971,12,47001,47027,12,47057,47083,12,47113,47139,12,47169,47195,12,47225,47251,12,47281,47307,12,47337,47363,12,47393,47419,12,47449,47475,12,47505,47531,12,47561,47587,12,47617,47643,12,47673,47699,12,47729,47755,12,47785,47811,12,47841,47867,12,47897,47923,12,47953,47979,12,48009,48035,12,48065,48091,12,48121,48147,12,48177,48203,12,48233,48259,12,48289,48315,12,48345,48371,12,48401,48427,12,48457,48483,12,48513,48539,12,48569,48595,12,48625,48651,12,48681,48707,12,48737,48763,12,48793,48819,12,48849,48875,12,48905,48931,12,48961,48987,12,49017,49043,12,49073,49099,12,49129,49155,12,49185,49211,12,49241,49267,12,49297,49323,12,49353,49379,12,49409,49435,12,49465,49491,12,49521,49547,12,49577,49603,12,49633,49659,12,49689,49715,12,49745,49771,12,49801,49827,12,49857,49883,12,49913,49939,12,49969,49995,12,50025,50051,12,50081,50107,12,50137,50163,12,50193,50219,12,50249,50275,12,50305,50331,12,50361,50387,12,50417,50443,12,50473,50499,12,50529,50555,12,50585,50611,12,50641,50667,12,50697,50723,12,50753,50779,12,50809,50835,12,50865,50891,12,50921,50947,12,50977,51003,12,51033,51059,12,51089,51115,12,51145,51171,12,51201,51227,12,51257,51283,12,51313,51339,12,51369,51395,12,51425,51451,12,51481,51507,12,51537,51563,12,51593,51619,12,51649,51675,12,51705,51731,12,51761,51787,12,51817,51843,12,51873,51899,12,51929,51955,12,51985,52011,12,52041,52067,12,52097,52123,12,52153,52179,12,52209,52235,12,52265,52291,12,52321,52347,12,52377,52403,12,52433,52459,12,52489,52515,12,52545,52571,12,52601,52627,12,52657,52683,12,52713,52739,12,52769,52795,12,52825,52851,12,52881,52907,12,52937,52963,12,52993,53019,12,53049,53075,12,53105,53131,12,53161,53187,12,53217,53243,12,53273,53299,12,53329,53355,12,53385,53411,12,53441,53467,12,53497,53523,12,53553,53579,12,53609,53635,12,53665,53691,12,53721,53747,12,53777,53803,12,53833,53859,12,53889,53915,12,53945,53971,12,54001,54027,12,54057,54083,12,54113,54139,12,54169,54195,12,54225,54251,12,54281,54307,12,54337,54363,12,54393,54419,12,54449,54475,12,54505,54531,12,54561,54587,12,54617,54643,12,54673,54699,12,54729,54755,12,54785,54811,12,54841,54867,12,54897,54923,12,54953,54979,12,55009,55035,12,55065,55091,12,55121,55147,12,55177,55203,12,65024,65039,5,65520,65528,4,66422,66426,5,68152,68154,5,69291,69292,5,69633,69633,5,69747,69748,5,69811,69814,5,69826,69826,5,69932,69932,7,70016,70017,5,70079,70080,7,70095,70095,5,70196,70196,5,70367,70367,5,70402,70403,7,70464,70464,5,70487,70487,5,70709,70711,7,70725,70725,7,70833,70834,7,70843,70844,7,70849,70849,7,71090,71093,5,71103,71104,5,71227,71228,7,71339,71339,5,71344,71349,5,71458,71461,5,71727,71735,5,71985,71989,7,71998,71998,5,72002,72002,7,72154,72155,5,72193,72202,5,72251,72254,5,72281,72283,5,72344,72345,5,72766,72766,7,72874,72880,5,72885,72886,5,73023,73029,5,73104,73105,5,73111,73111,5,92912,92916,5,94095,94098,5,113824,113827,4,119142,119142,7,119155,119162,4,119362,119364,5,121476,121476,5,122888,122904,5,123184,123190,5,125252,125258,5,127183,127183,14,127340,127343,14,127377,127386,14,127491,127503,14,127548,127551,14,127744,127756,14,127761,127761,14,127769,127769,14,127773,127774,14,127780,127788,14,127796,127797,14,127820,127823,14,127869,127869,14,127894,127895,14,127902,127903,14,127943,127943,14,127947,127950,14,127972,127972,14,127988,127988,14,127992,127994,14,128009,128011,14,128019,128019,14,128023,128041,14,128064,128064,14,128102,128107,14,128174,128181,14,128238,128238,14,128246,128247,14,128254,128254,14,128264,128264,14,128278,128299,14,128329,128330,14,128348,128359,14,128371,128377,14,128392,128393,14,128401,128404,14,128421,128421,14,128433,128434,14,128450,128452,14,128476,128478,14,128483,128483,14,128495,128495,14,128506,128506,14,128519,128520,14,128528,128528,14,128534,128534,14,128538,128538,14,128540,128542,14,128544,128549,14,128552,128555,14,128557,128557,14,128560,128563,14,128565,128565,14,128567,128576,14,128581,128591,14,128641,128642,14,128646,128646,14,128648,128648,14,128650,128651,14,128653,128653,14,128655,128655,14,128657,128659,14,128661,128661,14,128663,128663,14,128665,128666,14,128674,128674,14,128676,128677,14,128679,128685,14,128690,128690,14,128694,128694,14,128697,128702,14,128704,128704,14,128710,128714,14,128716,128716,14,128720,128720,14,128723,128724,14,128726,128727,14,128733,128735,14,128742,128744,14,128746,128746,14,128749,128751,14,128753,128754,14,128756,128758,14,128761,128761,14,128763,128764,14,128884,128895,14,128992,129003,14,129008,129008,14,129036,129039,14,129114,129119,14,129198,129279,14,129293,129295,14,129305,129310,14,129312,129319,14,129328,129328,14,129331,129338,14,129343,129343,14,129351,129355,14,129357,129359,14,129375,129387,14,129393,129393,14,129395,129398,14,129401,129401,14,129403,129403,14,129408,129412,14,129426,129431,14,129443,129444,14,129451,129453,14,129456,129465,14,129472,129472,14,129475,129482,14,129484,129484,14,129488,129510,14,129536,129647,14,129652,129652,14,129656,129658,14,129661,129663,14,129667,129670,14,129680,129685,14,129705,129708,14,129712,129718,14,129723,129727,14,129731,129733,14,129744,129750,14,129754,129759,14,129768,129775,14,129783,129791,14,917504,917504,4,917506,917535,4,917632,917759,4,918000,921599,4,0,9,4,11,12,4,14,31,4,169,169,14,174,174,14,1155,1159,5,1425,1469,5,1473,1474,5,1479,1479,5,1552,1562,5,1611,1631,5,1750,1756,5,1759,1764,5,1770,1773,5,1809,1809,5,1958,1968,5,2045,2045,5,2075,2083,5,2089,2093,5,2192,2193,1,2250,2273,5,2275,2306,5,2362,2362,5,2364,2364,5,2369,2376,5,2381,2381,5,2385,2391,5,2433,2433,5,2492,2492,5,2495,2496,7,2503,2504,7,2509,2509,5,2530,2531,5,2561,2562,5,2620,2620,5,2625,2626,5,2635,2637,5,2672,2673,5,2689,2690,5,2748,2748,5,2753,2757,5,2761,2761,7,2765,2765,5,2810,2815,5,2818,2819,7,2878,2878,5,2880,2880,7,2887,2888,7,2893,2893,5,2903,2903,5,2946,2946,5,3007,3007,7,3009,3010,7,3018,3020,7,3031,3031,5,3073,3075,7,3132,3132,5,3137,3140,7,3146,3149,5,3170,3171,5,3202,3203,7,3262,3262,7,3264,3265,7,3267,3268,7,3271,3272,7,3276,3277,5,3298,3299,5,3330,3331,7,3390,3390,5,3393,3396,5,3402,3404,7,3406,3406,1,3426,3427,5,3458,3459,7,3535,3535,5,3538,3540,5,3544,3550,7,3570,3571,7,3635,3635,7,3655,3662,5,3763,3763,7,3784,3789,5,3893,3893,5,3897,3897,5,3953,3966,5,3968,3972,5,3981,3991,5,4038,4038,5,4145,4145,7,4153,4154,5,4157,4158,5,4184,4185,5,4209,4212,5,4228,4228,7,4237,4237,5,4352,4447,8,4520,4607,10,5906,5908,5,5938,5939,5,5970,5971,5,6068,6069,5,6071,6077,5,6086,6086,5,6089,6099,5,6155,6157,5,6159,6159,5,6313,6313,5,6435,6438,7,6441,6443,7,6450,6450,5,6457,6459,5,6681,6682,7,6741,6741,7,6743,6743,7,6752,6752,5,6757,6764,5,6771,6780,5,6832,6845,5,6847,6862,5,6916,6916,7,6965,6965,5,6971,6971,7,6973,6977,7,6979,6980,7,7040,7041,5,7073,7073,7,7078,7079,7,7082,7082,7,7142,7142,5,7144,7145,5,7149,7149,5,7151,7153,5,7204,7211,7,7220,7221,7,7376,7378,5,7393,7393,7,7405,7405,5,7415,7415,7,7616,7679,5,8204,8204,5,8206,8207,4,8233,8233,4,8252,8252,14,8288,8292,4,8294,8303,4,8413,8416,5,8418,8420,5,8482,8482,14,8596,8601,14,8986,8987,14,9096,9096,14,9193,9196,14,9199,9199,14,9201,9202,14,9208,9210,14,9642,9643,14,9664,9664,14,9728,9729,14,9732,9732,14,9735,9741,14,9743,9744,14,9746,9746,14,9750,9751,14,9753,9756,14,9758,9759,14,9761,9761,14,9764,9765,14,9767,9769,14,9771,9773,14,9775,9775,14,9784,9785,14,9787,9791,14,9793,9793,14,9795,9799,14,9812,9822,14,9824,9824,14,9827,9827,14,9829,9830,14,9832,9832,14,9851,9851,14,9854,9854,14,9856,9861,14,9874,9874,14,9876,9876,14,9878,9879,14,9881,9881,14,9883,9884,14,9888,9889,14,9895,9895,14,9898,9899,14,9904,9905,14,9917,9918,14,9924,9925,14,9928,9928,14,9934,9934,14,9936,9936,14,9938,9938,14,9940,9940,14,9961,9961,14,9963,9967,14,9970,9971,14,9973,9973,14,9975,9977,14,9979,9980,14,9982,9985,14,9987,9988,14,9992,9996,14,9998,9998,14,10000,10001,14,10004,10004,14,10013,10013,14,10024,10024,14,10052,10052,14,10060,10060,14,10067,10069,14,10083,10083,14,10085,10087,14,10145,10145,14,10175,10175,14,11013,11015,14,11088,11088,14,11503,11505,5,11744,11775,5,12334,12335,5,12349,12349,14,12951,12951,14,42607,42607,5,42612,42621,5,42736,42737,5,43014,43014,5,43043,43044,7,43047,43047,7,43136,43137,7,43204,43205,5,43263,43263,5,43335,43345,5,43360,43388,8,43395,43395,7,43444,43445,7,43450,43451,7,43454,43456,7,43561,43566,5,43569,43570,5,43573,43574,5,43596,43596,5,43644,43644,5,43698,43700,5,43710,43711,5,43755,43755,7,43758,43759,7,43766,43766,5,44005,44005,5,44008,44008,5,44012,44012,7,44032,44032,11,44060,44060,11,44088,44088,11,44116,44116,11,44144,44144,11,44172,44172,11,44200,44200,11,44228,44228,11,44256,44256,11,44284,44284,11,44312,44312,11,44340,44340,11,44368,44368,11,44396,44396,11,44424,44424,11,44452,44452,11,44480,44480,11,44508,44508,11,44536,44536,11,44564,44564,11,44592,44592,11,44620,44620,11,44648,44648,11,44676,44676,11,44704,44704,11,44732,44732,11,44760,44760,11,44788,44788,11,44816,44816,11,44844,44844,11,44872,44872,11,44900,44900,11,44928,44928,11,44956,44956,11,44984,44984,11,45012,45012,11,45040,45040,11,45068,45068,11,45096,45096,11,45124,45124,11,45152,45152,11,45180,45180,11,45208,45208,11,45236,45236,11,45264,45264,11,45292,45292,11,45320,45320,11,45348,45348,11,45376,45376,11,45404,45404,11,45432,45432,11,45460,45460,11,45488,45488,11,45516,45516,11,45544,45544,11,45572,45572,11,45600,45600,11,45628,45628,11,45656,45656,11,45684,45684,11,45712,45712,11,45740,45740,11,45768,45768,11,45796,45796,11,45824,45824,11,45852,45852,11,45880,45880,11,45908,45908,11,45936,45936,11,45964,45964,11,45992,45992,11,46020,46020,11,46048,46048,11,46076,46076,11,46104,46104,11,46132,46132,11,46160,46160,11,46188,46188,11,46216,46216,11,46244,46244,11,46272,46272,11,46300,46300,11,46328,46328,11,46356,46356,11,46384,46384,11,46412,46412,11,46440,46440,11,46468,46468,11,46496,46496,11,46524,46524,11,46552,46552,11,46580,46580,11,46608,46608,11,46636,46636,11,46664,46664,11,46692,46692,11,46720,46720,11,46748,46748,11,46776,46776,11,46804,46804,11,46832,46832,11,46860,46860,11,46888,46888,11,46916,46916,11,46944,46944,11,46972,46972,11,47000,47000,11,47028,47028,11,47056,47056,11,47084,47084,11,47112,47112,11,47140,47140,11,47168,47168,11,47196,47196,11,47224,47224,11,47252,47252,11,47280,47280,11,47308,47308,11,47336,47336,11,47364,47364,11,47392,47392,11,47420,47420,11,47448,47448,11,47476,47476,11,47504,47504,11,47532,47532,11,47560,47560,11,47588,47588,11,47616,47616,11,47644,47644,11,47672,47672,11,47700,47700,11,47728,47728,11,47756,47756,11,47784,47784,11,47812,47812,11,47840,47840,11,47868,47868,11,47896,47896,11,47924,47924,11,47952,47952,11,47980,47980,11,48008,48008,11,48036,48036,11,48064,48064,11,48092,48092,11,48120,48120,11,48148,48148,11,48176,48176,11,48204,48204,11,48232,48232,11,48260,48260,11,48288,48288,11,48316,48316,11,48344,48344,11,48372,48372,11,48400,48400,11,48428,48428,11,48456,48456,11,48484,48484,11,48512,48512,11,48540,48540,11,48568,48568,11,48596,48596,11,48624,48624,11,48652,48652,11,48680,48680,11,48708,48708,11,48736,48736,11,48764,48764,11,48792,48792,11,48820,48820,11,48848,48848,11,48876,48876,11,48904,48904,11,48932,48932,11,48960,48960,11,48988,48988,11,49016,49016,11,49044,49044,11,49072,49072,11,49100,49100,11,49128,49128,11,49156,49156,11,49184,49184,11,49212,49212,11,49240,49240,11,49268,49268,11,49296,49296,11,49324,49324,11,49352,49352,11,49380,49380,11,49408,49408,11,49436,49436,11,49464,49464,11,49492,49492,11,49520,49520,11,49548,49548,11,49576,49576,11,49604,49604,11,49632,49632,11,49660,49660,11,49688,49688,11,49716,49716,11,49744,49744,11,49772,49772,11,49800,49800,11,49828,49828,11,49856,49856,11,49884,49884,11,49912,49912,11,49940,49940,11,49968,49968,11,49996,49996,11,50024,50024,11,50052,50052,11,50080,50080,11,50108,50108,11,50136,50136,11,50164,50164,11,50192,50192,11,50220,50220,11,50248,50248,11,50276,50276,11,50304,50304,11,50332,50332,11,50360,50360,11,50388,50388,11,50416,50416,11,50444,50444,11,50472,50472,11,50500,50500,11,50528,50528,11,50556,50556,11,50584,50584,11,50612,50612,11,50640,50640,11,50668,50668,11,50696,50696,11,50724,50724,11,50752,50752,11,50780,50780,11,50808,50808,11,50836,50836,11,50864,50864,11,50892,50892,11,50920,50920,11,50948,50948,11,50976,50976,11,51004,51004,11,51032,51032,11,51060,51060,11,51088,51088,11,51116,51116,11,51144,51144,11,51172,51172,11,51200,51200,11,51228,51228,11,51256,51256,11,51284,51284,11,51312,51312,11,51340,51340,11,51368,51368,11,51396,51396,11,51424,51424,11,51452,51452,11,51480,51480,11,51508,51508,11,51536,51536,11,51564,51564,11,51592,51592,11,51620,51620,11,51648,51648,11,51676,51676,11,51704,51704,11,51732,51732,11,51760,51760,11,51788,51788,11,51816,51816,11,51844,51844,11,51872,51872,11,51900,51900,11,51928,51928,11,51956,51956,11,51984,51984,11,52012,52012,11,52040,52040,11,52068,52068,11,52096,52096,11,52124,52124,11,52152,52152,11,52180,52180,11,52208,52208,11,52236,52236,11,52264,52264,11,52292,52292,11,52320,52320,11,52348,52348,11,52376,52376,11,52404,52404,11,52432,52432,11,52460,52460,11,52488,52488,11,52516,52516,11,52544,52544,11,52572,52572,11,52600,52600,11,52628,52628,11,52656,52656,11,52684,52684,11,52712,52712,11,52740,52740,11,52768,52768,11,52796,52796,11,52824,52824,11,52852,52852,11,52880,52880,11,52908,52908,11,52936,52936,11,52964,52964,11,52992,52992,11,53020,53020,11,53048,53048,11,53076,53076,11,53104,53104,11,53132,53132,11,53160,53160,11,53188,53188,11,53216,53216,11,53244,53244,11,53272,53272,11,53300,53300,11,53328,53328,11,53356,53356,11,53384,53384,11,53412,53412,11,53440,53440,11,53468,53468,11,53496,53496,11,53524,53524,11,53552,53552,11,53580,53580,11,53608,53608,11,53636,53636,11,53664,53664,11,53692,53692,11,53720,53720,11,53748,53748,11,53776,53776,11,53804,53804,11,53832,53832,11,53860,53860,11,53888,53888,11,53916,53916,11,53944,53944,11,53972,53972,11,54000,54000,11,54028,54028,11,54056,54056,11,54084,54084,11,54112,54112,11,54140,54140,11,54168,54168,11,54196,54196,11,54224,54224,11,54252,54252,11,54280,54280,11,54308,54308,11,54336,54336,11,54364,54364,11,54392,54392,11,54420,54420,11,54448,54448,11,54476,54476,11,54504,54504,11,54532,54532,11,54560,54560,11,54588,54588,11,54616,54616,11,54644,54644,11,54672,54672,11,54700,54700,11,54728,54728,11,54756,54756,11,54784,54784,11,54812,54812,11,54840,54840,11,54868,54868,11,54896,54896,11,54924,54924,11,54952,54952,11,54980,54980,11,55008,55008,11,55036,55036,11,55064,55064,11,55092,55092,11,55120,55120,11,55148,55148,11,55176,55176,11,55216,55238,9,64286,64286,5,65056,65071,5,65438,65439,5,65529,65531,4,66272,66272,5,68097,68099,5,68108,68111,5,68159,68159,5,68900,68903,5,69446,69456,5,69632,69632,7,69634,69634,7,69744,69744,5,69759,69761,5,69808,69810,7,69815,69816,7,69821,69821,1,69837,69837,1,69927,69931,5,69933,69940,5,70003,70003,5,70018,70018,7,70070,70078,5,70082,70083,1,70094,70094,7,70188,70190,7,70194,70195,7,70197,70197,7,70206,70206,5,70368,70370,7,70400,70401,5,70459,70460,5,70463,70463,7,70465,70468,7,70475,70477,7,70498,70499,7,70512,70516,5,70712,70719,5,70722,70724,5,70726,70726,5,70832,70832,5,70835,70840,5,70842,70842,5,70845,70845,5,70847,70848,5,70850,70851,5,71088,71089,7,71096,71099,7,71102,71102,7,71132,71133,5,71219,71226,5,71229,71229,5,71231,71232,5,71340,71340,7,71342,71343,7,71350,71350,7,71453,71455,5,71462,71462,7,71724,71726,7,71736,71736,7,71984,71984,5,71991,71992,7,71997,71997,7,71999,71999,1,72001,72001,1,72003,72003,5,72148,72151,5,72156,72159,7,72164,72164,7,72243,72248,5,72250,72250,1,72263,72263,5,72279,72280,7,72324,72329,1,72343,72343,7,72751,72751,7,72760,72765,5,72767,72767,5,72873,72873,7,72881,72881,7,72884,72884,7,73009,73014,5,73020,73021,5,73030,73030,1,73098,73102,7,73107,73108,7,73110,73110,7,73459,73460,5,78896,78904,4,92976,92982,5,94033,94087,7,94180,94180,5,113821,113822,5,118528,118573,5,119141,119141,5,119143,119145,5,119150,119154,5,119163,119170,5,119210,119213,5,121344,121398,5,121461,121461,5,121499,121503,5,122880,122886,5,122907,122913,5,122918,122922,5,123566,123566,5,125136,125142,5,126976,126979,14,126981,127182,14,127184,127231,14,127279,127279,14,127344,127345,14,127374,127374,14,127405,127461,14,127489,127490,14,127514,127514,14,127538,127546,14,127561,127567,14,127570,127743,14,127757,127758,14,127760,127760,14,127762,127762,14,127766,127768,14,127770,127770,14,127772,127772,14,127775,127776,14,127778,127779,14,127789,127791,14,127794,127795,14,127798,127798,14,127819,127819,14,127824,127824,14,127868,127868,14,127870,127871,14,127892,127893,14,127896,127896,14,127900,127901,14,127904,127940,14,127942,127942,14,127944,127944,14,127946,127946,14,127951,127955,14,127968,127971,14,127973,127984,14,127987,127987,14,127989,127989,14,127991,127991,14,127995,127999,5,128008,128008,14,128012,128014,14,128017,128018,14,128020,128020,14,128022,128022,14,128042,128042,14,128063,128063,14,128065,128065,14,128101,128101,14,128108,128109,14,128173,128173,14,128182,128183,14,128236,128237,14,128239,128239,14,128245,128245,14,128248,128248,14,128253,128253,14,128255,128258,14,128260,128263,14,128265,128265,14,128277,128277,14,128300,128301,14,128326,128328,14,128331,128334,14,128336,128347,14,128360,128366,14,128369,128370,14,128378,128378,14,128391,128391,14,128394,128397,14,128400,128400,14,128405,128406,14,128420,128420,14,128422,128423,14,128425,128432,14,128435,128443,14,128445,128449,14,128453,128464,14,128468,128475,14,128479,128480,14,128482,128482,14,128484,128487,14,128489,128494,14,128496,128498,14,128500,128505,14,128507,128511,14,128513,128518,14,128521,128525,14,128527,128527,14,128529,128529,14,128533,128533,14,128535,128535,14,128537,128537,14]")}function hJ(s,e){if(s===0)return 0;const t=gJ(s,e);if(t!==void 0)return t;const i=new WA(e,s);return i.prevCodePoint(),i.offset}function gJ(s,e){const t=new WA(e,s);let i=t.prevCodePoint();for(;fJ(i)||i===65039||i===8419;){if(t.offset===0)return;i=t.prevCodePoint()}if(!HA(i))return;let n=t.offset;return n>0&&t.prevCodePoint()===8205&&(n=t.offset),n}function fJ(s){return 127995<=s&&s<=127999}const qW=" ";class Ig{static getInstance(e){return lm.cache.get(Array.from(e))}static getLocales(){return lm._locales.value}constructor(e){this.confusableDictionary=e}isAmbiguous(e){return this.confusableDictionary.has(e)}getPrimaryConfusable(e){return this.confusableDictionary.get(e)}getConfusableCodePoints(){return new Set(this.confusableDictionary.keys())}}lm=Ig;Ig.ambiguousCharacterData=new ih(()=>JSON.parse('{"_common":[8232,32,8233,32,5760,32,8192,32,8193,32,8194,32,8195,32,8196,32,8197,32,8198,32,8200,32,8201,32,8202,32,8287,32,8199,32,8239,32,2042,95,65101,95,65102,95,65103,95,8208,45,8209,45,8210,45,65112,45,1748,45,8259,45,727,45,8722,45,10134,45,11450,45,1549,44,1643,44,8218,44,184,44,42233,44,894,59,2307,58,2691,58,1417,58,1795,58,1796,58,5868,58,65072,58,6147,58,6153,58,8282,58,1475,58,760,58,42889,58,8758,58,720,58,42237,58,451,33,11601,33,660,63,577,63,2429,63,5038,63,42731,63,119149,46,8228,46,1793,46,1794,46,42510,46,68176,46,1632,46,1776,46,42232,46,1373,96,65287,96,8219,96,8242,96,1370,96,1523,96,8175,96,65344,96,900,96,8189,96,8125,96,8127,96,8190,96,697,96,884,96,712,96,714,96,715,96,756,96,699,96,701,96,700,96,702,96,42892,96,1497,96,2036,96,2037,96,5194,96,5836,96,94033,96,94034,96,65339,91,10088,40,10098,40,12308,40,64830,40,65341,93,10089,41,10099,41,12309,41,64831,41,10100,123,119060,123,10101,125,65342,94,8270,42,1645,42,8727,42,66335,42,5941,47,8257,47,8725,47,8260,47,9585,47,10187,47,10744,47,119354,47,12755,47,12339,47,11462,47,20031,47,12035,47,65340,92,65128,92,8726,92,10189,92,10741,92,10745,92,119311,92,119355,92,12756,92,20022,92,12034,92,42872,38,708,94,710,94,5869,43,10133,43,66203,43,8249,60,10094,60,706,60,119350,60,5176,60,5810,60,5120,61,11840,61,12448,61,42239,61,8250,62,10095,62,707,62,119351,62,5171,62,94015,62,8275,126,732,126,8128,126,8764,126,65372,124,65293,45,120784,50,120794,50,120804,50,120814,50,120824,50,130034,50,42842,50,423,50,1000,50,42564,50,5311,50,42735,50,119302,51,120785,51,120795,51,120805,51,120815,51,120825,51,130035,51,42923,51,540,51,439,51,42858,51,11468,51,1248,51,94011,51,71882,51,120786,52,120796,52,120806,52,120816,52,120826,52,130036,52,5070,52,71855,52,120787,53,120797,53,120807,53,120817,53,120827,53,130037,53,444,53,71867,53,120788,54,120798,54,120808,54,120818,54,120828,54,130038,54,11474,54,5102,54,71893,54,119314,55,120789,55,120799,55,120809,55,120819,55,120829,55,130039,55,66770,55,71878,55,2819,56,2538,56,2666,56,125131,56,120790,56,120800,56,120810,56,120820,56,120830,56,130040,56,547,56,546,56,66330,56,2663,57,2920,57,2541,57,3437,57,120791,57,120801,57,120811,57,120821,57,120831,57,130041,57,42862,57,11466,57,71884,57,71852,57,71894,57,9082,97,65345,97,119834,97,119886,97,119938,97,119990,97,120042,97,120094,97,120146,97,120198,97,120250,97,120302,97,120354,97,120406,97,120458,97,593,97,945,97,120514,97,120572,97,120630,97,120688,97,120746,97,65313,65,119808,65,119860,65,119912,65,119964,65,120016,65,120068,65,120120,65,120172,65,120224,65,120276,65,120328,65,120380,65,120432,65,913,65,120488,65,120546,65,120604,65,120662,65,120720,65,5034,65,5573,65,42222,65,94016,65,66208,65,119835,98,119887,98,119939,98,119991,98,120043,98,120095,98,120147,98,120199,98,120251,98,120303,98,120355,98,120407,98,120459,98,388,98,5071,98,5234,98,5551,98,65314,66,8492,66,119809,66,119861,66,119913,66,120017,66,120069,66,120121,66,120173,66,120225,66,120277,66,120329,66,120381,66,120433,66,42932,66,914,66,120489,66,120547,66,120605,66,120663,66,120721,66,5108,66,5623,66,42192,66,66178,66,66209,66,66305,66,65347,99,8573,99,119836,99,119888,99,119940,99,119992,99,120044,99,120096,99,120148,99,120200,99,120252,99,120304,99,120356,99,120408,99,120460,99,7428,99,1010,99,11429,99,43951,99,66621,99,128844,67,71922,67,71913,67,65315,67,8557,67,8450,67,8493,67,119810,67,119862,67,119914,67,119966,67,120018,67,120174,67,120226,67,120278,67,120330,67,120382,67,120434,67,1017,67,11428,67,5087,67,42202,67,66210,67,66306,67,66581,67,66844,67,8574,100,8518,100,119837,100,119889,100,119941,100,119993,100,120045,100,120097,100,120149,100,120201,100,120253,100,120305,100,120357,100,120409,100,120461,100,1281,100,5095,100,5231,100,42194,100,8558,68,8517,68,119811,68,119863,68,119915,68,119967,68,120019,68,120071,68,120123,68,120175,68,120227,68,120279,68,120331,68,120383,68,120435,68,5024,68,5598,68,5610,68,42195,68,8494,101,65349,101,8495,101,8519,101,119838,101,119890,101,119942,101,120046,101,120098,101,120150,101,120202,101,120254,101,120306,101,120358,101,120410,101,120462,101,43826,101,1213,101,8959,69,65317,69,8496,69,119812,69,119864,69,119916,69,120020,69,120072,69,120124,69,120176,69,120228,69,120280,69,120332,69,120384,69,120436,69,917,69,120492,69,120550,69,120608,69,120666,69,120724,69,11577,69,5036,69,42224,69,71846,69,71854,69,66182,69,119839,102,119891,102,119943,102,119995,102,120047,102,120099,102,120151,102,120203,102,120255,102,120307,102,120359,102,120411,102,120463,102,43829,102,42905,102,383,102,7837,102,1412,102,119315,70,8497,70,119813,70,119865,70,119917,70,120021,70,120073,70,120125,70,120177,70,120229,70,120281,70,120333,70,120385,70,120437,70,42904,70,988,70,120778,70,5556,70,42205,70,71874,70,71842,70,66183,70,66213,70,66853,70,65351,103,8458,103,119840,103,119892,103,119944,103,120048,103,120100,103,120152,103,120204,103,120256,103,120308,103,120360,103,120412,103,120464,103,609,103,7555,103,397,103,1409,103,119814,71,119866,71,119918,71,119970,71,120022,71,120074,71,120126,71,120178,71,120230,71,120282,71,120334,71,120386,71,120438,71,1292,71,5056,71,5107,71,42198,71,65352,104,8462,104,119841,104,119945,104,119997,104,120049,104,120101,104,120153,104,120205,104,120257,104,120309,104,120361,104,120413,104,120465,104,1211,104,1392,104,5058,104,65320,72,8459,72,8460,72,8461,72,119815,72,119867,72,119919,72,120023,72,120179,72,120231,72,120283,72,120335,72,120387,72,120439,72,919,72,120494,72,120552,72,120610,72,120668,72,120726,72,11406,72,5051,72,5500,72,42215,72,66255,72,731,105,9075,105,65353,105,8560,105,8505,105,8520,105,119842,105,119894,105,119946,105,119998,105,120050,105,120102,105,120154,105,120206,105,120258,105,120310,105,120362,105,120414,105,120466,105,120484,105,618,105,617,105,953,105,8126,105,890,105,120522,105,120580,105,120638,105,120696,105,120754,105,1110,105,42567,105,1231,105,43893,105,5029,105,71875,105,65354,106,8521,106,119843,106,119895,106,119947,106,119999,106,120051,106,120103,106,120155,106,120207,106,120259,106,120311,106,120363,106,120415,106,120467,106,1011,106,1112,106,65322,74,119817,74,119869,74,119921,74,119973,74,120025,74,120077,74,120129,74,120181,74,120233,74,120285,74,120337,74,120389,74,120441,74,42930,74,895,74,1032,74,5035,74,5261,74,42201,74,119844,107,119896,107,119948,107,120000,107,120052,107,120104,107,120156,107,120208,107,120260,107,120312,107,120364,107,120416,107,120468,107,8490,75,65323,75,119818,75,119870,75,119922,75,119974,75,120026,75,120078,75,120130,75,120182,75,120234,75,120286,75,120338,75,120390,75,120442,75,922,75,120497,75,120555,75,120613,75,120671,75,120729,75,11412,75,5094,75,5845,75,42199,75,66840,75,1472,108,8739,73,9213,73,65512,73,1633,108,1777,73,66336,108,125127,108,120783,73,120793,73,120803,73,120813,73,120823,73,130033,73,65321,73,8544,73,8464,73,8465,73,119816,73,119868,73,119920,73,120024,73,120128,73,120180,73,120232,73,120284,73,120336,73,120388,73,120440,73,65356,108,8572,73,8467,108,119845,108,119897,108,119949,108,120001,108,120053,108,120105,73,120157,73,120209,73,120261,73,120313,73,120365,73,120417,73,120469,73,448,73,120496,73,120554,73,120612,73,120670,73,120728,73,11410,73,1030,73,1216,73,1493,108,1503,108,1575,108,126464,108,126592,108,65166,108,65165,108,1994,108,11599,73,5825,73,42226,73,93992,73,66186,124,66313,124,119338,76,8556,76,8466,76,119819,76,119871,76,119923,76,120027,76,120079,76,120131,76,120183,76,120235,76,120287,76,120339,76,120391,76,120443,76,11472,76,5086,76,5290,76,42209,76,93974,76,71843,76,71858,76,66587,76,66854,76,65325,77,8559,77,8499,77,119820,77,119872,77,119924,77,120028,77,120080,77,120132,77,120184,77,120236,77,120288,77,120340,77,120392,77,120444,77,924,77,120499,77,120557,77,120615,77,120673,77,120731,77,1018,77,11416,77,5047,77,5616,77,5846,77,42207,77,66224,77,66321,77,119847,110,119899,110,119951,110,120003,110,120055,110,120107,110,120159,110,120211,110,120263,110,120315,110,120367,110,120419,110,120471,110,1400,110,1404,110,65326,78,8469,78,119821,78,119873,78,119925,78,119977,78,120029,78,120081,78,120185,78,120237,78,120289,78,120341,78,120393,78,120445,78,925,78,120500,78,120558,78,120616,78,120674,78,120732,78,11418,78,42208,78,66835,78,3074,111,3202,111,3330,111,3458,111,2406,111,2662,111,2790,111,3046,111,3174,111,3302,111,3430,111,3664,111,3792,111,4160,111,1637,111,1781,111,65359,111,8500,111,119848,111,119900,111,119952,111,120056,111,120108,111,120160,111,120212,111,120264,111,120316,111,120368,111,120420,111,120472,111,7439,111,7441,111,43837,111,959,111,120528,111,120586,111,120644,111,120702,111,120760,111,963,111,120532,111,120590,111,120648,111,120706,111,120764,111,11423,111,4351,111,1413,111,1505,111,1607,111,126500,111,126564,111,126596,111,65259,111,65260,111,65258,111,65257,111,1726,111,64428,111,64429,111,64427,111,64426,111,1729,111,64424,111,64425,111,64423,111,64422,111,1749,111,3360,111,4125,111,66794,111,71880,111,71895,111,66604,111,1984,79,2534,79,2918,79,12295,79,70864,79,71904,79,120782,79,120792,79,120802,79,120812,79,120822,79,130032,79,65327,79,119822,79,119874,79,119926,79,119978,79,120030,79,120082,79,120134,79,120186,79,120238,79,120290,79,120342,79,120394,79,120446,79,927,79,120502,79,120560,79,120618,79,120676,79,120734,79,11422,79,1365,79,11604,79,4816,79,2848,79,66754,79,42227,79,71861,79,66194,79,66219,79,66564,79,66838,79,9076,112,65360,112,119849,112,119901,112,119953,112,120005,112,120057,112,120109,112,120161,112,120213,112,120265,112,120317,112,120369,112,120421,112,120473,112,961,112,120530,112,120544,112,120588,112,120602,112,120646,112,120660,112,120704,112,120718,112,120762,112,120776,112,11427,112,65328,80,8473,80,119823,80,119875,80,119927,80,119979,80,120031,80,120083,80,120187,80,120239,80,120291,80,120343,80,120395,80,120447,80,929,80,120504,80,120562,80,120620,80,120678,80,120736,80,11426,80,5090,80,5229,80,42193,80,66197,80,119850,113,119902,113,119954,113,120006,113,120058,113,120110,113,120162,113,120214,113,120266,113,120318,113,120370,113,120422,113,120474,113,1307,113,1379,113,1382,113,8474,81,119824,81,119876,81,119928,81,119980,81,120032,81,120084,81,120188,81,120240,81,120292,81,120344,81,120396,81,120448,81,11605,81,119851,114,119903,114,119955,114,120007,114,120059,114,120111,114,120163,114,120215,114,120267,114,120319,114,120371,114,120423,114,120475,114,43847,114,43848,114,7462,114,11397,114,43905,114,119318,82,8475,82,8476,82,8477,82,119825,82,119877,82,119929,82,120033,82,120189,82,120241,82,120293,82,120345,82,120397,82,120449,82,422,82,5025,82,5074,82,66740,82,5511,82,42211,82,94005,82,65363,115,119852,115,119904,115,119956,115,120008,115,120060,115,120112,115,120164,115,120216,115,120268,115,120320,115,120372,115,120424,115,120476,115,42801,115,445,115,1109,115,43946,115,71873,115,66632,115,65331,83,119826,83,119878,83,119930,83,119982,83,120034,83,120086,83,120138,83,120190,83,120242,83,120294,83,120346,83,120398,83,120450,83,1029,83,1359,83,5077,83,5082,83,42210,83,94010,83,66198,83,66592,83,119853,116,119905,116,119957,116,120009,116,120061,116,120113,116,120165,116,120217,116,120269,116,120321,116,120373,116,120425,116,120477,116,8868,84,10201,84,128872,84,65332,84,119827,84,119879,84,119931,84,119983,84,120035,84,120087,84,120139,84,120191,84,120243,84,120295,84,120347,84,120399,84,120451,84,932,84,120507,84,120565,84,120623,84,120681,84,120739,84,11430,84,5026,84,42196,84,93962,84,71868,84,66199,84,66225,84,66325,84,119854,117,119906,117,119958,117,120010,117,120062,117,120114,117,120166,117,120218,117,120270,117,120322,117,120374,117,120426,117,120478,117,42911,117,7452,117,43854,117,43858,117,651,117,965,117,120534,117,120592,117,120650,117,120708,117,120766,117,1405,117,66806,117,71896,117,8746,85,8899,85,119828,85,119880,85,119932,85,119984,85,120036,85,120088,85,120140,85,120192,85,120244,85,120296,85,120348,85,120400,85,120452,85,1357,85,4608,85,66766,85,5196,85,42228,85,94018,85,71864,85,8744,118,8897,118,65366,118,8564,118,119855,118,119907,118,119959,118,120011,118,120063,118,120115,118,120167,118,120219,118,120271,118,120323,118,120375,118,120427,118,120479,118,7456,118,957,118,120526,118,120584,118,120642,118,120700,118,120758,118,1141,118,1496,118,71430,118,43945,118,71872,118,119309,86,1639,86,1783,86,8548,86,119829,86,119881,86,119933,86,119985,86,120037,86,120089,86,120141,86,120193,86,120245,86,120297,86,120349,86,120401,86,120453,86,1140,86,11576,86,5081,86,5167,86,42719,86,42214,86,93960,86,71840,86,66845,86,623,119,119856,119,119908,119,119960,119,120012,119,120064,119,120116,119,120168,119,120220,119,120272,119,120324,119,120376,119,120428,119,120480,119,7457,119,1121,119,1309,119,1377,119,71434,119,71438,119,71439,119,43907,119,71919,87,71910,87,119830,87,119882,87,119934,87,119986,87,120038,87,120090,87,120142,87,120194,87,120246,87,120298,87,120350,87,120402,87,120454,87,1308,87,5043,87,5076,87,42218,87,5742,120,10539,120,10540,120,10799,120,65368,120,8569,120,119857,120,119909,120,119961,120,120013,120,120065,120,120117,120,120169,120,120221,120,120273,120,120325,120,120377,120,120429,120,120481,120,5441,120,5501,120,5741,88,9587,88,66338,88,71916,88,65336,88,8553,88,119831,88,119883,88,119935,88,119987,88,120039,88,120091,88,120143,88,120195,88,120247,88,120299,88,120351,88,120403,88,120455,88,42931,88,935,88,120510,88,120568,88,120626,88,120684,88,120742,88,11436,88,11613,88,5815,88,42219,88,66192,88,66228,88,66327,88,66855,88,611,121,7564,121,65369,121,119858,121,119910,121,119962,121,120014,121,120066,121,120118,121,120170,121,120222,121,120274,121,120326,121,120378,121,120430,121,120482,121,655,121,7935,121,43866,121,947,121,8509,121,120516,121,120574,121,120632,121,120690,121,120748,121,1199,121,4327,121,71900,121,65337,89,119832,89,119884,89,119936,89,119988,89,120040,89,120092,89,120144,89,120196,89,120248,89,120300,89,120352,89,120404,89,120456,89,933,89,978,89,120508,89,120566,89,120624,89,120682,89,120740,89,11432,89,1198,89,5033,89,5053,89,42220,89,94019,89,71844,89,66226,89,119859,122,119911,122,119963,122,120015,122,120067,122,120119,122,120171,122,120223,122,120275,122,120327,122,120379,122,120431,122,120483,122,7458,122,43923,122,71876,122,66293,90,71909,90,65338,90,8484,90,8488,90,119833,90,119885,90,119937,90,119989,90,120041,90,120197,90,120249,90,120301,90,120353,90,120405,90,120457,90,918,90,120493,90,120551,90,120609,90,120667,90,120725,90,5059,90,42204,90,71849,90,65282,34,65284,36,65285,37,65286,38,65290,42,65291,43,65294,46,65295,47,65296,48,65297,49,65298,50,65299,51,65300,52,65301,53,65302,54,65303,55,65304,56,65305,57,65308,60,65309,61,65310,62,65312,64,65316,68,65318,70,65319,71,65324,76,65329,81,65330,82,65333,85,65334,86,65335,87,65343,95,65346,98,65348,100,65350,102,65355,107,65357,109,65358,110,65361,113,65362,114,65364,116,65365,117,65367,119,65370,122,65371,123,65373,125,119846,109],"_default":[160,32,8211,45,65374,126,65306,58,65281,33,8216,96,8217,96,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"cs":[65374,126,65306,58,65281,33,8216,96,8217,96,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"de":[65374,126,65306,58,65281,33,8216,96,8217,96,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"es":[8211,45,65374,126,65306,58,65281,33,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"fr":[65374,126,65306,58,65281,33,8216,96,8245,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"it":[160,32,8211,45,65374,126,65306,58,65281,33,8216,96,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"ja":[8211,45,65306,58,65281,33,8216,96,8217,96,8245,96,180,96,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65292,44,65307,59],"ko":[8211,45,65374,126,65306,58,65281,33,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"pl":[65374,126,65306,58,65281,33,8216,96,8217,96,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"pt-BR":[65374,126,65306,58,65281,33,8216,96,8217,96,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"qps-ploc":[160,32,8211,45,65374,126,65306,58,65281,33,8216,96,8217,96,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"ru":[65374,126,65306,58,65281,33,8216,96,8217,96,8245,96,180,96,12494,47,305,105,921,73,1009,112,215,120,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"tr":[160,32,8211,45,65374,126,65306,58,65281,33,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65288,40,65289,41,65292,44,65307,59,65311,63],"zh-hans":[65374,126,65306,58,65281,33,8245,96,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65288,40,65289,41],"zh-hant":[8211,45,65374,126,180,96,12494,47,1047,51,1073,54,1072,97,1040,65,1068,98,1042,66,1089,99,1057,67,1077,101,1045,69,1053,72,305,105,1050,75,921,73,1052,77,1086,111,1054,79,1009,112,1088,112,1056,80,1075,114,1058,84,215,120,1093,120,1061,88,1091,121,1059,89,65283,35,65307,59]}'));Ig.cache=new JQ(s=>{function e(d){const c=new Map;for(let u=0;u<d.length;u+=2)c.set(d[u],d[u+1]);return c}function t(d,c){const u=new Map(d);for(const[h,g]of c)u.set(h,g);return u}function i(d,c){if(!d)return c;const u=new Map;for(const[h,g]of d)c.has(h)&&u.set(h,g);return u}const n=lm.ambiguousCharacterData.value;let o=s.filter(d=>!d.startsWith("_")&&d in n);o.length===0&&(o=["_default"]);let r;for(const d of o){const c=e(n[d]);r=i(r,c)}const a=e(n._common),l=t(a,r);return new lm(l)});Ig._locales=new ih(()=>Object.keys(lm.ambiguousCharacterData.value).filter(s=>!s.startsWith("_")));class Vl{static getRawData(){return JSON.parse("[9,10,11,12,13,32,127,160,173,847,1564,4447,4448,6068,6069,6155,6156,6157,6158,7355,7356,8192,8193,8194,8195,8196,8197,8198,8199,8200,8201,8202,8203,8204,8205,8206,8207,8234,8235,8236,8237,8238,8239,8287,8288,8289,8290,8291,8292,8293,8294,8295,8296,8297,8298,8299,8300,8301,8302,8303,10240,12288,12644,65024,65025,65026,65027,65028,65029,65030,65031,65032,65033,65034,65035,65036,65037,65038,65039,65279,65440,65520,65521,65522,65523,65524,65525,65526,65527,65528,65532,78844,119155,119156,119157,119158,119159,119160,119161,119162,917504,917505,917506,917507,917508,917509,917510,917511,917512,917513,917514,917515,917516,917517,917518,917519,917520,917521,917522,917523,917524,917525,917526,917527,917528,917529,917530,917531,917532,917533,917534,917535,917536,917537,917538,917539,917540,917541,917542,917543,917544,917545,917546,917547,917548,917549,917550,917551,917552,917553,917554,917555,917556,917557,917558,917559,917560,917561,917562,917563,917564,917565,917566,917567,917568,917569,917570,917571,917572,917573,917574,917575,917576,917577,917578,917579,917580,917581,917582,917583,917584,917585,917586,917587,917588,917589,917590,917591,917592,917593,917594,917595,917596,917597,917598,917599,917600,917601,917602,917603,917604,917605,917606,917607,917608,917609,917610,917611,917612,917613,917614,917615,917616,917617,917618,917619,917620,917621,917622,917623,917624,917625,917626,917627,917628,917629,917630,917631,917760,917761,917762,917763,917764,917765,917766,917767,917768,917769,917770,917771,917772,917773,917774,917775,917776,917777,917778,917779,917780,917781,917782,917783,917784,917785,917786,917787,917788,917789,917790,917791,917792,917793,917794,917795,917796,917797,917798,917799,917800,917801,917802,917803,917804,917805,917806,917807,917808,917809,917810,917811,917812,917813,917814,917815,917816,917817,917818,917819,917820,917821,917822,917823,917824,917825,917826,917827,917828,917829,917830,917831,917832,917833,917834,917835,917836,917837,917838,917839,917840,917841,917842,917843,917844,917845,917846,917847,917848,917849,917850,917851,917852,917853,917854,917855,917856,917857,917858,917859,917860,917861,917862,917863,917864,917865,917866,917867,917868,917869,917870,917871,917872,917873,917874,917875,917876,917877,917878,917879,917880,917881,917882,917883,917884,917885,917886,917887,917888,917889,917890,917891,917892,917893,917894,917895,917896,917897,917898,917899,917900,917901,917902,917903,917904,917905,917906,917907,917908,917909,917910,917911,917912,917913,917914,917915,917916,917917,917918,917919,917920,917921,917922,917923,917924,917925,917926,917927,917928,917929,917930,917931,917932,917933,917934,917935,917936,917937,917938,917939,917940,917941,917942,917943,917944,917945,917946,917947,917948,917949,917950,917951,917952,917953,917954,917955,917956,917957,917958,917959,917960,917961,917962,917963,917964,917965,917966,917967,917968,917969,917970,917971,917972,917973,917974,917975,917976,917977,917978,917979,917980,917981,917982,917983,917984,917985,917986,917987,917988,917989,917990,917991,917992,917993,917994,917995,917996,917997,917998,917999]")}static getData(){return this._data||(this._data=new Set(Vl.getRawData())),this._data}static isInvisibleCharacter(e){return Vl.getData().has(e)}static get codePoints(){return Vl.getData()}}Vl._data=void 0;class VN{constructor(){this._zoomFactor=1}getZoomFactor(){return this._zoomFactor}}VN.INSTANCE=new VN;class pJ extends j{constructor(){super(),this._onDidChange=this._register(new W),this.onDidChange=this._onDidChange.event,this._listener=()=>this._handleChange(!0),this._mediaQueryList=null,this._handleChange(!1)}_handleChange(e){var t;(t=this._mediaQueryList)===null||t===void 0||t.removeEventListener("change",this._listener),this._mediaQueryList=Wl.matchMedia(`(resolution: ${Wl.devicePixelRatio}dppx)`),this._mediaQueryList.addEventListener("change",this._listener),e&&this._onDidChange.fire()}}class mJ extends j{get value(){return this._value}constructor(){super(),this._onDidChange=this._register(new W),this.onDidChange=this._onDidChange.event,this._value=this._getPixelRatio();const e=this._register(new pJ);this._register(e.onDidChange(()=>{this._value=this._getPixelRatio(),this._onDidChange.fire(this._value)}))}_getPixelRatio(){const e=document.createElement("canvas").getContext("2d"),t=Wl.devicePixelRatio||1,i=e.webkitBackingStorePixelRatio||e.mozBackingStorePixelRatio||e.msBackingStorePixelRatio||e.oBackingStorePixelRatio||e.backingStorePixelRatio||1;return t/i}}class _J{constructor(){this._pixelRatioMonitor=null}_getOrCreatePixelRatioMonitor(){return this._pixelRatioMonitor||(this._pixelRatioMonitor=new mJ),this._pixelRatioMonitor}get value(){return this._getOrCreatePixelRatioMonitor().value}get onDidChange(){return this._getOrCreatePixelRatioMonitor().onDidChange}}function GW(s,e){typeof s=="string"&&(s=Wl.matchMedia(s)),s.addEventListener("change",e)}const D0=new _J;function vJ(){return VN.INSTANCE.getZoomFactor()}const e_=navigator.userAgent,yr=e_.indexOf("Firefox")>=0,ug=e_.indexOf("AppleWebKit")>=0,UA=e_.indexOf("Chrome")>=0,Jd=!UA&&e_.indexOf("Safari")>=0,ZW=!UA&&!Jd&&ug;e_.indexOf("Electron/")>=0;const l5=e_.indexOf("Android")>=0;let Nw=!1;if(Wl.matchMedia){const s=Wl.matchMedia("(display-mode: standalone) or (display-mode: window-controls-overlay)"),e=Wl.matchMedia("(display-mode: fullscreen)");Nw=s.matches,GW(s,({matches:t})=>{Nw&&e.matches||(Nw=t)})}function bJ(){return Nw}class YW{constructor(e){this.domNode=e,this._maxWidth="",this._width="",this._height="",this._top="",this._left="",this._bottom="",this._right="",this._paddingLeft="",this._fontFamily="",this._fontWeight="",this._fontSize="",this._fontStyle="",this._fontFeatureSettings="",this._fontVariationSettings="",this._textDecoration="",this._lineHeight="",this._letterSpacing="",this._className="",this._display="",this._position="",this._visibility="",this._color="",this._backgroundColor="",this._layerHint=!1,this._contain="none",this._boxShadow=""}setMaxWidth(e){const t=aa(e);this._maxWidth!==t&&(this._maxWidth=t,this.domNode.style.maxWidth=this._maxWidth)}setWidth(e){const t=aa(e);this._width!==t&&(this._width=t,this.domNode.style.width=this._width)}setHeight(e){const t=aa(e);this._height!==t&&(this._height=t,this.domNode.style.height=this._height)}setTop(e){const t=aa(e);this._top!==t&&(this._top=t,this.domNode.style.top=this._top)}setLeft(e){const t=aa(e);this._left!==t&&(this._left=t,this.domNode.style.left=this._left)}setBottom(e){const t=aa(e);this._bottom!==t&&(this._bottom=t,this.domNode.style.bottom=this._bottom)}setRight(e){const t=aa(e);this._right!==t&&(this._right=t,this.domNode.style.right=this._right)}setPaddingLeft(e){const t=aa(e);this._paddingLeft!==t&&(this._paddingLeft=t,this.domNode.style.paddingLeft=this._paddingLeft)}setFontFamily(e){this._fontFamily!==e&&(this._fontFamily=e,this.domNode.style.fontFamily=this._fontFamily)}setFontWeight(e){this._fontWeight!==e&&(this._fontWeight=e,this.domNode.style.fontWeight=this._fontWeight)}setFontSize(e){const t=aa(e);this._fontSize!==t&&(this._fontSize=t,this.domNode.style.fontSize=this._fontSize)}setFontStyle(e){this._fontStyle!==e&&(this._fontStyle=e,this.domNode.style.fontStyle=this._fontStyle)}setFontFeatureSettings(e){this._fontFeatureSettings!==e&&(this._fontFeatureSettings=e,this.domNode.style.fontFeatureSettings=this._fontFeatureSettings)}setFontVariationSettings(e){this._fontVariationSettings!==e&&(this._fontVariationSettings=e,this.domNode.style.fontVariationSettings=this._fontVariationSettings)}setTextDecoration(e){this._textDecoration!==e&&(this._textDecoration=e,this.domNode.style.textDecoration=this._textDecoration)}setLineHeight(e){const t=aa(e);this._lineHeight!==t&&(this._lineHeight=t,this.domNode.style.lineHeight=this._lineHeight)}setLetterSpacing(e){const t=aa(e);this._letterSpacing!==t&&(this._letterSpacing=t,this.domNode.style.letterSpacing=this._letterSpacing)}setClassName(e){this._className!==e&&(this._className=e,this.domNode.className=this._className)}toggleClassName(e,t){this.domNode.classList.toggle(e,t),this._className=this.domNode.className}setDisplay(e){this._display!==e&&(this._display=e,this.domNode.style.display=this._display)}setPosition(e){this._position!==e&&(this._position=e,this.domNode.style.position=this._position)}setVisibility(e){this._visibility!==e&&(this._visibility=e,this.domNode.style.visibility=this._visibility)}setColor(e){this._color!==e&&(this._color=e,this.domNode.style.color=this._color)}setBackgroundColor(e){this._backgroundColor!==e&&(this._backgroundColor=e,this.domNode.style.backgroundColor=this._backgroundColor)}setLayerHinting(e){this._layerHint!==e&&(this._layerHint=e,this.domNode.style.transform=this._layerHint?"translate3d(0px, 0px, 0px)":"")}setBoxShadow(e){this._boxShadow!==e&&(this._boxShadow=e,this.domNode.style.boxShadow=e)}setContain(e){this._contain!==e&&(this._contain=e,this.domNode.style.contain=this._contain)}setAttribute(e,t){this.domNode.setAttribute(e,t)}removeAttribute(e){this.domNode.removeAttribute(e)}appendChild(e){this.domNode.appendChild(e.domNode)}removeChild(e){this.domNode.removeChild(e.domNode)}}function aa(s){return typeof s=="number"?`${s}px`:s}function Mt(s){return new YW(s)}function Xn(s,e){s instanceof YW?(s.setFontFamily(e.getMassagedFontFamily()),s.setFontWeight(e.fontWeight),s.setFontSize(e.fontSize),s.setFontFeatureSettings(e.fontFeatureSettings),s.setFontVariationSettings(e.fontVariationSettings),s.setLineHeight(e.lineHeight),s.setLetterSpacing(e.letterSpacing)):(s.style.fontFamily=e.getMassagedFontFamily(),s.style.fontWeight=e.fontWeight,s.style.fontSize=e.fontSize+"px",s.style.fontFeatureSettings=e.fontFeatureSettings,s.style.fontVariationSettings=e.fontVariationSettings,s.style.lineHeight=e.lineHeight+"px",s.style.letterSpacing=e.letterSpacing+"px")}class CJ{constructor(e,t){this.chr=e,this.type=t,this.width=0}fulfill(e){this.width=e}}class $A{constructor(e,t){this._bareFontInfo=e,this._requests=t,this._container=null,this._testElements=null}read(){this._createDomElements(),Wl.document.body.appendChild(this._container),this._readFromDomElements(),Wl.document.body.removeChild(this._container),this._container=null,this._testElements=null}_createDomElements(){const e=document.createElement("div");e.style.position="absolute",e.style.top="-50000px",e.style.width="50000px";const t=document.createElement("div");Xn(t,this._bareFontInfo),e.appendChild(t);const i=document.createElement("div");Xn(i,this._bareFontInfo),i.style.fontWeight="bold",e.appendChild(i);const n=document.createElement("div");Xn(n,this._bareFontInfo),n.style.fontStyle="italic",e.appendChild(n);const o=[];for(const r of this._requests){let a;r.type===0&&(a=t),r.type===2&&(a=i),r.type===1&&(a=n),a.appendChild(document.createElement("br"));const l=document.createElement("span");$A._render(l,r),a.appendChild(l),o.push(l)}this._container=e,this._testElements=o}static _render(e,t){if(t.chr===" "){let i=" ";for(let n=0;n<8;n++)i+=i;e.innerText=i}else{let i=t.chr;for(let n=0;n<8;n++)i+=i;e.textContent=i}}_readFromDomElements(){for(let e=0,t=this._requests.length;e<t;e++){const i=this._requests[e],n=this._testElements[e];i.fulfill(n.offsetWidth/256)}}}function wJ(s,e){new $A(s,e).read()}const fr=new class{constructor(){this._zoomLevel=0,this._onDidChangeZoomLevel=new W,this.onDidChangeZoomLevel=this._onDidChangeZoomLevel.event}getZoomLevel(){return this._zoomLevel}setZoomLevel(s){s=Math.min(Math.max(-5,s),20),this._zoomLevel!==s&&(this._zoomLevel=s,this._onDidChangeZoomLevel.fire(this._zoomLevel))}},SJ=bt?1.5:1.35,Ek=8;class hg{static createFromValidatedSettings(e,t,i){const n=e.get(49),o=e.get(53),r=e.get(52),a=e.get(51),l=e.get(54),d=e.get(66),c=e.get(63);return hg._create(n,o,r,a,l,d,c,t,i)}static _create(e,t,i,n,o,r,a,l,d){r===0?r=SJ*i:r<Ek&&(r=r*i),r=Math.round(r),r<Ek&&(r=Ek);const c=1+(d?0:fr.getZoomLevel()*.1);return i*=c,r*=c,o===La.TRANSLATE&&(t==="normal"||t==="bold"?o=La.OFF:(o=`'wght' ${parseInt(t,10)}`,t="normal")),new hg({pixelRatio:l,fontFamily:e,fontWeight:t,fontSize:i,fontFeatureSettings:n,fontVariationSettings:o,lineHeight:r,letterSpacing:a})}constructor(e){this._bareFontInfoBrand=void 0,this.pixelRatio=e.pixelRatio,this.fontFamily=String(e.fontFamily),this.fontWeight=String(e.fontWeight),this.fontSize=e.fontSize,this.fontFeatureSettings=e.fontFeatureSettings,this.fontVariationSettings=e.fontVariationSettings,this.lineHeight=e.lineHeight|0,this.letterSpacing=e.letterSpacing}getId(){return`${this.pixelRatio}-${this.fontFamily}-${this.fontWeight}-${this.fontSize}-${this.fontFeatureSettings}-${this.fontVariationSettings}-${this.lineHeight}-${this.letterSpacing}`}getMassagedFontFamily(){const e=vo.fontFamily,t=hg._wrapInQuotes(this.fontFamily);return e&&this.fontFamily!==e?`${t}, ${e}`:t}static _wrapInQuotes(e){return/[,"']/.test(e)?e:/[+ ]/.test(e)?`"${e}"`:e}}const yJ=2;class HN extends hg{constructor(e,t){super(e),this._editorStylingBrand=void 0,this.version=yJ,this.isTrusted=t,this.isMonospace=e.isMonospace,this.typicalHalfwidthCharacterWidth=e.typicalHalfwidthCharacterWidth,this.typicalFullwidthCharacterWidth=e.typicalFullwidthCharacterWidth,this.canUseHalfwidthRightwardsArrow=e.canUseHalfwidthRightwardsArrow,this.spaceWidth=e.spaceWidth,this.middotWidth=e.middotWidth,this.wsmiddotWidth=e.wsmiddotWidth,this.maxDigitWidth=e.maxDigitWidth}equals(e){return this.fontFamily===e.fontFamily&&this.fontWeight===e.fontWeight&&this.fontSize===e.fontSize&&this.fontFeatureSettings===e.fontFeatureSettings&&this.fontVariationSettings===e.fontVariationSettings&&this.lineHeight===e.lineHeight&&this.letterSpacing===e.letterSpacing&&this.typicalHalfwidthCharacterWidth===e.typicalHalfwidthCharacterWidth&&this.typicalFullwidthCharacterWidth===e.typicalFullwidthCharacterWidth&&this.canUseHalfwidthRightwardsArrow===e.canUseHalfwidthRightwardsArrow&&this.spaceWidth===e.spaceWidth&&this.middotWidth===e.middotWidth&&this.wsmiddotWidth===e.wsmiddotWidth&&this.maxDigitWidth===e.maxDigitWidth}}class LJ extends j{constructor(){super(),this._onDidChange=this._register(new W),this.onDidChange=this._onDidChange.event,this._cache=new d5,this._evictUntrustedReadingsTimeout=-1}dispose(){this._evictUntrustedReadingsTimeout!==-1&&(clearTimeout(this._evictUntrustedReadingsTimeout),this._evictUntrustedReadingsTimeout=-1),super.dispose()}clearAllFontInfos(){this._cache=new d5,this._onDidChange.fire()}_writeToCache(e,t){this._cache.put(e,t),!t.isTrusted&&this._evictUntrustedReadingsTimeout===-1&&(this._evictUntrustedReadingsTimeout=Ci.setTimeout(()=>{this._evictUntrustedReadingsTimeout=-1,this._evictUntrustedReadings()},5e3))}_evictUntrustedReadings(){const e=this._cache.getValues();let t=!1;for(const i of e)i.isTrusted||(t=!0,this._cache.remove(i));t&&this._onDidChange.fire()}readFontInfo(e){if(!this._cache.has(e)){let t=this._actualReadFontInfo(e);(t.typicalHalfwidthCharacterWidth<=2||t.typicalFullwidthCharacterWidth<=2||t.spaceWidth<=2||t.maxDigitWidth<=2)&&(t=new HN({pixelRatio:D0.value,fontFamily:t.fontFamily,fontWeight:t.fontWeight,fontSize:t.fontSize,fontFeatureSettings:t.fontFeatureSettings,fontVariationSettings:t.fontVariationSettings,lineHeight:t.lineHeight,letterSpacing:t.letterSpacing,isMonospace:t.isMonospace,typicalHalfwidthCharacterWidth:Math.max(t.typicalHalfwidthCharacterWidth,5),typicalFullwidthCharacterWidth:Math.max(t.typicalFullwidthCharacterWidth,5),canUseHalfwidthRightwardsArrow:t.canUseHalfwidthRightwardsArrow,spaceWidth:Math.max(t.spaceWidth,5),middotWidth:Math.max(t.middotWidth,5),wsmiddotWidth:Math.max(t.wsmiddotWidth,5),maxDigitWidth:Math.max(t.maxDigitWidth,5)},!1)),this._writeToCache(e,t)}return this._cache.get(e)}_createRequest(e,t,i,n){const o=new CJ(e,t);return i.push(o),n==null||n.push(o),o}_actualReadFontInfo(e){const t=[],i=[],n=this._createRequest("n",0,t,i),o=this._createRequest("ｍ",0,t,null),r=this._createRequest(" ",0,t,i),a=this._createRequest("0",0,t,i),l=this._createRequest("1",0,t,i),d=this._createRequest("2",0,t,i),c=this._createRequest("3",0,t,i),u=this._createRequest("4",0,t,i),h=this._createRequest("5",0,t,i),g=this._createRequest("6",0,t,i),f=this._createRequest("7",0,t,i),m=this._createRequest("8",0,t,i),_=this._createRequest("9",0,t,i),v=this._createRequest("→",0,t,i),b=this._createRequest("￫",0,t,null),C=this._createRequest("·",0,t,i),w=this._createRequest("⸱",0,t,null),S="|/-_ilm%";for(let P=0,$=S.length;P<$;P++)this._createRequest(S.charAt(P),0,t,i),this._createRequest(S.charAt(P),1,t,i),this._createRequest(S.charAt(P),2,t,i);wJ(e,t);const x=Math.max(a.width,l.width,d.width,c.width,u.width,h.width,g.width,f.width,m.width,_.width);let L=e.fontFeatureSettings===$o.OFF;const k=i[0].width;for(let P=1,$=i.length;L&&P<$;P++){const A=k-i[P].width;if(A<-.001||A>.001){L=!1;break}}let I=!0;return L&&b.width!==k&&(I=!1),b.width>v.width&&(I=!1),new HN({pixelRatio:D0.value,fontFamily:e.fontFamily,fontWeight:e.fontWeight,fontSize:e.fontSize,fontFeatureSettings:e.fontFeatureSettings,fontVariationSettings:e.fontVariationSettings,lineHeight:e.lineHeight,letterSpacing:e.letterSpacing,isMonospace:L,typicalHalfwidthCharacterWidth:n.width,typicalFullwidthCharacterWidth:o.width,canUseHalfwidthRightwardsArrow:I,spaceWidth:r.width,middotWidth:C.width,wsmiddotWidth:w.width,maxDigitWidth:x},!0)}}class d5{constructor(){this._keys=Object.create(null),this._values=Object.create(null)}has(e){const t=e.getId();return!!this._values[t]}get(e){const t=e.getId();return this._values[t]}put(e,t){const i=e.getId();this._keys[i]=e,this._values[i]=t}remove(e){const t=e.getId();delete this._keys[t],delete this._values[t]}getValues(){return Object.keys(this._keys).map(e=>this._values[e])}}const zN=new LJ;var Ea;(function(s){s.serviceIds=new Map,s.DI_TARGET="$di$target",s.DI_DEPENDENCIES="$di$dependencies";function e(t){return t[s.DI_DEPENDENCIES]||[]}s.getServiceDependencies=e})(Ea||(Ea={}));const We=ut("instantiationService");function xJ(s,e,t){e[Ea.DI_TARGET]===e?e[Ea.DI_DEPENDENCIES].push({id:s,index:t}):(e[Ea.DI_DEPENDENCIES]=[{id:s,index:t}],e[Ea.DI_TARGET]=e)}function ut(s){if(Ea.serviceIds.has(s))return Ea.serviceIds.get(s);const e=function(t,i,n){if(arguments.length!==3)throw new Error("@IServiceName-decorator can only be used to decorate a parameter");xJ(e,t,n)};return e.toString=()=>s,Ea.serviceIds.set(s,e),e}const It=ut("codeEditorService"),vi=ut("modelService"),io=ut("textModelService");class Os extends j{constructor(e,t="",i="",n=!0,o){super(),this._onDidChange=this._register(new W),this.onDidChange=this._onDidChange.event,this._enabled=!0,this._id=e,this._label=t,this._cssClass=i,this._enabled=n,this._actionCallback=o}get id(){return this._id}get label(){return this._label}set label(e){this._setLabel(e)}_setLabel(e){this._label!==e&&(this._label=e,this._onDidChange.fire({label:e}))}get tooltip(){return this._tooltip||""}set tooltip(e){this._setTooltip(e)}_setTooltip(e){this._tooltip!==e&&(this._tooltip=e,this._onDidChange.fire({tooltip:e}))}get class(){return this._cssClass}set class(e){this._setClass(e)}_setClass(e){this._cssClass!==e&&(this._cssClass=e,this._onDidChange.fire({class:e}))}get enabled(){return this._enabled}set enabled(e){this._setEnabled(e)}_setEnabled(e){this._enabled!==e&&(this._enabled=e,this._onDidChange.fire({enabled:e}))}get checked(){return this._checked}set checked(e){this._setChecked(e)}_setChecked(e){this._checked!==e&&(this._checked=e,this._onDidChange.fire({checked:e}))}async run(e,t){this._actionCallback&&await this._actionCallback(e)}}class Eg extends j{constructor(){super(...arguments),this._onWillRun=this._register(new W),this.onWillRun=this._onWillRun.event,this._onDidRun=this._register(new W),this.onDidRun=this._onDidRun.event}async run(e,t){if(!e.enabled)return;this._onWillRun.fire({action:e});let i;try{await this.runAction(e,t)}catch(n){i=n}this._onDidRun.fire({action:e,error:i})}async runAction(e,t){await e.run(t)}}class In{constructor(){this.id=In.ID,this.label="",this.tooltip="",this.class="separator",this.enabled=!1,this.checked=!1}static join(...e){let t=[];for(const i of e)i.length&&(t.length?t=[...t,new In,...i]:t=i);return t}async run(){}}In.ID="vs.actions.separator";class cm{get actions(){return this._actions}constructor(e,t,i,n){this.tooltip="",this.enabled=!0,this.checked=void 0,this.id=e,this.label=t,this.class=n,this._actions=i}async run(){}}class GL extends Os{constructor(){super(GL.ID,p("submenu.empty","(empty)"),void 0,!1)}}GL.ID="vs.actions.empty";function Rp(s){var e,t;return{id:s.id,label:s.label,class:s.class,enabled:(e=s.enabled)!==null&&e!==void 0?e:!0,checked:(t=s.checked)!==null&&t!==void 0?t:!1,run:async(...i)=>s.run(...i),tooltip:s.label}}var UN;(function(s){function e(t){return t&&typeof t=="object"&&typeof t.id=="string"}s.isThemeColor=e})(UN||(UN={}));var Oe;(function(s){s.iconNameSegment="[A-Za-z0-9]+",s.iconNameExpression="[A-Za-z0-9-]+",s.iconModifierExpression="~[A-Za-z]+",s.iconNameCharacter="[A-Za-z0-9~-]";const e=new RegExp(`^(${s.iconNameExpression})(${s.iconModifierExpression})?$`);function t(h){const g=e.exec(h.id);if(!g)return t(le.error);const[,f,m]=g,_=["codicon","codicon-"+f];return m&&_.push("codicon-modifier-"+m.substring(1)),_}s.asClassNameArray=t;function i(h){return t(h).join(" ")}s.asClassName=i;function n(h){return"."+t(h).join(".")}s.asCSSSelector=n;function o(h){return h&&typeof h=="object"&&typeof h.id=="string"&&(typeof h.color>"u"||UN.isThemeColor(h.color))}s.isThemeIcon=o;const r=new RegExp(`^\\$\\((${s.iconNameExpression}(?:${s.iconModifierExpression})?)\\)$`);function a(h){const g=r.exec(h);if(!g)return;const[,f]=g;return{id:f}}s.fromString=a;function l(h){return{id:h}}s.fromId=l;function d(h,g){let f=h.id;const m=f.lastIndexOf("~");return m!==-1&&(f=f.substring(0,m)),g&&(f=`${f}~${g}`),{id:f}}s.modify=d;function c(h){const g=h.id.lastIndexOf("~");if(g!==-1)return h.id.substring(g+1)}s.getModifier=c;function u(h,g){var f,m;return h.id===g.id&&((f=h.color)===null||f===void 0?void 0:f.id)===((m=g.color)===null||m===void 0?void 0:m.id)}s.isEqual=u})(Oe||(Oe={}));const Ei=ut("commandService"),Ct=new class{constructor(){this._commands=new Map,this._onDidRegisterCommand=new W,this.onDidRegisterCommand=this._onDidRegisterCommand.event}registerCommand(s,e){if(!s)throw new Error("invalid command");if(typeof s=="string"){if(!e)throw new Error("invalid command");return this.registerCommand({id:s,handler:e})}if(s.metadata&&Array.isArray(s.metadata.args)){const r=[];for(const l of s.metadata.args)r.push(l.constraint);const a=s.handler;s.handler=function(l,...d){return oX(d,r),a(l,...d)}}const{id:t}=s;let i=this._commands.get(t);i||(i=new Ms,this._commands.set(t,i));const n=i.unshift(s),o=Fe(()=>{n();const r=this._commands.get(t);r!=null&&r.isEmpty()&&this._commands.delete(t)});return this._onDidRegisterCommand.fire(t),o}registerCommandAlias(s,e){return Ct.registerCommand(s,(t,...i)=>t.get(Ei).executeCommand(e,...i))}getCommand(s){const e=this._commands.get(s);if(!(!e||e.isEmpty()))return ht.first(e)}getCommands(){const s=new Map;for(const e of this._commands.keys()){const t=this.getCommand(e);t&&s.set(e,t)}return s}};Ct.registerCommand("noop",()=>{});function Nk(...s){switch(s.length){case 1:return p("contextkey.scanner.hint.didYouMean1","Did you mean {0}?",s[0]);case 2:return p("contextkey.scanner.hint.didYouMean2","Did you mean {0} or {1}?",s[0],s[1]);case 3:return p("contextkey.scanner.hint.didYouMean3","Did you mean {0}, {1} or {2}?",s[0],s[1],s[2]);default:return}}const DJ=p("contextkey.scanner.hint.didYouForgetToOpenOrCloseQuote","Did you forget to open or close the quote?"),kJ=p("contextkey.scanner.hint.didYouForgetToEscapeSlash","Did you forget to escape the '/' (slash) character? Put two backslashes before it to escape, e.g., '\\\\/'.");let Hh=class $N{constructor(){this._input="",this._start=0,this._current=0,this._tokens=[],this._errors=[],this.stringRe=/[a-zA-Z0-9_<>\-\./\\:\*\?\+\[\]\^,#@;"%\$\p{L}-]+/uy}static getLexeme(e){switch(e.type){case 0:return"(";case 1:return")";case 2:return"!";case 3:return e.isTripleEq?"===":"==";case 4:return e.isTripleEq?"!==":"!=";case 5:return"<";case 6:return"<=";case 7:return">=";case 8:return">=";case 9:return"=~";case 10:return e.lexeme;case 11:return"true";case 12:return"false";case 13:return"in";case 14:return"not";case 15:return"&&";case 16:return"||";case 17:return e.lexeme;case 18:return e.lexeme;case 19:return e.lexeme;case 20:return"EOF";default:throw IA(`unhandled token type: ${JSON.stringify(e)}; have you forgotten to add a case?`)}}reset(e){return this._input=e,this._start=0,this._current=0,this._tokens=[],this._errors=[],this}scan(){for(;!this._isAtEnd();)switch(this._start=this._current,this._advance()){case 40:this._addToken(0);break;case 41:this._addToken(1);break;case 33:if(this._match(61)){const t=this._match(61);this._tokens.push({type:4,offset:this._start,isTripleEq:t})}else this._addToken(2);break;case 39:this._quotedString();break;case 47:this._regex();break;case 61:if(this._match(61)){const t=this._match(61);this._tokens.push({type:3,offset:this._start,isTripleEq:t})}else this._match(126)?this._addToken(9):this._error(Nk("==","=~"));break;case 60:this._addToken(this._match(61)?6:5);break;case 62:this._addToken(this._match(61)?8:7);break;case 38:this._match(38)?this._addToken(15):this._error(Nk("&&"));break;case 124:this._match(124)?this._addToken(16):this._error(Nk("||"));break;case 32:case 13:case 9:case 10:case 160:break;default:this._string()}return this._start=this._current,this._addToken(20),Array.from(this._tokens)}_match(e){return this._isAtEnd()||this._input.charCodeAt(this._current)!==e?!1:(this._current++,!0)}_advance(){return this._input.charCodeAt(this._current++)}_peek(){return this._isAtEnd()?0:this._input.charCodeAt(this._current)}_addToken(e){this._tokens.push({type:e,offset:this._start})}_error(e){const t=this._start,i=this._input.substring(this._start,this._current),n={type:19,offset:this._start,lexeme:i};this._errors.push({offset:t,lexeme:i,additionalInfo:e}),this._tokens.push(n)}_string(){this.stringRe.lastIndex=this._start;const e=this.stringRe.exec(this._input);if(e){this._current=this._start+e[0].length;const t=this._input.substring(this._start,this._current),i=$N._keywords.get(t);i?this._addToken(i):this._tokens.push({type:17,lexeme:t,offset:this._start})}}_quotedString(){for(;this._peek()!==39&&!this._isAtEnd();)this._advance();if(this._isAtEnd()){this._error(DJ);return}this._advance(),this._tokens.push({type:18,lexeme:this._input.substring(this._start+1,this._current-1),offset:this._start+1})}_regex(){let e=this._current,t=!1,i=!1;for(;;){if(e>=this._input.length){this._current=e,this._error(kJ);return}const o=this._input.charCodeAt(e);if(t)t=!1;else if(o===47&&!i){e++;break}else o===91?i=!0:o===92?t=!0:o===93&&(i=!1);e++}for(;e<this._input.length&&$N._regexFlags.has(this._input.charCodeAt(e));)e++;this._current=e;const n=this._input.substring(this._start,this._current);this._tokens.push({type:10,lexeme:n,offset:this._start})}_isAtEnd(){return this._current>=this._input.length}};Hh._regexFlags=new Set(["i","g","s","m","y","u"].map(s=>s.charCodeAt(0)));Hh._keywords=new Map([["not",14],["in",13],["false",12],["true",11]]);const us=new Map;us.set("false",!1);us.set("true",!0);us.set("isMac",bt);us.set("isLinux",Ss);us.set("isWindows",es);us.set("isWeb",Ju);us.set("isMacNative",bt&&!Ju);us.set("isEdge",SX);us.set("isFirefox",CX);us.set("isChrome",CW);us.set("isSafari",wX);const IJ=Object.prototype.hasOwnProperty,EJ={regexParsingWithErrorRecovery:!0},NJ=p("contextkey.parser.error.emptyString","Empty context key expression"),TJ=p("contextkey.parser.error.emptyString.hint","Did you forget to write an expression? You can also put 'false' or 'true' to always evaluate to false or true, respectively."),MJ=p("contextkey.parser.error.noInAfterNot","'in' after 'not'."),c5=p("contextkey.parser.error.closingParenthesis","closing parenthesis ')'"),RJ=p("contextkey.parser.error.unexpectedToken","Unexpected token"),AJ=p("contextkey.parser.error.unexpectedToken.hint","Did you forget to put && or || before the token?"),PJ=p("contextkey.parser.error.unexpectedEOF","Unexpected end of expression"),OJ=p("contextkey.parser.error.unexpectedEOF.hint","Did you forget to put a context key?");let XW=class sv{constructor(e=EJ){this._config=e,this._scanner=new Hh,this._tokens=[],this._current=0,this._parsingErrors=[],this._flagsGYRe=/g|y/g}parse(e){if(e===""){this._parsingErrors.push({message:NJ,offset:0,lexeme:"",additionalInfo:TJ});return}this._tokens=this._scanner.reset(e).scan(),this._current=0,this._parsingErrors=[];try{const t=this._expr();if(!this._isAtEnd()){const i=this._peek(),n=i.type===17?AJ:void 0;throw this._parsingErrors.push({message:RJ,offset:i.offset,lexeme:Hh.getLexeme(i),additionalInfo:n}),sv._parseError}return t}catch(t){if(t!==sv._parseError)throw t;return}}_expr(){return this._or()}_or(){const e=[this._and()];for(;this._matchOne(16);){const t=this._and();e.push(t)}return e.length===1?e[0]:ee.or(...e)}_and(){const e=[this._term()];for(;this._matchOne(15);){const t=this._term();e.push(t)}return e.length===1?e[0]:ee.and(...e)}_term(){if(this._matchOne(2)){const e=this._peek();switch(e.type){case 11:return this._advance(),Bs.INSTANCE;case 12:return this._advance(),Qs.INSTANCE;case 0:{this._advance();const t=this._expr();return this._consume(1,c5),t==null?void 0:t.negate()}case 17:return this._advance(),af.create(e.lexeme);default:throw this._errExpectedButGot("KEY | true | false | '(' expression ')'",e)}}return this._primary()}_primary(){const e=this._peek();switch(e.type){case 11:return this._advance(),ee.true();case 12:return this._advance(),ee.false();case 0:{this._advance();const t=this._expr();return this._consume(1,c5),t}case 17:{const t=e.lexeme;if(this._advance(),this._matchOne(9)){const n=this._peek();if(!this._config.regexParsingWithErrorRecovery){if(this._advance(),n.type!==10)throw this._errExpectedButGot("REGEX",n);const o=n.lexeme,r=o.lastIndexOf("/"),a=r===o.length-1?void 0:this._removeFlagsGY(o.substring(r+1));let l;try{l=new RegExp(o.substring(1,r),a)}catch{throw this._errExpectedButGot("REGEX",n)}return k0.create(t,l)}switch(n.type){case 10:case 19:{const o=[n.lexeme];this._advance();let r=this._peek(),a=0;for(let h=0;h<n.lexeme.length;h++)n.lexeme.charCodeAt(h)===40?a++:n.lexeme.charCodeAt(h)===41&&a--;for(;!this._isAtEnd()&&r.type!==15&&r.type!==16;){switch(r.type){case 0:a++;break;case 1:a--;break;case 10:case 18:for(let h=0;h<r.lexeme.length;h++)r.lexeme.charCodeAt(h)===40?a++:n.lexeme.charCodeAt(h)===41&&a--}if(a<0)break;o.push(Hh.getLexeme(r)),this._advance(),r=this._peek()}const l=o.join(""),d=l.lastIndexOf("/"),c=d===l.length-1?void 0:this._removeFlagsGY(l.substring(d+1));let u;try{u=new RegExp(l.substring(1,d),c)}catch{throw this._errExpectedButGot("REGEX",n)}return ee.regex(t,u)}case 18:{const o=n.lexeme;this._advance();let r=null;if(!VW(o)){const a=o.indexOf("/"),l=o.lastIndexOf("/");if(a!==l&&a>=0){const d=o.slice(a+1,l),c=o[l+1]==="i"?"i":"";try{r=new RegExp(d,c)}catch{throw this._errExpectedButGot("REGEX",n)}}}if(r===null)throw this._errExpectedButGot("REGEX",n);return k0.create(t,r)}default:throw this._errExpectedButGot("REGEX",this._peek())}}if(this._matchOne(14)){this._consume(13,MJ);const n=this._value();return ee.notIn(t,n)}switch(this._peek().type){case 3:{this._advance();const n=this._value();if(this._previous().type===18)return ee.equals(t,n);switch(n){case"true":return ee.has(t);case"false":return ee.not(t);default:return ee.equals(t,n)}}case 4:{this._advance();const n=this._value();if(this._previous().type===18)return ee.notEquals(t,n);switch(n){case"true":return ee.not(t);case"false":return ee.has(t);default:return ee.notEquals(t,n)}}case 5:return this._advance(),tx.create(t,this._value());case 6:return this._advance(),ix.create(t,this._value());case 7:return this._advance(),JL.create(t,this._value());case 8:return this._advance(),ex.create(t,this._value());case 13:return this._advance(),ee.in(t,this._value());default:return ee.has(t)}}case 20:throw this._parsingErrors.push({message:PJ,offset:e.offset,lexeme:"",additionalInfo:OJ}),sv._parseError;default:throw this._errExpectedButGot(`true | false | KEY 
	| KEY '=~' REGEX 
	| KEY ('==' | '!=' | '<' | '<=' | '>' | '>=' | 'in' | 'not' 'in') value`,this._peek())}}_value(){const e=this._peek();switch(e.type){case 17:case 18:return this._advance(),e.lexeme;case 11:return this._advance(),"true";case 12:return this._advance(),"false";case 13:return this._advance(),"in";default:return""}}_removeFlagsGY(e){return e.replaceAll(this._flagsGYRe,"")}_previous(){return this._tokens[this._current-1]}_matchOne(e){return this._check(e)?(this._advance(),!0):!1}_advance(){return this._isAtEnd()||this._current++,this._previous()}_consume(e,t){if(this._check(e))return this._advance();throw this._errExpectedButGot(t,this._peek())}_errExpectedButGot(e,t,i){const n=p("contextkey.parser.error.expectedButGot",`Expected: {0}
Received: '{1}'.`,e,Hh.getLexeme(t)),o=t.offset,r=Hh.getLexeme(t);return this._parsingErrors.push({message:n,offset:o,lexeme:r,additionalInfo:i}),sv._parseError}_check(e){return this._peek().type===e}_peek(){return this._tokens[this._current]}_isAtEnd(){return this._peek().type===20}};XW._parseError=new Error;class ee{static false(){return Bs.INSTANCE}static true(){return Qs.INSTANCE}static has(e){return rf.create(e)}static equals(e,t){return t_.create(e,t)}static notEquals(e,t){return XL.create(e,t)}static regex(e,t){return k0.create(e,t)}static in(e,t){return ZL.create(e,t)}static notIn(e,t){return YL.create(e,t)}static not(e){return af.create(e)}static and(...e){return Xh.create(e,null,!0)}static or(...e){return Ed.create(e,null,!0)}static deserialize(e){return e==null?void 0:this._parser.parse(e)}}ee._parser=new XW({regexParsingWithErrorRecovery:!1});function FJ(s,e){const t=s?s.substituteConstants():void 0,i=e?e.substituteConstants():void 0;return!t&&!i?!0:!t||!i?!1:t.equals(i)}function Mv(s,e){return s.cmp(e)}class Bs{constructor(){this.type=0}cmp(e){return this.type-e.type}equals(e){return e.type===this.type}substituteConstants(){return this}evaluate(e){return!1}serialize(){return"false"}keys(){return[]}negate(){return Qs.INSTANCE}}Bs.INSTANCE=new Bs;class Qs{constructor(){this.type=1}cmp(e){return this.type-e.type}equals(e){return e.type===this.type}substituteConstants(){return this}evaluate(e){return!0}serialize(){return"true"}keys(){return[]}negate(){return Bs.INSTANCE}}Qs.INSTANCE=new Qs;class rf{static create(e,t=null){const i=us.get(e);return typeof i=="boolean"?i?Qs.INSTANCE:Bs.INSTANCE:new rf(e,t)}constructor(e,t){this.key=e,this.negated=t,this.type=2}cmp(e){return e.type!==this.type?this.type-e.type:JW(this.key,e.key)}equals(e){return e.type===this.type?this.key===e.key:!1}substituteConstants(){const e=us.get(this.key);return typeof e=="boolean"?e?Qs.INSTANCE:Bs.INSTANCE:this}evaluate(e){return!!e.getValue(this.key)}serialize(){return this.key}keys(){return[this.key]}negate(){return this.negated||(this.negated=af.create(this.key,this)),this.negated}}class t_{static create(e,t,i=null){if(typeof t=="boolean")return t?rf.create(e,i):af.create(e,i);const n=us.get(e);return typeof n=="boolean"?t===(n?"true":"false")?Qs.INSTANCE:Bs.INSTANCE:new t_(e,t,i)}constructor(e,t,i){this.key=e,this.value=t,this.negated=i,this.type=4}cmp(e){return e.type!==this.type?this.type-e.type:lf(this.key,this.value,e.key,e.value)}equals(e){return e.type===this.type?this.key===e.key&&this.value===e.value:!1}substituteConstants(){const e=us.get(this.key);if(typeof e=="boolean"){const t=e?"true":"false";return this.value===t?Qs.INSTANCE:Bs.INSTANCE}return this}evaluate(e){return e.getValue(this.key)==this.value}serialize(){return`${this.key} == '${this.value}'`}keys(){return[this.key]}negate(){return this.negated||(this.negated=XL.create(this.key,this.value,this)),this.negated}}class ZL{static create(e,t){return new ZL(e,t)}constructor(e,t){this.key=e,this.valueKey=t,this.type=10,this.negated=null}cmp(e){return e.type!==this.type?this.type-e.type:lf(this.key,this.valueKey,e.key,e.valueKey)}equals(e){return e.type===this.type?this.key===e.key&&this.valueKey===e.valueKey:!1}substituteConstants(){return this}evaluate(e){const t=e.getValue(this.valueKey),i=e.getValue(this.key);return Array.isArray(t)?t.includes(i):typeof i=="string"&&typeof t=="object"&&t!==null?IJ.call(t,i):!1}serialize(){return`${this.key} in '${this.valueKey}'`}keys(){return[this.key,this.valueKey]}negate(){return this.negated||(this.negated=YL.create(this.key,this.valueKey)),this.negated}}class YL{static create(e,t){return new YL(e,t)}constructor(e,t){this.key=e,this.valueKey=t,this.type=11,this._negated=ZL.create(e,t)}cmp(e){return e.type!==this.type?this.type-e.type:this._negated.cmp(e._negated)}equals(e){return e.type===this.type?this._negated.equals(e._negated):!1}substituteConstants(){return this}evaluate(e){return!this._negated.evaluate(e)}serialize(){return`${this.key} not in '${this.valueKey}'`}keys(){return this._negated.keys()}negate(){return this._negated}}class XL{static create(e,t,i=null){if(typeof t=="boolean")return t?af.create(e,i):rf.create(e,i);const n=us.get(e);return typeof n=="boolean"?t===(n?"true":"false")?Bs.INSTANCE:Qs.INSTANCE:new XL(e,t,i)}constructor(e,t,i){this.key=e,this.value=t,this.negated=i,this.type=5}cmp(e){return e.type!==this.type?this.type-e.type:lf(this.key,this.value,e.key,e.value)}equals(e){return e.type===this.type?this.key===e.key&&this.value===e.value:!1}substituteConstants(){const e=us.get(this.key);if(typeof e=="boolean"){const t=e?"true":"false";return this.value===t?Bs.INSTANCE:Qs.INSTANCE}return this}evaluate(e){return e.getValue(this.key)!=this.value}serialize(){return`${this.key} != '${this.value}'`}keys(){return[this.key]}negate(){return this.negated||(this.negated=t_.create(this.key,this.value,this)),this.negated}}class af{static create(e,t=null){const i=us.get(e);return typeof i=="boolean"?i?Bs.INSTANCE:Qs.INSTANCE:new af(e,t)}constructor(e,t){this.key=e,this.negated=t,this.type=3}cmp(e){return e.type!==this.type?this.type-e.type:JW(this.key,e.key)}equals(e){return e.type===this.type?this.key===e.key:!1}substituteConstants(){const e=us.get(this.key);return typeof e=="boolean"?e?Bs.INSTANCE:Qs.INSTANCE:this}evaluate(e){return!e.getValue(this.key)}serialize(){return`!${this.key}`}keys(){return[this.key]}negate(){return this.negated||(this.negated=rf.create(this.key,this)),this.negated}}function QL(s,e){if(typeof s=="string"){const t=parseFloat(s);isNaN(t)||(s=t)}return typeof s=="string"||typeof s=="number"?e(s):Bs.INSTANCE}class JL{static create(e,t,i=null){return QL(t,n=>new JL(e,n,i))}constructor(e,t,i){this.key=e,this.value=t,this.negated=i,this.type=12}cmp(e){return e.type!==this.type?this.type-e.type:lf(this.key,this.value,e.key,e.value)}equals(e){return e.type===this.type?this.key===e.key&&this.value===e.value:!1}substituteConstants(){return this}evaluate(e){return typeof this.value=="string"?!1:parseFloat(e.getValue(this.key))>this.value}serialize(){return`${this.key} > ${this.value}`}keys(){return[this.key]}negate(){return this.negated||(this.negated=ix.create(this.key,this.value,this)),this.negated}}class ex{static create(e,t,i=null){return QL(t,n=>new ex(e,n,i))}constructor(e,t,i){this.key=e,this.value=t,this.negated=i,this.type=13}cmp(e){return e.type!==this.type?this.type-e.type:lf(this.key,this.value,e.key,e.value)}equals(e){return e.type===this.type?this.key===e.key&&this.value===e.value:!1}substituteConstants(){return this}evaluate(e){return typeof this.value=="string"?!1:parseFloat(e.getValue(this.key))>=this.value}serialize(){return`${this.key} >= ${this.value}`}keys(){return[this.key]}negate(){return this.negated||(this.negated=tx.create(this.key,this.value,this)),this.negated}}class tx{static create(e,t,i=null){return QL(t,n=>new tx(e,n,i))}constructor(e,t,i){this.key=e,this.value=t,this.negated=i,this.type=14}cmp(e){return e.type!==this.type?this.type-e.type:lf(this.key,this.value,e.key,e.value)}equals(e){return e.type===this.type?this.key===e.key&&this.value===e.value:!1}substituteConstants(){return this}evaluate(e){return typeof this.value=="string"?!1:parseFloat(e.getValue(this.key))<this.value}serialize(){return`${this.key} < ${this.value}`}keys(){return[this.key]}negate(){return this.negated||(this.negated=ex.create(this.key,this.value,this)),this.negated}}class ix{static create(e,t,i=null){return QL(t,n=>new ix(e,n,i))}constructor(e,t,i){this.key=e,this.value=t,this.negated=i,this.type=15}cmp(e){return e.type!==this.type?this.type-e.type:lf(this.key,this.value,e.key,e.value)}equals(e){return e.type===this.type?this.key===e.key&&this.value===e.value:!1}substituteConstants(){return this}evaluate(e){return typeof this.value=="string"?!1:parseFloat(e.getValue(this.key))<=this.value}serialize(){return`${this.key} <= ${this.value}`}keys(){return[this.key]}negate(){return this.negated||(this.negated=JL.create(this.key,this.value,this)),this.negated}}class k0{static create(e,t){return new k0(e,t)}constructor(e,t){this.key=e,this.regexp=t,this.type=7,this.negated=null}cmp(e){if(e.type!==this.type)return this.type-e.type;if(this.key<e.key)return-1;if(this.key>e.key)return 1;const t=this.regexp?this.regexp.source:"",i=e.regexp?e.regexp.source:"";return t<i?-1:t>i?1:0}equals(e){if(e.type===this.type){const t=this.regexp?this.regexp.source:"",i=e.regexp?e.regexp.source:"";return this.key===e.key&&t===i}return!1}substituteConstants(){return this}evaluate(e){const t=e.getValue(this.key);return this.regexp?this.regexp.test(t):!1}serialize(){const e=this.regexp?`/${this.regexp.source}/${this.regexp.flags}`:"/invalid/";return`${this.key} =~ ${e}`}keys(){return[this.key]}negate(){return this.negated||(this.negated=jA.create(this)),this.negated}}class jA{static create(e){return new jA(e)}constructor(e){this._actual=e,this.type=8}cmp(e){return e.type!==this.type?this.type-e.type:this._actual.cmp(e._actual)}equals(e){return e.type===this.type?this._actual.equals(e._actual):!1}substituteConstants(){return this}evaluate(e){return!this._actual.evaluate(e)}serialize(){return`!(${this._actual.serialize()})`}keys(){return this._actual.keys()}negate(){return this._actual}}function QW(s){let e=null;for(let t=0,i=s.length;t<i;t++){const n=s[t].substituteConstants();if(s[t]!==n&&e===null){e=[];for(let o=0;o<t;o++)e[o]=s[o]}e!==null&&(e[t]=n)}return e===null?s:e}class Xh{static create(e,t,i){return Xh._normalizeArr(e,t,i)}constructor(e,t){this.expr=e,this.negated=t,this.type=6}cmp(e){if(e.type!==this.type)return this.type-e.type;if(this.expr.length<e.expr.length)return-1;if(this.expr.length>e.expr.length)return 1;for(let t=0,i=this.expr.length;t<i;t++){const n=Mv(this.expr[t],e.expr[t]);if(n!==0)return n}return 0}equals(e){if(e.type===this.type){if(this.expr.length!==e.expr.length)return!1;for(let t=0,i=this.expr.length;t<i;t++)if(!this.expr[t].equals(e.expr[t]))return!1;return!0}return!1}substituteConstants(){const e=QW(this.expr);return e===this.expr?this:Xh.create(e,this.negated,!1)}evaluate(e){for(let t=0,i=this.expr.length;t<i;t++)if(!this.expr[t].evaluate(e))return!1;return!0}static _normalizeArr(e,t,i){const n=[];let o=!1;for(const r of e)if(r){if(r.type===1){o=!0;continue}if(r.type===0)return Bs.INSTANCE;if(r.type===6){n.push(...r.expr);continue}n.push(r)}if(n.length===0&&o)return Qs.INSTANCE;if(n.length!==0){if(n.length===1)return n[0];n.sort(Mv);for(let r=1;r<n.length;r++)n[r-1].equals(n[r])&&(n.splice(r,1),r--);if(n.length===1)return n[0];for(;n.length>1;){const r=n[n.length-1];if(r.type!==9)break;n.pop();const a=n.pop(),l=n.length===0,d=Ed.create(r.expr.map(c=>Xh.create([c,a],null,i)),null,l);d&&(n.push(d),n.sort(Mv))}if(n.length===1)return n[0];if(i){for(let r=0;r<n.length;r++)for(let a=r+1;a<n.length;a++)if(n[r].negate().equals(n[a]))return Bs.INSTANCE;if(n.length===1)return n[0]}return new Xh(n,t)}}serialize(){return this.expr.map(e=>e.serialize()).join(" && ")}keys(){const e=[];for(const t of this.expr)e.push(...t.keys());return e}negate(){if(!this.negated){const e=[];for(const t of this.expr)e.push(t.negate());this.negated=Ed.create(e,this,!0)}return this.negated}}class Ed{static create(e,t,i){return Ed._normalizeArr(e,t,i)}constructor(e,t){this.expr=e,this.negated=t,this.type=9}cmp(e){if(e.type!==this.type)return this.type-e.type;if(this.expr.length<e.expr.length)return-1;if(this.expr.length>e.expr.length)return 1;for(let t=0,i=this.expr.length;t<i;t++){const n=Mv(this.expr[t],e.expr[t]);if(n!==0)return n}return 0}equals(e){if(e.type===this.type){if(this.expr.length!==e.expr.length)return!1;for(let t=0,i=this.expr.length;t<i;t++)if(!this.expr[t].equals(e.expr[t]))return!1;return!0}return!1}substituteConstants(){const e=QW(this.expr);return e===this.expr?this:Ed.create(e,this.negated,!1)}evaluate(e){for(let t=0,i=this.expr.length;t<i;t++)if(this.expr[t].evaluate(e))return!0;return!1}static _normalizeArr(e,t,i){let n=[],o=!1;if(e){for(let r=0,a=e.length;r<a;r++){const l=e[r];if(l){if(l.type===0){o=!0;continue}if(l.type===1)return Qs.INSTANCE;if(l.type===9){n=n.concat(l.expr);continue}n.push(l)}}if(n.length===0&&o)return Bs.INSTANCE;n.sort(Mv)}if(n.length!==0){if(n.length===1)return n[0];for(let r=1;r<n.length;r++)n[r-1].equals(n[r])&&(n.splice(r,1),r--);if(n.length===1)return n[0];if(i){for(let r=0;r<n.length;r++)for(let a=r+1;a<n.length;a++)if(n[r].negate().equals(n[a]))return Qs.INSTANCE;if(n.length===1)return n[0]}return new Ed(n,t)}}serialize(){return this.expr.map(e=>e.serialize()).join(" || ")}keys(){const e=[];for(const t of this.expr)e.push(...t.keys());return e}negate(){if(!this.negated){const e=[];for(const t of this.expr)e.push(t.negate());for(;e.length>1;){const t=e.shift(),i=e.shift(),n=[];for(const o of h5(t))for(const r of h5(i))n.push(Xh.create([o,r],null,!1));e.unshift(Ed.create(n,null,!1))}this.negated=Ed.create(e,this,!0)}return this.negated}}class me extends rf{static all(){return me._info.values()}constructor(e,t,i){super(e,null),this._defaultValue=t,typeof i=="object"?me._info.push({...i,key:e}):i!==!0&&me._info.push({key:e,description:i,type:t!=null?typeof t:void 0})}bindTo(e){return e.createKey(this.key,this._defaultValue)}getValue(e){return e.getContextKeyValue(this.key)}toNegated(){return this.negate()}isEqualTo(e){return t_.create(this.key,e)}}me._info=[];const je=ut("contextKeyService");function JW(s,e){return s<e?-1:s>e?1:0}function lf(s,e,t,i){return s<t?-1:s>t?1:e<i?-1:e>i?1:0}function jN(s,e){if(s.type===0||e.type===1)return!0;if(s.type===9)return e.type===9?u5(s.expr,e.expr):!1;if(e.type===9){for(const t of e.expr)if(jN(s,t))return!0;return!1}if(s.type===6){if(e.type===6)return u5(e.expr,s.expr);for(const t of s.expr)if(jN(t,e))return!0;return!1}return s.equals(e)}function u5(s,e){let t=0,i=0;for(;t<s.length&&i<e.length;){const n=s[t].cmp(e[i]);if(n<0)return!1;n===0&&t++,i++}return t===s.length}function h5(s){return s.type===9?s.expr:[s]}function KN(s,e){if(typeof s=="number"){if(s===0)return null;const t=(s&65535)>>>0,i=(s&4294901760)>>>16;return i!==0?new Tk([r1(t,e),r1(i,e)]):new Tk([r1(t,e)])}else{const t=[];for(let i=0;i<s.length;i++)t.push(r1(s[i],e));return new Tk(t)}}function r1(s,e){const t=!!(s&2048),i=!!(s&256),n=e===2?i:t,o=!!(s&1024),r=!!(s&512),a=e===2?t:i,l=s&255;return new ec(n,o,r,a,l)}class ec{constructor(e,t,i,n,o){this.ctrlKey=e,this.shiftKey=t,this.altKey=i,this.metaKey=n,this.keyCode=o}equals(e){return e instanceof ec&&this.ctrlKey===e.ctrlKey&&this.shiftKey===e.shiftKey&&this.altKey===e.altKey&&this.metaKey===e.metaKey&&this.keyCode===e.keyCode}isModifierKey(){return this.keyCode===0||this.keyCode===5||this.keyCode===57||this.keyCode===6||this.keyCode===4}isDuplicateModifierCase(){return this.ctrlKey&&this.keyCode===5||this.shiftKey&&this.keyCode===4||this.altKey&&this.keyCode===6||this.metaKey&&this.keyCode===57}}class Tk{constructor(e){if(e.length===0)throw Cr("chords");this.chords=e}}class BJ{constructor(e,t,i,n,o,r){this.ctrlKey=e,this.shiftKey=t,this.altKey=i,this.metaKey=n,this.keyLabel=o,this.keyAriaLabel=r}}class WJ{}function Mk(s,e){if(!s)throw new Error(e?`Assertion failed (${e})`:"Assertion Failed")}function nx(s,e="Unreachable"){throw new Error(e)}function I0(s){if(!s()){debugger;s(),et(new pi("Assertion Failed"))}}function eV(s,e){let t=0;for(;t<s.length-1;){const i=s[t],n=s[t+1];if(!e(i,n))return!1;t++}return!0}class VJ{constructor(){this.data=new Map}add(e,t){Mk(Ps(e)),Mk(Ts(t)),Mk(!this.data.has(e),"There is already an extension with this id"),this.data.set(e,t)}as(e){return this.data.get(e)||null}}const Si=new VJ;class KA{constructor(){this._coreKeybindings=new Ms,this._extensionKeybindings=[],this._cachedMergedKeybindings=null}static bindToCurrentPlatform(e){if(Go===1){if(e&&e.win)return e.win}else if(Go===2){if(e&&e.mac)return e.mac}else if(e&&e.linux)return e.linux;return e}registerKeybindingRule(e){const t=KA.bindToCurrentPlatform(e),i=new ie;if(t&&t.primary){const n=KN(t.primary,Go);n&&i.add(this._registerDefaultKeybinding(n,e.id,e.args,e.weight,0,e.when))}if(t&&Array.isArray(t.secondary))for(let n=0,o=t.secondary.length;n<o;n++){const r=t.secondary[n],a=KN(r,Go);a&&i.add(this._registerDefaultKeybinding(a,e.id,e.args,e.weight,-n-1,e.when))}return i}registerCommandAndKeybindingRule(e){return Gr(this.registerKeybindingRule(e),Ct.registerCommand(e))}_registerDefaultKeybinding(e,t,i,n,o,r){const a=this._coreKeybindings.push({keybinding:e,command:t,commandArgs:i,when:r,weight1:n,weight2:o,extensionId:null,isBuiltinExtension:!1});return this._cachedMergedKeybindings=null,Fe(()=>{a(),this._cachedMergedKeybindings=null})}getDefaultKeybindings(){return this._cachedMergedKeybindings||(this._cachedMergedKeybindings=Array.from(this._coreKeybindings).concat(this._extensionKeybindings),this._cachedMergedKeybindings.sort(zJ)),this._cachedMergedKeybindings.slice(0)}}const Js=new KA,HJ={EditorModes:"platform.keybindingsRegistry"};Si.add(HJ.EditorModes,Js);function zJ(s,e){if(s.weight1!==e.weight1)return s.weight1-e.weight1;if(s.command&&e.command){if(s.command<e.command)return-1;if(s.command>e.command)return 1}return s.weight2-e.weight2}var UJ=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},g5=function(s,e){return function(t,i){e(t,i,s)}},Tw;function sp(s){return s.command!==void 0}function $J(s){return s.submenu!==void 0}class N{constructor(e){if(N._instances.has(e))throw new TypeError(`MenuId with identifier '${e}' already exists. Use MenuId.for(ident) or a unique identifier`);N._instances.set(e,this),this.id=e}}N._instances=new Map;N.CommandPalette=new N("CommandPalette");N.DebugBreakpointsContext=new N("DebugBreakpointsContext");N.DebugCallStackContext=new N("DebugCallStackContext");N.DebugConsoleContext=new N("DebugConsoleContext");N.DebugVariablesContext=new N("DebugVariablesContext");N.DebugWatchContext=new N("DebugWatchContext");N.DebugToolBar=new N("DebugToolBar");N.DebugToolBarStop=new N("DebugToolBarStop");N.EditorContext=new N("EditorContext");N.SimpleEditorContext=new N("SimpleEditorContext");N.EditorContent=new N("EditorContent");N.EditorLineNumberContext=new N("EditorLineNumberContext");N.EditorContextCopy=new N("EditorContextCopy");N.EditorContextPeek=new N("EditorContextPeek");N.EditorContextShare=new N("EditorContextShare");N.EditorTitle=new N("EditorTitle");N.EditorTitleRun=new N("EditorTitleRun");N.EditorTitleContext=new N("EditorTitleContext");N.EditorTitleContextShare=new N("EditorTitleContextShare");N.EmptyEditorGroup=new N("EmptyEditorGroup");N.EmptyEditorGroupContext=new N("EmptyEditorGroupContext");N.EditorTabsBarContext=new N("EditorTabsBarContext");N.EditorTabsBarShowTabsSubmenu=new N("EditorTabsBarShowTabsSubmenu");N.EditorActionsPositionSubmenu=new N("EditorActionsPositionSubmenu");N.ExplorerContext=new N("ExplorerContext");N.ExplorerContextShare=new N("ExplorerContextShare");N.ExtensionContext=new N("ExtensionContext");N.GlobalActivity=new N("GlobalActivity");N.CommandCenter=new N("CommandCenter");N.CommandCenterCenter=new N("CommandCenterCenter");N.LayoutControlMenuSubmenu=new N("LayoutControlMenuSubmenu");N.LayoutControlMenu=new N("LayoutControlMenu");N.MenubarMainMenu=new N("MenubarMainMenu");N.MenubarAppearanceMenu=new N("MenubarAppearanceMenu");N.MenubarDebugMenu=new N("MenubarDebugMenu");N.MenubarEditMenu=new N("MenubarEditMenu");N.MenubarCopy=new N("MenubarCopy");N.MenubarFileMenu=new N("MenubarFileMenu");N.MenubarGoMenu=new N("MenubarGoMenu");N.MenubarHelpMenu=new N("MenubarHelpMenu");N.MenubarLayoutMenu=new N("MenubarLayoutMenu");N.MenubarNewBreakpointMenu=new N("MenubarNewBreakpointMenu");N.PanelAlignmentMenu=new N("PanelAlignmentMenu");N.PanelPositionMenu=new N("PanelPositionMenu");N.ActivityBarPositionMenu=new N("ActivityBarPositionMenu");N.MenubarPreferencesMenu=new N("MenubarPreferencesMenu");N.MenubarRecentMenu=new N("MenubarRecentMenu");N.MenubarSelectionMenu=new N("MenubarSelectionMenu");N.MenubarShare=new N("MenubarShare");N.MenubarSwitchEditorMenu=new N("MenubarSwitchEditorMenu");N.MenubarSwitchGroupMenu=new N("MenubarSwitchGroupMenu");N.MenubarTerminalMenu=new N("MenubarTerminalMenu");N.MenubarViewMenu=new N("MenubarViewMenu");N.MenubarHomeMenu=new N("MenubarHomeMenu");N.OpenEditorsContext=new N("OpenEditorsContext");N.OpenEditorsContextShare=new N("OpenEditorsContextShare");N.ProblemsPanelContext=new N("ProblemsPanelContext");N.SCMInputBox=new N("SCMInputBox");N.SCMHistoryItem=new N("SCMHistoryItem");N.SCMChangeContext=new N("SCMChangeContext");N.SCMResourceContext=new N("SCMResourceContext");N.SCMResourceContextShare=new N("SCMResourceContextShare");N.SCMResourceFolderContext=new N("SCMResourceFolderContext");N.SCMResourceGroupContext=new N("SCMResourceGroupContext");N.SCMSourceControl=new N("SCMSourceControl");N.SCMTitle=new N("SCMTitle");N.SearchContext=new N("SearchContext");N.SearchActionMenu=new N("SearchActionContext");N.StatusBarWindowIndicatorMenu=new N("StatusBarWindowIndicatorMenu");N.StatusBarRemoteIndicatorMenu=new N("StatusBarRemoteIndicatorMenu");N.StickyScrollContext=new N("StickyScrollContext");N.TestItem=new N("TestItem");N.TestItemGutter=new N("TestItemGutter");N.TestMessageContext=new N("TestMessageContext");N.TestMessageContent=new N("TestMessageContent");N.TestPeekElement=new N("TestPeekElement");N.TestPeekTitle=new N("TestPeekTitle");N.TouchBarContext=new N("TouchBarContext");N.TitleBarContext=new N("TitleBarContext");N.TitleBarTitleContext=new N("TitleBarTitleContext");N.TunnelContext=new N("TunnelContext");N.TunnelPrivacy=new N("TunnelPrivacy");N.TunnelProtocol=new N("TunnelProtocol");N.TunnelPortInline=new N("TunnelInline");N.TunnelTitle=new N("TunnelTitle");N.TunnelLocalAddressInline=new N("TunnelLocalAddressInline");N.TunnelOriginInline=new N("TunnelOriginInline");N.ViewItemContext=new N("ViewItemContext");N.ViewContainerTitle=new N("ViewContainerTitle");N.ViewContainerTitleContext=new N("ViewContainerTitleContext");N.ViewTitle=new N("ViewTitle");N.ViewTitleContext=new N("ViewTitleContext");N.CommentEditorActions=new N("CommentEditorActions");N.CommentThreadTitle=new N("CommentThreadTitle");N.CommentThreadActions=new N("CommentThreadActions");N.CommentThreadAdditionalActions=new N("CommentThreadAdditionalActions");N.CommentThreadTitleContext=new N("CommentThreadTitleContext");N.CommentThreadCommentContext=new N("CommentThreadCommentContext");N.CommentTitle=new N("CommentTitle");N.CommentActions=new N("CommentActions");N.InteractiveToolbar=new N("InteractiveToolbar");N.InteractiveCellTitle=new N("InteractiveCellTitle");N.InteractiveCellDelete=new N("InteractiveCellDelete");N.InteractiveCellExecute=new N("InteractiveCellExecute");N.InteractiveInputExecute=new N("InteractiveInputExecute");N.NotebookToolbar=new N("NotebookToolbar");N.NotebookStickyScrollContext=new N("NotebookStickyScrollContext");N.NotebookCellTitle=new N("NotebookCellTitle");N.NotebookCellDelete=new N("NotebookCellDelete");N.NotebookCellInsert=new N("NotebookCellInsert");N.NotebookCellBetween=new N("NotebookCellBetween");N.NotebookCellListTop=new N("NotebookCellTop");N.NotebookCellExecute=new N("NotebookCellExecute");N.NotebookCellExecutePrimary=new N("NotebookCellExecutePrimary");N.NotebookDiffCellInputTitle=new N("NotebookDiffCellInputTitle");N.NotebookDiffCellMetadataTitle=new N("NotebookDiffCellMetadataTitle");N.NotebookDiffCellOutputsTitle=new N("NotebookDiffCellOutputsTitle");N.NotebookOutputToolbar=new N("NotebookOutputToolbar");N.NotebookEditorLayoutConfigure=new N("NotebookEditorLayoutConfigure");N.NotebookKernelSource=new N("NotebookKernelSource");N.BulkEditTitle=new N("BulkEditTitle");N.BulkEditContext=new N("BulkEditContext");N.TimelineItemContext=new N("TimelineItemContext");N.TimelineTitle=new N("TimelineTitle");N.TimelineTitleContext=new N("TimelineTitleContext");N.TimelineFilterSubMenu=new N("TimelineFilterSubMenu");N.AccountsContext=new N("AccountsContext");N.SidebarTitle=new N("SidebarTitle");N.PanelTitle=new N("PanelTitle");N.AuxiliaryBarTitle=new N("AuxiliaryBarTitle");N.TerminalInstanceContext=new N("TerminalInstanceContext");N.TerminalEditorInstanceContext=new N("TerminalEditorInstanceContext");N.TerminalNewDropdownContext=new N("TerminalNewDropdownContext");N.TerminalTabContext=new N("TerminalTabContext");N.TerminalTabEmptyAreaContext=new N("TerminalTabEmptyAreaContext");N.TerminalStickyScrollContext=new N("TerminalStickyScrollContext");N.WebviewContext=new N("WebviewContext");N.InlineCompletionsActions=new N("InlineCompletionsActions");N.NewFile=new N("NewFile");N.MergeInput1Toolbar=new N("MergeToolbar1Toolbar");N.MergeInput2Toolbar=new N("MergeToolbar2Toolbar");N.MergeBaseToolbar=new N("MergeBaseToolbar");N.MergeInputResultToolbar=new N("MergeToolbarResultToolbar");N.InlineSuggestionToolbar=new N("InlineSuggestionToolbar");N.ChatContext=new N("ChatContext");N.ChatCodeBlock=new N("ChatCodeblock");N.ChatMessageTitle=new N("ChatMessageTitle");N.ChatExecute=new N("ChatExecute");N.ChatInputSide=new N("ChatInputSide");N.AccessibleView=new N("AccessibleView");N.MultiDiffEditorFileToolbar=new N("MultiDiffEditorFileToolbar");const qa=ut("menuService");class Nd{static for(e){let t=this._all.get(e);return t||(t=new Nd(e),this._all.set(e,t)),t}static merge(e){const t=new Set;for(const i of e)i instanceof Nd&&t.add(i.id);return t}constructor(e){this.id=e,this.has=t=>t===e}}Nd._all=new Map;const Wn=new class{constructor(){this._commands=new Map,this._menuItems=new Map,this._onDidChangeMenu=new yQ({merge:Nd.merge}),this.onDidChangeMenu=this._onDidChangeMenu.event}addCommand(s){return this._commands.set(s.id,s),this._onDidChangeMenu.fire(Nd.for(N.CommandPalette)),Fe(()=>{this._commands.delete(s.id)&&this._onDidChangeMenu.fire(Nd.for(N.CommandPalette))})}getCommand(s){return this._commands.get(s)}getCommands(){const s=new Map;return this._commands.forEach((e,t)=>s.set(t,e)),s}appendMenuItem(s,e){let t=this._menuItems.get(s);t||(t=new Ms,this._menuItems.set(s,t));const i=t.push(e);return this._onDidChangeMenu.fire(Nd.for(s)),Fe(()=>{i(),this._onDidChangeMenu.fire(Nd.for(s))})}appendMenuItems(s){const e=new ie;for(const{id:t,item:i}of s)e.add(this.appendMenuItem(t,i));return e}getMenuItems(s){let e;return this._menuItems.has(s)?e=[...this._menuItems.get(s)]:e=[],s===N.CommandPalette&&this._appendImplicitItems(e),e}_appendImplicitItems(s){const e=new Set;for(const t of s)sp(t)&&(e.add(t.command.id),t.alt&&e.add(t.alt.id));this._commands.forEach((t,i)=>{e.has(i)||s.push({command:t})})}};class E0 extends cm{constructor(e,t,i){super(`submenuitem.${e.submenu.id}`,typeof e.title=="string"?e.title:e.title.value,i,"submenu"),this.item=e,this.hideActions=t}}let Xr=Tw=class{static label(e,t){return t!=null&&t.renderShortTitle&&e.shortTitle?typeof e.shortTitle=="string"?e.shortTitle:e.shortTitle.value:typeof e.title=="string"?e.title:e.title.value}constructor(e,t,i,n,o,r){var a,l;this.hideActions=n,this._commandService=r,this.id=e.id,this.label=Tw.label(e,i),this.tooltip=(l=typeof e.tooltip=="string"?e.tooltip:(a=e.tooltip)===null||a===void 0?void 0:a.value)!==null&&l!==void 0?l:"",this.enabled=!e.precondition||o.contextMatchesRules(e.precondition),this.checked=void 0;let d;if(e.toggled){const c=e.toggled.condition?e.toggled:{condition:e.toggled};this.checked=o.contextMatchesRules(c.condition),this.checked&&c.tooltip&&(this.tooltip=typeof c.tooltip=="string"?c.tooltip:c.tooltip.value),this.checked&&Oe.isThemeIcon(c.icon)&&(d=c.icon),this.checked&&c.title&&(this.label=typeof c.title=="string"?c.title:c.title.value)}d||(d=Oe.isThemeIcon(e.icon)?e.icon:void 0),this.item=e,this.alt=t?new Tw(t,void 0,i,n,o,r):void 0,this._options=i,this.class=d&&Oe.asClassName(d)}run(...e){var t,i;let n=[];return!((t=this._options)===null||t===void 0)&&t.arg&&(n=[...n,this._options.arg]),!((i=this._options)===null||i===void 0)&&i.shouldForwardArgs&&(n=[...n,...e]),this._commandService.executeCommand(this.id,...n)}};Xr=Tw=UJ([g5(4,je),g5(5,Ei)],Xr);class ar{constructor(e){this.desc=e}}function di(s){const e=new ie,t=new s,{f1:i,menu:n,keybinding:o,...r}=t.desc;if(e.add(Ct.registerCommand({id:r.id,handler:(a,...l)=>t.run(a,...l),metadata:r.metadata})),Array.isArray(n))for(const a of n)e.add(Wn.appendMenuItem(a.id,{command:{...r,precondition:a.precondition===null?void 0:r.precondition},...a}));else n&&e.add(Wn.appendMenuItem(n.id,{command:{...r,precondition:n.precondition===null?void 0:r.precondition},...n}));if(i&&(e.add(Wn.appendMenuItem(N.CommandPalette,{command:r,when:r.precondition})),e.add(Wn.addCommand(r))),Array.isArray(o))for(const a of o)e.add(Js.registerKeybindingRule({...a,id:r.id,when:r.precondition?ee.and(r.precondition,a.when):a.when}));else o&&e.add(Js.registerKeybindingRule({...o,id:r.id,when:r.precondition?ee.and(r.precondition,o.when):o.when}));return e}const Do=ut("telemetryService"),ko=ut("logService");var Gn;(function(s){s[s.Off=0]="Off",s[s.Trace=1]="Trace",s[s.Debug=2]="Debug",s[s.Info=3]="Info",s[s.Warning=4]="Warning",s[s.Error=5]="Error"})(Gn||(Gn={}));const tV=Gn.Info;class iV extends j{constructor(){super(...arguments),this.level=tV,this._onDidChangeLogLevel=this._register(new W),this.onDidChangeLogLevel=this._onDidChangeLogLevel.event}setLevel(e){this.level!==e&&(this.level=e,this._onDidChangeLogLevel.fire(this.level))}getLevel(){return this.level}checkLogLevel(e){return this.level!==Gn.Off&&this.level<=e}}class jJ extends iV{constructor(e=tV,t=!0){super(),this.useColors=t,this.setLevel(e)}trace(e,...t){this.checkLogLevel(Gn.Trace)&&(this.useColors?console.log("%cTRACE","color: #888",e,...t):console.log(e,...t))}debug(e,...t){this.checkLogLevel(Gn.Debug)&&(this.useColors?console.log("%cDEBUG","background: #eee; color: #888",e,...t):console.log(e,...t))}info(e,...t){this.checkLogLevel(Gn.Info)&&(this.useColors?console.log("%c INFO","color: #33f",e,...t):console.log(e,...t))}warn(e,...t){this.checkLogLevel(Gn.Warning)&&(this.useColors?console.log("%c WARN","color: #993",e,...t):console.log(e,...t))}error(e,...t){this.checkLogLevel(Gn.Error)&&(this.useColors?console.log("%c  ERR","color: #f33",e,...t):console.error(e,...t))}dispose(){}}class KJ extends iV{constructor(e){super(),this.loggers=e,e.length&&this.setLevel(e[0].getLevel())}setLevel(e){for(const t of this.loggers)t.setLevel(e);super.setLevel(e)}trace(e,...t){for(const i of this.loggers)i.trace(e,...t)}debug(e,...t){for(const i of this.loggers)i.debug(e,...t)}info(e,...t){for(const i of this.loggers)i.info(e,...t)}warn(e,...t){for(const i of this.loggers)i.warn(e,...t)}error(e,...t){for(const i of this.loggers)i.error(e,...t)}dispose(){for(const e of this.loggers)e.dispose()}}function qJ(s){switch(s){case Gn.Trace:return"trace";case Gn.Debug:return"debug";case Gn.Info:return"info";case Gn.Warning:return"warn";case Gn.Error:return"error";case Gn.Off:return"off"}}new me("logLevel",qJ(Gn.Info));const qA={clipboard:{writeText:Ra||document.queryCommandSupported&&document.queryCommandSupported("copy")||!!(navigator&&navigator.clipboard&&navigator.clipboard.writeText),readText:Ra||!!(navigator&&navigator.clipboard&&navigator.clipboard.readText)},keyboard:Ra||bJ()?0:navigator.keyboard||Jd?1:2,touch:"ontouchstart"in Ci||navigator.maxTouchPoints>0,pointerEvents:Ci.PointerEvent&&("ontouchstart"in Ci||navigator.maxTouchPoints>0||navigator.maxTouchPoints>0)};function GJ(s){if(s.charCode){const t=String.fromCharCode(s.charCode).toUpperCase();return Id.fromString(t)}const e=s.keyCode;if(e===3)return 7;if(yr)switch(e){case 59:return 85;case 60:if(Ss)return 97;break;case 61:return 86;case 107:return 109;case 109:return 111;case 173:return 88;case 224:if(bt)return 57;break}else if(ug){if(bt&&e===93)return 57;if(!bt&&e===92)return 57}return EW[e]||0}const ZJ=bt?256:2048,YJ=512,XJ=1024,QJ=bt?2048:256;class ri{constructor(e){this._standardKeyboardEventBrand=!0;const t=e;this.browserEvent=t,this.target=t.target,this.ctrlKey=t.ctrlKey,this.shiftKey=t.shiftKey,this.altKey=t.altKey,this.metaKey=t.metaKey,this.altGraphKey=t.getModifierState("AltGraph"),this.keyCode=GJ(t),this.code=t.code,this.ctrlKey=this.ctrlKey||this.keyCode===5,this.altKey=this.altKey||this.keyCode===6,this.shiftKey=this.shiftKey||this.keyCode===4,this.metaKey=this.metaKey||this.keyCode===57,this._asKeybinding=this._computeKeybinding(),this._asKeyCodeChord=this._computeKeyCodeChord()}preventDefault(){this.browserEvent&&this.browserEvent.preventDefault&&this.browserEvent.preventDefault()}stopPropagation(){this.browserEvent&&this.browserEvent.stopPropagation&&this.browserEvent.stopPropagation()}toKeyCodeChord(){return this._asKeyCodeChord}equals(e){return this._asKeybinding===e}_computeKeybinding(){let e=0;this.keyCode!==5&&this.keyCode!==4&&this.keyCode!==6&&this.keyCode!==57&&(e=this.keyCode);let t=0;return this.ctrlKey&&(t|=ZJ),this.altKey&&(t|=YJ),this.shiftKey&&(t|=XJ),this.metaKey&&(t|=QJ),t|=e,t}_computeKeyCodeChord(){let e=0;return this.keyCode!==5&&this.keyCode!==4&&this.keyCode!==6&&this.keyCode!==57&&(e=this.keyCode),new ec(this.ctrlKey,this.shiftKey,this.altKey,this.metaKey,e)}}const f5=new WeakMap;function JJ(s){if(!s.parent||s.parent===s)return null;try{const e=s.location,t=s.parent.location;if(e.origin!=="null"&&t.origin!=="null"&&e.origin!==t.origin)return null}catch{return null}return s.parent}class eee{static getSameOriginWindowChain(e){let t=f5.get(e);if(!t){t=[],f5.set(e,t);let i=e,n;do n=JJ(i),n?t.push({window:new WeakRef(i),iframeElement:i.frameElement||null}):t.push({window:new WeakRef(i),iframeElement:null}),i=n;while(i)}return t.slice(0)}static getPositionOfChildWindowRelativeToAncestorWindow(e,t){var i,n;if(!t||e===t)return{top:0,left:0};let o=0,r=0;const a=this.getSameOriginWindowChain(e);for(const l of a){const d=l.window.deref();if(o+=(i=d==null?void 0:d.scrollY)!==null&&i!==void 0?i:0,r+=(n=d==null?void 0:d.scrollX)!==null&&n!==void 0?n:0,d===t||!l.iframeElement)break;const c=l.iframeElement.getBoundingClientRect();o+=c.top,r+=c.left}return{top:o,left:r}}}class zr{constructor(e,t){this.timestamp=Date.now(),this.browserEvent=t,this.leftButton=t.button===0,this.middleButton=t.button===1,this.rightButton=t.button===2,this.buttons=t.buttons,this.target=t.target,this.detail=t.detail||1,t.type==="dblclick"&&(this.detail=2),this.ctrlKey=t.ctrlKey,this.shiftKey=t.shiftKey,this.altKey=t.altKey,this.metaKey=t.metaKey,typeof t.pageX=="number"?(this.posx=t.pageX,this.posy=t.pageY):(this.posx=t.clientX+this.target.ownerDocument.body.scrollLeft+this.target.ownerDocument.documentElement.scrollLeft,this.posy=t.clientY+this.target.ownerDocument.body.scrollTop+this.target.ownerDocument.documentElement.scrollTop);const i=eee.getPositionOfChildWindowRelativeToAncestorWindow(e,t.view);this.posx-=i.left,this.posy-=i.top}preventDefault(){this.browserEvent.preventDefault()}stopPropagation(){this.browserEvent.stopPropagation()}}class Ng{constructor(e,t=0,i=0){if(this.browserEvent=e||null,this.target=e?e.target||e.targetNode||e.srcElement:null,this.deltaY=i,this.deltaX=t,e){const n=e,o=e;if(typeof n.wheelDeltaY<"u")this.deltaY=n.wheelDeltaY/120;else if(typeof o.VERTICAL_AXIS<"u"&&o.axis===o.VERTICAL_AXIS)this.deltaY=-o.detail/3;else if(e.type==="wheel"){const r=e;r.deltaMode===r.DOM_DELTA_LINE?yr&&!bt?this.deltaY=-e.deltaY/3:this.deltaY=-e.deltaY:this.deltaY=-e.deltaY/40}if(typeof n.wheelDeltaX<"u")Jd&&es?this.deltaX=-(n.wheelDeltaX/120):this.deltaX=n.wheelDeltaX/120;else if(typeof o.HORIZONTAL_AXIS<"u"&&o.axis===o.HORIZONTAL_AXIS)this.deltaX=-e.detail/3;else if(e.type==="wheel"){const r=e;r.deltaMode===r.DOM_DELTA_LINE?yr&&!bt?this.deltaX=-e.deltaX/3:this.deltaX=-e.deltaX:this.deltaX=-e.deltaX/40}this.deltaY===0&&this.deltaX===0&&e.wheelDelta&&(this.deltaY=e.wheelDelta/120)}}preventDefault(){var e;(e=this.browserEvent)===null||e===void 0||e.preventDefault()}stopPropagation(){var e;(e=this.browserEvent)===null||e===void 0||e.stopPropagation()}}const nV=Symbol("MicrotaskDelay");function qN(s){return!!s&&typeof s.then=="function"}function gn(s){const e=new Yi,t=s(e.token),i=new Promise((n,o)=>{const r=e.token.onCancellationRequested(()=>{r.dispose(),e.dispose(),o(new eh)});Promise.resolve(t).then(a=>{r.dispose(),e.dispose(),n(a)},a=>{r.dispose(),e.dispose(),o(a)})});return new class{cancel(){e.cancel()}then(n,o){return i.then(n,o)}catch(n){return this.then(void 0,n)}finally(n){return i.finally(n)}}}function sx(s,e,t){return new Promise((i,n)=>{const o=e.onCancellationRequested(()=>{o.dispose(),i(t)});s.then(i,n).finally(()=>o.dispose())})}class tee{constructor(){this.isDisposed=!1,this.activePromise=null,this.queuedPromise=null,this.queuedPromiseFactory=null}queue(e){if(this.isDisposed)return Promise.reject(new Error("Throttler is disposed"));if(this.activePromise){if(this.queuedPromiseFactory=e,!this.queuedPromise){const t=()=>{if(this.queuedPromise=null,this.isDisposed)return;const i=this.queue(this.queuedPromiseFactory);return this.queuedPromiseFactory=null,i};this.queuedPromise=new Promise(i=>{this.activePromise.then(t,t).then(i)})}return new Promise((t,i)=>{this.queuedPromise.then(t,i)})}return this.activePromise=e(),new Promise((t,i)=>{this.activePromise.then(n=>{this.activePromise=null,t(n)},n=>{this.activePromise=null,i(n)})})}dispose(){this.isDisposed=!0}}const iee=(s,e)=>{let t=!0;const i=setTimeout(()=>{t=!1,e()},s);return{isTriggered:()=>t,dispose:()=>{clearTimeout(i),t=!1}}},nee=s=>{let e=!0;return queueMicrotask(()=>{e&&(e=!1,s())}),{isTriggered:()=>e,dispose:()=>{e=!1}}};class Qr{constructor(e){this.defaultDelay=e,this.deferred=null,this.completionPromise=null,this.doResolve=null,this.doReject=null,this.task=null}trigger(e,t=this.defaultDelay){this.task=e,this.cancelTimeout(),this.completionPromise||(this.completionPromise=new Promise((n,o)=>{this.doResolve=n,this.doReject=o}).then(()=>{if(this.completionPromise=null,this.doResolve=null,this.task){const n=this.task;return this.task=null,n()}}));const i=()=>{var n;this.deferred=null,(n=this.doResolve)===null||n===void 0||n.call(this,null)};return this.deferred=t===nV?nee(i):iee(t,i),this.completionPromise}isTriggered(){var e;return!!(!((e=this.deferred)===null||e===void 0)&&e.isTriggered())}cancel(){var e;this.cancelTimeout(),this.completionPromise&&((e=this.doReject)===null||e===void 0||e.call(this,new eh),this.completionPromise=null)}cancelTimeout(){var e;(e=this.deferred)===null||e===void 0||e.dispose(),this.deferred=null}dispose(){this.cancel()}}class sV{constructor(e){this.delayer=new Qr(e),this.throttler=new tee}trigger(e,t){return this.delayer.trigger(()=>this.throttler.queue(e),t)}cancel(){this.delayer.cancel()}dispose(){this.delayer.dispose(),this.throttler.dispose()}}function Iu(s,e){return e?new Promise((t,i)=>{const n=setTimeout(()=>{o.dispose(),t()},s),o=e.onCancellationRequested(()=>{clearTimeout(n),o.dispose(),i(new eh)})}):gn(t=>Iu(s,t))}function Eu(s,e=0,t){const i=setTimeout(()=>{s(),t&&n.dispose()},e),n=Fe(()=>{clearTimeout(i),t==null||t.deleteAndLeak(n)});return t==null||t.add(n),n}function GA(s,e=i=>!!i,t=null){let i=0;const n=s.length,o=()=>{if(i>=n)return Promise.resolve(t);const r=s[i++];return Promise.resolve(r()).then(l=>e(l)?Promise.resolve(l):o())};return o()}class ea{constructor(e,t){this._token=-1,typeof e=="function"&&typeof t=="number"&&this.setIfNotSet(e,t)}dispose(){this.cancel()}cancel(){this._token!==-1&&(clearTimeout(this._token),this._token=-1)}cancelAndSet(e,t){this.cancel(),this._token=setTimeout(()=>{this._token=-1,e()},t)}setIfNotSet(e,t){this._token===-1&&(this._token=setTimeout(()=>{this._token=-1,e()},t))}}class ZA{constructor(){this.disposable=void 0}cancel(){var e;(e=this.disposable)===null||e===void 0||e.dispose(),this.disposable=void 0}cancelAndSet(e,t,i=globalThis){this.cancel();const n=i.setInterval(()=>{e()},t);this.disposable=Fe(()=>{i.clearInterval(n),this.disposable=void 0})}dispose(){this.cancel()}}class jt{constructor(e,t){this.timeoutToken=-1,this.runner=e,this.timeout=t,this.timeoutHandler=this.onTimeout.bind(this)}dispose(){this.cancel(),this.runner=null}cancel(){this.isScheduled()&&(clearTimeout(this.timeoutToken),this.timeoutToken=-1)}schedule(e=this.timeout){this.cancel(),this.timeoutToken=setTimeout(this.timeoutHandler,e)}get delay(){return this.timeout}set delay(e){this.timeout=e}isScheduled(){return this.timeoutToken!==-1}onTimeout(){this.timeoutToken=-1,this.runner&&this.doRun()}doRun(){var e;(e=this.runner)===null||e===void 0||e.call(this)}}let oV,Rv;(function(){typeof globalThis.requestIdleCallback!="function"||typeof globalThis.cancelIdleCallback!="function"?Rv=(s,e)=>{vW(()=>{if(t)return;const i=Date.now()+15;e(Object.freeze({didTimeout:!0,timeRemaining(){return Math.max(0,i-Date.now())}}))});let t=!1;return{dispose(){t||(t=!0)}}}:Rv=(s,e,t)=>{const i=s.requestIdleCallback(e,typeof t=="number"?{timeout:t}:void 0);let n=!1;return{dispose(){n||(n=!0,s.cancelIdleCallback(i))}}},oV=s=>Rv(globalThis,s)})();class rV{constructor(e,t){this._didRun=!1,this._executor=()=>{try{this._value=t()}catch(i){this._error=i}finally{this._didRun=!0}},this._handle=Rv(e,()=>this._executor())}dispose(){this._handle.dispose()}get value(){if(this._didRun||(this._handle.dispose(),this._executor()),this._error)throw this._error;return this._value}get isInitialized(){return this._didRun}}class see extends rV{constructor(e){super(globalThis,e)}}class ox{get isRejected(){var e;return((e=this.outcome)===null||e===void 0?void 0:e.outcome)===1}get isSettled(){return!!this.outcome}constructor(){this.p=new Promise((e,t)=>{this.completeCallback=e,this.errorCallback=t})}complete(e){return new Promise(t=>{this.completeCallback(e),this.outcome={outcome:0,value:e},t()})}error(e){return new Promise(t=>{this.errorCallback(e),this.outcome={outcome:1,value:e},t()})}cancel(){return this.error(new eh)}}var GN;(function(s){async function e(i){let n;const o=await Promise.all(i.map(r=>r.then(a=>a,a=>{n||(n=a)})));if(typeof n<"u")throw n;return o}s.settled=e;function t(i){return new Promise(async(n,o)=>{try{await i(n,o)}catch(r){o(r)}})}s.withAsyncBody=t})(GN||(GN={}));class tn{static fromArray(e){return new tn(t=>{t.emitMany(e)})}static fromPromise(e){return new tn(async t=>{t.emitMany(await e)})}static fromPromises(e){return new tn(async t=>{await Promise.all(e.map(async i=>t.emitOne(await i)))})}static merge(e){return new tn(async t=>{await Promise.all(e.map(async i=>{for await(const n of i)t.emitOne(n)}))})}constructor(e){this._state=0,this._results=[],this._error=null,this._onStateChanged=new W,queueMicrotask(async()=>{const t={emitOne:i=>this.emitOne(i),emitMany:i=>this.emitMany(i),reject:i=>this.reject(i)};try{await Promise.resolve(e(t)),this.resolve()}catch(i){this.reject(i)}finally{t.emitOne=void 0,t.emitMany=void 0,t.reject=void 0}})}[Symbol.asyncIterator](){let e=0;return{next:async()=>{do{if(this._state===2)throw this._error;if(e<this._results.length)return{done:!1,value:this._results[e++]};if(this._state===1)return{done:!0,value:void 0};await ge.toPromise(this._onStateChanged.event)}while(!0)}}}static map(e,t){return new tn(async i=>{for await(const n of e)i.emitOne(t(n))})}map(e){return tn.map(this,e)}static filter(e,t){return new tn(async i=>{for await(const n of e)t(n)&&i.emitOne(n)})}filter(e){return tn.filter(this,e)}static coalesce(e){return tn.filter(e,t=>!!t)}coalesce(){return tn.coalesce(this)}static async toPromise(e){const t=[];for await(const i of e)t.push(i);return t}toPromise(){return tn.toPromise(this)}emitOne(e){this._state===0&&(this._results.push(e),this._onStateChanged.fire())}emitMany(e){this._state===0&&(this._results=this._results.concat(e),this._onStateChanged.fire())}resolve(){this._state===0&&(this._state=1,this._onStateChanged.fire())}reject(e){this._state===0&&(this._state=2,this._error=e,this._onStateChanged.fire())}}tn.EMPTY=tn.fromArray([]);class oee extends tn{constructor(e,t){super(t),this._source=e}cancel(){this._source.cancel()}}function ree(s){const e=new Yi,t=s(e.token);return new oee(e,async i=>{const n=e.token.onCancellationRequested(()=>{n.dispose(),e.dispose(),i.reject(new eh)});try{for await(const o of t){if(e.token.isCancellationRequested)return;i.emitOne(o)}n.dispose(),e.dispose()}catch(o){n.dispose(),e.dispose(),i.reject(o)}})}/*! @license DOMPurify 3.0.5 | (c) Cure53 and other contributors | Released under the Apache license 2.0 and Mozilla Public License 2.0 | github.com/cure53/DOMPurify/blob/3.0.5/LICENSE */const{entries:aV,setPrototypeOf:p5,isFrozen:aee,getPrototypeOf:lee,getOwnPropertyDescriptor:dee}=Object;let{freeze:So,seal:Va,create:cee}=Object,{apply:ZN,construct:YN}=typeof Reflect<"u"&&Reflect;ZN||(ZN=function(e,t,i){return e.apply(t,i)});So||(So=function(e){return e});Va||(Va=function(e){return e});YN||(YN=function(e,t){return new e(...t)});const uee=Jr(Array.prototype.forEach),m5=Jr(Array.prototype.pop),k_=Jr(Array.prototype.push),Mw=Jr(String.prototype.toLowerCase),Rk=Jr(String.prototype.toString),hee=Jr(String.prototype.match),la=Jr(String.prototype.replace),gee=Jr(String.prototype.indexOf),fee=Jr(String.prototype.trim),cr=Jr(RegExp.prototype.test),I_=pee(TypeError);function Jr(s){return function(e){for(var t=arguments.length,i=new Array(t>1?t-1:0),n=1;n<t;n++)i[n-1]=arguments[n];return ZN(s,e,i)}}function pee(s){return function(){for(var e=arguments.length,t=new Array(e),i=0;i<e;i++)t[i]=arguments[i];return YN(s,t)}}function Ut(s,e,t){var i;t=(i=t)!==null&&i!==void 0?i:Mw,p5&&p5(s,null);let n=e.length;for(;n--;){let o=e[n];if(typeof o=="string"){const r=t(o);r!==o&&(aee(e)||(e[n]=r),o=r)}s[o]=!0}return s}function xf(s){const e=cee(null);for(const[t,i]of aV(s))e[t]=i;return e}function a1(s,e){for(;s!==null;){const i=dee(s,e);if(i){if(i.get)return Jr(i.get);if(typeof i.value=="function")return Jr(i.value)}s=lee(s)}function t(i){return console.warn("fallback value for",i),null}return t}const _5=So(["a","abbr","acronym","address","area","article","aside","audio","b","bdi","bdo","big","blink","blockquote","body","br","button","canvas","caption","center","cite","code","col","colgroup","content","data","datalist","dd","decorator","del","details","dfn","dialog","dir","div","dl","dt","element","em","fieldset","figcaption","figure","font","footer","form","h1","h2","h3","h4","h5","h6","head","header","hgroup","hr","html","i","img","input","ins","kbd","label","legend","li","main","map","mark","marquee","menu","menuitem","meter","nav","nobr","ol","optgroup","option","output","p","picture","pre","progress","q","rp","rt","ruby","s","samp","section","select","shadow","small","source","spacer","span","strike","strong","style","sub","summary","sup","table","tbody","td","template","textarea","tfoot","th","thead","time","tr","track","tt","u","ul","var","video","wbr"]),Ak=So(["svg","a","altglyph","altglyphdef","altglyphitem","animatecolor","animatemotion","animatetransform","circle","clippath","defs","desc","ellipse","filter","font","g","glyph","glyphref","hkern","image","line","lineargradient","marker","mask","metadata","mpath","path","pattern","polygon","polyline","radialgradient","rect","stop","style","switch","symbol","text","textpath","title","tref","tspan","view","vkern"]),Pk=So(["feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence"]),mee=So(["animate","color-profile","cursor","discard","font-face","font-face-format","font-face-name","font-face-src","font-face-uri","foreignobject","hatch","hatchpath","mesh","meshgradient","meshpatch","meshrow","missing-glyph","script","set","solidcolor","unknown","use"]),Ok=So(["math","menclose","merror","mfenced","mfrac","mglyph","mi","mlabeledtr","mmultiscripts","mn","mo","mover","mpadded","mphantom","mroot","mrow","ms","mspace","msqrt","mstyle","msub","msup","msubsup","mtable","mtd","mtext","mtr","munder","munderover","mprescripts"]),_ee=So(["maction","maligngroup","malignmark","mlongdiv","mscarries","mscarry","msgroup","mstack","msline","msrow","semantics","annotation","annotation-xml","mprescripts","none"]),v5=So(["#text"]),b5=So(["accept","action","align","alt","autocapitalize","autocomplete","autopictureinpicture","autoplay","background","bgcolor","border","capture","cellpadding","cellspacing","checked","cite","class","clear","color","cols","colspan","controls","controlslist","coords","crossorigin","datetime","decoding","default","dir","disabled","disablepictureinpicture","disableremoteplayback","download","draggable","enctype","enterkeyhint","face","for","headers","height","hidden","high","href","hreflang","id","inputmode","integrity","ismap","kind","label","lang","list","loading","loop","low","max","maxlength","media","method","min","minlength","multiple","muted","name","nonce","noshade","novalidate","nowrap","open","optimum","pattern","placeholder","playsinline","poster","preload","pubdate","radiogroup","readonly","rel","required","rev","reversed","role","rows","rowspan","spellcheck","scope","selected","shape","size","sizes","span","srclang","start","src","srcset","step","style","summary","tabindex","title","translate","type","usemap","valign","value","width","xmlns","slot"]),Fk=So(["accent-height","accumulate","additive","alignment-baseline","ascent","attributename","attributetype","azimuth","basefrequency","baseline-shift","begin","bias","by","class","clip","clippathunits","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","cx","cy","d","dx","dy","diffuseconstant","direction","display","divisor","dur","edgemode","elevation","end","fill","fill-opacity","fill-rule","filter","filterunits","flood-color","flood-opacity","font-family","font-size","font-size-adjust","font-stretch","font-style","font-variant","font-weight","fx","fy","g1","g2","glyph-name","glyphref","gradientunits","gradienttransform","height","href","id","image-rendering","in","in2","k","k1","k2","k3","k4","kerning","keypoints","keysplines","keytimes","lang","lengthadjust","letter-spacing","kernelmatrix","kernelunitlength","lighting-color","local","marker-end","marker-mid","marker-start","markerheight","markerunits","markerwidth","maskcontentunits","maskunits","max","mask","media","method","mode","min","name","numoctaves","offset","operator","opacity","order","orient","orientation","origin","overflow","paint-order","path","pathlength","patterncontentunits","patterntransform","patternunits","points","preservealpha","preserveaspectratio","primitiveunits","r","rx","ry","radius","refx","refy","repeatcount","repeatdur","restart","result","rotate","scale","seed","shape-rendering","specularconstant","specularexponent","spreadmethod","startoffset","stddeviation","stitchtiles","stop-color","stop-opacity","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke","stroke-width","style","surfacescale","systemlanguage","tabindex","targetx","targety","transform","transform-origin","text-anchor","text-decoration","text-rendering","textlength","type","u1","u2","unicode","values","viewbox","visibility","version","vert-adv-y","vert-origin-x","vert-origin-y","width","word-spacing","wrap","writing-mode","xchannelselector","ychannelselector","x","x1","x2","xmlns","y","y1","y2","z","zoomandpan"]),C5=So(["accent","accentunder","align","bevelled","close","columnsalign","columnlines","columnspan","denomalign","depth","dir","display","displaystyle","encoding","fence","frame","height","href","id","largeop","length","linethickness","lspace","lquote","mathbackground","mathcolor","mathsize","mathvariant","maxsize","minsize","movablelimits","notation","numalign","open","rowalign","rowlines","rowspacing","rowspan","rspace","rquote","scriptlevel","scriptminsize","scriptsizemultiplier","selection","separator","separators","stretchy","subscriptshift","supscriptshift","symmetric","voffset","width","xmlns"]),l1=So(["xlink:href","xml:id","xlink:title","xml:space","xmlns:xlink"]),vee=Va(/\{\{[\w\W]*|[\w\W]*\}\}/gm),bee=Va(/<%[\w\W]*|[\w\W]*%>/gm),Cee=Va(/\${[\w\W]*}/gm),wee=Va(/^data-[\-\w.\u00B7-\uFFFF]/),See=Va(/^aria-[\-\w]+$/),lV=Va(/^(?:(?:(?:f|ht)tps?|mailto|tel|callto|sms|cid|xmpp):|[^a-z]|[a-z+.\-]+(?:[^a-z+.\-:]|$))/i),yee=Va(/^(?:\w+script|data):/i),Lee=Va(/[\u0000-\u0020\u00A0\u1680\u180E\u2000-\u2029\u205F\u3000]/g),dV=Va(/^html$/i);var w5=Object.freeze({__proto__:null,MUSTACHE_EXPR:vee,ERB_EXPR:bee,TMPLIT_EXPR:Cee,DATA_ATTR:wee,ARIA_ATTR:See,IS_ALLOWED_URI:lV,IS_SCRIPT_OR_DATA:yee,ATTR_WHITESPACE:Lee,DOCTYPE_NAME:dV});const xee=()=>typeof window>"u"?null:window,Dee=function(e,t){if(typeof e!="object"||typeof e.createPolicy!="function")return null;let i=null;const n="data-tt-policy-suffix";t&&t.hasAttribute(n)&&(i=t.getAttribute(n));const o="dompurify"+(i?"#"+i:"");try{return e.createPolicy(o,{createHTML(r){return r},createScriptURL(r){return r}})}catch{return console.warn("TrustedTypes policy "+o+" could not be created."),null}};function cV(){let s=arguments.length>0&&arguments[0]!==void 0?arguments[0]:xee();const e=dt=>cV(dt);if(e.version="3.0.5",e.removed=[],!s||!s.document||s.document.nodeType!==9)return e.isSupported=!1,e;const t=s.document,i=t.currentScript;let{document:n}=s;const{DocumentFragment:o,HTMLTemplateElement:r,Node:a,Element:l,NodeFilter:d,NamedNodeMap:c=s.NamedNodeMap||s.MozNamedAttrMap,HTMLFormElement:u,DOMParser:h,trustedTypes:g}=s,f=l.prototype,m=a1(f,"cloneNode"),_=a1(f,"nextSibling"),v=a1(f,"childNodes"),b=a1(f,"parentNode");if(typeof r=="function"){const dt=n.createElement("template");dt.content&&dt.content.ownerDocument&&(n=dt.content.ownerDocument)}let C,w="";const{implementation:S,createNodeIterator:x,createDocumentFragment:L,getElementsByTagName:k}=n,{importNode:I}=t;let P={};e.isSupported=typeof aV=="function"&&typeof b=="function"&&S&&S.createHTMLDocument!==void 0;const{MUSTACHE_EXPR:$,ERB_EXPR:A,TMPLIT_EXPR:z,DATA_ATTR:K,ARIA_ATTR:Q,IS_SCRIPT_OR_DATA:ne,ATTR_WHITESPACE:fe}=w5;let{IS_ALLOWED_URI:ve}=w5,ye=null;const Be=Ut({},[..._5,...Ak,...Pk,...Ok,...v5]);let Ve=null;const Ie=Ut({},[...b5,...Fk,...C5,...l1]);let pe=Object.seal(Object.create(null,{tagNameCheck:{writable:!0,configurable:!1,enumerable:!0,value:null},attributeNameCheck:{writable:!0,configurable:!1,enumerable:!0,value:null},allowCustomizedBuiltInElements:{writable:!0,configurable:!1,enumerable:!0,value:!1}})),Ji=null,wn=null,ni=!0,wt=!0,$i=!1,no=!0,ji=!1,Ze=!1,zn=!1,q=!1,Z=!1,ae=!1,be=!1,Le=!0,Re=!1;const ze="user-content-";let U=!0,V=!1,F={},E=null;const M=Ut({},["annotation-xml","audio","colgroup","desc","foreignobject","head","iframe","math","mi","mn","mo","ms","mtext","noembed","noframes","noscript","plaintext","script","style","svg","template","thead","title","video","xmp"]);let B=null;const O=Ut({},["audio","video","img","source","image","track"]);let X=null;const ce=Ut({},["alt","class","for","id","label","name","pattern","placeholder","role","summary","title","value","style","xmlns"]),Se="http://www.w3.org/1998/Math/MathML",ke="http://www.w3.org/2000/svg",Ke="http://www.w3.org/1999/xhtml";let Ye=Ke,Kt=!1,At=null;const qe=Ut({},[Se,ke,Ke],Rk);let Ot;const $t=["application/xhtml+xml","text/html"],so="text/html";let Ft,cn=null;const gh=n.createElement("form"),fh=function(J){return J instanceof RegExp||J instanceof Function},ra=function(J){if(!(cn&&cn===J)){if((!J||typeof J!="object")&&(J={}),J=xf(J),Ot=$t.indexOf(J.PARSER_MEDIA_TYPE)===-1?Ot=so:Ot=J.PARSER_MEDIA_TYPE,Ft=Ot==="application/xhtml+xml"?Rk:Mw,ye="ALLOWED_TAGS"in J?Ut({},J.ALLOWED_TAGS,Ft):Be,Ve="ALLOWED_ATTR"in J?Ut({},J.ALLOWED_ATTR,Ft):Ie,At="ALLOWED_NAMESPACES"in J?Ut({},J.ALLOWED_NAMESPACES,Rk):qe,X="ADD_URI_SAFE_ATTR"in J?Ut(xf(ce),J.ADD_URI_SAFE_ATTR,Ft):ce,B="ADD_DATA_URI_TAGS"in J?Ut(xf(O),J.ADD_DATA_URI_TAGS,Ft):O,E="FORBID_CONTENTS"in J?Ut({},J.FORBID_CONTENTS,Ft):M,Ji="FORBID_TAGS"in J?Ut({},J.FORBID_TAGS,Ft):{},wn="FORBID_ATTR"in J?Ut({},J.FORBID_ATTR,Ft):{},F="USE_PROFILES"in J?J.USE_PROFILES:!1,ni=J.ALLOW_ARIA_ATTR!==!1,wt=J.ALLOW_DATA_ATTR!==!1,$i=J.ALLOW_UNKNOWN_PROTOCOLS||!1,no=J.ALLOW_SELF_CLOSE_IN_ATTR!==!1,ji=J.SAFE_FOR_TEMPLATES||!1,Ze=J.WHOLE_DOCUMENT||!1,Z=J.RETURN_DOM||!1,ae=J.RETURN_DOM_FRAGMENT||!1,be=J.RETURN_TRUSTED_TYPE||!1,q=J.FORCE_BODY||!1,Le=J.SANITIZE_DOM!==!1,Re=J.SANITIZE_NAMED_PROPS||!1,U=J.KEEP_CONTENT!==!1,V=J.IN_PLACE||!1,ve=J.ALLOWED_URI_REGEXP||lV,Ye=J.NAMESPACE||Ke,pe=J.CUSTOM_ELEMENT_HANDLING||{},J.CUSTOM_ELEMENT_HANDLING&&fh(J.CUSTOM_ELEMENT_HANDLING.tagNameCheck)&&(pe.tagNameCheck=J.CUSTOM_ELEMENT_HANDLING.tagNameCheck),J.CUSTOM_ELEMENT_HANDLING&&fh(J.CUSTOM_ELEMENT_HANDLING.attributeNameCheck)&&(pe.attributeNameCheck=J.CUSTOM_ELEMENT_HANDLING.attributeNameCheck),J.CUSTOM_ELEMENT_HANDLING&&typeof J.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements=="boolean"&&(pe.allowCustomizedBuiltInElements=J.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements),ji&&(wt=!1),ae&&(Z=!0),F&&(ye=Ut({},[...v5]),Ve=[],F.html===!0&&(Ut(ye,_5),Ut(Ve,b5)),F.svg===!0&&(Ut(ye,Ak),Ut(Ve,Fk),Ut(Ve,l1)),F.svgFilters===!0&&(Ut(ye,Pk),Ut(Ve,Fk),Ut(Ve,l1)),F.mathMl===!0&&(Ut(ye,Ok),Ut(Ve,C5),Ut(Ve,l1))),J.ADD_TAGS&&(ye===Be&&(ye=xf(ye)),Ut(ye,J.ADD_TAGS,Ft)),J.ADD_ATTR&&(Ve===Ie&&(Ve=xf(Ve)),Ut(Ve,J.ADD_ATTR,Ft)),J.ADD_URI_SAFE_ATTR&&Ut(X,J.ADD_URI_SAFE_ATTR,Ft),J.FORBID_CONTENTS&&(E===M&&(E=xf(E)),Ut(E,J.FORBID_CONTENTS,Ft)),U&&(ye["#text"]=!0),Ze&&Ut(ye,["html","head","body"]),ye.table&&(Ut(ye,["tbody"]),delete Ji.tbody),J.TRUSTED_TYPES_POLICY){if(typeof J.TRUSTED_TYPES_POLICY.createHTML!="function")throw I_('TRUSTED_TYPES_POLICY configuration option must provide a "createHTML" hook.');if(typeof J.TRUSTED_TYPES_POLICY.createScriptURL!="function")throw I_('TRUSTED_TYPES_POLICY configuration option must provide a "createScriptURL" hook.');C=J.TRUSTED_TYPES_POLICY,w=C.createHTML("")}else C===void 0&&(C=Dee(g,i)),C!==null&&typeof w=="string"&&(w=C.createHTML(""));So&&So(J),cn=J}},hc=Ut({},["mi","mo","mn","ms","mtext"]),ph=Ut({},["foreignobject","desc","title","annotation-xml"]),mh=Ut({},["title","style","font","a","script"]),yf=Ut({},Ak);Ut(yf,Pk),Ut(yf,mee);const _h=Ut({},Ok);Ut(_h,_ee);const dk=function(J){let Ne=b(J);(!Ne||!Ne.tagName)&&(Ne={namespaceURI:Ye,tagName:"template"});const Ge=Mw(J.tagName),Oi=Mw(Ne.tagName);return At[J.namespaceURI]?J.namespaceURI===ke?Ne.namespaceURI===Ke?Ge==="svg":Ne.namespaceURI===Se?Ge==="svg"&&(Oi==="annotation-xml"||hc[Oi]):!!yf[Ge]:J.namespaceURI===Se?Ne.namespaceURI===Ke?Ge==="math":Ne.namespaceURI===ke?Ge==="math"&&ph[Oi]:!!_h[Ge]:J.namespaceURI===Ke?Ne.namespaceURI===ke&&!ph[Oi]||Ne.namespaceURI===Se&&!hc[Oi]?!1:!_h[Ge]&&(mh[Ge]||!yf[Ge]):!!(Ot==="application/xhtml+xml"&&At[J.namespaceURI]):!1},Qa=function(J){k_(e.removed,{element:J});try{J.parentNode.removeChild(J)}catch{J.remove()}},L_=function(J,Ne){try{k_(e.removed,{attribute:Ne.getAttributeNode(J),from:Ne})}catch{k_(e.removed,{attribute:null,from:Ne})}if(Ne.removeAttribute(J),J==="is"&&!Ve[J])if(Z||ae)try{Qa(Ne)}catch{}else try{Ne.setAttribute(J,"")}catch{}},x_=function(J){let Ne,Ge;if(q)J="<remove></remove>"+J;else{const Rr=hee(J,/^[\r\n\t ]+/);Ge=Rr&&Rr[0]}Ot==="application/xhtml+xml"&&Ye===Ke&&(J='<html xmlns="http://www.w3.org/1999/xhtml"><head></head><body>'+J+"</body></html>");const Oi=C?C.createHTML(J):J;if(Ye===Ke)try{Ne=new h().parseFromString(Oi,Ot)}catch{}if(!Ne||!Ne.documentElement){Ne=S.createDocument(Ye,"template",null);try{Ne.documentElement.innerHTML=Kt?w:Oi}catch{}}const gs=Ne.body||Ne.documentElement;return J&&Ge&&gs.insertBefore(n.createTextNode(Ge),gs.childNodes[0]||null),Ye===Ke?k.call(Ne,Ze?"html":"body")[0]:Ze?Ne.documentElement:gs},KC=function(J){return x.call(J.ownerDocument||J,J,d.SHOW_ELEMENT|d.SHOW_COMMENT|d.SHOW_TEXT,null,!1)},vq=function(J){return J instanceof u&&(typeof J.nodeName!="string"||typeof J.textContent!="string"||typeof J.removeChild!="function"||!(J.attributes instanceof c)||typeof J.removeAttribute!="function"||typeof J.setAttribute!="function"||typeof J.namespaceURI!="string"||typeof J.insertBefore!="function"||typeof J.hasChildNodes!="function")},qC=function(J){return typeof a=="object"?J instanceof a:J&&typeof J=="object"&&typeof J.nodeType=="number"&&typeof J.nodeName=="string"},dd=function(J,Ne,Ge){P[J]&&uee(P[J],Oi=>{Oi.call(e,Ne,Ge,cn)})},X4=function(J){let Ne;if(dd("beforeSanitizeElements",J,null),vq(J))return Qa(J),!0;const Ge=Ft(J.nodeName);if(dd("uponSanitizeElement",J,{tagName:Ge,allowedTags:ye}),J.hasChildNodes()&&!qC(J.firstElementChild)&&(!qC(J.content)||!qC(J.content.firstElementChild))&&cr(/<[/\w]/g,J.innerHTML)&&cr(/<[/\w]/g,J.textContent))return Qa(J),!0;if(!ye[Ge]||Ji[Ge]){if(!Ji[Ge]&&J4(Ge)&&(pe.tagNameCheck instanceof RegExp&&cr(pe.tagNameCheck,Ge)||pe.tagNameCheck instanceof Function&&pe.tagNameCheck(Ge)))return!1;if(U&&!E[Ge]){const Oi=b(J)||J.parentNode,gs=v(J)||J.childNodes;if(gs&&Oi){const Rr=gs.length;for(let pn=Rr-1;pn>=0;--pn)Oi.insertBefore(m(gs[pn],!0),_(J))}}return Qa(J),!0}return J instanceof l&&!dk(J)||(Ge==="noscript"||Ge==="noembed"||Ge==="noframes")&&cr(/<\/no(script|embed|frames)/i,J.innerHTML)?(Qa(J),!0):(ji&&J.nodeType===3&&(Ne=J.textContent,Ne=la(Ne,$," "),Ne=la(Ne,A," "),Ne=la(Ne,z," "),J.textContent!==Ne&&(k_(e.removed,{element:J.cloneNode()}),J.textContent=Ne)),dd("afterSanitizeElements",J,null),!1)},Q4=function(J,Ne,Ge){if(Le&&(Ne==="id"||Ne==="name")&&(Ge in n||Ge in gh))return!1;if(!(wt&&!wn[Ne]&&cr(K,Ne))){if(!(ni&&cr(Q,Ne))){if(!Ve[Ne]||wn[Ne]){if(!(J4(J)&&(pe.tagNameCheck instanceof RegExp&&cr(pe.tagNameCheck,J)||pe.tagNameCheck instanceof Function&&pe.tagNameCheck(J))&&(pe.attributeNameCheck instanceof RegExp&&cr(pe.attributeNameCheck,Ne)||pe.attributeNameCheck instanceof Function&&pe.attributeNameCheck(Ne))||Ne==="is"&&pe.allowCustomizedBuiltInElements&&(pe.tagNameCheck instanceof RegExp&&cr(pe.tagNameCheck,Ge)||pe.tagNameCheck instanceof Function&&pe.tagNameCheck(Ge))))return!1}else if(!X[Ne]){if(!cr(ve,la(Ge,fe,""))){if(!((Ne==="src"||Ne==="xlink:href"||Ne==="href")&&J!=="script"&&gee(Ge,"data:")===0&&B[J])){if(!($i&&!cr(ne,la(Ge,fe,"")))){if(Ge)return!1}}}}}}return!0},J4=function(J){return J.indexOf("-")>0},eF=function(J){let Ne,Ge,Oi,gs;dd("beforeSanitizeAttributes",J,null);const{attributes:Rr}=J;if(!Rr)return;const pn={attrName:"",attrValue:"",keepAttr:!0,allowedAttributes:Ve};for(gs=Rr.length;gs--;){Ne=Rr[gs];const{name:Ja,namespaceURI:ck}=Ne;if(Ge=Ja==="value"?Ne.value:fee(Ne.value),Oi=Ft(Ja),pn.attrName=Oi,pn.attrValue=Ge,pn.keepAttr=!0,pn.forceKeepAttr=void 0,dd("uponSanitizeAttribute",J,pn),Ge=pn.attrValue,pn.forceKeepAttr||(L_(Ja,J),!pn.keepAttr))continue;if(!no&&cr(/\/>/i,Ge)){L_(Ja,J);continue}ji&&(Ge=la(Ge,$," "),Ge=la(Ge,A," "),Ge=la(Ge,z," "));const tF=Ft(J.nodeName);if(Q4(tF,Oi,Ge)){if(Re&&(Oi==="id"||Oi==="name")&&(L_(Ja,J),Ge=ze+Ge),C&&typeof g=="object"&&typeof g.getAttributeType=="function"&&!ck)switch(g.getAttributeType(tF,Oi)){case"TrustedHTML":{Ge=C.createHTML(Ge);break}case"TrustedScriptURL":{Ge=C.createScriptURL(Ge);break}}try{ck?J.setAttributeNS(ck,Ja,Ge):J.setAttribute(Ja,Ge),m5(e.removed)}catch{}}}dd("afterSanitizeAttributes",J,null)},bq=function dt(J){let Ne;const Ge=KC(J);for(dd("beforeSanitizeShadowDOM",J,null);Ne=Ge.nextNode();)dd("uponSanitizeShadowNode",Ne,null),!X4(Ne)&&(Ne.content instanceof o&&dt(Ne.content),eF(Ne));dd("afterSanitizeShadowDOM",J,null)};return e.sanitize=function(dt){let J=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},Ne,Ge,Oi,gs;if(Kt=!dt,Kt&&(dt="<!-->"),typeof dt!="string"&&!qC(dt))if(typeof dt.toString=="function"){if(dt=dt.toString(),typeof dt!="string")throw I_("dirty is not a string, aborting")}else throw I_("toString is not a function");if(!e.isSupported)return dt;if(zn||ra(J),e.removed=[],typeof dt=="string"&&(V=!1),V){if(dt.nodeName){const Ja=Ft(dt.nodeName);if(!ye[Ja]||Ji[Ja])throw I_("root node is forbidden and cannot be sanitized in-place")}}else if(dt instanceof a)Ne=x_("<!---->"),Ge=Ne.ownerDocument.importNode(dt,!0),Ge.nodeType===1&&Ge.nodeName==="BODY"||Ge.nodeName==="HTML"?Ne=Ge:Ne.appendChild(Ge);else{if(!Z&&!ji&&!Ze&&dt.indexOf("<")===-1)return C&&be?C.createHTML(dt):dt;if(Ne=x_(dt),!Ne)return Z?null:be?w:""}Ne&&q&&Qa(Ne.firstChild);const Rr=KC(V?dt:Ne);for(;Oi=Rr.nextNode();)X4(Oi)||(Oi.content instanceof o&&bq(Oi.content),eF(Oi));if(V)return dt;if(Z){if(ae)for(gs=L.call(Ne.ownerDocument);Ne.firstChild;)gs.appendChild(Ne.firstChild);else gs=Ne;return(Ve.shadowroot||Ve.shadowrootmode)&&(gs=I.call(t,gs,!0)),gs}let pn=Ze?Ne.outerHTML:Ne.innerHTML;return Ze&&ye["!doctype"]&&Ne.ownerDocument&&Ne.ownerDocument.doctype&&Ne.ownerDocument.doctype.name&&cr(dV,Ne.ownerDocument.doctype.name)&&(pn="<!DOCTYPE "+Ne.ownerDocument.doctype.name+`>
`+pn),ji&&(pn=la(pn,$," "),pn=la(pn,A," "),pn=la(pn,z," ")),C&&be?C.createHTML(pn):pn},e.setConfig=function(dt){ra(dt),zn=!0},e.clearConfig=function(){cn=null,zn=!1},e.isValidAttribute=function(dt,J,Ne){cn||ra({});const Ge=Ft(dt),Oi=Ft(J);return Q4(Ge,Oi,Ne)},e.addHook=function(dt,J){typeof J=="function"&&(P[dt]=P[dt]||[],k_(P[dt],J))},e.removeHook=function(dt){if(P[dt])return m5(P[dt])},e.removeHooks=function(dt){P[dt]&&(P[dt]=[])},e.removeAllHooks=function(){P={}},e}var sd=cV();sd.version;sd.isSupported;const uV=sd.sanitize;sd.setConfig;sd.clearConfig;sd.isValidAttribute;const hV=sd.addHook,gV=sd.removeHook;sd.removeHooks;sd.removeAllHooks;var it;(function(s){s.inMemory="inmemory",s.vscode="vscode",s.internal="private",s.walkThrough="walkThrough",s.walkThroughSnippet="walkThroughSnippet",s.http="http",s.https="https",s.file="file",s.mailto="mailto",s.untitled="untitled",s.data="data",s.command="command",s.vscodeRemote="vscode-remote",s.vscodeRemoteResource="vscode-remote-resource",s.vscodeManagedRemoteResource="vscode-managed-remote-resource",s.vscodeUserData="vscode-userdata",s.vscodeCustomEditor="vscode-custom-editor",s.vscodeNotebookCell="vscode-notebook-cell",s.vscodeNotebookCellMetadata="vscode-notebook-cell-metadata",s.vscodeNotebookCellOutput="vscode-notebook-cell-output",s.vscodeInteractiveInput="vscode-interactive-input",s.vscodeSettings="vscode-settings",s.vscodeWorkspaceTrust="vscode-workspace-trust",s.vscodeTerminal="vscode-terminal",s.vscodeChatSesssion="vscode-chat-editor",s.webviewPanel="webview-panel",s.vscodeWebview="vscode-webview",s.extension="extension",s.vscodeFileResource="vscode-file",s.tmp="tmp",s.vsls="vsls",s.vscodeSourceControl="vscode-scm"})(it||(it={}));function YA(s,e){return Pe.isUri(s)?np(s.scheme,e):FA(s,e+":")}function S5(s,...e){return e.some(t=>YA(s,t))}const kee="tkn";class Iee{constructor(){this._hosts=Object.create(null),this._ports=Object.create(null),this._connectionTokens=Object.create(null),this._preferredWebSchema="http",this._delegate=null,this._remoteResourcesPath=`/${it.vscodeRemoteResource}`}setPreferredWebSchema(e){this._preferredWebSchema=e}rewrite(e){if(this._delegate)try{return this._delegate(e)}catch(a){return et(a),e}const t=e.authority;let i=this._hosts[t];i&&i.indexOf(":")!==-1&&i.indexOf("[")===-1&&(i=`[${i}]`);const n=this._ports[t],o=this._connectionTokens[t];let r=`path=${encodeURIComponent(e.path)}`;return typeof o=="string"&&(r+=`&${kee}=${encodeURIComponent(o)}`),Pe.from({scheme:Ju?this._preferredWebSchema:it.vscodeRemoteResource,authority:`${i}:${n}`,path:this._remoteResourcesPath,query:r})}}const fV=new Iee,Eee="vscode-app";class N0{uriToBrowserUri(e){return e.scheme===it.vscodeRemote?fV.rewrite(e):e.scheme===it.file&&(Ra||mX===`${it.vscodeFileResource}://${N0.FALLBACK_AUTHORITY}`)?e.with({scheme:it.vscodeFileResource,authority:e.authority||N0.FALLBACK_AUTHORITY,query:null,fragment:null}):e}}N0.FALLBACK_AUTHORITY=Eee;const pV=new N0;var y5;(function(s){const e=new Map([["1",{"Cross-Origin-Opener-Policy":"same-origin"}],["2",{"Cross-Origin-Embedder-Policy":"require-corp"}],["3",{"Cross-Origin-Opener-Policy":"same-origin","Cross-Origin-Embedder-Policy":"require-corp"}]]);s.CoopAndCoep=Object.freeze(e.get("3"));const t="vscode-coi";function i(o){let r;typeof o=="string"?r=new URL(o).searchParams:o instanceof URL?r=o.searchParams:Pe.isUri(o)&&(r=new URL(o.toString(!0)).searchParams);const a=r==null?void 0:r.get(t);if(a)return e.get(a)}s.getHeadersFromQuery=i;function n(o,r,a){if(!globalThis.crossOriginIsolated)return;const l=r&&a?"3":a?"2":"1";o instanceof URLSearchParams?o.set(t,l):o[t]=l}s.addSearchParam=n})(y5||(y5={}));function XA(s){return rx(s,0)}function rx(s,e){switch(typeof s){case"object":return s===null?Ad(349,e):Array.isArray(s)?Tee(s,e):Mee(s,e);case"string":return QA(s,e);case"boolean":return Nee(s,e);case"number":return Ad(s,e);case"undefined":return Ad(937,e);default:return Ad(617,e)}}function Ad(s,e){return(e<<5)-e+s|0}function Nee(s,e){return Ad(s?433:863,e)}function QA(s,e){e=Ad(149417,e);for(let t=0,i=s.length;t<i;t++)e=Ad(s.charCodeAt(t),e);return e}function Tee(s,e){return e=Ad(104579,e),s.reduce((t,i)=>rx(i,t),e)}function Mee(s,e){return e=Ad(181387,e),Object.keys(s).sort().reduce((t,i)=>(t=QA(i,t),rx(s[i],t)),e)}function Bk(s,e,t=32){const i=t-e,n=~((1<<i)-1);return(s<<e|(n&s)>>>i)>>>0}function L5(s,e=0,t=s.byteLength,i=0){for(let n=0;n<t;n++)s[e+n]=i}function Ree(s,e,t="0"){for(;s.length<e;)s=t+s;return s}function E_(s,e=32){return s instanceof ArrayBuffer?Array.from(new Uint8Array(s)).map(t=>t.toString(16).padStart(2,"0")).join(""):Ree((s>>>0).toString(16),e/4)}class ax{constructor(){this._h0=1732584193,this._h1=4023233417,this._h2=2562383102,this._h3=271733878,this._h4=3285377520,this._buff=new Uint8Array(67),this._buffDV=new DataView(this._buff.buffer),this._buffLen=0,this._totalLen=0,this._leftoverHighSurrogate=0,this._finished=!1}update(e){const t=e.length;if(t===0)return;const i=this._buff;let n=this._buffLen,o=this._leftoverHighSurrogate,r,a;for(o!==0?(r=o,a=-1,o=0):(r=e.charCodeAt(0),a=0);;){let l=r;if(_n(r))if(a+1<t){const d=e.charCodeAt(a+1);kg(d)?(a++,l=BA(r,d)):l=65533}else{o=r;break}else kg(r)&&(l=65533);if(n=this._push(i,n,l),a++,a<t)r=e.charCodeAt(a);else break}this._buffLen=n,this._leftoverHighSurrogate=o}_push(e,t,i){return i<128?e[t++]=i:i<2048?(e[t++]=192|(i&1984)>>>6,e[t++]=128|(i&63)>>>0):i<65536?(e[t++]=224|(i&61440)>>>12,e[t++]=128|(i&4032)>>>6,e[t++]=128|(i&63)>>>0):(e[t++]=240|(i&1835008)>>>18,e[t++]=128|(i&258048)>>>12,e[t++]=128|(i&4032)>>>6,e[t++]=128|(i&63)>>>0),t>=64&&(this._step(),t-=64,this._totalLen+=64,e[0]=e[64],e[1]=e[65],e[2]=e[66]),t}digest(){return this._finished||(this._finished=!0,this._leftoverHighSurrogate&&(this._leftoverHighSurrogate=0,this._buffLen=this._push(this._buff,this._buffLen,65533)),this._totalLen+=this._buffLen,this._wrapUp()),E_(this._h0)+E_(this._h1)+E_(this._h2)+E_(this._h3)+E_(this._h4)}_wrapUp(){this._buff[this._buffLen++]=128,L5(this._buff,this._buffLen),this._buffLen>56&&(this._step(),L5(this._buff));const e=8*this._totalLen;this._buffDV.setUint32(56,Math.floor(e/4294967296),!1),this._buffDV.setUint32(60,e%4294967296,!1),this._step()}_step(){const e=ax._bigBlock32,t=this._buffDV;for(let u=0;u<64;u+=4)e.setUint32(u,t.getUint32(u,!1),!1);for(let u=64;u<320;u+=4)e.setUint32(u,Bk(e.getUint32(u-12,!1)^e.getUint32(u-32,!1)^e.getUint32(u-56,!1)^e.getUint32(u-64,!1),1),!1);let i=this._h0,n=this._h1,o=this._h2,r=this._h3,a=this._h4,l,d,c;for(let u=0;u<80;u++)u<20?(l=n&o|~n&r,d=1518500249):u<40?(l=n^o^r,d=1859775393):u<60?(l=n&o|n&r|o&r,d=2400959708):(l=n^o^r,d=3395469782),c=Bk(i,5)+l+a+d+e.getUint32(u*4,!1)&4294967295,a=r,r=o,o=Bk(n,30),n=i,i=c;this._h0=this._h0+i&4294967295,this._h1=this._h1+n&4294967295,this._h2=this._h2+o&4294967295,this._h3=this._h3+r&4294967295,this._h4=this._h4+a&4294967295}}ax._bigBlock32=new DataView(new ArrayBuffer(320));const{registerWindow:nNe,getWindow:Xe,getDocument:sNe,getWindows:mV,getWindowsCount:Aee,getWindowId:x5,getWindowById:oNe,hasWindow:rNe,onDidRegisterWindow:JA,onWillUnregisterWindow:Pee,onDidUnregisterWindow:aNe}=function(){const s=new Map;QQ(Ci,1),s.set(Ci.vscodeWindowId,{window:Ci,disposables:new ie});const e=new W,t=new W,i=new W;return{onDidRegisterWindow:e.event,onWillUnregisterWindow:i.event,onDidUnregisterWindow:t.event,registerWindow(n){if(s.has(n.vscodeWindowId))return j.None;const o=new ie,r={window:n,disposables:o.add(new ie)};return s.set(n.vscodeWindowId,r),o.add(Fe(()=>{s.delete(n.vscodeWindowId),t.fire(n)})),o.add(Y(n,he.BEFORE_UNLOAD,()=>{i.fire(n)})),e.fire(r),o},getWindows(){return s.values()},getWindowsCount(){return s.size},getWindowId(n){return n.vscodeWindowId},hasWindow(n){return s.has(n)},getWindowById(n){return s.get(n)},getWindow(n){var o;const r=n;if(!((o=r==null?void 0:r.ownerDocument)===null||o===void 0)&&o.defaultView)return r.ownerDocument.defaultView.window;const a=n;return a!=null&&a.view?a.view.window:Ci},getDocument(n){return Xe(n).document}}}();function Vn(s){for(;s.firstChild;)s.firstChild.remove()}class Oee{constructor(e,t,i,n){this._node=e,this._type=t,this._handler=i,this._options=n||!1,this._node.addEventListener(this._type,this._handler,this._options)}dispose(){this._handler&&(this._node.removeEventListener(this._type,this._handler,this._options),this._node=null,this._handler=null)}}function Y(s,e,t,i){return new Oee(s,e,t,i)}function _V(s,e){return function(t){return e(new zr(s,t))}}function Fee(s){return function(e){return s(new ri(e))}}const Pi=function(e,t,i,n){let o=i;return t==="click"||t==="mousedown"?o=_V(Xe(e),i):(t==="keydown"||t==="keypress"||t==="keyup")&&(o=Fee(i)),Y(e,t,o,n)},Bee=function(e,t,i){const n=_V(Xe(e),t);return Wee(e,n,i)};function Wee(s,e,t){return Y(s,Wa&&qA.pointerEvents?he.POINTER_DOWN:he.MOUSE_DOWN,e,t)}function ov(s,e,t){return Rv(s,e,t)}class Wk extends rV{constructor(e,t){super(e,t)}}let OS,yo;class eP extends ZA{cancelAndSet(e,t,i){return super.cancelAndSet(e,t,i)}}class Vk{constructor(e,t=0){this._runner=e,this.priority=t,this._canceled=!1}dispose(){this._canceled=!0}execute(){if(!this._canceled)try{this._runner()}catch(e){et(e)}}static sort(e,t){return t.priority-e.priority}}(function(){const s=new Map,e=new Map,t=new Map,i=new Map,n=o=>{var r;t.set(o,!1);const a=(r=s.get(o))!==null&&r!==void 0?r:[];for(e.set(o,a),s.set(o,[]),i.set(o,!0);a.length>0;)a.sort(Vk.sort),a.shift().execute();i.set(o,!1)};yo=(o,r,a=0)=>{const l=x5(o),d=new Vk(r,a);let c=s.get(l);return c||(c=[],s.set(l,c)),c.push(d),t.get(l)||(t.set(l,!0),o.requestAnimationFrame(()=>n(l))),d},OS=(o,r,a)=>{const l=x5(o);if(i.get(l)){const d=new Vk(r,a);let c=e.get(l);return c||(c=[],e.set(l,c)),c.push(d),d}else return yo(o,r,a)}})();function lx(s){return Xe(s).getComputedStyle(s,null)}function Nu(s,e){const t=Xe(s),i=t.document;if(s!==i.body)return new Dt(s.clientWidth,s.clientHeight);if(Wa&&(t!=null&&t.visualViewport))return new Dt(t.visualViewport.width,t.visualViewport.height);if(t!=null&&t.innerWidth&&t.innerHeight)return new Dt(t.innerWidth,t.innerHeight);if(i.body&&i.body.clientWidth&&i.body.clientHeight)return new Dt(i.body.clientWidth,i.body.clientHeight);if(i.documentElement&&i.documentElement.clientWidth&&i.documentElement.clientHeight)return new Dt(i.documentElement.clientWidth,i.documentElement.clientHeight);if(e)return Nu(e);throw new Error("Unable to figure out browser width and height")}class Bi{static convertToPixels(e,t){return parseFloat(t)||0}static getDimension(e,t,i){const n=lx(e),o=n?n.getPropertyValue(t):"0";return Bi.convertToPixels(e,o)}static getBorderLeftWidth(e){return Bi.getDimension(e,"border-left-width","borderLeftWidth")}static getBorderRightWidth(e){return Bi.getDimension(e,"border-right-width","borderRightWidth")}static getBorderTopWidth(e){return Bi.getDimension(e,"border-top-width","borderTopWidth")}static getBorderBottomWidth(e){return Bi.getDimension(e,"border-bottom-width","borderBottomWidth")}static getPaddingLeft(e){return Bi.getDimension(e,"padding-left","paddingLeft")}static getPaddingRight(e){return Bi.getDimension(e,"padding-right","paddingRight")}static getPaddingTop(e){return Bi.getDimension(e,"padding-top","paddingTop")}static getPaddingBottom(e){return Bi.getDimension(e,"padding-bottom","paddingBottom")}static getMarginLeft(e){return Bi.getDimension(e,"margin-left","marginLeft")}static getMarginTop(e){return Bi.getDimension(e,"margin-top","marginTop")}static getMarginRight(e){return Bi.getDimension(e,"margin-right","marginRight")}static getMarginBottom(e){return Bi.getDimension(e,"margin-bottom","marginBottom")}}class Dt{constructor(e,t){this.width=e,this.height=t}with(e=this.width,t=this.height){return e!==this.width||t!==this.height?new Dt(e,t):this}static is(e){return typeof e=="object"&&typeof e.height=="number"&&typeof e.width=="number"}static lift(e){return e instanceof Dt?e:new Dt(e.width,e.height)}static equals(e,t){return e===t?!0:!e||!t?!1:e.width===t.width&&e.height===t.height}}Dt.None=new Dt(0,0);function vV(s){let e=s.offsetParent,t=s.offsetTop,i=s.offsetLeft;for(;(s=s.parentNode)!==null&&s!==s.ownerDocument.body&&s!==s.ownerDocument.documentElement;){t-=s.scrollTop;const n=bV(s)?null:lx(s);n&&(i-=n.direction!=="rtl"?s.scrollLeft:-s.scrollLeft),s===e&&(i+=Bi.getBorderLeftWidth(s),t+=Bi.getBorderTopWidth(s),t+=s.offsetTop,i+=s.offsetLeft,e=s.offsetParent)}return{left:i,top:t}}function Vee(s,e,t){typeof e=="number"&&(s.style.width=`${e}px`),typeof t=="number"&&(s.style.height=`${t}px`)}function ln(s){const e=s.getBoundingClientRect(),t=Xe(s);return{left:e.left+t.scrollX,top:e.top+t.scrollY,width:e.width,height:e.height}}function Hee(s){let e=s,t=1;do{const i=lx(e).zoom;i!=null&&i!=="1"&&(t*=i),e=e.parentElement}while(e!==null&&e!==e.ownerDocument.documentElement);return t}function js(s){const e=Bi.getMarginLeft(s)+Bi.getMarginRight(s);return s.offsetWidth+e}function Hk(s){const e=Bi.getBorderLeftWidth(s)+Bi.getBorderRightWidth(s),t=Bi.getPaddingLeft(s)+Bi.getPaddingRight(s);return s.offsetWidth-e-t}function zee(s){const e=Bi.getBorderTopWidth(s)+Bi.getBorderBottomWidth(s),t=Bi.getPaddingTop(s)+Bi.getPaddingBottom(s);return s.offsetHeight-e-t}function Qh(s){const e=Bi.getMarginTop(s)+Bi.getMarginBottom(s);return s.offsetHeight+e}function Yn(s,e){return!!(e!=null&&e.contains(s))}function Uee(s,e,t){for(;s&&s.nodeType===s.ELEMENT_NODE;){if(s.classList.contains(e))return s;if(t){if(typeof t=="string"){if(s.classList.contains(t))return null}else if(s===t)return null}s=s.parentNode}return null}function zk(s,e,t){return!!Uee(s,e,t)}function bV(s){return s&&!!s.host&&!!s.mode}function FS(s){return!!Tg(s)}function Tg(s){for(var e;s.parentNode;){if(s===((e=s.ownerDocument)===null||e===void 0?void 0:e.body))return null;s=s.parentNode}return bV(s)?s:null}function Jo(){let s=i_().activeElement;for(;s!=null&&s.shadowRoot;)s=s.shadowRoot.activeElement;return s}function dx(s){return s.ownerDocument.activeElement===s}function $ee(s){return Yn(s.ownerDocument.activeElement,s)}function i_(){var s;return Aee()<=1?document:(s=Array.from(mV()).map(({window:t})=>t.document).find(t=>t.hasFocus()))!==null&&s!==void 0?s:document}function jee(){var s,e;return(e=(s=i_().defaultView)===null||s===void 0?void 0:s.window)!==null&&e!==void 0?e:Ci}const tP=new Map;function Lr(s=Ci.document.head,e,t){const i=document.createElement("style");if(i.type="text/css",i.media="screen",e==null||e(i),s.appendChild(i),t&&t.add(Fe(()=>s.removeChild(i))),s===Ci.document.head){const n=new Set;tP.set(i,n);for(const{window:o,disposables:r}of mV()){if(o===Ci)continue;const a=r.add(Kee(i,n,o));t==null||t.add(a)}}return i}function Kee(s,e,t){var i,n;const o=new ie,r=s.cloneNode(!0);t.document.head.appendChild(r),o.add(Fe(()=>t.document.head.removeChild(r)));for(const a of wV(s))(i=r.sheet)===null||i===void 0||i.insertRule(a.cssText,(n=r.sheet)===null||n===void 0?void 0:n.cssRules.length);return o.add(qee.observe(s,o,{childList:!0})(()=>{r.textContent=s.textContent})),e.add(r),o.add(Fe(()=>e.delete(r))),o}const qee=new class{constructor(){this.mutationObservers=new Map}observe(s,e,t){let i=this.mutationObservers.get(s);i||(i=new Map,this.mutationObservers.set(s,i));const n=XA(t);let o=i.get(n);if(o)o.users+=1;else{const r=new W,a=new MutationObserver(d=>r.fire(d));a.observe(s,t);const l=o={users:1,observer:a,onDidMutate:r.event};e.add(Fe(()=>{l.users-=1,l.users===0&&(r.dispose(),a.disconnect(),i==null||i.delete(n),(i==null?void 0:i.size)===0&&this.mutationObservers.delete(s))})),i.set(n,o)}return o.onDidMutate}};let Uk=null;function CV(){return Uk||(Uk=Lr()),Uk}function wV(s){var e,t;return!((e=s==null?void 0:s.sheet)===null||e===void 0)&&e.rules?s.sheet.rules:!((t=s==null?void 0:s.sheet)===null||t===void 0)&&t.cssRules?s.sheet.cssRules:[]}function BS(s,e,t=CV()){var i,n;if(!(!t||!e)){(i=t.sheet)===null||i===void 0||i.insertRule(`${s} {${e}}`,0);for(const o of(n=tP.get(t))!==null&&n!==void 0?n:[])BS(s,e,o)}}function XN(s,e=CV()){var t,i;if(!e)return;const n=wV(e),o=[];for(let r=0;r<n.length;r++){const a=n[r];Gee(a)&&a.selectorText.indexOf(s)!==-1&&o.push(r)}for(let r=o.length-1;r>=0;r--)(t=e.sheet)===null||t===void 0||t.deleteRule(o[r]);for(const r of(i=tP.get(e))!==null&&i!==void 0?i:[])XN(s,r)}function Gee(s){return typeof s.selectorText=="string"}function iP(s){return s instanceof MouseEvent||s instanceof Xe(s).MouseEvent}function SV(s){return s instanceof KeyboardEvent||s instanceof Xe(s).KeyboardEvent}const he={CLICK:"click",AUXCLICK:"auxclick",DBLCLICK:"dblclick",MOUSE_UP:"mouseup",MOUSE_DOWN:"mousedown",MOUSE_OVER:"mouseover",MOUSE_MOVE:"mousemove",MOUSE_OUT:"mouseout",MOUSE_ENTER:"mouseenter",MOUSE_LEAVE:"mouseleave",MOUSE_WHEEL:"wheel",POINTER_UP:"pointerup",POINTER_DOWN:"pointerdown",POINTER_MOVE:"pointermove",POINTER_LEAVE:"pointerleave",CONTEXT_MENU:"contextmenu",WHEEL:"wheel",KEY_DOWN:"keydown",KEY_PRESS:"keypress",KEY_UP:"keyup",LOAD:"load",BEFORE_UNLOAD:"beforeunload",UNLOAD:"unload",PAGE_SHOW:"pageshow",PAGE_HIDE:"pagehide",PASTE:"paste",ABORT:"abort",ERROR:"error",RESIZE:"resize",SCROLL:"scroll",FULLSCREEN_CHANGE:"fullscreenchange",WK_FULLSCREEN_CHANGE:"webkitfullscreenchange",SELECT:"select",CHANGE:"change",SUBMIT:"submit",RESET:"reset",FOCUS:"focus",FOCUS_IN:"focusin",FOCUS_OUT:"focusout",BLUR:"blur",INPUT:"input",STORAGE:"storage",DRAG_START:"dragstart",DRAG:"drag",DRAG_ENTER:"dragenter",DRAG_LEAVE:"dragleave",DRAG_OVER:"dragover",DROP:"drop",DRAG_END:"dragend",ANIMATION_START:ug?"webkitAnimationStart":"animationstart",ANIMATION_END:ug?"webkitAnimationEnd":"animationend",ANIMATION_ITERATION:ug?"webkitAnimationIteration":"animationiteration"};function Zee(s){const e=s;return!!(e&&typeof e.preventDefault=="function"&&typeof e.stopPropagation=="function")}const ot={stop:(s,e)=>(s.preventDefault(),e&&s.stopPropagation(),s)};function Yee(s){const e=[];for(let t=0;s&&s.nodeType===s.ELEMENT_NODE;t++)e[t]=s.scrollTop,s=s.parentNode;return e}function Xee(s,e){for(let t=0;s&&s.nodeType===s.ELEMENT_NODE;t++)s.scrollTop!==e[t]&&(s.scrollTop=e[t]),s=s.parentNode}class WS extends j{static hasFocusWithin(e){if(e instanceof HTMLElement){const t=Tg(e),i=t?t.activeElement:e.ownerDocument.activeElement;return Yn(i,e)}else{const t=e;return Yn(t.document.activeElement,t.document)}}constructor(e){super(),this._onDidFocus=this._register(new W),this.onDidFocus=this._onDidFocus.event,this._onDidBlur=this._register(new W),this.onDidBlur=this._onDidBlur.event;let t=WS.hasFocusWithin(e),i=!1;const n=()=>{i=!1,t||(t=!0,this._onDidFocus.fire())},o=()=>{t&&(i=!0,(e instanceof HTMLElement?Xe(e):e).setTimeout(()=>{i&&(i=!1,t=!1,this._onDidBlur.fire())},0))};this._refreshStateHandler=()=>{WS.hasFocusWithin(e)!==t&&(t?o():n())},this._register(Y(e,he.FOCUS,n,!0)),this._register(Y(e,he.BLUR,o,!0)),e instanceof HTMLElement&&(this._register(Y(e,he.FOCUS_IN,()=>this._refreshStateHandler())),this._register(Y(e,he.FOCUS_OUT,()=>this._refreshStateHandler())))}}function ql(s){return new WS(s)}function Qee(s,e){return s.after(e),e}function te(s,...e){if(s.append(...e),e.length===1&&typeof e[0]!="string")return e[0]}function yV(s,e){return s.insertBefore(e,s.firstChild),e}function Qn(s,...e){s.innerText="",te(s,...e)}const Jee=/([\w\-]+)?(#([\w\-]+))?((\.([\w\-]+))*)/;var T0;(function(s){s.HTML="http://www.w3.org/1999/xhtml",s.SVG="http://www.w3.org/2000/svg"})(T0||(T0={}));function LV(s,e,t,...i){const n=Jee.exec(e);if(!n)throw new Error("Bad use of emmet");const o=n[1]||"div";let r;return s!==T0.HTML?r=document.createElementNS(s,o):r=document.createElement(o),n[3]&&(r.id=n[3]),n[4]&&(r.className=n[4].replace(/\./g," ").trim()),t&&Object.entries(t).forEach(([a,l])=>{typeof l>"u"||(/^on\w+$/.test(a)?r[a]=l:a==="selected"?l&&r.setAttribute(a,"true"):r.setAttribute(a,l))}),r.append(...i),r}function se(s,e,...t){return LV(T0.HTML,s,e,...t)}se.SVG=function(s,e,...t){return LV(T0.SVG,s,e,...t)};function ete(s,...e){s?go(...e):ks(...e)}function go(...s){for(const e of s)e.style.display="",e.removeAttribute("aria-hidden")}function ks(...s){for(const e of s)e.style.display="none",e.setAttribute("aria-hidden","true")}function D5(s,e){const t=s.devicePixelRatio*e;return Math.max(1,Math.floor(t))/s.devicePixelRatio}function xV(s){Ci.open(s,"_blank","noopener")}function tte(s,e){const t=()=>{e(),i=yo(s,t)};let i=yo(s,t);return Fe(()=>i.dispose())}fV.setPreferredWebSchema(/^https:/.test(Ci.location.href)?"https":"http");function Tu(s){return s?`url('${pV.uriToBrowserUri(s).toString(!0).replace(/'/g,"%27")}')`:"url('')"}function k5(s){return`'${s.replace(/'/g,"%27")}'`}function gg(s,e){if(s!==void 0){const t=s.match(/^\s*var\((.+)\)$/);if(t){const i=t[1].split(",",2);return i.length===2&&(e=gg(i[1].trim(),e)),`var(${i[0]}, ${e})`}return s}return e}function ite(s,e=!1){const t=document.createElement("a");return hV("afterSanitizeAttributes",i=>{for(const n of["href","src"])if(i.hasAttribute(n)){const o=i.getAttribute(n);if(n==="href"&&o.startsWith("#"))continue;if(t.href=o,!s.includes(t.protocol.replace(/:$/,""))){if(e&&n==="src"&&t.href.startsWith("data:"))continue;i.removeAttribute(n)}}}),Fe(()=>{gV("afterSanitizeAttributes")})}const nte=Object.freeze(["a","abbr","b","bdo","blockquote","br","caption","cite","code","col","colgroup","dd","del","details","dfn","div","dl","dt","em","figcaption","figure","h1","h2","h3","h4","h5","h6","hr","i","img","ins","kbd","label","li","mark","ol","p","pre","q","rp","rt","ruby","samp","small","small","source","span","strike","strong","sub","summary","sup","table","tbody","td","tfoot","th","thead","time","tr","tt","u","ul","var","video","wbr"]);class Pd extends W{constructor(){super(),this._subscriptions=new ie,this._keyStatus={altKey:!1,shiftKey:!1,ctrlKey:!1,metaKey:!1},this._subscriptions.add(ge.runAndSubscribe(JA,({window:e,disposables:t})=>this.registerListeners(e,t),{window:Ci,disposables:this._subscriptions}))}registerListeners(e,t){t.add(Y(e,"keydown",i=>{if(i.defaultPrevented)return;const n=new ri(i);if(!(n.keyCode===6&&i.repeat)){if(i.altKey&&!this._keyStatus.altKey)this._keyStatus.lastKeyPressed="alt";else if(i.ctrlKey&&!this._keyStatus.ctrlKey)this._keyStatus.lastKeyPressed="ctrl";else if(i.metaKey&&!this._keyStatus.metaKey)this._keyStatus.lastKeyPressed="meta";else if(i.shiftKey&&!this._keyStatus.shiftKey)this._keyStatus.lastKeyPressed="shift";else if(n.keyCode!==6)this._keyStatus.lastKeyPressed=void 0;else return;this._keyStatus.altKey=i.altKey,this._keyStatus.ctrlKey=i.ctrlKey,this._keyStatus.metaKey=i.metaKey,this._keyStatus.shiftKey=i.shiftKey,this._keyStatus.lastKeyPressed&&(this._keyStatus.event=i,this.fire(this._keyStatus))}},!0)),t.add(Y(e,"keyup",i=>{i.defaultPrevented||(!i.altKey&&this._keyStatus.altKey?this._keyStatus.lastKeyReleased="alt":!i.ctrlKey&&this._keyStatus.ctrlKey?this._keyStatus.lastKeyReleased="ctrl":!i.metaKey&&this._keyStatus.metaKey?this._keyStatus.lastKeyReleased="meta":!i.shiftKey&&this._keyStatus.shiftKey?this._keyStatus.lastKeyReleased="shift":this._keyStatus.lastKeyReleased=void 0,this._keyStatus.lastKeyPressed!==this._keyStatus.lastKeyReleased&&(this._keyStatus.lastKeyPressed=void 0),this._keyStatus.altKey=i.altKey,this._keyStatus.ctrlKey=i.ctrlKey,this._keyStatus.metaKey=i.metaKey,this._keyStatus.shiftKey=i.shiftKey,this._keyStatus.lastKeyReleased&&(this._keyStatus.event=i,this.fire(this._keyStatus)))},!0)),t.add(Y(e.document.body,"mousedown",()=>{this._keyStatus.lastKeyPressed=void 0},!0)),t.add(Y(e.document.body,"mouseup",()=>{this._keyStatus.lastKeyPressed=void 0},!0)),t.add(Y(e.document.body,"mousemove",i=>{i.buttons&&(this._keyStatus.lastKeyPressed=void 0)},!0)),t.add(Y(e,"blur",()=>{this.resetKeyStatus()}))}get keyStatus(){return this._keyStatus}resetKeyStatus(){this.doResetKeyStatus(),this.fire(this._keyStatus)}doResetKeyStatus(){this._keyStatus={altKey:!1,shiftKey:!1,ctrlKey:!1,metaKey:!1}}static getInstance(){return Pd.instance||(Pd.instance=new Pd),Pd.instance}dispose(){super.dispose(),this._subscriptions.dispose()}}class ste extends j{constructor(e,t){super(),this.element=e,this.callbacks=t,this.counter=0,this.dragStartTime=0,this.registerListeners()}registerListeners(){this.callbacks.onDragStart&&this._register(Y(this.element,he.DRAG_START,e=>{var t,i;(i=(t=this.callbacks).onDragStart)===null||i===void 0||i.call(t,e)})),this.callbacks.onDrag&&this._register(Y(this.element,he.DRAG,e=>{var t,i;(i=(t=this.callbacks).onDrag)===null||i===void 0||i.call(t,e)})),this._register(Y(this.element,he.DRAG_ENTER,e=>{var t,i;this.counter++,this.dragStartTime=e.timeStamp,(i=(t=this.callbacks).onDragEnter)===null||i===void 0||i.call(t,e)})),this._register(Y(this.element,he.DRAG_OVER,e=>{var t,i;e.preventDefault(),(i=(t=this.callbacks).onDragOver)===null||i===void 0||i.call(t,e,e.timeStamp-this.dragStartTime)})),this._register(Y(this.element,he.DRAG_LEAVE,e=>{var t,i;this.counter--,this.counter===0&&(this.dragStartTime=0,(i=(t=this.callbacks).onDragLeave)===null||i===void 0||i.call(t,e))})),this._register(Y(this.element,he.DRAG_END,e=>{var t,i;this.counter=0,this.dragStartTime=0,(i=(t=this.callbacks).onDragEnd)===null||i===void 0||i.call(t,e)})),this._register(Y(this.element,he.DROP,e=>{var t,i;this.counter=0,this.dragStartTime=0,(i=(t=this.callbacks).onDrop)===null||i===void 0||i.call(t,e)}))}}const ote=/(?<tag>[\w\-]+)?(?:#(?<id>[\w\-]+))?(?<class>(?:\.(?:[\w\-]+))*)(?:@(?<name>(?:[\w\_])+))?/;function hi(s,...e){let t,i;Array.isArray(e[0])?(t={},i=e[0]):(t=e[0]||{},i=e[1]);const n=ote.exec(s);if(!n||!n.groups)throw new Error("Bad use of h");const o=n.groups.tag||"div",r=document.createElement(o);n.groups.id&&(r.id=n.groups.id);const a=[];if(n.groups.class)for(const d of n.groups.class.split("."))d!==""&&a.push(d);if(t.className!==void 0)for(const d of t.className.split("."))d!==""&&a.push(d);a.length>0&&(r.className=a.join(" "));const l={};if(n.groups.name&&(l[n.groups.name]=r),i)for(const d of i)d instanceof HTMLElement?r.appendChild(d):typeof d=="string"?r.append(d):"root"in d&&(Object.assign(l,d),r.appendChild(d.root));for(const[d,c]of Object.entries(t))if(d!=="className")if(d==="style")for(const[u,h]of Object.entries(c))r.style.setProperty(I5(u),typeof h=="number"?h+"px":""+h);else d==="tabIndex"?r.tabIndex=c:r.setAttribute(I5(d),c.toString());return l.root=r,l}function I5(s){return s.replace(/([a-z])([A-Z])/g,"$1-$2").toLowerCase()}class cx{constructor(e){this.id=e.id,this.precondition=e.precondition,this._kbOpts=e.kbOpts,this._menuOpts=e.menuOpts,this.metadata=e.metadata}register(){if(Array.isArray(this._menuOpts)?this._menuOpts.forEach(this._registerMenuItem,this):this._menuOpts&&this._registerMenuItem(this._menuOpts),this._kbOpts){const e=Array.isArray(this._kbOpts)?this._kbOpts:[this._kbOpts];for(const t of e){let i=t.kbExpr;this.precondition&&(i?i=ee.and(i,this.precondition):i=this.precondition);const n={id:this.id,weight:t.weight,args:t.args,when:i,primary:t.primary,secondary:t.secondary,win:t.win,linux:t.linux,mac:t.mac};Js.registerKeybindingRule(n)}}Ct.registerCommand({id:this.id,handler:(e,t)=>this.runCommand(e,t),metadata:this.metadata})}_registerMenuItem(e){Wn.appendMenuItem(e.menuId,{group:e.group,command:{id:this.id,title:e.title,icon:e.icon,precondition:this.precondition},when:e.when,order:e.order})}}class n_ extends cx{constructor(){super(...arguments),this._implementations=[]}addImplementation(e,t,i,n){return this._implementations.push({priority:e,name:t,implementation:i,when:n}),this._implementations.sort((o,r)=>r.priority-o.priority),{dispose:()=>{for(let o=0;o<this._implementations.length;o++)if(this._implementations[o].implementation===i){this._implementations.splice(o,1);return}}}}runCommand(e,t){const i=e.get(ko),n=e.get(je);i.trace(`Executing Command '${this.id}' which has ${this._implementations.length} bound.`);for(const o of this._implementations){if(o.when){const a=n.getContext(Jo());if(!o.when.evaluate(a))continue}const r=o.implementation(e,t);if(r)return i.trace(`Command '${this.id}' was handled by '${o.name}'.`),typeof r=="boolean"?void 0:r}i.trace(`The Command '${this.id}' was not handled by any implementation.`)}}class DV extends cx{constructor(e,t){super(t),this.command=e}runCommand(e,t){return this.command.runCommand(e,t)}}class Nn extends cx{static bindToContribution(e){return class extends Nn{constructor(i){super(i),this._callback=i.handler}runEditorCommand(i,n,o){const r=e(n);r&&this._callback(r,o)}}}static runEditorCommand(e,t,i,n){const o=e.get(It),r=o.getFocusedCodeEditor()||o.getActiveCodeEditor();if(r)return r.invokeWithinContext(a=>{if(a.get(je).contextMatchesRules(i??void 0))return n(a,r,t)})}runCommand(e,t){return Nn.runEditorCommand(e,t,this.precondition,(i,n,o)=>this.runEditorCommand(i,n,o))}}class we extends Nn{static convertOptions(e){let t;Array.isArray(e.menuOpts)?t=e.menuOpts:e.menuOpts?t=[e.menuOpts]:t=[];function i(n){return n.menuId||(n.menuId=N.EditorContext),n.title||(n.title=e.label),n.when=ee.and(e.precondition,n.when),n}return Array.isArray(e.contextMenuOpts)?t.push(...e.contextMenuOpts.map(i)):e.contextMenuOpts&&t.push(i(e.contextMenuOpts)),e.menuOpts=t,e}constructor(e){super(we.convertOptions(e)),this.label=e.label,this.alias=e.alias}runEditorCommand(e,t,i){return this.reportTelemetry(e,t),this.run(e,t,i||{})}reportTelemetry(e,t){e.get(Do).publicLog2("editorActionInvoked",{name:this.label,id:this.id})}}class kV extends we{constructor(){super(...arguments),this._implementations=[]}addImplementation(e,t){return this._implementations.push([e,t]),this._implementations.sort((i,n)=>n[0]-i[0]),{dispose:()=>{for(let i=0;i<this._implementations.length;i++)if(this._implementations[i][1]===t){this._implementations.splice(i,1);return}}}}run(e,t,i){for(const n of this._implementations){const o=n[1](e,t,i);if(o)return typeof o=="boolean"?void 0:o}}}class Ga extends ar{run(e,...t){const i=e.get(It),n=i.getFocusedCodeEditor()||i.getActiveCodeEditor();if(n)return n.invokeWithinContext(o=>{var r,a;const l=o.get(je),d=o.get(ko);if(!l.contextMatchesRules((r=this.desc.precondition)!==null&&r!==void 0?r:void 0)){d.debug("[EditorAction2] NOT running command because its precondition is FALSE",this.desc.id,(a=this.desc.precondition)===null||a===void 0?void 0:a.serialize());return}return this.runEditorCommand(o,n,...t)})}}function od(s,e){Ct.registerCommand(s,function(t,...i){const n=t.get(We),[o,r]=i;zt(Pe.isUri(o)),zt(H.isIPosition(r));const a=t.get(vi).getModel(o);if(a){const l=H.lift(r);return n.invokeFunction(e,a,l,...i.slice(2))}return t.get(io).createModelReference(o).then(l=>new Promise((d,c)=>{try{const u=n.invokeFunction(e,l.object.textEditorModel,H.lift(r),i.slice(2));d(u)}catch(u){c(u)}}).finally(()=>{l.dispose()}))})}function ue(s){return pr.INSTANCE.registerEditorCommand(s),s}function re(s){const e=new s;return pr.INSTANCE.registerEditorAction(e),e}function IV(s){return pr.INSTANCE.registerEditorAction(s),s}function rte(s){pr.INSTANCE.registerEditorAction(s)}function Lt(s,e,t){pr.INSTANCE.registerEditorContribution(s,e,t)}var Ap;(function(s){function e(r){return pr.INSTANCE.getEditorCommand(r)}s.getEditorCommand=e;function t(){return pr.INSTANCE.getEditorActions()}s.getEditorActions=t;function i(){return pr.INSTANCE.getEditorContributions()}s.getEditorContributions=i;function n(r){return pr.INSTANCE.getEditorContributions().filter(a=>r.indexOf(a.id)>=0)}s.getSomeEditorContributions=n;function o(){return pr.INSTANCE.getDiffEditorContributions()}s.getDiffEditorContributions=o})(Ap||(Ap={}));const ate={EditorCommonContributions:"editor.contributions"};class pr{constructor(){this.editorContributions=[],this.diffEditorContributions=[],this.editorActions=[],this.editorCommands=Object.create(null)}registerEditorContribution(e,t,i){this.editorContributions.push({id:e,ctor:t,instantiation:i})}getEditorContributions(){return this.editorContributions.slice(0)}getDiffEditorContributions(){return this.diffEditorContributions.slice(0)}registerEditorAction(e){e.register(),this.editorActions.push(e)}getEditorActions(){return this.editorActions}registerEditorCommand(e){e.register(),this.editorCommands[e.id]=e}getEditorCommand(e){return this.editorCommands[e]||null}}pr.INSTANCE=new pr;Si.add(ate.EditorCommonContributions,pr.INSTANCE);function oC(s){return s.register(),s}const EV=oC(new n_({id:"undo",precondition:void 0,kbOpts:{weight:0,primary:2104},menuOpts:[{menuId:N.MenubarEditMenu,group:"1_do",title:p({key:"miUndo",comment:["&& denotes a mnemonic"]},"&&Undo"),order:1},{menuId:N.CommandPalette,group:"",title:p("undo","Undo"),order:1}]}));oC(new DV(EV,{id:"default:undo",precondition:void 0}));const NV=oC(new n_({id:"redo",precondition:void 0,kbOpts:{weight:0,primary:2103,secondary:[3128],mac:{primary:3128}},menuOpts:[{menuId:N.MenubarEditMenu,group:"1_do",title:p({key:"miRedo",comment:["&& denotes a mnemonic"]},"&&Redo"),order:2},{menuId:N.CommandPalette,group:"",title:p("redo","Redo"),order:1}]}));oC(new DV(NV,{id:"default:redo",precondition:void 0}));const lte=oC(new n_({id:"editor.action.selectAll",precondition:void 0,kbOpts:{weight:0,kbExpr:null,primary:2079},menuOpts:[{menuId:N.MenubarSelectionMenu,group:"1_basic",title:p({key:"miSelectAll",comment:["&& denotes a mnemonic"]},"&&Select All"),order:1},{menuId:N.CommandPalette,group:"",title:p("selectAll","Select All"),order:1}]})),dte="$initialize";let E5=!1;function QN(s){Ju&&(E5||(E5=!0,console.warn("Could not create web worker(s). Falling back to loading web worker code in main thread, which might cause UI freezes. Please see https://github.com/microsoft/monaco-editor#faq")),console.warn(s.message))}class cte{constructor(e,t,i,n){this.vsWorker=e,this.req=t,this.method=i,this.args=n,this.type=0}}class N5{constructor(e,t,i,n){this.vsWorker=e,this.seq=t,this.res=i,this.err=n,this.type=1}}class ute{constructor(e,t,i,n){this.vsWorker=e,this.req=t,this.eventName=i,this.arg=n,this.type=2}}class hte{constructor(e,t,i){this.vsWorker=e,this.req=t,this.event=i,this.type=3}}class gte{constructor(e,t){this.vsWorker=e,this.req=t,this.type=4}}class fte{constructor(e){this._workerId=-1,this._handler=e,this._lastSentReq=0,this._pendingReplies=Object.create(null),this._pendingEmitters=new Map,this._pendingEvents=new Map}setWorkerId(e){this._workerId=e}sendMessage(e,t){const i=String(++this._lastSentReq);return new Promise((n,o)=>{this._pendingReplies[i]={resolve:n,reject:o},this._send(new cte(this._workerId,i,e,t))})}listen(e,t){let i=null;const n=new W({onWillAddFirstListener:()=>{i=String(++this._lastSentReq),this._pendingEmitters.set(i,n),this._send(new ute(this._workerId,i,e,t))},onDidRemoveLastListener:()=>{this._pendingEmitters.delete(i),this._send(new gte(this._workerId,i)),i=null}});return n.event}handleMessage(e){!e||!e.vsWorker||this._workerId!==-1&&e.vsWorker!==this._workerId||this._handleMessage(e)}_handleMessage(e){switch(e.type){case 1:return this._handleReplyMessage(e);case 0:return this._handleRequestMessage(e);case 2:return this._handleSubscribeEventMessage(e);case 3:return this._handleEventMessage(e);case 4:return this._handleUnsubscribeEventMessage(e)}}_handleReplyMessage(e){if(!this._pendingReplies[e.seq]){console.warn("Got reply to unknown seq");return}const t=this._pendingReplies[e.seq];if(delete this._pendingReplies[e.seq],e.err){let i=e.err;e.err.$isError&&(i=new Error,i.name=e.err.name,i.message=e.err.message,i.stack=e.err.stack),t.reject(i);return}t.resolve(e.res)}_handleRequestMessage(e){const t=e.req;this._handler.handleMessage(e.method,e.args).then(n=>{this._send(new N5(this._workerId,t,n,void 0))},n=>{n.detail instanceof Error&&(n.detail=t5(n.detail)),this._send(new N5(this._workerId,t,void 0,t5(n)))})}_handleSubscribeEventMessage(e){const t=e.req,i=this._handler.handleEvent(e.eventName,e.arg)(n=>{this._send(new hte(this._workerId,t,n))});this._pendingEvents.set(t,i)}_handleEventMessage(e){if(!this._pendingEmitters.has(e.req)){console.warn("Got event for unknown req");return}this._pendingEmitters.get(e.req).fire(e.event)}_handleUnsubscribeEventMessage(e){if(!this._pendingEvents.has(e.req)){console.warn("Got unsubscribe for unknown req");return}this._pendingEvents.get(e.req).dispose(),this._pendingEvents.delete(e.req)}_send(e){const t=[];if(e.type===0)for(let i=0;i<e.args.length;i++)e.args[i]instanceof ArrayBuffer&&t.push(e.args[i]);else e.type===1&&e.res instanceof ArrayBuffer&&t.push(e.res);this._handler.sendMessage(e,t)}}class pte extends j{constructor(e,t,i){super();let n=null;this._worker=this._register(e.create("vs/base/common/worker/simpleWorker",c=>{this._protocol.handleMessage(c)},c=>{n==null||n(c)})),this._protocol=new fte({sendMessage:(c,u)=>{this._worker.postMessage(c,u)},handleMessage:(c,u)=>{if(typeof i[c]!="function")return Promise.reject(new Error("Missing method "+c+" on main thread host."));try{return Promise.resolve(i[c].apply(i,u))}catch(h){return Promise.reject(h)}},handleEvent:(c,u)=>{if(MV(c)){const h=i[c].call(i,u);if(typeof h!="function")throw new Error(`Missing dynamic event ${c} on main thread host.`);return h}if(TV(c)){const h=i[c];if(typeof h!="function")throw new Error(`Missing event ${c} on main thread host.`);return h}throw new Error(`Malformed event name ${c}`)}}),this._protocol.setWorkerId(this._worker.getId());let o=null;const r=globalThis.require;typeof r<"u"&&typeof r.getConfig=="function"?o=r.getConfig():typeof globalThis.requirejs<"u"&&(o=globalThis.requirejs.s.contexts._.config);const a=yA(i);this._onModuleLoaded=this._protocol.sendMessage(dte,[this._worker.getId(),JSON.parse(JSON.stringify(o)),t,a]);const l=(c,u)=>this._request(c,u),d=(c,u)=>this._protocol.listen(c,u);this._lazyProxy=new Promise((c,u)=>{n=u,this._onModuleLoaded.then(h=>{c(mte(h,l,d))},h=>{u(h),this._onError("Worker failed to load "+t,h)})})}getProxyObject(){return this._lazyProxy}_request(e,t){return new Promise((i,n)=>{this._onModuleLoaded.then(()=>{this._protocol.sendMessage(e,t).then(i,n)},n)})}_onError(e,t){console.error(e),console.info(t)}}function TV(s){return s[0]==="o"&&s[1]==="n"&&ul(s.charCodeAt(2))}function MV(s){return/^onDynamic/.test(s)&&ul(s.charCodeAt(9))}function mte(s,e,t){const i=r=>function(){const a=Array.prototype.slice.call(arguments,0);return e(r,a)},n=r=>function(a){return t(r,a)},o={};for(const r of s){if(MV(r)){o[r]=n(r);continue}if(TV(r)){o[r]=t(r,void 0);continue}o[r]=i(r)}return o}function oc(s,e){var t;const i=globalThis.MonacoEnvironment;if(i!=null&&i.createTrustedTypesPolicy)try{return i.createTrustedTypesPolicy(s,e)}catch(n){et(n);return}try{return(t=Ci.trustedTypes)===null||t===void 0?void 0:t.createPolicy(s,e)}catch(n){et(n);return}}const T5=oc("defaultWorkerFactory",{createScriptURL:s=>s});function _te(s){const e=globalThis.MonacoEnvironment;if(e){if(typeof e.getWorker=="function")return e.getWorker("workerMain.js",s);if(typeof e.getWorkerUrl=="function"){const t=e.getWorkerUrl("workerMain.js",s);return new Worker(T5?T5.createScriptURL(t):t,{name:s})}}throw new Error("You must define a function MonacoEnvironment.getWorkerUrl or MonacoEnvironment.getWorker")}function vte(s){return typeof s.then=="function"}class bte{constructor(e,t,i,n,o){this.id=t,this.label=i;const r=_te(i);vte(r)?this.worker=r:this.worker=Promise.resolve(r),this.postMessage(e,[]),this.worker.then(a=>{a.onmessage=function(l){n(l.data)},a.onmessageerror=o,typeof a.addEventListener=="function"&&a.addEventListener("error",o)})}getId(){return this.id}postMessage(e,t){var i;(i=this.worker)===null||i===void 0||i.then(n=>{try{n.postMessage(e,t)}catch(o){et(o),et(new Error(`FAILED to post message to '${this.label}'-worker`,{cause:o}))}})}dispose(){var e;(e=this.worker)===null||e===void 0||e.then(t=>t.terminate()),this.worker=null}}class ux{constructor(e){this._label=e,this._webWorkerFailedBeforeError=!1}create(e,t,i){const n=++ux.LAST_WORKER_ID;if(this._webWorkerFailedBeforeError)throw this._webWorkerFailedBeforeError;return new bte(e,n,this._label||"anonymous"+n,t,o=>{QN(o),this._webWorkerFailedBeforeError=o,i(o)})}}ux.LAST_WORKER_ID=0;var nn;(function(s){s[s.None=0]="None",s[s.Indent=1]="Indent",s[s.IndentOutdent=2]="IndentOutdent",s[s.Outdent=3]="Outdent"})(nn||(nn={}));class $k{constructor(e){if(this._neutralCharacter=null,this._neutralCharacterSearched=!1,this.open=e.open,this.close=e.close,this._inString=!0,this._inComment=!0,this._inRegEx=!0,Array.isArray(e.notIn))for(let t=0,i=e.notIn.length;t<i;t++)switch(e.notIn[t]){case"string":this._inString=!1;break;case"comment":this._inComment=!1;break;case"regex":this._inRegEx=!1;break}}isOK(e){switch(e){case 0:return!0;case 1:return this._inComment;case 2:return this._inString;case 3:return this._inRegEx}}shouldAutoClose(e,t){if(e.getTokenCount()===0)return!0;const i=e.findTokenIndexAtOffset(t-2),n=e.getStandardTokenType(i);return this.isOK(n)}_findNeutralCharacterInRange(e,t){for(let i=e;i<=t;i++){const n=String.fromCharCode(i);if(!this.open.includes(n)&&!this.close.includes(n))return n}return null}findNeutralCharacter(){return this._neutralCharacterSearched||(this._neutralCharacterSearched=!0,this._neutralCharacter||(this._neutralCharacter=this._findNeutralCharacterInRange(48,57)),this._neutralCharacter||(this._neutralCharacter=this._findNeutralCharacterInRange(97,122)),this._neutralCharacter||(this._neutralCharacter=this._findNeutralCharacterInRange(65,90))),this._neutralCharacter}}class Cte{constructor(e){this.autoClosingPairsOpenByStart=new Map,this.autoClosingPairsOpenByEnd=new Map,this.autoClosingPairsCloseByStart=new Map,this.autoClosingPairsCloseByEnd=new Map,this.autoClosingPairsCloseSingleChar=new Map;for(const t of e)N_(this.autoClosingPairsOpenByStart,t.open.charAt(0),t),N_(this.autoClosingPairsOpenByEnd,t.open.charAt(t.open.length-1),t),N_(this.autoClosingPairsCloseByStart,t.close.charAt(0),t),N_(this.autoClosingPairsCloseByEnd,t.close.charAt(t.close.length-1),t),t.close.length===1&&t.open.length===1&&N_(this.autoClosingPairsCloseSingleChar,t.close,t)}}function N_(s,e,t){s.has(e)?s.get(e).push(t):s.set(e,[t])}function hx(s,e){const t=s.getCount(),i=s.findTokenIndexAtOffset(e),n=s.getLanguageId(i);let o=i;for(;o+1<t&&s.getLanguageId(o+1)===n;)o++;let r=i;for(;r>0&&s.getLanguageId(r-1)===n;)r--;return new wte(s,n,r,o+1,s.getStartOffset(r),s.getEndOffset(o))}class wte{constructor(e,t,i,n,o,r){this._scopedLineTokensBrand=void 0,this._actual=e,this.languageId=t,this._firstTokenIndex=i,this._lastTokenIndex=n,this.firstCharOffset=o,this._lastCharOffset=r}getLineContent(){return this._actual.getLineContent().substring(this.firstCharOffset,this._lastCharOffset)}getActualLineContentBefore(e){return this._actual.getLineContent().substring(0,this.firstCharOffset+e)}getTokenCount(){return this._lastTokenIndex-this._firstTokenIndex}findTokenIndexAtOffset(e){return this._actual.findTokenIndexAtOffset(e+this.firstCharOffset)-this._firstTokenIndex}getStandardTokenType(e){return this._actual.getStandardTokenType(e+this._firstTokenIndex)}}function ol(s){return(s&3)!==0}class um{constructor(e){if(e.autoClosingPairs?this._autoClosingPairs=e.autoClosingPairs.map(t=>new $k(t)):e.brackets?this._autoClosingPairs=e.brackets.map(t=>new $k({open:t[0],close:t[1]})):this._autoClosingPairs=[],e.__electricCharacterSupport&&e.__electricCharacterSupport.docComment){const t=e.__electricCharacterSupport.docComment;this._autoClosingPairs.push(new $k({open:t.open,close:t.close||""}))}this._autoCloseBeforeForQuotes=typeof e.autoCloseBefore=="string"?e.autoCloseBefore:um.DEFAULT_AUTOCLOSE_BEFORE_LANGUAGE_DEFINED_QUOTES,this._autoCloseBeforeForBrackets=typeof e.autoCloseBefore=="string"?e.autoCloseBefore:um.DEFAULT_AUTOCLOSE_BEFORE_LANGUAGE_DEFINED_BRACKETS,this._surroundingPairs=e.surroundingPairs||this._autoClosingPairs}getAutoClosingPairs(){return this._autoClosingPairs}getAutoCloseBeforeSet(e){return e?this._autoCloseBeforeForQuotes:this._autoCloseBeforeForBrackets}getSurroundingPairs(){return this._surroundingPairs}}um.DEFAULT_AUTOCLOSE_BEFORE_LANGUAGE_DEFINED_QUOTES=`;:.,=}])> 
	`;um.DEFAULT_AUTOCLOSE_BEFORE_LANGUAGE_DEFINED_BRACKETS=`'"\`;:.,=}])> 
	`;const M5=typeof Buffer<"u";let jk;class gx{static wrap(e){return M5&&!Buffer.isBuffer(e)&&(e=Buffer.from(e.buffer,e.byteOffset,e.byteLength)),new gx(e)}constructor(e){this.buffer=e,this.byteLength=this.buffer.byteLength}toString(){return M5?this.buffer.toString():(jk||(jk=new TextDecoder),jk.decode(this.buffer))}}function Ste(s,e){return s[e+0]<<0>>>0|s[e+1]<<8>>>0}function yte(s,e,t){s[t+0]=e&255,e=e>>>8,s[t+1]=e&255}function fa(s,e){return s[e]*2**24+s[e+1]*2**16+s[e+2]*2**8+s[e+3]}function pa(s,e,t){s[t+3]=e,e=e>>>8,s[t+2]=e,e=e>>>8,s[t+1]=e,e=e>>>8,s[t]=e}function R5(s,e){return s[e]}function A5(s,e,t){s[t]=e}let Kk;function RV(){return Kk||(Kk=new TextDecoder("UTF-16LE")),Kk}let qk;function Lte(){return qk||(qk=new TextDecoder("UTF-16BE")),qk}let Gk;function AV(){return Gk||(Gk=bW()?RV():Lte()),Gk}function xte(s,e,t){const i=new Uint16Array(s.buffer,e,t);return t>0&&(i[0]===65279||i[0]===65534)?Dte(s,e,t):RV().decode(i)}function Dte(s,e,t){const i=[];let n=0;for(let o=0;o<t;o++){const r=Ste(s,e);e+=2,i[n++]=String.fromCharCode(r)}return i.join("")}class s_{constructor(e){this._capacity=e|0,this._buffer=new Uint16Array(this._capacity),this._completedStrings=null,this._bufferLength=0}reset(){this._completedStrings=null,this._bufferLength=0}build(){return this._completedStrings!==null?(this._flushBuffer(),this._completedStrings.join("")):this._buildBuffer()}_buildBuffer(){if(this._bufferLength===0)return"";const e=new Uint16Array(this._buffer.buffer,0,this._bufferLength);return AV().decode(e)}_flushBuffer(){const e=this._buildBuffer();this._bufferLength=0,this._completedStrings===null?this._completedStrings=[e]:this._completedStrings[this._completedStrings.length]=e}appendCharCode(e){const t=this._capacity-this._bufferLength;t<=1&&(t===0||_n(e))&&this._flushBuffer(),this._buffer[this._bufferLength++]=e}appendASCIICharCode(e){this._bufferLength===this._capacity&&this._flushBuffer(),this._buffer[this._bufferLength++]=e}appendString(e){const t=e.length;if(this._bufferLength+t>=this._capacity){this._flushBuffer(),this._completedStrings[this._completedStrings.length]=e;return}for(let i=0;i<t;i++)this._buffer[this._bufferLength++]=e.charCodeAt(i)}}class VS{constructor(e,t,i,n,o,r){this._richEditBracketBrand=void 0,this.languageId=e,this.index=t,this.open=i,this.close=n,this.forwardRegex=o,this.reversedRegex=r,this._openSet=VS._toSet(this.open),this._closeSet=VS._toSet(this.close)}isOpen(e){return this._openSet.has(e)}isClose(e){return this._closeSet.has(e)}static _toSet(e){const t=new Set;for(const i of e)t.add(i);return t}}function kte(s){const e=s.length;s=s.map(r=>[r[0].toLowerCase(),r[1].toLowerCase()]);const t=[];for(let r=0;r<e;r++)t[r]=r;const i=(r,a)=>{const[l,d]=r,[c,u]=a;return l===c||l===u||d===c||d===u},n=(r,a)=>{const l=Math.min(r,a),d=Math.max(r,a);for(let c=0;c<e;c++)t[c]===d&&(t[c]=l)};for(let r=0;r<e;r++){const a=s[r];for(let l=r+1;l<e;l++){const d=s[l];i(a,d)&&n(t[r],t[l])}}const o=[];for(let r=0;r<e;r++){const a=[],l=[];for(let d=0;d<e;d++)if(t[d]===r){const[c,u]=s[d];a.push(c),l.push(u)}a.length>0&&o.push({open:a,close:l})}return o}class Ite{constructor(e,t){this._richEditBracketsBrand=void 0;const i=kte(t);this.brackets=i.map((n,o)=>new VS(e,o,n.open,n.close,Ete(n.open,n.close,i,o),Nte(n.open,n.close,i,o))),this.forwardRegex=Tte(this.brackets),this.reversedRegex=Mte(this.brackets),this.textIsBracket={},this.textIsOpenBracket={},this.maxBracketLength=0;for(const n of this.brackets){for(const o of n.open)this.textIsBracket[o]=n,this.textIsOpenBracket[o]=!0,this.maxBracketLength=Math.max(this.maxBracketLength,o.length);for(const o of n.close)this.textIsBracket[o]=n,this.textIsOpenBracket[o]=!1,this.maxBracketLength=Math.max(this.maxBracketLength,o.length)}}}function PV(s,e,t,i){for(let n=0,o=e.length;n<o;n++){if(n===t)continue;const r=e[n];for(const a of r.open)a.indexOf(s)>=0&&i.push(a);for(const a of r.close)a.indexOf(s)>=0&&i.push(a)}}function OV(s,e){return s.length-e.length}function fx(s){if(s.length<=1)return s;const e=[],t=new Set;for(const i of s)t.has(i)||(e.push(i),t.add(i));return e}function Ete(s,e,t,i){let n=[];n=n.concat(s),n=n.concat(e);for(let o=0,r=n.length;o<r;o++)PV(n[o],t,i,n);return n=fx(n),n.sort(OV),n.reverse(),px(n)}function Nte(s,e,t,i){let n=[];n=n.concat(s),n=n.concat(e);for(let o=0,r=n.length;o<r;o++)PV(n[o],t,i,n);return n=fx(n),n.sort(OV),n.reverse(),px(n.map(nP))}function Tte(s){let e=[];for(const t of s){for(const i of t.open)e.push(i);for(const i of t.close)e.push(i)}return e=fx(e),px(e)}function Mte(s){let e=[];for(const t of s){for(const i of t.open)e.push(i);for(const i of t.close)e.push(i)}return e=fx(e),px(e.map(nP))}function Rte(s){const e=/^[\w ]+$/.test(s);return s=ir(s),e?`\\b${s}\\b`:s}function px(s){const e=`(${s.map(Rte).join(")|(")})`;return zW(e,!0)}const nP=function(){function s(i){const n=new Uint16Array(i.length);let o=0;for(let r=i.length-1;r>=0;r--)n[o++]=i.charCodeAt(r);return AV().decode(n)}let e=null,t=null;return function(n){return e!==n&&(e=n,t=s(e)),t}}();class Or{static _findPrevBracketInText(e,t,i,n){const o=i.match(e);if(!o)return null;const r=i.length-(o.index||0),a=o[0].length,l=n+r;return new D(t,l-a+1,t,l+1)}static findPrevBracketInRange(e,t,i,n,o){const a=nP(i).substring(i.length-o,i.length-n);return this._findPrevBracketInText(e,t,a,n)}static findNextBracketInText(e,t,i,n){const o=i.match(e);if(!o)return null;const r=o.index||0,a=o[0].length;if(a===0)return null;const l=n+r;return new D(t,l+1,t,l+1+a)}static findNextBracketInRange(e,t,i,n,o){const r=i.substring(n,o);return this.findNextBracketInText(e,t,r,n)}}class Ate{constructor(e){this._richEditBrackets=e}getElectricCharacters(){const e=[];if(this._richEditBrackets)for(const t of this._richEditBrackets.brackets)for(const i of t.close){const n=i.charAt(i.length-1);e.push(n)}return Lu(e)}onElectricCharacter(e,t,i){if(!this._richEditBrackets||this._richEditBrackets.brackets.length===0)return null;const n=t.findTokenIndexAtOffset(i-1);if(ol(t.getStandardTokenType(n)))return null;const o=this._richEditBrackets.reversedRegex,r=t.getLineContent().substring(0,i-1)+e,a=Or.findPrevBracketInRange(o,1,r,0,r.length);if(!a)return null;const l=r.substring(a.startColumn-1,a.endColumn-1).toLowerCase();if(this._richEditBrackets.textIsOpenBracket[l])return null;const c=t.getActualLineContentBefore(a.startColumn-1);return/^\s*$/.test(c)?{matchOpenBracket:l}:null}}function d1(s){return s.global&&(s.lastIndex=0),!0}class Pte{constructor(e){this._indentationRules=e}shouldIncrease(e){return!!(this._indentationRules&&this._indentationRules.increaseIndentPattern&&d1(this._indentationRules.increaseIndentPattern)&&this._indentationRules.increaseIndentPattern.test(e))}shouldDecrease(e){return!!(this._indentationRules&&this._indentationRules.decreaseIndentPattern&&d1(this._indentationRules.decreaseIndentPattern)&&this._indentationRules.decreaseIndentPattern.test(e))}shouldIndentNextLine(e){return!!(this._indentationRules&&this._indentationRules.indentNextLinePattern&&d1(this._indentationRules.indentNextLinePattern)&&this._indentationRules.indentNextLinePattern.test(e))}shouldIgnore(e){return!!(this._indentationRules&&this._indentationRules.unIndentedLinePattern&&d1(this._indentationRules.unIndentedLinePattern)&&this._indentationRules.unIndentedLinePattern.test(e))}getIndentMetadata(e){let t=0;return this.shouldIncrease(e)&&(t+=1),this.shouldDecrease(e)&&(t+=2),this.shouldIndentNextLine(e)&&(t+=4),this.shouldIgnore(e)&&(t+=8),t}}class op{constructor(e){e=e||{},e.brackets=e.brackets||[["(",")"],["{","}"],["[","]"]],this._brackets=[],e.brackets.forEach(t=>{const i=op._createOpenBracketRegExp(t[0]),n=op._createCloseBracketRegExp(t[1]);i&&n&&this._brackets.push({open:t[0],openRegExp:i,close:t[1],closeRegExp:n})}),this._regExpRules=e.onEnterRules||[]}onEnter(e,t,i,n){if(e>=3)for(let o=0,r=this._regExpRules.length;o<r;o++){const a=this._regExpRules[o];if([{reg:a.beforeText,text:i},{reg:a.afterText,text:n},{reg:a.previousLineText,text:t}].every(d=>d.reg?(d.reg.lastIndex=0,d.reg.test(d.text)):!0))return a.action}if(e>=2&&i.length>0&&n.length>0)for(let o=0,r=this._brackets.length;o<r;o++){const a=this._brackets[o];if(a.openRegExp.test(i)&&a.closeRegExp.test(n))return{indentAction:nn.IndentOutdent}}if(e>=2&&i.length>0){for(let o=0,r=this._brackets.length;o<r;o++)if(this._brackets[o].openRegExp.test(i))return{indentAction:nn.Indent}}return null}static _createOpenBracketRegExp(e){let t=ir(e);return/\B/.test(t.charAt(0))||(t="\\b"+t),t+="\\s*$",op._safeRegExp(t)}static _createCloseBracketRegExp(e){let t=ir(e);return/\B/.test(t.charAt(t.length-1))||(t=t+"\\b"),t="^\\s*"+t,op._safeRegExp(t)}static _safeRegExp(e){try{return new RegExp(e)}catch(t){return et(t),null}}}const mt=ut("configurationService");function JN(s,e){const t=Object.create(null);for(const i in s)FV(t,i,s[i],e);return t}function FV(s,e,t,i){const n=e.split("."),o=n.pop();let r=s;for(let a=0;a<n.length;a++){const l=n[a];let d=r[l];switch(typeof d){case"undefined":d=r[l]=Object.create(null);break;case"object":break;default:i(`Ignoring ${e} as ${n.slice(0,a+1).join(".")} is ${JSON.stringify(d)}`);return}r=d}if(typeof r=="object"&&r!==null)try{r[o]=t}catch{i(`Ignoring ${e} as ${n.join(".")} is ${JSON.stringify(r)}`)}else i(`Ignoring ${e} as ${n.join(".")} is ${JSON.stringify(r)}`)}function Ote(s,e){const t=e.split(".");BV(s,t)}function BV(s,e){const t=e.shift();if(e.length===0){delete s[t];return}if(Object.keys(s).indexOf(t)!==-1){const i=s[t];typeof i=="object"&&!Array.isArray(i)&&(BV(i,e),Object.keys(i).length===0&&delete s[t])}}function P5(s,e,t){function i(r,a){let l=r;for(const d of a){if(typeof l!="object"||l===null)return;l=l[d]}return l}const n=e.split("."),o=i(s,n);return typeof o>"u"?t:o}function Fte(s){return s.replace(/[\[\]]/g,"")}const fi=ut("languageService");class hl{constructor(e,t=[],i=!1){this.ctor=e,this.staticArguments=t,this.supportsDelayedInstantiation=i}}const WV=[];function _t(s,e,t){e instanceof hl||(e=new hl(e,[],!!t)),WV.push([s,e])}function O5(){return WV}const Hi=Object.freeze({text:"text/plain",binary:"application/octet-stream",unknown:"application/unknown",markdown:"text/markdown",latex:"text/latex",uriList:"text/uri-list"}),mx={JSONContribution:"base.contributions.json"};function Bte(s){return s.length>0&&s.charAt(s.length-1)==="#"?s.substring(0,s.length-1):s}class Wte{constructor(){this._onDidChangeSchema=new W,this.schemasById={}}registerSchema(e,t){this.schemasById[Bte(e)]=t,this._onDidChangeSchema.fire(e)}notifySchemaChanged(e){this._onDidChangeSchema.fire(e)}}const Vte=new Wte;Si.add(mx.JSONContribution,Vte);const Za={Configuration:"base.contributions.configuration"},T_="vscode://schemas/settings/resourceLanguage",F5=Si.as(mx.JSONContribution);class Hte{constructor(){this.overrideIdentifiers=new Set,this._onDidSchemaChange=new W,this._onDidUpdateConfiguration=new W,this.configurationDefaultsOverrides=new Map,this.defaultLanguageConfigurationOverridesNode={id:"defaultOverrides",title:p("defaultLanguageConfigurationOverrides.title","Default Language Configuration Overrides"),properties:{}},this.configurationContributors=[this.defaultLanguageConfigurationOverridesNode],this.resourceLanguageSettingsSchema={properties:{},patternProperties:{},additionalProperties:!0,allowTrailingCommas:!0,allowComments:!0},this.configurationProperties={},this.policyConfigurations=new Map,this.excludedConfigurationProperties={},F5.registerSchema(T_,this.resourceLanguageSettingsSchema),this.registerOverridePropertyPatternKey()}registerConfiguration(e,t=!0){this.registerConfigurations([e],t)}registerConfigurations(e,t=!0){const i=new Set;this.doRegisterConfigurations(e,t,i),F5.registerSchema(T_,this.resourceLanguageSettingsSchema),this._onDidSchemaChange.fire(),this._onDidUpdateConfiguration.fire({properties:i})}registerDefaultConfigurations(e){const t=new Set;this.doRegisterDefaultConfigurations(e,t),this._onDidSchemaChange.fire(),this._onDidUpdateConfiguration.fire({properties:t,defaultsOverrides:!0})}doRegisterDefaultConfigurations(e,t){var i;const n=[];for(const{overrides:o,source:r}of e)for(const a in o)if(t.add(a),Mu.test(a)){const l=this.configurationDefaultsOverrides.get(a),d=(i=l==null?void 0:l.valuesSources)!==null&&i!==void 0?i:new Map;if(r)for(const g of Object.keys(o[a]))d.set(g,r);const c={...(l==null?void 0:l.value)||{},...o[a]};this.configurationDefaultsOverrides.set(a,{source:r,value:c,valuesSources:d});const u=Fte(a),h={type:"object",default:c,description:p("defaultLanguageConfiguration.description","Configure settings to be overridden for the {0} language.",u),$ref:T_,defaultDefaultValue:c,source:Ps(r)?void 0:r,defaultValueSource:r};n.push(...HS(a)),this.configurationProperties[a]=h,this.defaultLanguageConfigurationOverridesNode.properties[a]=h}else{this.configurationDefaultsOverrides.set(a,{value:o[a],source:r});const l=this.configurationProperties[a];l&&(this.updatePropertyDefaultValue(a,l),this.updateSchema(a,l))}this.doRegisterOverrideIdentifiers(n)}registerOverrideIdentifiers(e){this.doRegisterOverrideIdentifiers(e),this._onDidSchemaChange.fire()}doRegisterOverrideIdentifiers(e){for(const t of e)this.overrideIdentifiers.add(t);this.updateOverridePropertyPatternKey()}doRegisterConfigurations(e,t,i){e.forEach(n=>{this.validateAndRegisterProperties(n,t,n.extensionInfo,n.restrictedProperties,void 0,i),this.configurationContributors.push(n),this.registerJSONConfiguration(n)})}validateAndRegisterProperties(e,t=!0,i,n,o=3,r){var a;o=Uo(e.scope)?o:e.scope;const l=e.properties;if(l)for(const c in l){const u=l[c];if(t&&$te(c,u)){delete l[c];continue}if(u.source=i,u.defaultDefaultValue=l[c].default,this.updatePropertyDefaultValue(c,u),Mu.test(c)?u.scope=void 0:(u.scope=Uo(u.scope)?o:u.scope,u.restricted=Uo(u.restricted)?!!(n!=null&&n.includes(c)):u.restricted),l[c].hasOwnProperty("included")&&!l[c].included){this.excludedConfigurationProperties[c]=l[c],delete l[c];continue}else this.configurationProperties[c]=l[c],!((a=l[c].policy)===null||a===void 0)&&a.name&&this.policyConfigurations.set(l[c].policy.name,c);!l[c].deprecationMessage&&l[c].markdownDeprecationMessage&&(l[c].deprecationMessage=l[c].markdownDeprecationMessage),r.add(c)}const d=e.allOf;if(d)for(const c of d)this.validateAndRegisterProperties(c,t,i,n,o,r)}getConfigurationProperties(){return this.configurationProperties}getPolicyConfigurations(){return this.policyConfigurations}registerJSONConfiguration(e){const t=i=>{const n=i.properties;if(n)for(const r in n)this.updateSchema(r,n[r]);const o=i.allOf;o==null||o.forEach(t)};t(e)}updateSchema(e,t){switch(t.scope){case 1:break;case 2:break;case 6:break;case 3:break;case 4:break;case 5:this.resourceLanguageSettingsSchema.properties[e]=t;break}}updateOverridePropertyPatternKey(){for(const e of this.overrideIdentifiers.values()){const t=`[${e}]`,i={type:"object",description:p("overrideSettings.defaultDescription","Configure editor settings to be overridden for a language."),errorMessage:p("overrideSettings.errorMessage","This setting does not support per-language configuration."),$ref:T_};this.updatePropertyDefaultValue(t,i)}}registerOverridePropertyPatternKey(){p("overrideSettings.defaultDescription","Configure editor settings to be overridden for a language."),p("overrideSettings.errorMessage","This setting does not support per-language configuration."),this._onDidSchemaChange.fire()}updatePropertyDefaultValue(e,t){const i=this.configurationDefaultsOverrides.get(e);let n=i==null?void 0:i.value,o=i==null?void 0:i.source;fo(n)&&(n=t.defaultDefaultValue,o=void 0),fo(n)&&(n=Ute(t.type)),t.default=n,t.defaultValueSource=o}}const VV="\\[([^\\]]+)\\]",B5=new RegExp(VV,"g"),zte=`^(${VV})+$`,Mu=new RegExp(zte);function HS(s){const e=[];if(Mu.test(s)){let t=B5.exec(s);for(;t!=null&&t.length;){const i=t[1].trim();i&&e.push(i),t=B5.exec(s)}}return Lu(e)}function Ute(s){switch(Array.isArray(s)?s[0]:s){case"boolean":return!1;case"integer":case"number":return 0;case"string":return"";case"array":return[];case"object":return{};default:return null}}const Rw=new Hte;Si.add(Za.Configuration,Rw);function $te(s,e){var t,i,n,o;return s.trim()?Mu.test(s)?p("config.property.languageDefault","Cannot register '{0}'. This matches property pattern '\\\\[.*\\\\]$' for describing language specific editor settings. Use 'configurationDefaults' contribution.",s):Rw.getConfigurationProperties()[s]!==void 0?p("config.property.duplicate","Cannot register '{0}'. This property is already registered.",s):!((t=e.policy)===null||t===void 0)&&t.name&&Rw.getPolicyConfigurations().get((i=e.policy)===null||i===void 0?void 0:i.name)!==void 0?p("config.policy.duplicate","Cannot register '{0}'. The associated policy {1} is already registered with {2}.",s,(n=e.policy)===null||n===void 0?void 0:n.name,Rw.getPolicyConfigurations().get((o=e.policy)===null||o===void 0?void 0:o.name)):null:p("config.property.empty","Cannot register an empty property")}const jte={ModesRegistry:"editor.modesRegistry"};class Kte{constructor(){this._onDidChangeLanguages=new W,this.onDidChangeLanguages=this._onDidChangeLanguages.event,this._languages=[]}registerLanguage(e){return this._languages.push(e),this._onDidChangeLanguages.fire(void 0),{dispose:()=>{for(let t=0,i=this._languages.length;t<i;t++)if(this._languages[t]===e){this._languages.splice(t,1);return}}}}getLanguages(){return this._languages}}const hm=new Kte;Si.add(jte.ModesRegistry,hm);const er="plaintext",qte=".txt";hm.registerLanguage({id:er,extensions:[qte],aliases:[p("plainText.alias","Plain Text"),"text"],mimetypes:[Hi.text]});Si.as(Za.Configuration).registerDefaultConfigurations([{overrides:{"[plaintext]":{"editor.unicodeHighlight.ambiguousCharacters":!1,"editor.unicodeHighlight.invisibleCharacters":!1}}}]);class Gte{constructor(e,t){this.languageId=e;const i=t.brackets?W5(t.brackets):[],n=new r5(a=>{const l=new Set;return{info:new Zte(this,a,l),closing:l}}),o=new r5(a=>{const l=new Set,d=new Set;return{info:new Yte(this,a,l,d),opening:l,openingColorized:d}});for(const[a,l]of i){const d=n.get(a),c=o.get(l);d.closing.add(c.info),c.opening.add(d.info)}const r=t.colorizedBracketPairs?W5(t.colorizedBracketPairs):i.filter(a=>!(a[0]==="<"&&a[1]===">"));for(const[a,l]of r){const d=n.get(a),c=o.get(l);d.closing.add(c.info),c.openingColorized.add(d.info),c.opening.add(d.info)}this._openingBrackets=new Map([...n.cachedValues].map(([a,l])=>[a,l.info])),this._closingBrackets=new Map([...o.cachedValues].map(([a,l])=>[a,l.info]))}get openingBrackets(){return[...this._openingBrackets.values()]}get closingBrackets(){return[...this._closingBrackets.values()]}getOpeningBracketInfo(e){return this._openingBrackets.get(e)}getClosingBracketInfo(e){return this._closingBrackets.get(e)}getBracketInfo(e){return this.getOpeningBracketInfo(e)||this.getClosingBracketInfo(e)}}function W5(s){return s.filter(([e,t])=>e!==""&&t!=="")}class HV{constructor(e,t){this.config=e,this.bracketText=t}get languageId(){return this.config.languageId}}class Zte extends HV{constructor(e,t,i){super(e,t),this.openedBrackets=i,this.isOpeningBracket=!0}}class Yte extends HV{constructor(e,t,i,n){super(e,t),this.openingBrackets=i,this.openingColorizedBrackets=n,this.isOpeningBracket=!1}closes(e){return e.config!==this.config?!1:this.openingBrackets.has(e)}closesColorized(e){return e.config!==this.config?!1:this.openingColorizedBrackets.has(e)}getOpeningBrackets(){return[...this.openingBrackets]}}var Xte=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},V5=function(s,e){return function(t,i){e(t,i,s)}};class Zk{constructor(e){this.languageId=e}affects(e){return this.languageId?this.languageId===e:!0}}const Jt=ut("languageConfigurationService");let eT=class extends j{constructor(e,t){super(),this.configurationService=e,this.languageService=t,this._registry=this._register(new tie),this.onDidChangeEmitter=this._register(new W),this.onDidChange=this.onDidChangeEmitter.event,this.configurations=new Map;const i=new Set(Object.values(tT));this._register(this.configurationService.onDidChangeConfiguration(n=>{const o=n.change.keys.some(a=>i.has(a)),r=n.change.overrides.filter(([a,l])=>l.some(d=>i.has(d))).map(([a])=>a);if(o)this.configurations.clear(),this.onDidChangeEmitter.fire(new Zk(void 0));else for(const a of r)this.languageService.isRegisteredLanguageId(a)&&(this.configurations.delete(a),this.onDidChangeEmitter.fire(new Zk(a)))})),this._register(this._registry.onDidChange(n=>{this.configurations.delete(n.languageId),this.onDidChangeEmitter.fire(new Zk(n.languageId))}))}register(e,t,i){return this._registry.register(e,t,i)}getLanguageConfiguration(e){let t=this.configurations.get(e);return t||(t=Qte(e,this._registry,this.configurationService,this.languageService),this.configurations.set(e,t)),t}};eT=Xte([V5(0,mt),V5(1,fi)],eT);function Qte(s,e,t,i){let n=e.getLanguageConfiguration(s);if(!n){if(!i.isRegisteredLanguageId(s))return new Op(s,{});n=new Op(s,{})}const o=Jte(n.languageId,t),r=UV([n.underlyingConfig,o]);return new Op(n.languageId,r)}const tT={brackets:"editor.language.brackets",colorizedBracketPairs:"editor.language.colorizedBracketPairs"};function Jte(s,e){const t=e.getValue(tT.brackets,{overrideIdentifier:s}),i=e.getValue(tT.colorizedBracketPairs,{overrideIdentifier:s});return{brackets:H5(t),colorizedBracketPairs:H5(i)}}function H5(s){if(Array.isArray(s))return s.map(e=>{if(!(!Array.isArray(e)||e.length!==2))return[e[0],e[1]]}).filter(e=>!!e)}function zV(s,e,t){const i=s.getLineContent(e);let n=Zt(i);return n.length>t-1&&(n=n.substring(0,t-1)),n}function Pp(s,e,t){s.tokenization.forceTokenization(e);const i=s.tokenization.getLineTokens(e),n=typeof t>"u"?s.getLineMaxColumn(e)-1:t-1;return hx(i,n)}class eie{constructor(e){this.languageId=e,this._resolved=null,this._entries=[],this._order=0,this._resolved=null}register(e,t){const i=new z5(e,t,++this._order);return this._entries.push(i),this._resolved=null,Fe(()=>{for(let n=0;n<this._entries.length;n++)if(this._entries[n]===i){this._entries.splice(n,1),this._resolved=null;break}})}getResolvedConfiguration(){if(!this._resolved){const e=this._resolve();e&&(this._resolved=new Op(this.languageId,e))}return this._resolved}_resolve(){return this._entries.length===0?null:(this._entries.sort(z5.cmp),UV(this._entries.map(e=>e.configuration)))}}function UV(s){let e={comments:void 0,brackets:void 0,wordPattern:void 0,indentationRules:void 0,onEnterRules:void 0,autoClosingPairs:void 0,surroundingPairs:void 0,autoCloseBefore:void 0,folding:void 0,colorizedBracketPairs:void 0,__electricCharacterSupport:void 0};for(const t of s)e={comments:t.comments||e.comments,brackets:t.brackets||e.brackets,wordPattern:t.wordPattern||e.wordPattern,indentationRules:t.indentationRules||e.indentationRules,onEnterRules:t.onEnterRules||e.onEnterRules,autoClosingPairs:t.autoClosingPairs||e.autoClosingPairs,surroundingPairs:t.surroundingPairs||e.surroundingPairs,autoCloseBefore:t.autoCloseBefore||e.autoCloseBefore,folding:t.folding||e.folding,colorizedBracketPairs:t.colorizedBracketPairs||e.colorizedBracketPairs,__electricCharacterSupport:t.__electricCharacterSupport||e.__electricCharacterSupport};return e}class z5{constructor(e,t,i){this.configuration=e,this.priority=t,this.order=i}static cmp(e,t){return e.priority===t.priority?e.order-t.order:e.priority-t.priority}}class U5{constructor(e){this.languageId=e}}class tie extends j{constructor(){super(),this._entries=new Map,this._onDidChange=this._register(new W),this.onDidChange=this._onDidChange.event,this._register(this.register(er,{brackets:[["(",")"],["[","]"],["{","}"]],surroundingPairs:[{open:"{",close:"}"},{open:"[",close:"]"},{open:"(",close:")"},{open:"<",close:">"},{open:'"',close:'"'},{open:"'",close:"'"},{open:"`",close:"`"}],colorizedBracketPairs:[],folding:{offSide:!0}},0))}register(e,t,i=0){let n=this._entries.get(e);n||(n=new eie(e),this._entries.set(e,n));const o=n.register(t,i);return this._onDidChange.fire(new U5(e)),Fe(()=>{o.dispose(),this._onDidChange.fire(new U5(e))})}getLanguageConfiguration(e){const t=this._entries.get(e);return(t==null?void 0:t.getResolvedConfiguration())||null}}class Op{constructor(e,t){this.languageId=e,this.underlyingConfig=t,this._brackets=null,this._electricCharacter=null,this._onEnterSupport=this.underlyingConfig.brackets||this.underlyingConfig.indentationRules||this.underlyingConfig.onEnterRules?new op(this.underlyingConfig):null,this.comments=Op._handleComments(this.underlyingConfig),this.characterPair=new um(this.underlyingConfig),this.wordDefinition=this.underlyingConfig.wordPattern||DA,this.indentationRules=this.underlyingConfig.indentationRules,this.underlyingConfig.indentationRules?this.indentRulesSupport=new Pte(this.underlyingConfig.indentationRules):this.indentRulesSupport=null,this.foldingRules=this.underlyingConfig.folding||{},this.bracketsNew=new Gte(e,this.underlyingConfig)}getWordDefinition(){return kA(this.wordDefinition)}get brackets(){return!this._brackets&&this.underlyingConfig.brackets&&(this._brackets=new Ite(this.languageId,this.underlyingConfig.brackets)),this._brackets}get electricCharacter(){return this._electricCharacter||(this._electricCharacter=new Ate(this.brackets)),this._electricCharacter}onEnter(e,t,i,n){return this._onEnterSupport?this._onEnterSupport.onEnter(e,t,i,n):null}getAutoClosingPairs(){return new Cte(this.characterPair.getAutoClosingPairs())}getAutoCloseBeforeSet(e){return this.characterPair.getAutoCloseBeforeSet(e)}getSurroundingPairs(){return this.characterPair.getSurroundingPairs()}static _handleComments(e){const t=e.comments;if(!t)return null;const i={};if(t.lineComment&&(i.lineCommentToken=t.lineComment),t.blockComment){const[n,o]=t.blockComment;i.blockCommentStartToken=n,i.blockCommentEndToken=o}return i}}_t(Jt,eT,1);class wc{constructor(e,t,i,n){this.originalStart=e,this.originalLength=t,this.modifiedStart=i,this.modifiedLength=n}getOriginalEnd(){return this.originalStart+this.originalLength}getModifiedEnd(){return this.modifiedStart+this.modifiedLength}}class $5{constructor(e){this.source=e}getElements(){const e=this.source,t=new Int32Array(e.length);for(let i=0,n=e.length;i<n;i++)t[i]=e.charCodeAt(i);return t}}function iie(s,e,t){return new vl(new $5(s),new $5(e)).ComputeDiff(t).changes}class Df{static Assert(e,t){if(!e)throw new Error(t)}}class kf{static Copy(e,t,i,n,o){for(let r=0;r<o;r++)i[n+r]=e[t+r]}static Copy2(e,t,i,n,o){for(let r=0;r<o;r++)i[n+r]=e[t+r]}}class j5{constructor(){this.m_changes=[],this.m_originalStart=1073741824,this.m_modifiedStart=1073741824,this.m_originalCount=0,this.m_modifiedCount=0}MarkNextChange(){(this.m_originalCount>0||this.m_modifiedCount>0)&&this.m_changes.push(new wc(this.m_originalStart,this.m_originalCount,this.m_modifiedStart,this.m_modifiedCount)),this.m_originalCount=0,this.m_modifiedCount=0,this.m_originalStart=1073741824,this.m_modifiedStart=1073741824}AddOriginalElement(e,t){this.m_originalStart=Math.min(this.m_originalStart,e),this.m_modifiedStart=Math.min(this.m_modifiedStart,t),this.m_originalCount++}AddModifiedElement(e,t){this.m_originalStart=Math.min(this.m_originalStart,e),this.m_modifiedStart=Math.min(this.m_modifiedStart,t),this.m_modifiedCount++}getChanges(){return(this.m_originalCount>0||this.m_modifiedCount>0)&&this.MarkNextChange(),this.m_changes}getReverseChanges(){return(this.m_originalCount>0||this.m_modifiedCount>0)&&this.MarkNextChange(),this.m_changes.reverse(),this.m_changes}}class vl{constructor(e,t,i=null){this.ContinueProcessingPredicate=i,this._originalSequence=e,this._modifiedSequence=t;const[n,o,r]=vl._getElements(e),[a,l,d]=vl._getElements(t);this._hasStrings=r&&d,this._originalStringElements=n,this._originalElementsOrHash=o,this._modifiedStringElements=a,this._modifiedElementsOrHash=l,this.m_forwardHistory=[],this.m_reverseHistory=[]}static _isStringArray(e){return e.length>0&&typeof e[0]=="string"}static _getElements(e){const t=e.getElements();if(vl._isStringArray(t)){const i=new Int32Array(t.length);for(let n=0,o=t.length;n<o;n++)i[n]=QA(t[n],0);return[t,i,!0]}return t instanceof Int32Array?[[],t,!1]:[[],new Int32Array(t),!1]}ElementsAreEqual(e,t){return this._originalElementsOrHash[e]!==this._modifiedElementsOrHash[t]?!1:this._hasStrings?this._originalStringElements[e]===this._modifiedStringElements[t]:!0}ElementsAreStrictEqual(e,t){if(!this.ElementsAreEqual(e,t))return!1;const i=vl._getStrictElement(this._originalSequence,e),n=vl._getStrictElement(this._modifiedSequence,t);return i===n}static _getStrictElement(e,t){return typeof e.getStrictElement=="function"?e.getStrictElement(t):null}OriginalElementsAreEqual(e,t){return this._originalElementsOrHash[e]!==this._originalElementsOrHash[t]?!1:this._hasStrings?this._originalStringElements[e]===this._originalStringElements[t]:!0}ModifiedElementsAreEqual(e,t){return this._modifiedElementsOrHash[e]!==this._modifiedElementsOrHash[t]?!1:this._hasStrings?this._modifiedStringElements[e]===this._modifiedStringElements[t]:!0}ComputeDiff(e){return this._ComputeDiff(0,this._originalElementsOrHash.length-1,0,this._modifiedElementsOrHash.length-1,e)}_ComputeDiff(e,t,i,n,o){const r=[!1];let a=this.ComputeDiffRecursive(e,t,i,n,r);return o&&(a=this.PrettifyChanges(a)),{quitEarly:r[0],changes:a}}ComputeDiffRecursive(e,t,i,n,o){for(o[0]=!1;e<=t&&i<=n&&this.ElementsAreEqual(e,i);)e++,i++;for(;t>=e&&n>=i&&this.ElementsAreEqual(t,n);)t--,n--;if(e>t||i>n){let u;return i<=n?(Df.Assert(e===t+1,"originalStart should only be one more than originalEnd"),u=[new wc(e,0,i,n-i+1)]):e<=t?(Df.Assert(i===n+1,"modifiedStart should only be one more than modifiedEnd"),u=[new wc(e,t-e+1,i,0)]):(Df.Assert(e===t+1,"originalStart should only be one more than originalEnd"),Df.Assert(i===n+1,"modifiedStart should only be one more than modifiedEnd"),u=[]),u}const r=[0],a=[0],l=this.ComputeRecursionPoint(e,t,i,n,r,a,o),d=r[0],c=a[0];if(l!==null)return l;if(!o[0]){const u=this.ComputeDiffRecursive(e,d,i,c,o);let h=[];return o[0]?h=[new wc(d+1,t-(d+1)+1,c+1,n-(c+1)+1)]:h=this.ComputeDiffRecursive(d+1,t,c+1,n,o),this.ConcatenateChanges(u,h)}return[new wc(e,t-e+1,i,n-i+1)]}WALKTRACE(e,t,i,n,o,r,a,l,d,c,u,h,g,f,m,_,v,b){let C=null,w=null,S=new j5,x=t,L=i,k=g[0]-_[0]-n,I=-1073741824,P=this.m_forwardHistory.length-1;do{const $=k+e;$===x||$<L&&d[$-1]<d[$+1]?(u=d[$+1],f=u-k-n,u<I&&S.MarkNextChange(),I=u,S.AddModifiedElement(u+1,f),k=$+1-e):(u=d[$-1]+1,f=u-k-n,u<I&&S.MarkNextChange(),I=u-1,S.AddOriginalElement(u,f+1),k=$-1-e),P>=0&&(d=this.m_forwardHistory[P],e=d[0],x=1,L=d.length-1)}while(--P>=-1);if(C=S.getReverseChanges(),b[0]){let $=g[0]+1,A=_[0]+1;if(C!==null&&C.length>0){const z=C[C.length-1];$=Math.max($,z.getOriginalEnd()),A=Math.max(A,z.getModifiedEnd())}w=[new wc($,h-$+1,A,m-A+1)]}else{S=new j5,x=r,L=a,k=g[0]-_[0]-l,I=1073741824,P=v?this.m_reverseHistory.length-1:this.m_reverseHistory.length-2;do{const $=k+o;$===x||$<L&&c[$-1]>=c[$+1]?(u=c[$+1]-1,f=u-k-l,u>I&&S.MarkNextChange(),I=u+1,S.AddOriginalElement(u+1,f+1),k=$+1-o):(u=c[$-1],f=u-k-l,u>I&&S.MarkNextChange(),I=u,S.AddModifiedElement(u+1,f+1),k=$-1-o),P>=0&&(c=this.m_reverseHistory[P],o=c[0],x=1,L=c.length-1)}while(--P>=-1);w=S.getChanges()}return this.ConcatenateChanges(C,w)}ComputeRecursionPoint(e,t,i,n,o,r,a){let l=0,d=0,c=0,u=0,h=0,g=0;e--,i--,o[0]=0,r[0]=0,this.m_forwardHistory=[],this.m_reverseHistory=[];const f=t-e+(n-i),m=f+1,_=new Int32Array(m),v=new Int32Array(m),b=n-i,C=t-e,w=e-i,S=t-n,L=(C-b)%2===0;_[b]=e,v[C]=t,a[0]=!1;for(let k=1;k<=f/2+1;k++){let I=0,P=0;c=this.ClipDiagonalBound(b-k,k,b,m),u=this.ClipDiagonalBound(b+k,k,b,m);for(let A=c;A<=u;A+=2){A===c||A<u&&_[A-1]<_[A+1]?l=_[A+1]:l=_[A-1]+1,d=l-(A-b)-w;const z=l;for(;l<t&&d<n&&this.ElementsAreEqual(l+1,d+1);)l++,d++;if(_[A]=l,l+d>I+P&&(I=l,P=d),!L&&Math.abs(A-C)<=k-1&&l>=v[A])return o[0]=l,r[0]=d,z<=v[A]&&1447>0&&k<=1448?this.WALKTRACE(b,c,u,w,C,h,g,S,_,v,l,t,o,d,n,r,L,a):null}const $=(I-e+(P-i)-k)/2;if(this.ContinueProcessingPredicate!==null&&!this.ContinueProcessingPredicate(I,$))return a[0]=!0,o[0]=I,r[0]=P,$>0&&1447>0&&k<=1448?this.WALKTRACE(b,c,u,w,C,h,g,S,_,v,l,t,o,d,n,r,L,a):(e++,i++,[new wc(e,t-e+1,i,n-i+1)]);h=this.ClipDiagonalBound(C-k,k,C,m),g=this.ClipDiagonalBound(C+k,k,C,m);for(let A=h;A<=g;A+=2){A===h||A<g&&v[A-1]>=v[A+1]?l=v[A+1]-1:l=v[A-1],d=l-(A-C)-S;const z=l;for(;l>e&&d>i&&this.ElementsAreEqual(l,d);)l--,d--;if(v[A]=l,L&&Math.abs(A-b)<=k&&l<=_[A])return o[0]=l,r[0]=d,z>=_[A]&&1447>0&&k<=1448?this.WALKTRACE(b,c,u,w,C,h,g,S,_,v,l,t,o,d,n,r,L,a):null}if(k<=1447){let A=new Int32Array(u-c+2);A[0]=b-c+1,kf.Copy2(_,c,A,1,u-c+1),this.m_forwardHistory.push(A),A=new Int32Array(g-h+2),A[0]=C-h+1,kf.Copy2(v,h,A,1,g-h+1),this.m_reverseHistory.push(A)}}return this.WALKTRACE(b,c,u,w,C,h,g,S,_,v,l,t,o,d,n,r,L,a)}PrettifyChanges(e){for(let t=0;t<e.length;t++){const i=e[t],n=t<e.length-1?e[t+1].originalStart:this._originalElementsOrHash.length,o=t<e.length-1?e[t+1].modifiedStart:this._modifiedElementsOrHash.length,r=i.originalLength>0,a=i.modifiedLength>0;for(;i.originalStart+i.originalLength<n&&i.modifiedStart+i.modifiedLength<o&&(!r||this.OriginalElementsAreEqual(i.originalStart,i.originalStart+i.originalLength))&&(!a||this.ModifiedElementsAreEqual(i.modifiedStart,i.modifiedStart+i.modifiedLength));){const d=this.ElementsAreStrictEqual(i.originalStart,i.modifiedStart);if(this.ElementsAreStrictEqual(i.originalStart+i.originalLength,i.modifiedStart+i.modifiedLength)&&!d)break;i.originalStart++,i.modifiedStart++}const l=[null];if(t<e.length-1&&this.ChangesOverlap(e[t],e[t+1],l)){e[t]=l[0],e.splice(t+1,1),t--;continue}}for(let t=e.length-1;t>=0;t--){const i=e[t];let n=0,o=0;if(t>0){const u=e[t-1];n=u.originalStart+u.originalLength,o=u.modifiedStart+u.modifiedLength}const r=i.originalLength>0,a=i.modifiedLength>0;let l=0,d=this._boundaryScore(i.originalStart,i.originalLength,i.modifiedStart,i.modifiedLength);for(let u=1;;u++){const h=i.originalStart-u,g=i.modifiedStart-u;if(h<n||g<o||r&&!this.OriginalElementsAreEqual(h,h+i.originalLength)||a&&!this.ModifiedElementsAreEqual(g,g+i.modifiedLength))break;const m=(h===n&&g===o?5:0)+this._boundaryScore(h,i.originalLength,g,i.modifiedLength);m>d&&(d=m,l=u)}i.originalStart-=l,i.modifiedStart-=l;const c=[null];if(t>0&&this.ChangesOverlap(e[t-1],e[t],c)){e[t-1]=c[0],e.splice(t,1),t++;continue}}if(this._hasStrings)for(let t=1,i=e.length;t<i;t++){const n=e[t-1],o=e[t],r=o.originalStart-n.originalStart-n.originalLength,a=n.originalStart,l=o.originalStart+o.originalLength,d=l-a,c=n.modifiedStart,u=o.modifiedStart+o.modifiedLength,h=u-c;if(r<5&&d<20&&h<20){const g=this._findBetterContiguousSequence(a,d,c,h,r);if(g){const[f,m]=g;(f!==n.originalStart+n.originalLength||m!==n.modifiedStart+n.modifiedLength)&&(n.originalLength=f-n.originalStart,n.modifiedLength=m-n.modifiedStart,o.originalStart=f+r,o.modifiedStart=m+r,o.originalLength=l-o.originalStart,o.modifiedLength=u-o.modifiedStart)}}}return e}_findBetterContiguousSequence(e,t,i,n,o){if(t<o||n<o)return null;const r=e+t-o+1,a=i+n-o+1;let l=0,d=0,c=0;for(let u=e;u<r;u++)for(let h=i;h<a;h++){const g=this._contiguousSequenceScore(u,h,o);g>0&&g>l&&(l=g,d=u,c=h)}return l>0?[d,c]:null}_contiguousSequenceScore(e,t,i){let n=0;for(let o=0;o<i;o++){if(!this.ElementsAreEqual(e+o,t+o))return 0;n+=this._originalStringElements[e+o].length}return n}_OriginalIsBoundary(e){return e<=0||e>=this._originalElementsOrHash.length-1?!0:this._hasStrings&&/^\s*$/.test(this._originalStringElements[e])}_OriginalRegionIsBoundary(e,t){if(this._OriginalIsBoundary(e)||this._OriginalIsBoundary(e-1))return!0;if(t>0){const i=e+t;if(this._OriginalIsBoundary(i-1)||this._OriginalIsBoundary(i))return!0}return!1}_ModifiedIsBoundary(e){return e<=0||e>=this._modifiedElementsOrHash.length-1?!0:this._hasStrings&&/^\s*$/.test(this._modifiedStringElements[e])}_ModifiedRegionIsBoundary(e,t){if(this._ModifiedIsBoundary(e)||this._ModifiedIsBoundary(e-1))return!0;if(t>0){const i=e+t;if(this._ModifiedIsBoundary(i-1)||this._ModifiedIsBoundary(i))return!0}return!1}_boundaryScore(e,t,i,n){const o=this._OriginalRegionIsBoundary(e,t)?1:0,r=this._ModifiedRegionIsBoundary(i,n)?1:0;return o+r}ConcatenateChanges(e,t){const i=[];if(e.length===0||t.length===0)return t.length>0?t:e;if(this.ChangesOverlap(e[e.length-1],t[0],i)){const n=new Array(e.length+t.length-1);return kf.Copy(e,0,n,0,e.length-1),n[e.length-1]=i[0],kf.Copy(t,1,n,e.length,t.length-1),n}else{const n=new Array(e.length+t.length);return kf.Copy(e,0,n,0,e.length),kf.Copy(t,0,n,e.length,t.length),n}}ChangesOverlap(e,t,i){if(Df.Assert(e.originalStart<=t.originalStart,"Left change is not less than or equal to right change"),Df.Assert(e.modifiedStart<=t.modifiedStart,"Left change is not less than or equal to right change"),e.originalStart+e.originalLength>=t.originalStart||e.modifiedStart+e.modifiedLength>=t.modifiedStart){const n=e.originalStart;let o=e.originalLength;const r=e.modifiedStart;let a=e.modifiedLength;return e.originalStart+e.originalLength>=t.originalStart&&(o=t.originalStart+t.originalLength-e.originalStart),e.modifiedStart+e.modifiedLength>=t.modifiedStart&&(a=t.modifiedStart+t.modifiedLength-e.modifiedStart),i[0]=new wc(n,o,r,a),!0}else return i[0]=null,!1}ClipDiagonalBound(e,t,i,n){if(e>=0&&e<n)return e;const o=i,r=n-i-1,a=t%2===0;if(e<0){const l=o%2===0;return a===l?0:1}else{const l=r%2===0;return a===l?n-1:n-2}}}function zS(s){return s<0?0:s>255?255:s|0}function If(s){return s<0?0:s>4294967295?4294967295:s|0}class nie{constructor(e){this.values=e,this.prefixSum=new Uint32Array(e.length),this.prefixSumValidIndex=new Int32Array(1),this.prefixSumValidIndex[0]=-1}insertValues(e,t){e=If(e);const i=this.values,n=this.prefixSum,o=t.length;return o===0?!1:(this.values=new Uint32Array(i.length+o),this.values.set(i.subarray(0,e),0),this.values.set(i.subarray(e),e+o),this.values.set(t,e),e-1<this.prefixSumValidIndex[0]&&(this.prefixSumValidIndex[0]=e-1),this.prefixSum=new Uint32Array(this.values.length),this.prefixSumValidIndex[0]>=0&&this.prefixSum.set(n.subarray(0,this.prefixSumValidIndex[0]+1)),!0)}setValue(e,t){return e=If(e),t=If(t),this.values[e]===t?!1:(this.values[e]=t,e-1<this.prefixSumValidIndex[0]&&(this.prefixSumValidIndex[0]=e-1),!0)}removeValues(e,t){e=If(e),t=If(t);const i=this.values,n=this.prefixSum;if(e>=i.length)return!1;const o=i.length-e;return t>=o&&(t=o),t===0?!1:(this.values=new Uint32Array(i.length-t),this.values.set(i.subarray(0,e),0),this.values.set(i.subarray(e+t),e),this.prefixSum=new Uint32Array(this.values.length),e-1<this.prefixSumValidIndex[0]&&(this.prefixSumValidIndex[0]=e-1),this.prefixSumValidIndex[0]>=0&&this.prefixSum.set(n.subarray(0,this.prefixSumValidIndex[0]+1)),!0)}getTotalSum(){return this.values.length===0?0:this._getPrefixSum(this.values.length-1)}getPrefixSum(e){return e<0?0:(e=If(e),this._getPrefixSum(e))}_getPrefixSum(e){if(e<=this.prefixSumValidIndex[0])return this.prefixSum[e];let t=this.prefixSumValidIndex[0]+1;t===0&&(this.prefixSum[0]=this.values[0],t++),e>=this.values.length&&(e=this.values.length-1);for(let i=t;i<=e;i++)this.prefixSum[i]=this.prefixSum[i-1]+this.values[i];return this.prefixSumValidIndex[0]=Math.max(this.prefixSumValidIndex[0],e),this.prefixSum[e]}getIndexOf(e){e=Math.floor(e),this.getTotalSum();let t=0,i=this.values.length-1,n=0,o=0,r=0;for(;t<=i;)if(n=t+(i-t)/2|0,o=this.prefixSum[n],r=o-this.values[n],e<r)i=n-1;else if(e>=o)t=n+1;else break;return new $V(n,e-r)}}class sie{constructor(e){this._values=e,this._isValid=!1,this._validEndIndex=-1,this._prefixSum=[],this._indexBySum=[]}getTotalSum(){return this._ensureValid(),this._indexBySum.length}getPrefixSum(e){return this._ensureValid(),e===0?0:this._prefixSum[e-1]}getIndexOf(e){this._ensureValid();const t=this._indexBySum[e],i=t>0?this._prefixSum[t-1]:0;return new $V(t,e-i)}removeValues(e,t){this._values.splice(e,t),this._invalidate(e)}insertValues(e,t){this._values=$L(this._values,e,t),this._invalidate(e)}_invalidate(e){this._isValid=!1,this._validEndIndex=Math.min(this._validEndIndex,e-1)}_ensureValid(){if(!this._isValid){for(let e=this._validEndIndex+1,t=this._values.length;e<t;e++){const i=this._values[e],n=e>0?this._prefixSum[e-1]:0;this._prefixSum[e]=n+i;for(let o=0;o<i;o++)this._indexBySum[n+o]=e}this._prefixSum.length=this._values.length,this._indexBySum.length=this._prefixSum[this._prefixSum.length-1],this._isValid=!0,this._validEndIndex=this._values.length-1}}setValue(e,t){this._values[e]!==t&&(this._values[e]=t,this._invalidate(e))}}class $V{constructor(e,t){this.index=e,this.remainder=t,this._prefixSumIndexOfResultBrand=void 0,this.index=e,this.remainder=t}}class oie{constructor(e,t,i,n){this._uri=e,this._lines=t,this._eol=i,this._versionId=n,this._lineStarts=null,this._cachedTextValue=null}dispose(){this._lines.length=0}get version(){return this._versionId}getText(){return this._cachedTextValue===null&&(this._cachedTextValue=this._lines.join(this._eol)),this._cachedTextValue}onEvents(e){e.eol&&e.eol!==this._eol&&(this._eol=e.eol,this._lineStarts=null);const t=e.changes;for(const i of t)this._acceptDeleteRange(i.range),this._acceptInsertText(new H(i.range.startLineNumber,i.range.startColumn),i.text);this._versionId=e.versionId,this._cachedTextValue=null}_ensureLineStarts(){if(!this._lineStarts){const e=this._eol.length,t=this._lines.length,i=new Uint32Array(t);for(let n=0;n<t;n++)i[n]=this._lines[n].length+e;this._lineStarts=new nie(i)}}_setLineText(e,t){this._lines[e]=t,this._lineStarts&&this._lineStarts.setValue(e,this._lines[e].length+this._eol.length)}_acceptDeleteRange(e){if(e.startLineNumber===e.endLineNumber){if(e.startColumn===e.endColumn)return;this._setLineText(e.startLineNumber-1,this._lines[e.startLineNumber-1].substring(0,e.startColumn-1)+this._lines[e.startLineNumber-1].substring(e.endColumn-1));return}this._setLineText(e.startLineNumber-1,this._lines[e.startLineNumber-1].substring(0,e.startColumn-1)+this._lines[e.endLineNumber-1].substring(e.endColumn-1)),this._lines.splice(e.startLineNumber,e.endLineNumber-e.startLineNumber),this._lineStarts&&this._lineStarts.removeValues(e.startLineNumber,e.endLineNumber-e.startLineNumber)}_acceptInsertText(e,t){if(t.length===0)return;const i=Kl(t);if(i.length===1){this._setLineText(e.lineNumber-1,this._lines[e.lineNumber-1].substring(0,e.column-1)+i[0]+this._lines[e.lineNumber-1].substring(e.column-1));return}i[i.length-1]+=this._lines[e.lineNumber-1].substring(e.column-1),this._setLineText(e.lineNumber-1,this._lines[e.lineNumber-1].substring(0,e.column-1)+i[0]);const n=new Uint32Array(i.length-1);for(let o=1;o<i.length;o++)this._lines.splice(e.lineNumber+o-1,0,i[o]),n[o-1]=i[o].length+this._eol.length;this._lineStarts&&this._lineStarts.insertValues(e.lineNumber,n)}}class o_{constructor(e){const t=zS(e);this._defaultValue=t,this._asciiMap=o_._createAsciiMap(t),this._map=new Map}static _createAsciiMap(e){const t=new Uint8Array(256);return t.fill(e),t}set(e,t){const i=zS(t);e>=0&&e<256?this._asciiMap[e]=i:this._map.set(e,i)}get(e){return e>=0&&e<256?this._asciiMap[e]:this._map.get(e)||this._defaultValue}clear(){this._asciiMap.fill(this._defaultValue),this._map.clear()}}class US{constructor(){this._actual=new o_(0)}add(e){this._actual.set(e,1)}has(e){return this._actual.get(e)===1}clear(){return this._actual.clear()}}class rie{constructor(e,t,i){const n=new Uint8Array(e*t);for(let o=0,r=e*t;o<r;o++)n[o]=i;this._data=n,this.rows=e,this.cols=t}get(e,t){return this._data[e*this.cols+t]}set(e,t,i){this._data[e*this.cols+t]=i}}class aie{constructor(e){let t=0,i=0;for(let o=0,r=e.length;o<r;o++){const[a,l,d]=e[o];l>t&&(t=l),a>i&&(i=a),d>i&&(i=d)}t++,i++;const n=new rie(i,t,0);for(let o=0,r=e.length;o<r;o++){const[a,l,d]=e[o];n.set(a,l,d)}this._states=n,this._maxCharCode=t}nextState(e,t){return t<0||t>=this._maxCharCode?0:this._states.get(e,t)}}let Yk=null;function lie(){return Yk===null&&(Yk=new aie([[1,104,2],[1,72,2],[1,102,6],[1,70,6],[2,116,3],[2,84,3],[3,116,4],[3,84,4],[4,112,5],[4,80,5],[5,115,9],[5,83,9],[5,58,10],[6,105,7],[6,73,7],[7,108,8],[7,76,8],[8,101,9],[8,69,9],[9,58,10],[10,47,11],[11,47,12]])),Yk}let M_=null;function die(){if(M_===null){M_=new o_(0);const s=` 	<>'"、。｡､，．：；‘〈「『〔（［｛｢｣｝］）〕』」〉’｀～…`;for(let t=0;t<s.length;t++)M_.set(s.charCodeAt(t),1);const e=".,;:";for(let t=0;t<e.length;t++)M_.set(e.charCodeAt(t),2)}return M_}class $S{static _createLink(e,t,i,n,o){let r=o-1;do{const a=t.charCodeAt(r);if(e.get(a)!==2)break;r--}while(r>n);if(n>0){const a=t.charCodeAt(n-1),l=t.charCodeAt(r);(a===40&&l===41||a===91&&l===93||a===123&&l===125)&&r--}return{range:{startLineNumber:i,startColumn:n+1,endLineNumber:i,endColumn:r+2},url:t.substring(n,r+1)}}static computeLinks(e,t=lie()){const i=die(),n=[];for(let o=1,r=e.getLineCount();o<=r;o++){const a=e.getLineContent(o),l=a.length;let d=0,c=0,u=0,h=1,g=!1,f=!1,m=!1,_=!1;for(;d<l;){let v=!1;const b=a.charCodeAt(d);if(h===13){let C;switch(b){case 40:g=!0,C=0;break;case 41:C=g?0:1;break;case 91:m=!0,f=!0,C=0;break;case 93:m=!1,C=f?0:1;break;case 123:_=!0,C=0;break;case 125:C=_?0:1;break;case 39:case 34:case 96:u===b?C=1:u===39||u===34||u===96?C=0:C=1;break;case 42:C=u===42?1:0;break;case 124:C=u===124?1:0;break;case 32:C=m?0:1;break;default:C=i.get(b)}C===1&&(n.push($S._createLink(i,a,o,c,d)),v=!0)}else if(h===12){let C;b===91?(f=!0,C=0):C=i.get(b),C===1?v=!0:h=13}else h=t.nextState(h,b),h===0&&(v=!0);v&&(h=1,g=!1,f=!1,_=!1,c=d+1,u=b),d++}h===13&&n.push($S._createLink(i,a,o,c,l))}return n}}function cie(s){return!s||typeof s.getLineCount!="function"||typeof s.getLineContent!="function"?[]:$S.computeLinks(s)}class iT{constructor(){this._defaultValueSet=[["true","false"],["True","False"],["Private","Public","Friend","ReadOnly","Partial","Protected","WriteOnly"],["public","protected","private"]]}navigateValueSet(e,t,i,n,o){if(e&&t){const r=this.doNavigateValueSet(t,o);if(r)return{range:e,value:r}}if(i&&n){const r=this.doNavigateValueSet(n,o);if(r)return{range:i,value:r}}return null}doNavigateValueSet(e,t){const i=this.numberReplace(e,t);return i!==null?i:this.textReplace(e,t)}numberReplace(e,t){const i=Math.pow(10,e.length-(e.lastIndexOf(".")+1));let n=Number(e);const o=parseFloat(e);return!isNaN(n)&&!isNaN(o)&&n===o?n===0&&!t?null:(n=Math.floor(n*i),n+=t?i:-i,String(n/i)):null}textReplace(e,t){return this.valueSetsReplace(this._defaultValueSet,e,t)}valueSetsReplace(e,t,i){let n=null;for(let o=0,r=e.length;n===null&&o<r;o++)n=this.valueSetReplace(e[o],t,i);return n}valueSetReplace(e,t,i){let n=e.indexOf(t);return n>=0?(n+=i?1:-1,n<0?n=e.length-1:n%=e.length,e[n]):null}}iT.INSTANCE=new iT;class uie extends o_{constructor(e){super(0);for(let t=0,i=e.length;t<i;t++)this.set(e.charCodeAt(t),2);this.set(32,1),this.set(9,1)}}function hie(s){const e={};return t=>(e.hasOwnProperty(t)||(e[t]=s(t)),e[t])}const xr=hie(s=>new uie(s));var nr;(function(s){s[s.Left=1]="Left",s[s.Center=2]="Center",s[s.Right=4]="Right",s[s.Full=7]="Full"})(nr||(nr={}));var fg;(function(s){s[s.Left=1]="Left",s[s.Right=2]="Right"})(fg||(fg={}));var bo;(function(s){s[s.Inline=1]="Inline",s[s.Gutter=2]="Gutter"})(bo||(bo={}));var Na;(function(s){s[s.Both=0]="Both",s[s.Right=1]="Right",s[s.Left=2]="Left",s[s.None=3]="None"})(Na||(Na={}));class Aw{get originalIndentSize(){return this._indentSizeIsTabSize?"tabSize":this.indentSize}constructor(e){this._textModelResolvedOptionsBrand=void 0,this.tabSize=Math.max(1,e.tabSize|0),e.indentSize==="tabSize"?(this.indentSize=this.tabSize,this._indentSizeIsTabSize=!0):(this.indentSize=Math.max(1,e.indentSize|0),this._indentSizeIsTabSize=!1),this.insertSpaces=!!e.insertSpaces,this.defaultEOL=e.defaultEOL|0,this.trimAutoWhitespace=!!e.trimAutoWhitespace,this.bracketPairColorizationOptions=e.bracketPairColorizationOptions}equals(e){return this.tabSize===e.tabSize&&this._indentSizeIsTabSize===e._indentSizeIsTabSize&&this.indentSize===e.indentSize&&this.insertSpaces===e.insertSpaces&&this.defaultEOL===e.defaultEOL&&this.trimAutoWhitespace===e.trimAutoWhitespace&&Qo(this.bracketPairColorizationOptions,e.bracketPairColorizationOptions)}createChangeEvent(e){return{tabSize:this.tabSize!==e.tabSize,indentSize:this.indentSize!==e.indentSize,insertSpaces:this.insertSpaces!==e.insertSpaces,trimAutoWhitespace:this.trimAutoWhitespace!==e.trimAutoWhitespace}}}class M0{constructor(e,t){this._findMatchBrand=void 0,this.range=e,this.matches=t}}function gie(s){return s&&typeof s.read=="function"}class Xk{constructor(e,t,i,n,o,r){this.identifier=e,this.range=t,this.text=i,this.forceMoveMarkers=n,this.isAutoWhitespaceEdit=o,this._isTracked=r}}class fie{constructor(e,t,i){this.regex=e,this.wordSeparators=t,this.simpleSearch=i}}class pie{constructor(e,t,i){this.reverseEdits=e,this.changes=t,this.trimAutoWhitespaceLineNumbers=i}}function mie(s){return!s.isTooLargeForSyncing()&&!s.isForSimpleWidget}const _ie=999;class Mh{constructor(e,t,i,n){this.searchString=e,this.isRegex=t,this.matchCase=i,this.wordSeparators=n}parseSearchRequest(){if(this.searchString==="")return null;let e;this.isRegex?e=vie(this.searchString):e=this.searchString.indexOf(`
`)>=0;let t=null;try{t=zW(this.searchString,this.isRegex,{matchCase:this.matchCase,wholeWord:!1,multiline:e,global:!0,unicode:!0})}catch{return null}if(!t)return null;let i=!this.isRegex&&!e;return i&&this.searchString.toLowerCase()!==this.searchString.toUpperCase()&&(i=this.matchCase),new fie(t,this.wordSeparators?xr(this.wordSeparators):null,i?this.searchString:null)}}function vie(s){if(!s||s.length===0)return!1;for(let e=0,t=s.length;e<t;e++){const i=s.charCodeAt(e);if(i===10)return!0;if(i===92){if(e++,e>=t)break;const n=s.charCodeAt(e);if(n===110||n===114||n===87)return!0}}return!1}function zh(s,e,t){if(!t)return new M0(s,null);const i=[];for(let n=0,o=e.length;n<o;n++)i[n]=e[n];return new M0(s,i)}class K5{constructor(e){const t=[];let i=0;for(let n=0,o=e.length;n<o;n++)e.charCodeAt(n)===10&&(t[i++]=n);this._lineFeedsOffsets=t}findLineFeedCountBeforeOffset(e){const t=this._lineFeedsOffsets;let i=0,n=t.length-1;if(n===-1||e<=t[0])return 0;for(;i<n;){const o=i+((n-i)/2>>0);t[o]>=e?n=o-1:t[o+1]>=e?(i=o,n=o):i=o+1}return i+1}}class c1{static findMatches(e,t,i,n,o){const r=t.parseSearchRequest();return r?r.regex.multiline?this._doFindMatchesMultiline(e,i,new rp(r.wordSeparators,r.regex),n,o):this._doFindMatchesLineByLine(e,i,r,n,o):[]}static _getMultilineMatchRange(e,t,i,n,o,r){let a,l=0;n?(l=n.findLineFeedCountBeforeOffset(o),a=t+o+l):a=t+o;let d;if(n){const g=n.findLineFeedCountBeforeOffset(o+r.length)-l;d=a+r.length+g}else d=a+r.length;const c=e.getPositionAt(a),u=e.getPositionAt(d);return new D(c.lineNumber,c.column,u.lineNumber,u.column)}static _doFindMatchesMultiline(e,t,i,n,o){const r=e.getOffsetAt(t.getStartPosition()),a=e.getValueInRange(t,1),l=e.getEOL()===`\r
`?new K5(a):null,d=[];let c=0,u;for(i.reset(0);u=i.next(a);)if(d[c++]=zh(this._getMultilineMatchRange(e,r,a,l,u.index,u[0]),u,n),c>=o)return d;return d}static _doFindMatchesLineByLine(e,t,i,n,o){const r=[];let a=0;if(t.startLineNumber===t.endLineNumber){const d=e.getLineContent(t.startLineNumber).substring(t.startColumn-1,t.endColumn-1);return a=this._findMatchesInLine(i,d,t.startLineNumber,t.startColumn-1,a,r,n,o),r}const l=e.getLineContent(t.startLineNumber).substring(t.startColumn-1);a=this._findMatchesInLine(i,l,t.startLineNumber,t.startColumn-1,a,r,n,o);for(let d=t.startLineNumber+1;d<t.endLineNumber&&a<o;d++)a=this._findMatchesInLine(i,e.getLineContent(d),d,0,a,r,n,o);if(a<o){const d=e.getLineContent(t.endLineNumber).substring(0,t.endColumn-1);a=this._findMatchesInLine(i,d,t.endLineNumber,0,a,r,n,o)}return r}static _findMatchesInLine(e,t,i,n,o,r,a,l){const d=e.wordSeparators;if(!a&&e.simpleSearch){const h=e.simpleSearch,g=h.length,f=t.length;let m=-g;for(;(m=t.indexOf(h,m+g))!==-1;)if((!d||sP(d,t,f,m,g))&&(r[o++]=new M0(new D(i,m+1+n,i,m+1+g+n),null),o>=l))return o;return o}const c=new rp(e.wordSeparators,e.regex);let u;c.reset(0);do if(u=c.next(t),u&&(r[o++]=zh(new D(i,u.index+1+n,i,u.index+1+u[0].length+n),u,a),o>=l))return o;while(u);return o}static findNextMatch(e,t,i,n){const o=t.parseSearchRequest();if(!o)return null;const r=new rp(o.wordSeparators,o.regex);return o.regex.multiline?this._doFindNextMatchMultiline(e,i,r,n):this._doFindNextMatchLineByLine(e,i,r,n)}static _doFindNextMatchMultiline(e,t,i,n){const o=new H(t.lineNumber,1),r=e.getOffsetAt(o),a=e.getLineCount(),l=e.getValueInRange(new D(o.lineNumber,o.column,a,e.getLineMaxColumn(a)),1),d=e.getEOL()===`\r
`?new K5(l):null;i.reset(t.column-1);const c=i.next(l);return c?zh(this._getMultilineMatchRange(e,r,l,d,c.index,c[0]),c,n):t.lineNumber!==1||t.column!==1?this._doFindNextMatchMultiline(e,new H(1,1),i,n):null}static _doFindNextMatchLineByLine(e,t,i,n){const o=e.getLineCount(),r=t.lineNumber,a=e.getLineContent(r),l=this._findFirstMatchInLine(i,a,r,t.column,n);if(l)return l;for(let d=1;d<=o;d++){const c=(r+d-1)%o,u=e.getLineContent(c+1),h=this._findFirstMatchInLine(i,u,c+1,1,n);if(h)return h}return null}static _findFirstMatchInLine(e,t,i,n,o){e.reset(n-1);const r=e.next(t);return r?zh(new D(i,r.index+1,i,r.index+1+r[0].length),r,o):null}static findPreviousMatch(e,t,i,n){const o=t.parseSearchRequest();if(!o)return null;const r=new rp(o.wordSeparators,o.regex);return o.regex.multiline?this._doFindPreviousMatchMultiline(e,i,r,n):this._doFindPreviousMatchLineByLine(e,i,r,n)}static _doFindPreviousMatchMultiline(e,t,i,n){const o=this._doFindMatchesMultiline(e,new D(1,1,t.lineNumber,t.column),i,n,10*_ie);if(o.length>0)return o[o.length-1];const r=e.getLineCount();return t.lineNumber!==r||t.column!==e.getLineMaxColumn(r)?this._doFindPreviousMatchMultiline(e,new H(r,e.getLineMaxColumn(r)),i,n):null}static _doFindPreviousMatchLineByLine(e,t,i,n){const o=e.getLineCount(),r=t.lineNumber,a=e.getLineContent(r).substring(0,t.column-1),l=this._findLastMatchInLine(i,a,r,n);if(l)return l;for(let d=1;d<=o;d++){const c=(o+r-d-1)%o,u=e.getLineContent(c+1),h=this._findLastMatchInLine(i,u,c+1,n);if(h)return h}return null}static _findLastMatchInLine(e,t,i,n){let o=null,r;for(e.reset(0);r=e.next(t);)o=zh(new D(i,r.index+1,i,r.index+1+r[0].length),r,n);return o}}function bie(s,e,t,i,n){if(i===0)return!0;const o=e.charCodeAt(i-1);if(s.get(o)!==0||o===13||o===10)return!0;if(n>0){const r=e.charCodeAt(i);if(s.get(r)!==0)return!0}return!1}function Cie(s,e,t,i,n){if(i+n===t)return!0;const o=e.charCodeAt(i+n);if(s.get(o)!==0||o===13||o===10)return!0;if(n>0){const r=e.charCodeAt(i+n-1);if(s.get(r)!==0)return!0}return!1}function sP(s,e,t,i,n){return bie(s,e,t,i,n)&&Cie(s,e,t,i,n)}class rp{constructor(e,t){this._wordSeparators=e,this._searchRegex=t,this._prevMatchStartIndex=-1,this._prevMatchLength=0}reset(e){this._searchRegex.lastIndex=e,this._prevMatchStartIndex=-1,this._prevMatchLength=0}next(e){const t=e.length;let i;do{if(this._prevMatchStartIndex+this._prevMatchLength===t||(i=this._searchRegex.exec(e),!i))return null;const n=i.index,o=i[0].length;if(n===this._prevMatchStartIndex&&o===this._prevMatchLength){if(o===0){AS(e,t,this._searchRegex.lastIndex)>65535?this._searchRegex.lastIndex+=2:this._searchRegex.lastIndex+=1;continue}return null}if(this._prevMatchStartIndex=n,this._prevMatchLength=o,!this._wordSeparators||sP(this._wordSeparators,e,t,n,o))return i}while(i);return null}}class oP{static computeUnicodeHighlights(e,t,i){const n=i?i.startLineNumber:1,o=i?i.endLineNumber:e.getLineCount(),r=new q5(t),a=r.getCandidateCodePoints();let l;a==="allNonBasicAscii"?l=new RegExp("[^\\t\\n\\r\\x20-\\x7E]","g"):l=new RegExp(`${wie(Array.from(a))}`,"g");const d=new rp(null,l),c=[];let u=!1,h,g=0,f=0,m=0;e:for(let _=n,v=o;_<=v;_++){const b=e.getLineContent(_),C=b.length;d.reset(0);do if(h=d.next(b),h){let w=h.index,S=h.index+h[0].length;if(w>0){const I=b.charCodeAt(w-1);_n(I)&&w--}if(S+1<C){const I=b.charCodeAt(S-1);_n(I)&&S++}const x=b.substring(w,S);let L=w0(w+1,DA,b,0);L&&L.endColumn<=w+1&&(L=null);const k=r.shouldHighlightNonBasicASCII(x,L?L.word:null);if(k!==0){if(k===3?g++:k===2?f++:k===1?m++:nx(),c.length>=1e3){u=!0;break e}c.push(new D(_,w+1,_,S+1))}}while(h)}return{ranges:c,hasMore:u,ambiguousCharacterCount:g,invisibleCharacterCount:f,nonBasicAsciiCharacterCount:m}}static computeUnicodeHighlightReason(e,t){const i=new q5(t);switch(i.shouldHighlightNonBasicASCII(e,null)){case 0:return null;case 2:return{kind:1};case 3:{const o=e.codePointAt(0),r=i.ambiguousCharacters.getPrimaryConfusable(o),a=Ig.getLocales().filter(l=>!Ig.getInstance(new Set([...t.allowedLocales,l])).isAmbiguous(o));return{kind:0,confusableWith:String.fromCodePoint(r),notAmbiguousInLocales:a}}case 1:return{kind:2}}}}function wie(s,e){return`[${ir(s.map(i=>String.fromCodePoint(i)).join(""))}]`}class q5{constructor(e){this.options=e,this.allowedCodePoints=new Set(e.allowedCodePoints),this.ambiguousCharacters=Ig.getInstance(new Set(e.allowedLocales))}getCandidateCodePoints(){if(this.options.nonBasicASCII)return"allNonBasicAscii";const e=new Set;if(this.options.invisibleCharacters)for(const t of Vl.codePoints)G5(String.fromCodePoint(t))||e.add(t);if(this.options.ambiguousCharacters)for(const t of this.ambiguousCharacters.getConfusableCodePoints())e.add(t);for(const t of this.allowedCodePoints)e.delete(t);return e}shouldHighlightNonBasicASCII(e,t){const i=e.codePointAt(0);if(this.allowedCodePoints.has(i))return 0;if(this.options.nonBasicASCII)return 1;let n=!1,o=!1;if(t)for(const r of t){const a=r.codePointAt(0),l=sC(r);n=n||l,!l&&!this.ambiguousCharacters.isAmbiguous(a)&&!Vl.isInvisibleCharacter(a)&&(o=!0)}return!n&&o?0:this.options.invisibleCharacters&&!G5(e)&&Vl.isInvisibleCharacter(i)?2:this.options.ambiguousCharacters&&this.ambiguousCharacters.isAmbiguous(i)?3:0}}function G5(s){return s===" "||s===`
`||s==="	"}class Pw{constructor(e,t,i){this.changes=e,this.moves=t,this.hitTimeout=i}}class jV{constructor(e,t){this.lineRangeMapping=e,this.changes=t}}class rt{static addRange(e,t){let i=0;for(;i<t.length&&t[i].endExclusive<e.start;)i++;let n=i;for(;n<t.length&&t[n].start<=e.endExclusive;)n++;if(i===n)t.splice(i,0,e);else{const o=Math.min(e.start,t[i].start),r=Math.max(e.endExclusive,t[n-1].endExclusive);t.splice(i,n-i,new rt(o,r))}}static tryCreate(e,t){if(!(e>t))return new rt(e,t)}static ofLength(e){return new rt(0,e)}static ofStartAndLength(e,t){return new rt(e,e+t)}constructor(e,t){if(this.start=e,this.endExclusive=t,e>t)throw new pi(`Invalid range: ${this.toString()}`)}get isEmpty(){return this.start===this.endExclusive}delta(e){return new rt(this.start+e,this.endExclusive+e)}deltaStart(e){return new rt(this.start+e,this.endExclusive)}deltaEnd(e){return new rt(this.start,this.endExclusive+e)}get length(){return this.endExclusive-this.start}toString(){return`[${this.start}, ${this.endExclusive})`}equals(e){return this.start===e.start&&this.endExclusive===e.endExclusive}containsRange(e){return this.start<=e.start&&e.endExclusive<=this.endExclusive}contains(e){return this.start<=e&&e<this.endExclusive}join(e){return new rt(Math.min(this.start,e.start),Math.max(this.endExclusive,e.endExclusive))}intersect(e){const t=Math.max(this.start,e.start),i=Math.min(this.endExclusive,e.endExclusive);if(t<=i)return new rt(t,i)}isBefore(e){return this.endExclusive<=e.start}isAfter(e){return this.start>=e.endExclusive}slice(e){return e.slice(this.start,this.endExclusive)}clip(e){if(this.isEmpty)throw new pi(`Invalid clipping range: ${this.toString()}`);return Math.max(this.start,Math.min(this.endExclusive-1,e))}clipCyclic(e){if(this.isEmpty)throw new pi(`Invalid clipping range: ${this.toString()}`);return e<this.start?this.endExclusive-(this.start-e)%this.length:e>=this.endExclusive?this.start+(e-this.start)%this.length:e}forEach(e){for(let t=this.start;t<this.endExclusive;t++)e(t)}}class rP{constructor(){this._sortedRanges=[]}addRange(e){let t=0;for(;t<this._sortedRanges.length&&this._sortedRanges[t].endExclusive<e.start;)t++;let i=t;for(;i<this._sortedRanges.length&&this._sortedRanges[i].start<=e.endExclusive;)i++;if(t===i)this._sortedRanges.splice(t,0,e);else{const n=Math.min(e.start,this._sortedRanges[t].start),o=Math.max(e.endExclusive,this._sortedRanges[i-1].endExclusive);this._sortedRanges.splice(t,i-t,new rt(n,o))}}toString(){return this._sortedRanges.map(e=>e.toString()).join(", ")}intersectsStrict(e){let t=0;for(;t<this._sortedRanges.length&&this._sortedRanges[t].endExclusive<=e.start;)t++;return t<this._sortedRanges.length&&this._sortedRanges[t].start<e.endExclusive}intersectWithRange(e){const t=new rP;for(const i of this._sortedRanges){const n=i.intersect(e);n&&t.addRange(n)}return t}intersectWithRangeLength(e){return this.intersectWithRange(e).length}get length(){return this._sortedRanges.reduce((e,t)=>e+t.length,0)}}function R0(s,e,t){const i=Sie(s,e);if(i!==-1)return s[i]}function Sie(s,e,t=s.length-1){for(let i=t;i>=0;i--){const n=s[i];if(e(n))return i}return-1}function gm(s,e){const t=A0(s,e);return t===-1?void 0:s[t]}function A0(s,e,t=0,i=s.length){let n=t,o=i;for(;n<o;){const r=Math.floor((n+o)/2);e(s[r])?n=r+1:o=r}return n-1}function yie(s,e){const t=P0(s,e);return t===s.length?void 0:s[t]}function P0(s,e,t=0,i=s.length){let n=t,o=i;for(;n<o;){const r=Math.floor((n+o)/2);e(s[r])?o=r:n=r+1}return n}class rC{constructor(e){this._array=e,this._findLastMonotonousLastIdx=0}findLastMonotonous(e){if(rC.assertInvariants){if(this._prevFindLastPredicate){for(const i of this._array)if(this._prevFindLastPredicate(i)&&!e(i))throw new Error("MonotonousArray: current predicate must be weaker than (or equal to) the previous predicate.")}this._prevFindLastPredicate=e}const t=A0(this._array,e,this._findLastMonotonousLastIdx);return this._findLastMonotonousLastIdx=t+1,t===-1?void 0:this._array[t]}}rC.assertInvariants=!1;function aP(s,e){if(s.length===0)return;let t=s[0];for(let i=1;i<s.length;i++){const n=s[i];e(n,t)>0&&(t=n)}return t}function Lie(s,e){if(s.length===0)return;let t=s[0];for(let i=1;i<s.length;i++){const n=s[i];e(n,t)>=0&&(t=n)}return t}function xie(s,e){return aP(s,(t,i)=>-e(t,i))}function Die(s,e){if(s.length===0)return-1;let t=0;for(let i=1;i<s.length;i++){const n=s[i];e(n,s[t])>0&&(t=i)}return t}function kie(s,e){for(const t of s){const i=e(t);if(i!==void 0)return i}}let ft=class _d{static fromRange(e){return new _d(e.startLineNumber,e.endLineNumber)}static fromRangeInclusive(e){return new _d(e.startLineNumber,e.endLineNumber+1)}static joinMany(e){if(e.length===0)return[];let t=new xa(e[0].slice());for(let i=1;i<e.length;i++)t=t.getUnion(new xa(e[i].slice()));return t.ranges}static ofLength(e,t){return new _d(e,e+t)}static deserialize(e){return new _d(e[0],e[1])}constructor(e,t){if(e>t)throw new pi(`startLineNumber ${e} cannot be after endLineNumberExclusive ${t}`);this.startLineNumber=e,this.endLineNumberExclusive=t}contains(e){return this.startLineNumber<=e&&e<this.endLineNumberExclusive}get isEmpty(){return this.startLineNumber===this.endLineNumberExclusive}delta(e){return new _d(this.startLineNumber+e,this.endLineNumberExclusive+e)}deltaLength(e){return new _d(this.startLineNumber,this.endLineNumberExclusive+e)}get length(){return this.endLineNumberExclusive-this.startLineNumber}join(e){return new _d(Math.min(this.startLineNumber,e.startLineNumber),Math.max(this.endLineNumberExclusive,e.endLineNumberExclusive))}toString(){return`[${this.startLineNumber},${this.endLineNumberExclusive})`}intersect(e){const t=Math.max(this.startLineNumber,e.startLineNumber),i=Math.min(this.endLineNumberExclusive,e.endLineNumberExclusive);if(t<=i)return new _d(t,i)}intersectsStrict(e){return this.startLineNumber<e.endLineNumberExclusive&&e.startLineNumber<this.endLineNumberExclusive}overlapOrTouch(e){return this.startLineNumber<=e.endLineNumberExclusive&&e.startLineNumber<=this.endLineNumberExclusive}equals(e){return this.startLineNumber===e.startLineNumber&&this.endLineNumberExclusive===e.endLineNumberExclusive}toInclusiveRange(){return this.isEmpty?null:new D(this.startLineNumber,1,this.endLineNumberExclusive-1,Number.MAX_SAFE_INTEGER)}toExclusiveRange(){return new D(this.startLineNumber,1,this.endLineNumberExclusive,1)}mapToLineArray(e){const t=[];for(let i=this.startLineNumber;i<this.endLineNumberExclusive;i++)t.push(e(i));return t}forEach(e){for(let t=this.startLineNumber;t<this.endLineNumberExclusive;t++)e(t)}serialize(){return[this.startLineNumber,this.endLineNumberExclusive]}includes(e){return this.startLineNumber<=e&&e<this.endLineNumberExclusive}toOffsetRange(){return new rt(this.startLineNumber-1,this.endLineNumberExclusive-1)}};class xa{constructor(e=[]){this._normalizedRanges=e}get ranges(){return this._normalizedRanges}addRange(e){if(e.length===0)return;const t=P0(this._normalizedRanges,n=>n.endLineNumberExclusive>=e.startLineNumber),i=A0(this._normalizedRanges,n=>n.startLineNumber<=e.endLineNumberExclusive)+1;if(t===i)this._normalizedRanges.splice(t,0,e);else if(t===i-1){const n=this._normalizedRanges[t];this._normalizedRanges[t]=n.join(e)}else{const n=this._normalizedRanges[t].join(this._normalizedRanges[i-1]).join(e);this._normalizedRanges.splice(t,i-t,n)}}contains(e){const t=gm(this._normalizedRanges,i=>i.startLineNumber<=e);return!!t&&t.endLineNumberExclusive>e}intersects(e){const t=gm(this._normalizedRanges,i=>i.startLineNumber<e.endLineNumberExclusive);return!!t&&t.endLineNumberExclusive>e.startLineNumber}getUnion(e){if(this._normalizedRanges.length===0)return e;if(e._normalizedRanges.length===0)return this;const t=[];let i=0,n=0,o=null;for(;i<this._normalizedRanges.length||n<e._normalizedRanges.length;){let r=null;if(i<this._normalizedRanges.length&&n<e._normalizedRanges.length){const a=this._normalizedRanges[i],l=e._normalizedRanges[n];a.startLineNumber<l.startLineNumber?(r=a,i++):(r=l,n++)}else i<this._normalizedRanges.length?(r=this._normalizedRanges[i],i++):(r=e._normalizedRanges[n],n++);o===null?o=r:o.endLineNumberExclusive>=r.startLineNumber?o=new ft(o.startLineNumber,Math.max(o.endLineNumberExclusive,r.endLineNumberExclusive)):(t.push(o),o=r)}return o!==null&&t.push(o),new xa(t)}subtractFrom(e){const t=P0(this._normalizedRanges,r=>r.endLineNumberExclusive>=e.startLineNumber),i=A0(this._normalizedRanges,r=>r.startLineNumber<=e.endLineNumberExclusive)+1;if(t===i)return new xa([e]);const n=[];let o=e.startLineNumber;for(let r=t;r<i;r++){const a=this._normalizedRanges[r];a.startLineNumber>o&&n.push(new ft(o,a.startLineNumber)),o=a.endLineNumberExclusive}return o<e.endLineNumberExclusive&&n.push(new ft(o,e.endLineNumberExclusive)),new xa(n)}toString(){return this._normalizedRanges.map(e=>e.toString()).join(", ")}getIntersection(e){const t=[];let i=0,n=0;for(;i<this._normalizedRanges.length&&n<e._normalizedRanges.length;){const o=this._normalizedRanges[i],r=e._normalizedRanges[n],a=o.intersect(r);a&&!a.isEmpty&&t.push(a),o.endLineNumberExclusive<r.endLineNumberExclusive?i++:n++}return new xa(t)}getWithDelta(e){return new xa(this._normalizedRanges.map(t=>t.delta(e)))}}class Gl{static inverse(e,t,i){const n=[];let o=1,r=1;for(const l of e){const d=new Dr(new ft(o,l.original.startLineNumber),new ft(r,l.modified.startLineNumber),void 0);d.modified.isEmpty||n.push(d),o=l.original.endLineNumberExclusive,r=l.modified.endLineNumberExclusive}const a=new Dr(new ft(o,t+1),new ft(r,i+1),void 0);return a.modified.isEmpty||n.push(a),n}constructor(e,t){this.original=e,this.modified=t}toString(){return`{${this.original.toString()}->${this.modified.toString()}}`}flip(){return new Gl(this.modified,this.original)}join(e){return new Gl(this.original.join(e.original),this.modified.join(e.modified))}}class Dr extends Gl{constructor(e,t,i){super(e,t),this.innerChanges=i}flip(){var e;return new Dr(this.modified,this.original,(e=this.innerChanges)===null||e===void 0?void 0:e.map(t=>t.flip()))}}class Ru{constructor(e,t){this.originalRange=e,this.modifiedRange=t}toString(){return`{${this.originalRange.toString()}->${this.modifiedRange.toString()}}`}flip(){return new Ru(this.modifiedRange,this.originalRange)}}const Iie=3;class Eie{computeDiff(e,t,i){var n;const r=new Mie(e,t,{maxComputationTime:i.maxComputationTimeMs,shouldIgnoreTrimWhitespace:i.ignoreTrimWhitespace,shouldComputeCharChanges:!0,shouldMakePrettyDiff:!0,shouldPostProcessCharChanges:!0}).computeDiff(),a=[];let l=null;for(const d of r.changes){let c;d.originalEndLineNumber===0?c=new ft(d.originalStartLineNumber+1,d.originalStartLineNumber+1):c=new ft(d.originalStartLineNumber,d.originalEndLineNumber+1);let u;d.modifiedEndLineNumber===0?u=new ft(d.modifiedStartLineNumber+1,d.modifiedStartLineNumber+1):u=new ft(d.modifiedStartLineNumber,d.modifiedEndLineNumber+1);let h=new Dr(c,u,(n=d.charChanges)===null||n===void 0?void 0:n.map(g=>new Ru(new D(g.originalStartLineNumber,g.originalStartColumn,g.originalEndLineNumber,g.originalEndColumn),new D(g.modifiedStartLineNumber,g.modifiedStartColumn,g.modifiedEndLineNumber,g.modifiedEndColumn))));l&&(l.modified.endLineNumberExclusive===h.modified.startLineNumber||l.original.endLineNumberExclusive===h.original.startLineNumber)&&(h=new Dr(l.original.join(h.original),l.modified.join(h.modified),l.innerChanges&&h.innerChanges?l.innerChanges.concat(h.innerChanges):void 0),a.pop()),a.push(h),l=h}return I0(()=>eV(a,(d,c)=>c.original.startLineNumber-d.original.endLineNumberExclusive===c.modified.startLineNumber-d.modified.endLineNumberExclusive&&d.original.endLineNumberExclusive<c.original.startLineNumber&&d.modified.endLineNumberExclusive<c.modified.startLineNumber)),new Pw(a,[],r.quitEarly)}}function KV(s,e,t,i){return new vl(s,e,t).ComputeDiff(i)}let Z5=class{constructor(e){const t=[],i=[];for(let n=0,o=e.length;n<o;n++)t[n]=nT(e[n],1),i[n]=sT(e[n],1);this.lines=e,this._startColumns=t,this._endColumns=i}getElements(){const e=[];for(let t=0,i=this.lines.length;t<i;t++)e[t]=this.lines[t].substring(this._startColumns[t]-1,this._endColumns[t]-1);return e}getStrictElement(e){return this.lines[e]}getStartLineNumber(e){return e+1}getEndLineNumber(e){return e+1}createCharSequence(e,t,i){const n=[],o=[],r=[];let a=0;for(let l=t;l<=i;l++){const d=this.lines[l],c=e?this._startColumns[l]:1,u=e?this._endColumns[l]:d.length+1;for(let h=c;h<u;h++)n[a]=d.charCodeAt(h-1),o[a]=l+1,r[a]=h,a++;!e&&l<i&&(n[a]=10,o[a]=l+1,r[a]=d.length+1,a++)}return new Nie(n,o,r)}};class Nie{constructor(e,t,i){this._charCodes=e,this._lineNumbers=t,this._columns=i}toString(){return"["+this._charCodes.map((e,t)=>(e===10?"\\n":String.fromCharCode(e))+`-(${this._lineNumbers[t]},${this._columns[t]})`).join(", ")+"]"}_assertIndex(e,t){if(e<0||e>=t.length)throw new Error("Illegal index")}getElements(){return this._charCodes}getStartLineNumber(e){return e>0&&e===this._lineNumbers.length?this.getEndLineNumber(e-1):(this._assertIndex(e,this._lineNumbers),this._lineNumbers[e])}getEndLineNumber(e){return e===-1?this.getStartLineNumber(e+1):(this._assertIndex(e,this._lineNumbers),this._charCodes[e]===10?this._lineNumbers[e]+1:this._lineNumbers[e])}getStartColumn(e){return e>0&&e===this._columns.length?this.getEndColumn(e-1):(this._assertIndex(e,this._columns),this._columns[e])}getEndColumn(e){return e===-1?this.getStartColumn(e+1):(this._assertIndex(e,this._columns),this._charCodes[e]===10?1:this._columns[e]+1)}}class Fp{constructor(e,t,i,n,o,r,a,l){this.originalStartLineNumber=e,this.originalStartColumn=t,this.originalEndLineNumber=i,this.originalEndColumn=n,this.modifiedStartLineNumber=o,this.modifiedStartColumn=r,this.modifiedEndLineNumber=a,this.modifiedEndColumn=l}static createFromDiffChange(e,t,i){const n=t.getStartLineNumber(e.originalStart),o=t.getStartColumn(e.originalStart),r=t.getEndLineNumber(e.originalStart+e.originalLength-1),a=t.getEndColumn(e.originalStart+e.originalLength-1),l=i.getStartLineNumber(e.modifiedStart),d=i.getStartColumn(e.modifiedStart),c=i.getEndLineNumber(e.modifiedStart+e.modifiedLength-1),u=i.getEndColumn(e.modifiedStart+e.modifiedLength-1);return new Fp(n,o,r,a,l,d,c,u)}}function Tie(s){if(s.length<=1)return s;const e=[s[0]];let t=e[0];for(let i=1,n=s.length;i<n;i++){const o=s[i],r=o.originalStart-(t.originalStart+t.originalLength),a=o.modifiedStart-(t.modifiedStart+t.modifiedLength);Math.min(r,a)<Iie?(t.originalLength=o.originalStart+o.originalLength-t.originalStart,t.modifiedLength=o.modifiedStart+o.modifiedLength-t.modifiedStart):(e.push(o),t=o)}return e}class Av{constructor(e,t,i,n,o){this.originalStartLineNumber=e,this.originalEndLineNumber=t,this.modifiedStartLineNumber=i,this.modifiedEndLineNumber=n,this.charChanges=o}static createFromDiffResult(e,t,i,n,o,r,a){let l,d,c,u,h;if(t.originalLength===0?(l=i.getStartLineNumber(t.originalStart)-1,d=0):(l=i.getStartLineNumber(t.originalStart),d=i.getEndLineNumber(t.originalStart+t.originalLength-1)),t.modifiedLength===0?(c=n.getStartLineNumber(t.modifiedStart)-1,u=0):(c=n.getStartLineNumber(t.modifiedStart),u=n.getEndLineNumber(t.modifiedStart+t.modifiedLength-1)),r&&t.originalLength>0&&t.originalLength<20&&t.modifiedLength>0&&t.modifiedLength<20&&o()){const g=i.createCharSequence(e,t.originalStart,t.originalStart+t.originalLength-1),f=n.createCharSequence(e,t.modifiedStart,t.modifiedStart+t.modifiedLength-1);if(g.getElements().length>0&&f.getElements().length>0){let m=KV(g,f,o,!0).changes;a&&(m=Tie(m)),h=[];for(let _=0,v=m.length;_<v;_++)h.push(Fp.createFromDiffChange(m[_],g,f))}}return new Av(l,d,c,u,h)}}class Mie{constructor(e,t,i){this.shouldComputeCharChanges=i.shouldComputeCharChanges,this.shouldPostProcessCharChanges=i.shouldPostProcessCharChanges,this.shouldIgnoreTrimWhitespace=i.shouldIgnoreTrimWhitespace,this.shouldMakePrettyDiff=i.shouldMakePrettyDiff,this.originalLines=e,this.modifiedLines=t,this.original=new Z5(e),this.modified=new Z5(t),this.continueLineDiff=Y5(i.maxComputationTime),this.continueCharDiff=Y5(i.maxComputationTime===0?0:Math.min(i.maxComputationTime,5e3))}computeDiff(){if(this.original.lines.length===1&&this.original.lines[0].length===0)return this.modified.lines.length===1&&this.modified.lines[0].length===0?{quitEarly:!1,changes:[]}:{quitEarly:!1,changes:[{originalStartLineNumber:1,originalEndLineNumber:1,modifiedStartLineNumber:1,modifiedEndLineNumber:this.modified.lines.length,charChanges:void 0}]};if(this.modified.lines.length===1&&this.modified.lines[0].length===0)return{quitEarly:!1,changes:[{originalStartLineNumber:1,originalEndLineNumber:this.original.lines.length,modifiedStartLineNumber:1,modifiedEndLineNumber:1,charChanges:void 0}]};const e=KV(this.original,this.modified,this.continueLineDiff,this.shouldMakePrettyDiff),t=e.changes,i=e.quitEarly;if(this.shouldIgnoreTrimWhitespace){const a=[];for(let l=0,d=t.length;l<d;l++)a.push(Av.createFromDiffResult(this.shouldIgnoreTrimWhitespace,t[l],this.original,this.modified,this.continueCharDiff,this.shouldComputeCharChanges,this.shouldPostProcessCharChanges));return{quitEarly:i,changes:a}}const n=[];let o=0,r=0;for(let a=-1,l=t.length;a<l;a++){const d=a+1<l?t[a+1]:null,c=d?d.originalStart:this.originalLines.length,u=d?d.modifiedStart:this.modifiedLines.length;for(;o<c&&r<u;){const h=this.originalLines[o],g=this.modifiedLines[r];if(h!==g){{let f=nT(h,1),m=nT(g,1);for(;f>1&&m>1;){const _=h.charCodeAt(f-2),v=g.charCodeAt(m-2);if(_!==v)break;f--,m--}(f>1||m>1)&&this._pushTrimWhitespaceCharChange(n,o+1,1,f,r+1,1,m)}{let f=sT(h,1),m=sT(g,1);const _=h.length+1,v=g.length+1;for(;f<_&&m<v;){const b=h.charCodeAt(f-1),C=h.charCodeAt(m-1);if(b!==C)break;f++,m++}(f<_||m<v)&&this._pushTrimWhitespaceCharChange(n,o+1,f,_,r+1,m,v)}}o++,r++}d&&(n.push(Av.createFromDiffResult(this.shouldIgnoreTrimWhitespace,d,this.original,this.modified,this.continueCharDiff,this.shouldComputeCharChanges,this.shouldPostProcessCharChanges)),o+=d.originalLength,r+=d.modifiedLength)}return{quitEarly:i,changes:n}}_pushTrimWhitespaceCharChange(e,t,i,n,o,r,a){if(this._mergeTrimWhitespaceCharChange(e,t,i,n,o,r,a))return;let l;this.shouldComputeCharChanges&&(l=[new Fp(t,i,t,n,o,r,o,a)]),e.push(new Av(t,t,o,o,l))}_mergeTrimWhitespaceCharChange(e,t,i,n,o,r,a){const l=e.length;if(l===0)return!1;const d=e[l-1];return d.originalEndLineNumber===0||d.modifiedEndLineNumber===0?!1:d.originalEndLineNumber===t&&d.modifiedEndLineNumber===o?(this.shouldComputeCharChanges&&d.charChanges&&d.charChanges.push(new Fp(t,i,t,n,o,r,o,a)),!0):d.originalEndLineNumber+1===t&&d.modifiedEndLineNumber+1===o?(d.originalEndLineNumber=t,d.modifiedEndLineNumber=o,this.shouldComputeCharChanges&&d.charChanges&&d.charChanges.push(new Fp(t,i,t,n,o,r,o,a)),!0):!1}}function nT(s,e){const t=ws(s);return t===-1?e:t+1}function sT(s,e){const t=Pa(s);return t===-1?e:t+2}function Y5(s){if(s===0)return()=>!0;const e=Date.now();return()=>Date.now()-e<s}class Kd{static trivial(e,t){return new Kd([new Pn(rt.ofLength(e.length),rt.ofLength(t.length))],!1)}static trivialTimedOut(e,t){return new Kd([new Pn(rt.ofLength(e.length),rt.ofLength(t.length))],!0)}constructor(e,t){this.diffs=e,this.hitTimeout=t}}class Pn{static invert(e,t){const i=[];return lW(e,(n,o)=>{i.push(Pn.fromOffsetPairs(n?n.getEndExclusives():Dl.zero,o?o.getStarts():new Dl(t,(n?n.seq2Range.endExclusive-n.seq1Range.endExclusive:0)+t)))}),i}static fromOffsetPairs(e,t){return new Pn(new rt(e.offset1,t.offset1),new rt(e.offset2,t.offset2))}constructor(e,t){this.seq1Range=e,this.seq2Range=t}swap(){return new Pn(this.seq2Range,this.seq1Range)}toString(){return`${this.seq1Range} <-> ${this.seq2Range}`}join(e){return new Pn(this.seq1Range.join(e.seq1Range),this.seq2Range.join(e.seq2Range))}delta(e){return e===0?this:new Pn(this.seq1Range.delta(e),this.seq2Range.delta(e))}deltaStart(e){return e===0?this:new Pn(this.seq1Range.deltaStart(e),this.seq2Range.deltaStart(e))}deltaEnd(e){return e===0?this:new Pn(this.seq1Range.deltaEnd(e),this.seq2Range.deltaEnd(e))}intersect(e){const t=this.seq1Range.intersect(e.seq1Range),i=this.seq2Range.intersect(e.seq2Range);if(!(!t||!i))return new Pn(t,i)}getStarts(){return new Dl(this.seq1Range.start,this.seq2Range.start)}getEndExclusives(){return new Dl(this.seq1Range.endExclusive,this.seq2Range.endExclusive)}}class Dl{constructor(e,t){this.offset1=e,this.offset2=t}toString(){return`${this.offset1} <-> ${this.offset2}`}}Dl.zero=new Dl(0,0);Dl.max=new Dl(Number.MAX_SAFE_INTEGER,Number.MAX_SAFE_INTEGER);class O0{isValid(){return!0}}O0.instance=new O0;class Rie{constructor(e){if(this.timeout=e,this.startTime=Date.now(),this.valid=!0,e<=0)throw new pi("timeout must be positive")}isValid(){if(!(Date.now()-this.startTime<this.timeout)&&this.valid){this.valid=!1;debugger}return this.valid}}class Qk{constructor(e,t){this.width=e,this.height=t,this.array=[],this.array=new Array(e*t)}get(e,t){return this.array[e+t*this.width]}set(e,t,i){this.array[e+t*this.width]=i}}function oT(s){return s===32||s===9}class fm{static getKey(e){let t=this.chrKeys.get(e);return t===void 0&&(t=this.chrKeys.size,this.chrKeys.set(e,t)),t}constructor(e,t,i){this.range=e,this.lines=t,this.source=i,this.histogram=[];let n=0;for(let o=e.startLineNumber-1;o<e.endLineNumberExclusive-1;o++){const r=t[o];for(let l=0;l<r.length;l++){n++;const d=r[l],c=fm.getKey(d);this.histogram[c]=(this.histogram[c]||0)+1}n++;const a=fm.getKey(`
`);this.histogram[a]=(this.histogram[a]||0)+1}this.totalCount=n}computeSimilarity(e){var t,i;let n=0;const o=Math.max(this.histogram.length,e.histogram.length);for(let r=0;r<o;r++)n+=Math.abs(((t=this.histogram[r])!==null&&t!==void 0?t:0)-((i=e.histogram[r])!==null&&i!==void 0?i:0));return 1-n/(this.totalCount+e.totalCount)}}fm.chrKeys=new Map;class Aie{compute(e,t,i=O0.instance,n){if(e.length===0||t.length===0)return Kd.trivial(e,t);const o=new Qk(e.length,t.length),r=new Qk(e.length,t.length),a=new Qk(e.length,t.length);for(let f=0;f<e.length;f++)for(let m=0;m<t.length;m++){if(!i.isValid())return Kd.trivialTimedOut(e,t);const _=f===0?0:o.get(f-1,m),v=m===0?0:o.get(f,m-1);let b;e.getElement(f)===t.getElement(m)?(f===0||m===0?b=0:b=o.get(f-1,m-1),f>0&&m>0&&r.get(f-1,m-1)===3&&(b+=a.get(f-1,m-1)),b+=n?n(f,m):1):b=-1;const C=Math.max(_,v,b);if(C===b){const w=f>0&&m>0?a.get(f-1,m-1):0;a.set(f,m,w+1),r.set(f,m,3)}else C===_?(a.set(f,m,0),r.set(f,m,1)):C===v&&(a.set(f,m,0),r.set(f,m,2));o.set(f,m,C)}const l=[];let d=e.length,c=t.length;function u(f,m){(f+1!==d||m+1!==c)&&l.push(new Pn(new rt(f+1,d),new rt(m+1,c))),d=f,c=m}let h=e.length-1,g=t.length-1;for(;h>=0&&g>=0;)r.get(h,g)===3?(u(h,g),h--,g--):r.get(h,g)===1?h--:g--;return u(-1,-1),l.reverse(),new Kd(l,!1)}}class qV{compute(e,t,i=O0.instance){if(e.length===0||t.length===0)return Kd.trivial(e,t);const n=e,o=t;function r(m,_){for(;m<n.length&&_<o.length&&n.getElement(m)===o.getElement(_);)m++,_++;return m}let a=0;const l=new Pie;l.set(0,r(0,0));const d=new Oie;d.set(0,l.get(0)===0?null:new X5(null,0,0,l.get(0)));let c=0;e:for(;;){if(a++,!i.isValid())return Kd.trivialTimedOut(n,o);const m=-Math.min(a,o.length+a%2),_=Math.min(a,n.length+a%2);for(c=m;c<=_;c+=2){const v=c===_?-1:l.get(c+1),b=c===m?-1:l.get(c-1)+1,C=Math.min(Math.max(v,b),n.length),w=C-c;if(C>n.length||w>o.length)continue;const S=r(C,w);l.set(c,S);const x=C===v?d.get(c+1):d.get(c-1);if(d.set(c,S!==C?new X5(x,C,w,S-C):x),l.get(c)===n.length&&l.get(c)-c===o.length)break e}}let u=d.get(c);const h=[];let g=n.length,f=o.length;for(;;){const m=u?u.x+u.length:0,_=u?u.y+u.length:0;if((m!==g||_!==f)&&h.push(new Pn(new rt(m,g),new rt(_,f))),!u)break;g=u.x,f=u.y,u=u.prev}return h.reverse(),new Kd(h,!1)}}class X5{constructor(e,t,i,n){this.prev=e,this.x=t,this.y=i,this.length=n}}class Pie{constructor(){this.positiveArr=new Int32Array(10),this.negativeArr=new Int32Array(10)}get(e){return e<0?(e=-e-1,this.negativeArr[e]):this.positiveArr[e]}set(e,t){if(e<0){if(e=-e-1,e>=this.negativeArr.length){const i=this.negativeArr;this.negativeArr=new Int32Array(i.length*2),this.negativeArr.set(i)}this.negativeArr[e]=t}else{if(e>=this.positiveArr.length){const i=this.positiveArr;this.positiveArr=new Int32Array(i.length*2),this.positiveArr.set(i)}this.positiveArr[e]=t}}}class Oie{constructor(){this.positiveArr=[],this.negativeArr=[]}get(e){return e<0?(e=-e-1,this.negativeArr[e]):this.positiveArr[e]}set(e,t){e<0?(e=-e-1,this.negativeArr[e]=t):this.positiveArr[e]=t}}var Q5,J5;class Fie{constructor(e,t){this.uri=e,this.value=t}}function Bie(s){return Array.isArray(s)}class zi{constructor(e,t){if(this[Q5]="ResourceMap",e instanceof zi)this.map=new Map(e.map),this.toKey=t??zi.defaultToKey;else if(Bie(e)){this.map=new Map,this.toKey=t??zi.defaultToKey;for(const[i,n]of e)this.set(i,n)}else this.map=new Map,this.toKey=e??zi.defaultToKey}set(e,t){return this.map.set(this.toKey(e),new Fie(e,t)),this}get(e){var t;return(t=this.map.get(this.toKey(e)))===null||t===void 0?void 0:t.value}has(e){return this.map.has(this.toKey(e))}get size(){return this.map.size}clear(){this.map.clear()}delete(e){return this.map.delete(this.toKey(e))}forEach(e,t){typeof t<"u"&&(e=e.bind(t));for(const[i,n]of this.map)e(n.value,n.uri,this)}*values(){for(const e of this.map.values())yield e.value}*keys(){for(const e of this.map.values())yield e.uri}*entries(){for(const e of this.map.values())yield[e.uri,e.value]}*[(Q5=Symbol.toStringTag,Symbol.iterator)](){for(const[,e]of this.map)yield[e.uri,e.value]}}zi.defaultToKey=s=>s.toString();class Wie{constructor(){this[J5]="LinkedMap",this._map=new Map,this._head=void 0,this._tail=void 0,this._size=0,this._state=0}clear(){this._map.clear(),this._head=void 0,this._tail=void 0,this._size=0,this._state++}isEmpty(){return!this._head&&!this._tail}get size(){return this._size}get first(){var e;return(e=this._head)===null||e===void 0?void 0:e.value}get last(){var e;return(e=this._tail)===null||e===void 0?void 0:e.value}has(e){return this._map.has(e)}get(e,t=0){const i=this._map.get(e);if(i)return t!==0&&this.touch(i,t),i.value}set(e,t,i=0){let n=this._map.get(e);if(n)n.value=t,i!==0&&this.touch(n,i);else{switch(n={key:e,value:t,next:void 0,previous:void 0},i){case 0:this.addItemLast(n);break;case 1:this.addItemFirst(n);break;case 2:this.addItemLast(n);break;default:this.addItemLast(n);break}this._map.set(e,n),this._size++}return this}delete(e){return!!this.remove(e)}remove(e){const t=this._map.get(e);if(t)return this._map.delete(e),this.removeItem(t),this._size--,t.value}shift(){if(!this._head&&!this._tail)return;if(!this._head||!this._tail)throw new Error("Invalid list");const e=this._head;return this._map.delete(e.key),this.removeItem(e),this._size--,e.value}forEach(e,t){const i=this._state;let n=this._head;for(;n;){if(t?e.bind(t)(n.value,n.key,this):e(n.value,n.key,this),this._state!==i)throw new Error("LinkedMap got modified during iteration.");n=n.next}}keys(){const e=this,t=this._state;let i=this._head;const n={[Symbol.iterator](){return n},next(){if(e._state!==t)throw new Error("LinkedMap got modified during iteration.");if(i){const o={value:i.key,done:!1};return i=i.next,o}else return{value:void 0,done:!0}}};return n}values(){const e=this,t=this._state;let i=this._head;const n={[Symbol.iterator](){return n},next(){if(e._state!==t)throw new Error("LinkedMap got modified during iteration.");if(i){const o={value:i.value,done:!1};return i=i.next,o}else return{value:void 0,done:!0}}};return n}entries(){const e=this,t=this._state;let i=this._head;const n={[Symbol.iterator](){return n},next(){if(e._state!==t)throw new Error("LinkedMap got modified during iteration.");if(i){const o={value:[i.key,i.value],done:!1};return i=i.next,o}else return{value:void 0,done:!0}}};return n}[(J5=Symbol.toStringTag,Symbol.iterator)](){return this.entries()}trimOld(e){if(e>=this.size)return;if(e===0){this.clear();return}let t=this._head,i=this.size;for(;t&&i>e;)this._map.delete(t.key),t=t.next,i--;this._head=t,this._size=i,t&&(t.previous=void 0),this._state++}addItemFirst(e){if(!this._head&&!this._tail)this._tail=e;else if(this._head)e.next=this._head,this._head.previous=e;else throw new Error("Invalid list");this._head=e,this._state++}addItemLast(e){if(!this._head&&!this._tail)this._head=e;else if(this._tail)e.previous=this._tail,this._tail.next=e;else throw new Error("Invalid list");this._tail=e,this._state++}removeItem(e){if(e===this._head&&e===this._tail)this._head=void 0,this._tail=void 0;else if(e===this._head){if(!e.next)throw new Error("Invalid list");e.next.previous=void 0,this._head=e.next}else if(e===this._tail){if(!e.previous)throw new Error("Invalid list");e.previous.next=void 0,this._tail=e.previous}else{const t=e.next,i=e.previous;if(!t||!i)throw new Error("Invalid list");t.previous=i,i.next=t}e.next=void 0,e.previous=void 0,this._state++}touch(e,t){if(!this._head||!this._tail)throw new Error("Invalid list");if(!(t!==1&&t!==2)){if(t===1){if(e===this._head)return;const i=e.next,n=e.previous;e===this._tail?(n.next=void 0,this._tail=n):(i.previous=n,n.next=i),e.previous=void 0,e.next=this._head,this._head.previous=e,this._head=e,this._state++}else if(t===2){if(e===this._tail)return;const i=e.next,n=e.previous;e===this._head?(i.previous=void 0,this._head=i):(i.previous=n,n.next=i),e.next=void 0,e.previous=this._tail,this._tail.next=e,this._tail=e,this._state++}}}toJSON(){const e=[];return this.forEach((t,i)=>{e.push([i,t])}),e}fromJSON(e){this.clear();for(const[t,i]of e)this.set(t,i)}}class nh extends Wie{constructor(e,t=1){super(),this._limit=e,this._ratio=Math.min(Math.max(0,t),1)}get limit(){return this._limit}set limit(e){this._limit=e,this.checkTrim()}get(e,t=2){return super.get(e,t)}peek(e){return super.get(e,0)}set(e,t){return super.set(e,t,2),this.checkTrim(),this}checkTrim(){this.size>this._limit&&this.trimOld(Math.round(this._limit*this._ratio))}}class Vie{constructor(e){if(this._m1=new Map,this._m2=new Map,e)for(const[t,i]of e)this.set(t,i)}clear(){this._m1.clear(),this._m2.clear()}set(e,t){this._m1.set(e,t),this._m2.set(t,e)}get(e){return this._m1.get(e)}getKey(e){return this._m2.get(e)}delete(e){const t=this._m1.get(e);return t===void 0?!1:(this._m1.delete(e),this._m2.delete(t),!0)}keys(){return this._m1.keys()}values(){return this._m1.values()}}class lP{constructor(){this.map=new Map}add(e,t){let i=this.map.get(e);i||(i=new Set,this.map.set(e,i)),i.add(t)}delete(e,t){const i=this.map.get(e);i&&(i.delete(t),i.size===0&&this.map.delete(e))}forEach(e,t){const i=this.map.get(e);i&&i.forEach(t)}get(e){const t=this.map.get(e);return t||new Set}}class jS{constructor(e,t,i){this.lines=e,this.considerWhitespaceChanges=i,this.elements=[],this.firstCharOffsetByLine=[],this.additionalOffsetByLine=[];let n=!1;t.start>0&&t.endExclusive>=e.length&&(t=new rt(t.start-1,t.endExclusive),n=!0),this.lineRange=t,this.firstCharOffsetByLine[0]=0;for(let o=this.lineRange.start;o<this.lineRange.endExclusive;o++){let r=e[o],a=0;if(n)a=r.length,r="",n=!1;else if(!i){const l=r.trimStart();a=r.length-l.length,r=l.trimEnd()}this.additionalOffsetByLine.push(a);for(let l=0;l<r.length;l++)this.elements.push(r.charCodeAt(l));o<e.length-1&&(this.elements.push(10),this.firstCharOffsetByLine[o-this.lineRange.start+1]=this.elements.length)}this.additionalOffsetByLine.push(0)}toString(){return`Slice: "${this.text}"`}get text(){return this.getText(new rt(0,this.length))}getText(e){return this.elements.slice(e.start,e.endExclusive).map(t=>String.fromCharCode(t)).join("")}getElement(e){return this.elements[e]}get length(){return this.elements.length}getBoundaryScore(e){const t=t3(e>0?this.elements[e-1]:-1),i=t3(e<this.elements.length?this.elements[e]:-1);if(t===7&&i===8)return 0;let n=0;return t!==i&&(n+=10,t===0&&i===1&&(n+=1)),n+=e3(t),n+=e3(i),n}translateOffset(e){if(this.lineRange.isEmpty)return new H(this.lineRange.start+1,1);const t=A0(this.firstCharOffsetByLine,i=>i<=e);return new H(this.lineRange.start+t+1,e-this.firstCharOffsetByLine[t]+this.additionalOffsetByLine[t]+1)}translateRange(e){return D.fromPositions(this.translateOffset(e.start),this.translateOffset(e.endExclusive))}findWordContaining(e){if(e<0||e>=this.elements.length||!Jk(this.elements[e]))return;let t=e;for(;t>0&&Jk(this.elements[t-1]);)t--;let i=e;for(;i<this.elements.length&&Jk(this.elements[i]);)i++;return new rt(t,i)}countLinesIn(e){return this.translateOffset(e.endExclusive).lineNumber-this.translateOffset(e.start).lineNumber}isStronglyEqual(e,t){return this.elements[e]===this.elements[t]}extendToFullLines(e){var t,i;const n=(t=gm(this.firstCharOffsetByLine,r=>r<=e.start))!==null&&t!==void 0?t:0,o=(i=yie(this.firstCharOffsetByLine,r=>e.endExclusive<=r))!==null&&i!==void 0?i:this.elements.length;return new rt(n,o)}}function Jk(s){return s>=97&&s<=122||s>=65&&s<=90||s>=48&&s<=57}const Hie={0:0,1:0,2:0,3:10,4:2,5:3,6:3,7:10,8:10};function e3(s){return Hie[s]}function t3(s){return s===10?8:s===13?7:oT(s)?6:s>=97&&s<=122?0:s>=65&&s<=90?1:s>=48&&s<=57?2:s===-1?3:s===44||s===59?5:4}function zie(s,e,t,i,n,o){let{moves:r,excludedChanges:a}=$ie(s,e,t,o);if(!o.isValid())return[];const l=s.filter(c=>!a.has(c)),d=jie(l,i,n,e,t,o);return $E(r,d),r=Kie(r),r=r.filter(c=>{const u=c.original.toOffsetRange().slice(e).map(g=>g.trim());return u.join(`
`).length>=15&&Uie(u,g=>g.length>=2)>=2}),r=qie(s,r),r}function Uie(s,e){let t=0;for(const i of s)e(i)&&t++;return t}function $ie(s,e,t,i){const n=[],o=s.filter(l=>l.modified.isEmpty&&l.original.length>=3).map(l=>new fm(l.original,e,l)),r=new Set(s.filter(l=>l.original.isEmpty&&l.modified.length>=3).map(l=>new fm(l.modified,t,l))),a=new Set;for(const l of o){let d=-1,c;for(const u of r){const h=l.computeSimilarity(u);h>d&&(d=h,c=u)}if(d>.9&&c&&(r.delete(c),n.push(new Gl(l.range,c.range)),a.add(l.source),a.add(c.source)),!i.isValid())return{moves:n,excludedChanges:a}}return{moves:n,excludedChanges:a}}function jie(s,e,t,i,n,o){const r=[],a=new lP;for(const h of s)for(let g=h.original.startLineNumber;g<h.original.endLineNumberExclusive-2;g++){const f=`${e[g-1]}:${e[g+1-1]}:${e[g+2-1]}`;a.add(f,{range:new ft(g,g+3)})}const l=[];s.sort(br(h=>h.modified.startLineNumber,Ud));for(const h of s){let g=[];for(let f=h.modified.startLineNumber;f<h.modified.endLineNumberExclusive-2;f++){const m=`${t[f-1]}:${t[f+1-1]}:${t[f+2-1]}`,_=new ft(f,f+3),v=[];a.forEach(m,({range:b})=>{for(const w of g)if(w.originalLineRange.endLineNumberExclusive+1===b.endLineNumberExclusive&&w.modifiedLineRange.endLineNumberExclusive+1===_.endLineNumberExclusive){w.originalLineRange=new ft(w.originalLineRange.startLineNumber,b.endLineNumberExclusive),w.modifiedLineRange=new ft(w.modifiedLineRange.startLineNumber,_.endLineNumberExclusive),v.push(w);return}const C={modifiedLineRange:_,originalLineRange:b};l.push(C),v.push(C)}),g=v}if(!o.isValid())return[]}l.sort(uW(br(h=>h.modifiedLineRange.length,Ud)));const d=new xa,c=new xa;for(const h of l){const g=h.modifiedLineRange.startLineNumber-h.originalLineRange.startLineNumber,f=d.subtractFrom(h.modifiedLineRange),m=c.subtractFrom(h.originalLineRange).getWithDelta(g),_=f.getIntersection(m);for(const v of _.ranges){if(v.length<3)continue;const b=v,C=v.delta(-g);r.push(new Gl(C,b)),d.addRange(b),c.addRange(C)}}r.sort(br(h=>h.original.startLineNumber,Ud));const u=new rC(s);for(let h=0;h<r.length;h++){const g=r[h],f=u.findLastMonotonous(x=>x.original.startLineNumber<=g.original.startLineNumber),m=gm(s,x=>x.modified.startLineNumber<=g.modified.startLineNumber),_=Math.max(g.original.startLineNumber-f.original.startLineNumber,g.modified.startLineNumber-m.modified.startLineNumber),v=u.findLastMonotonous(x=>x.original.startLineNumber<g.original.endLineNumberExclusive),b=gm(s,x=>x.modified.startLineNumber<g.modified.endLineNumberExclusive),C=Math.max(v.original.endLineNumberExclusive-g.original.endLineNumberExclusive,b.modified.endLineNumberExclusive-g.modified.endLineNumberExclusive);let w;for(w=0;w<_;w++){const x=g.original.startLineNumber-w-1,L=g.modified.startLineNumber-w-1;if(x>i.length||L>n.length||d.contains(L)||c.contains(x)||!i3(i[x-1],n[L-1],o))break}w>0&&(c.addRange(new ft(g.original.startLineNumber-w,g.original.startLineNumber)),d.addRange(new ft(g.modified.startLineNumber-w,g.modified.startLineNumber)));let S;for(S=0;S<C;S++){const x=g.original.endLineNumberExclusive+S,L=g.modified.endLineNumberExclusive+S;if(x>i.length||L>n.length||d.contains(L)||c.contains(x)||!i3(i[x-1],n[L-1],o))break}S>0&&(c.addRange(new ft(g.original.endLineNumberExclusive,g.original.endLineNumberExclusive+S)),d.addRange(new ft(g.modified.endLineNumberExclusive,g.modified.endLineNumberExclusive+S))),(w>0||S>0)&&(r[h]=new Gl(new ft(g.original.startLineNumber-w,g.original.endLineNumberExclusive+S),new ft(g.modified.startLineNumber-w,g.modified.endLineNumberExclusive+S)))}return r}function i3(s,e,t){if(s.trim()===e.trim())return!0;if(s.length>300&&e.length>300)return!1;const n=new qV().compute(new jS([s],new rt(0,1),!1),new jS([e],new rt(0,1),!1),t);let o=0;const r=Pn.invert(n.diffs,s.length);for(const c of r)c.seq1Range.forEach(u=>{oT(s.charCodeAt(u))||o++});function a(c){let u=0;for(let h=0;h<s.length;h++)oT(c.charCodeAt(h))||u++;return u}const l=a(s.length>e.length?s:e);return o/l>.6&&l>10}function Kie(s){if(s.length===0)return s;s.sort(br(t=>t.original.startLineNumber,Ud));const e=[s[0]];for(let t=1;t<s.length;t++){const i=e[e.length-1],n=s[t],o=n.original.startLineNumber-i.original.endLineNumberExclusive,r=n.modified.startLineNumber-i.modified.endLineNumberExclusive;if(o>=0&&r>=0&&o+r<=2){e[e.length-1]=i.join(n);continue}e.push(n)}return e}function qie(s,e){const t=new rC(s);return e=e.filter(i=>{const n=t.findLastMonotonous(a=>a.original.startLineNumber<i.original.endLineNumberExclusive)||new Gl(new ft(1,1),new ft(1,1)),o=gm(s,a=>a.modified.startLineNumber<i.modified.endLineNumberExclusive);return n!==o}),e}function rT(s,e,t){let i=t;return i=n3(s,e,i),i=n3(s,e,i),i=Gie(s,e,i),i}function n3(s,e,t){if(t.length===0)return t;const i=[];i.push(t[0]);for(let o=1;o<t.length;o++){const r=i[i.length-1];let a=t[o];if(a.seq1Range.isEmpty||a.seq2Range.isEmpty){const l=a.seq1Range.start-r.seq1Range.endExclusive;let d;for(d=1;d<=l&&!(s.getElement(a.seq1Range.start-d)!==s.getElement(a.seq1Range.endExclusive-d)||e.getElement(a.seq2Range.start-d)!==e.getElement(a.seq2Range.endExclusive-d));d++);if(d--,d===l){i[i.length-1]=new Pn(new rt(r.seq1Range.start,a.seq1Range.endExclusive-l),new rt(r.seq2Range.start,a.seq2Range.endExclusive-l));continue}a=a.delta(-d)}i.push(a)}const n=[];for(let o=0;o<i.length-1;o++){const r=i[o+1];let a=i[o];if(a.seq1Range.isEmpty||a.seq2Range.isEmpty){const l=r.seq1Range.start-a.seq1Range.endExclusive;let d;for(d=0;d<l&&!(!s.isStronglyEqual(a.seq1Range.start+d,a.seq1Range.endExclusive+d)||!e.isStronglyEqual(a.seq2Range.start+d,a.seq2Range.endExclusive+d));d++);if(d===l){i[o+1]=new Pn(new rt(a.seq1Range.start+l,r.seq1Range.endExclusive),new rt(a.seq2Range.start+l,r.seq2Range.endExclusive));continue}d>0&&(a=a.delta(d))}n.push(a)}return i.length>0&&n.push(i[i.length-1]),n}function Gie(s,e,t){if(!s.getBoundaryScore||!e.getBoundaryScore)return t;for(let i=0;i<t.length;i++){const n=i>0?t[i-1]:void 0,o=t[i],r=i+1<t.length?t[i+1]:void 0,a=new rt(n?n.seq1Range.start+1:0,r?r.seq1Range.endExclusive-1:s.length),l=new rt(n?n.seq2Range.start+1:0,r?r.seq2Range.endExclusive-1:e.length);o.seq1Range.isEmpty?t[i]=s3(o,s,e,a,l):o.seq2Range.isEmpty&&(t[i]=s3(o.swap(),e,s,l,a).swap())}return t}function s3(s,e,t,i,n){let r=1;for(;s.seq1Range.start-r>=i.start&&s.seq2Range.start-r>=n.start&&t.isStronglyEqual(s.seq2Range.start-r,s.seq2Range.endExclusive-r)&&r<100;)r++;r--;let a=0;for(;s.seq1Range.start+a<i.endExclusive&&s.seq2Range.endExclusive+a<n.endExclusive&&t.isStronglyEqual(s.seq2Range.start+a,s.seq2Range.endExclusive+a)&&a<100;)a++;if(r===0&&a===0)return s;let l=0,d=-1;for(let c=-r;c<=a;c++){const u=s.seq2Range.start+c,h=s.seq2Range.endExclusive+c,g=s.seq1Range.start+c,f=e.getBoundaryScore(g)+t.getBoundaryScore(u)+t.getBoundaryScore(h);f>d&&(d=f,l=c)}return s.delta(l)}function Zie(s,e,t){const i=[];for(const n of t){const o=i[i.length-1];if(!o){i.push(n);continue}n.seq1Range.start-o.seq1Range.endExclusive<=2||n.seq2Range.start-o.seq2Range.endExclusive<=2?i[i.length-1]=new Pn(o.seq1Range.join(n.seq1Range),o.seq2Range.join(n.seq2Range)):i.push(n)}return i}function Yie(s,e,t){const i=[];let n;function o(){if(!n)return;const a=n.s1Range.length-n.deleted;n.s2Range.length-n.added,Math.max(n.deleted,n.added)+(n.count-1)>a&&i.push(new Pn(n.s1Range,n.s2Range)),n=void 0}for(const a of t){let l=function(g,f){var m,_,v,b;if(!n||!n.s1Range.containsRange(g)||!n.s2Range.containsRange(f))if(n&&!(n.s1Range.endExclusive<g.start&&n.s2Range.endExclusive<f.start)){const S=rt.tryCreate(n.s1Range.endExclusive,g.start),x=rt.tryCreate(n.s2Range.endExclusive,f.start);n.deleted+=(m=S==null?void 0:S.length)!==null&&m!==void 0?m:0,n.added+=(_=x==null?void 0:x.length)!==null&&_!==void 0?_:0,n.s1Range=n.s1Range.join(g),n.s2Range=n.s2Range.join(f)}else o(),n={added:0,deleted:0,count:0,s1Range:g,s2Range:f};const C=g.intersect(a.seq1Range),w=f.intersect(a.seq2Range);n.count++,n.deleted+=(v=C==null?void 0:C.length)!==null&&v!==void 0?v:0,n.added+=(b=w==null?void 0:w.length)!==null&&b!==void 0?b:0};const d=s.findWordContaining(a.seq1Range.start-1),c=e.findWordContaining(a.seq2Range.start-1),u=s.findWordContaining(a.seq1Range.endExclusive),h=e.findWordContaining(a.seq2Range.endExclusive);d&&u&&c&&h&&d.equals(u)&&c.equals(h)?l(d,c):(d&&c&&l(d,c),u&&h&&l(u,h))}return o(),Xie(t,i)}function Xie(s,e){const t=[];for(;s.length>0||e.length>0;){const i=s[0],n=e[0];let o;i&&(!n||i.seq1Range.start<n.seq1Range.start)?o=s.shift():o=e.shift(),t.length>0&&t[t.length-1].seq1Range.endExclusive>=o.seq1Range.start?t[t.length-1]=t[t.length-1].join(o):t.push(o)}return t}function Qie(s,e,t){let i=t;if(i.length===0)return i;let n=0,o;do{o=!1;const r=[i[0]];for(let a=1;a<i.length;a++){let c=function(h,g){const f=new rt(d.seq1Range.endExclusive,l.seq1Range.start);return s.getText(f).replace(/\s/g,"").length<=4&&(h.seq1Range.length+h.seq2Range.length>5||g.seq1Range.length+g.seq2Range.length>5)};const l=i[a],d=r[r.length-1];c(d,l)?(o=!0,r[r.length-1]=r[r.length-1].join(l)):r.push(l)}i=r}while(n++<10&&o);return i}function Jie(s,e,t){let i=t;if(i.length===0)return i;let n=0,o;do{o=!1;const a=[i[0]];for(let l=1;l<i.length;l++){let u=function(g,f){const m=new rt(c.seq1Range.endExclusive,d.seq1Range.start);if(s.countLinesIn(m)>5||m.length>500)return!1;const v=s.getText(m).trim();if(v.length>20||v.split(/\r\n|\r|\n/).length>1)return!1;const b=s.countLinesIn(g.seq1Range),C=g.seq1Range.length,w=e.countLinesIn(g.seq2Range),S=g.seq2Range.length,x=s.countLinesIn(f.seq1Range),L=f.seq1Range.length,k=e.countLinesIn(f.seq2Range),I=f.seq2Range.length,P=2*40+50;function $(A){return Math.min(A,P)}return Math.pow(Math.pow($(b*40+C),1.5)+Math.pow($(w*40+S),1.5),1.5)+Math.pow(Math.pow($(x*40+L),1.5)+Math.pow($(k*40+I),1.5),1.5)>(P**1.5)**1.5*1.3};const d=i[l],c=a[a.length-1];u(c,d)?(o=!0,a[a.length-1]=a[a.length-1].join(d)):a.push(d)}i=a}while(n++<10&&o);const r=[];return eX(i,(a,l,d)=>{let c=l;function u(v){return v.length>0&&v.trim().length<=3&&l.seq1Range.length+l.seq2Range.length>100}const h=s.extendToFullLines(l.seq1Range),g=s.getText(new rt(h.start,l.seq1Range.start));u(g)&&(c=c.deltaStart(-g.length));const f=s.getText(new rt(l.seq1Range.endExclusive,h.endExclusive));u(f)&&(c=c.deltaEnd(f.length));const m=Pn.fromOffsetPairs(a?a.getEndExclusives():Dl.zero,d?d.getStarts():Dl.max),_=c.intersect(m);r.push(_)}),r}class o3{constructor(e,t){this.trimmedHash=e,this.lines=t}getElement(e){return this.trimmedHash[e]}get length(){return this.trimmedHash.length}getBoundaryScore(e){const t=e===0?0:r3(this.lines[e-1]),i=e===this.lines.length?0:r3(this.lines[e]);return 1e3-(t+i)}getText(e){return this.lines.slice(e.start,e.endExclusive).join(`
`)}isStronglyEqual(e,t){return this.lines[e]===this.lines[t]}}function r3(s){let e=0;for(;e<s.length&&(s.charCodeAt(e)===32||s.charCodeAt(e)===9);)e++;return e}class GV{constructor(){this.dynamicProgrammingDiffing=new Aie,this.myersDiffingAlgorithm=new qV}computeDiff(e,t,i){if(e.length<=1&&Ai(e,t,(S,x)=>S===x))return new Pw([],[],!1);if(e.length===1&&e[0].length===0||t.length===1&&t[0].length===0)return new Pw([new Dr(new ft(1,e.length+1),new ft(1,t.length+1),[new Ru(new D(1,1,e.length,e[0].length+1),new D(1,1,t.length,t[0].length+1))])],[],!1);const n=i.maxComputationTimeMs===0?O0.instance:new Rie(i.maxComputationTimeMs),o=!i.ignoreTrimWhitespace,r=new Map;function a(S){let x=r.get(S);return x===void 0&&(x=r.size,r.set(S,x)),x}const l=e.map(S=>a(S.trim())),d=t.map(S=>a(S.trim())),c=new o3(l,e),u=new o3(d,t),h=c.length+u.length<1700?this.dynamicProgrammingDiffing.compute(c,u,n,(S,x)=>e[S]===t[x]?t[x].length===0?.1:1+Math.log(1+t[x].length):.99):this.myersDiffingAlgorithm.compute(c,u);let g=h.diffs,f=h.hitTimeout;g=rT(c,u,g),g=Qie(c,u,g);const m=[],_=S=>{if(o)for(let x=0;x<S;x++){const L=v+x,k=b+x;if(e[L]!==t[k]){const I=this.refineDiff(e,t,new Pn(new rt(L,L+1),new rt(k,k+1)),n,o);for(const P of I.mappings)m.push(P);I.hitTimeout&&(f=!0)}}};let v=0,b=0;for(const S of g){I0(()=>S.seq1Range.start-v===S.seq2Range.start-b);const x=S.seq1Range.start-v;_(x),v=S.seq1Range.endExclusive,b=S.seq2Range.endExclusive;const L=this.refineDiff(e,t,S,n,o);L.hitTimeout&&(f=!0);for(const k of L.mappings)m.push(k)}_(e.length-v);const C=a3(m,e,t);let w=[];return i.computeMoves&&(w=this.computeMoves(C,e,t,l,d,n,o)),I0(()=>{function S(L,k){if(L.lineNumber<1||L.lineNumber>k.length)return!1;const I=k[L.lineNumber-1];return!(L.column<1||L.column>I.length+1)}function x(L,k){return!(L.startLineNumber<1||L.startLineNumber>k.length+1||L.endLineNumberExclusive<1||L.endLineNumberExclusive>k.length+1)}for(const L of C){if(!L.innerChanges)return!1;for(const k of L.innerChanges)if(!(S(k.modifiedRange.getStartPosition(),t)&&S(k.modifiedRange.getEndPosition(),t)&&S(k.originalRange.getStartPosition(),e)&&S(k.originalRange.getEndPosition(),e)))return!1;if(!x(L.modified,t)||!x(L.original,e))return!1}return!0}),new Pw(C,w,f)}computeMoves(e,t,i,n,o,r,a){return zie(e,t,i,n,o,r).map(c=>{const u=this.refineDiff(t,i,new Pn(c.original.toOffsetRange(),c.modified.toOffsetRange()),r,a),h=a3(u.mappings,t,i,!0);return new jV(c,h)})}refineDiff(e,t,i,n,o){const r=new jS(e,i.seq1Range,o),a=new jS(t,i.seq2Range,o),l=r.length+a.length<500?this.dynamicProgrammingDiffing.compute(r,a,n):this.myersDiffingAlgorithm.compute(r,a,n);let d=l.diffs;return d=rT(r,a,d),d=Yie(r,a,d),d=Zie(r,a,d),d=Jie(r,a,d),{mappings:d.map(u=>new Ru(r.translateRange(u.seq1Range),a.translateRange(u.seq2Range))),hitTimeout:l.hitTimeout}}}function a3(s,e,t,i=!1){const n=[];for(const o of aW(s.map(r=>ene(r,e,t)),(r,a)=>r.original.overlapOrTouch(a.original)||r.modified.overlapOrTouch(a.modified))){const r=o[0],a=o[o.length-1];n.push(new Dr(r.original.join(a.original),r.modified.join(a.modified),o.map(l=>l.innerChanges[0])))}return I0(()=>!i&&n.length>0&&n[0].original.startLineNumber!==n[0].modified.startLineNumber?!1:eV(n,(o,r)=>r.original.startLineNumber-o.original.endLineNumberExclusive===r.modified.startLineNumber-o.modified.endLineNumberExclusive&&o.original.endLineNumberExclusive<r.original.startLineNumber&&o.modified.endLineNumberExclusive<r.modified.startLineNumber)),n}function ene(s,e,t){let i=0,n=0;s.modifiedRange.endColumn===1&&s.originalRange.endColumn===1&&s.originalRange.startLineNumber+i<=s.originalRange.endLineNumber&&s.modifiedRange.startLineNumber+i<=s.modifiedRange.endLineNumber&&(n=-1),s.modifiedRange.startColumn-1>=t[s.modifiedRange.startLineNumber-1].length&&s.originalRange.startColumn-1>=e[s.originalRange.startLineNumber-1].length&&s.originalRange.startLineNumber<=s.originalRange.endLineNumber+n&&s.modifiedRange.startLineNumber<=s.modifiedRange.endLineNumber+n&&(i=1);const o=new ft(s.originalRange.startLineNumber+i,s.originalRange.endLineNumber+1+n),r=new ft(s.modifiedRange.startLineNumber+i,s.modifiedRange.endLineNumber+1+n);return new Dr(o,r,[s])}const l3={getLegacy:()=>new Eie,getDefault:()=>new GV};function au(s,e){const t=Math.pow(10,e);return Math.round(s*t)/t}class vt{constructor(e,t,i,n=1){this._rgbaBrand=void 0,this.r=Math.min(255,Math.max(0,e))|0,this.g=Math.min(255,Math.max(0,t))|0,this.b=Math.min(255,Math.max(0,i))|0,this.a=au(Math.max(Math.min(1,n),0),3)}static equals(e,t){return e.r===t.r&&e.g===t.g&&e.b===t.b&&e.a===t.a}}class Wr{constructor(e,t,i,n){this._hslaBrand=void 0,this.h=Math.max(Math.min(360,e),0)|0,this.s=au(Math.max(Math.min(1,t),0),3),this.l=au(Math.max(Math.min(1,i),0),3),this.a=au(Math.max(Math.min(1,n),0),3)}static equals(e,t){return e.h===t.h&&e.s===t.s&&e.l===t.l&&e.a===t.a}static fromRGBA(e){const t=e.r/255,i=e.g/255,n=e.b/255,o=e.a,r=Math.max(t,i,n),a=Math.min(t,i,n);let l=0,d=0;const c=(a+r)/2,u=r-a;if(u>0){switch(d=Math.min(c<=.5?u/(2*c):u/(2-2*c),1),r){case t:l=(i-n)/u+(i<n?6:0);break;case i:l=(n-t)/u+2;break;case n:l=(t-i)/u+4;break}l*=60,l=Math.round(l)}return new Wr(l,d,c,o)}static _hue2rgb(e,t,i){return i<0&&(i+=1),i>1&&(i-=1),i<1/6?e+(t-e)*6*i:i<1/2?t:i<2/3?e+(t-e)*(2/3-i)*6:e}static toRGBA(e){const t=e.h/360,{s:i,l:n,a:o}=e;let r,a,l;if(i===0)r=a=l=n;else{const d=n<.5?n*(1+i):n+i-n*i,c=2*n-d;r=Wr._hue2rgb(c,d,t+1/3),a=Wr._hue2rgb(c,d,t),l=Wr._hue2rgb(c,d,t-1/3)}return new vt(Math.round(r*255),Math.round(a*255),Math.round(l*255),o)}}class kl{constructor(e,t,i,n){this._hsvaBrand=void 0,this.h=Math.max(Math.min(360,e),0)|0,this.s=au(Math.max(Math.min(1,t),0),3),this.v=au(Math.max(Math.min(1,i),0),3),this.a=au(Math.max(Math.min(1,n),0),3)}static equals(e,t){return e.h===t.h&&e.s===t.s&&e.v===t.v&&e.a===t.a}static fromRGBA(e){const t=e.r/255,i=e.g/255,n=e.b/255,o=Math.max(t,i,n),r=Math.min(t,i,n),a=o-r,l=o===0?0:a/o;let d;return a===0?d=0:o===t?d=((i-n)/a%6+6)%6:o===i?d=(n-t)/a+2:d=(t-i)/a+4,new kl(Math.round(d*60),l,o,e.a)}static toRGBA(e){const{h:t,s:i,v:n,a:o}=e,r=n*i,a=r*(1-Math.abs(t/60%2-1)),l=n-r;let[d,c,u]=[0,0,0];return t<60?(d=r,c=a):t<120?(d=a,c=r):t<180?(c=r,u=a):t<240?(c=a,u=r):t<300?(d=a,u=r):t<=360&&(d=r,u=a),d=Math.round((d+l)*255),c=Math.round((c+l)*255),u=Math.round((u+l)*255),new vt(d,c,u,o)}}class G{static fromHex(e){return G.Format.CSS.parseHex(e)||G.red}static equals(e,t){return!e&&!t?!0:!e||!t?!1:e.equals(t)}get hsla(){return this._hsla?this._hsla:Wr.fromRGBA(this.rgba)}get hsva(){return this._hsva?this._hsva:kl.fromRGBA(this.rgba)}constructor(e){if(e)if(e instanceof vt)this.rgba=e;else if(e instanceof Wr)this._hsla=e,this.rgba=Wr.toRGBA(e);else if(e instanceof kl)this._hsva=e,this.rgba=kl.toRGBA(e);else throw new Error("Invalid color ctor argument");else throw new Error("Color needs a value")}equals(e){return!!e&&vt.equals(this.rgba,e.rgba)&&Wr.equals(this.hsla,e.hsla)&&kl.equals(this.hsva,e.hsva)}getRelativeLuminance(){const e=G._relativeLuminanceForComponent(this.rgba.r),t=G._relativeLuminanceForComponent(this.rgba.g),i=G._relativeLuminanceForComponent(this.rgba.b),n=.2126*e+.7152*t+.0722*i;return au(n,4)}static _relativeLuminanceForComponent(e){const t=e/255;return t<=.03928?t/12.92:Math.pow((t+.055)/1.055,2.4)}isLighter(){return(this.rgba.r*299+this.rgba.g*587+this.rgba.b*114)/1e3>=128}isLighterThan(e){const t=this.getRelativeLuminance(),i=e.getRelativeLuminance();return t>i}isDarkerThan(e){const t=this.getRelativeLuminance(),i=e.getRelativeLuminance();return t<i}lighten(e){return new G(new Wr(this.hsla.h,this.hsla.s,this.hsla.l+this.hsla.l*e,this.hsla.a))}darken(e){return new G(new Wr(this.hsla.h,this.hsla.s,this.hsla.l-this.hsla.l*e,this.hsla.a))}transparent(e){const{r:t,g:i,b:n,a:o}=this.rgba;return new G(new vt(t,i,n,o*e))}isTransparent(){return this.rgba.a===0}isOpaque(){return this.rgba.a===1}opposite(){return new G(new vt(255-this.rgba.r,255-this.rgba.g,255-this.rgba.b,this.rgba.a))}makeOpaque(e){if(this.isOpaque()||e.rgba.a!==1)return this;const{r:t,g:i,b:n,a:o}=this.rgba;return new G(new vt(e.rgba.r-o*(e.rgba.r-t),e.rgba.g-o*(e.rgba.g-i),e.rgba.b-o*(e.rgba.b-n),1))}toString(){return this._toString||(this._toString=G.Format.CSS.format(this)),this._toString}static getLighterColor(e,t,i){if(e.isLighterThan(t))return e;i=i||.5;const n=e.getRelativeLuminance(),o=t.getRelativeLuminance();return i=i*(o-n)/o,e.lighten(i)}static getDarkerColor(e,t,i){if(e.isDarkerThan(t))return e;i=i||.5;const n=e.getRelativeLuminance(),o=t.getRelativeLuminance();return i=i*(n-o)/n,e.darken(i)}}G.white=new G(new vt(255,255,255,1));G.black=new G(new vt(0,0,0,1));G.red=new G(new vt(255,0,0,1));G.blue=new G(new vt(0,0,255,1));G.green=new G(new vt(0,255,0,1));G.cyan=new G(new vt(0,255,255,1));G.lightgrey=new G(new vt(211,211,211,1));G.transparent=new G(new vt(0,0,0,0));(function(s){(function(e){(function(t){function i(g){return g.rgba.a===1?`rgb(${g.rgba.r}, ${g.rgba.g}, ${g.rgba.b})`:s.Format.CSS.formatRGBA(g)}t.formatRGB=i;function n(g){return`rgba(${g.rgba.r}, ${g.rgba.g}, ${g.rgba.b}, ${+g.rgba.a.toFixed(2)})`}t.formatRGBA=n;function o(g){return g.hsla.a===1?`hsl(${g.hsla.h}, ${(g.hsla.s*100).toFixed(2)}%, ${(g.hsla.l*100).toFixed(2)}%)`:s.Format.CSS.formatHSLA(g)}t.formatHSL=o;function r(g){return`hsla(${g.hsla.h}, ${(g.hsla.s*100).toFixed(2)}%, ${(g.hsla.l*100).toFixed(2)}%, ${g.hsla.a.toFixed(2)})`}t.formatHSLA=r;function a(g){const f=g.toString(16);return f.length!==2?"0"+f:f}function l(g){return`#${a(g.rgba.r)}${a(g.rgba.g)}${a(g.rgba.b)}`}t.formatHex=l;function d(g,f=!1){return f&&g.rgba.a===1?s.Format.CSS.formatHex(g):`#${a(g.rgba.r)}${a(g.rgba.g)}${a(g.rgba.b)}${a(Math.round(g.rgba.a*255))}`}t.formatHexA=d;function c(g){return g.isOpaque()?s.Format.CSS.formatHex(g):s.Format.CSS.formatRGBA(g)}t.format=c;function u(g){const f=g.length;if(f===0||g.charCodeAt(0)!==35)return null;if(f===7){const m=16*h(g.charCodeAt(1))+h(g.charCodeAt(2)),_=16*h(g.charCodeAt(3))+h(g.charCodeAt(4)),v=16*h(g.charCodeAt(5))+h(g.charCodeAt(6));return new s(new vt(m,_,v,1))}if(f===9){const m=16*h(g.charCodeAt(1))+h(g.charCodeAt(2)),_=16*h(g.charCodeAt(3))+h(g.charCodeAt(4)),v=16*h(g.charCodeAt(5))+h(g.charCodeAt(6)),b=16*h(g.charCodeAt(7))+h(g.charCodeAt(8));return new s(new vt(m,_,v,b/255))}if(f===4){const m=h(g.charCodeAt(1)),_=h(g.charCodeAt(2)),v=h(g.charCodeAt(3));return new s(new vt(16*m+m,16*_+_,16*v+v))}if(f===5){const m=h(g.charCodeAt(1)),_=h(g.charCodeAt(2)),v=h(g.charCodeAt(3)),b=h(g.charCodeAt(4));return new s(new vt(16*m+m,16*_+_,16*v+v,(16*b+b)/255))}return null}t.parseHex=u;function h(g){switch(g){case 48:return 0;case 49:return 1;case 50:return 2;case 51:return 3;case 52:return 4;case 53:return 5;case 54:return 6;case 55:return 7;case 56:return 8;case 57:return 9;case 97:return 10;case 65:return 10;case 98:return 11;case 66:return 11;case 99:return 12;case 67:return 12;case 100:return 13;case 68:return 13;case 101:return 14;case 69:return 14;case 102:return 15;case 70:return 15}return 0}})(e.CSS||(e.CSS={}))})(s.Format||(s.Format={}))})(G||(G={}));function ZV(s){const e=[];for(const t of s){const i=Number(t);(i||i===0&&t.replace(/\s/g,"")!=="")&&e.push(i)}return e}function dP(s,e,t,i){return{red:s/255,blue:t/255,green:e/255,alpha:i}}function R_(s,e){const t=e.index,i=e[0].length;if(!t)return;const n=s.positionAt(t);return{startLineNumber:n.lineNumber,startColumn:n.column,endLineNumber:n.lineNumber,endColumn:n.column+i}}function tne(s,e){if(!s)return;const t=G.Format.CSS.parseHex(e);if(t)return{range:s,color:dP(t.rgba.r,t.rgba.g,t.rgba.b,t.rgba.a)}}function d3(s,e,t){if(!s||e.length!==1)return;const n=e[0].values(),o=ZV(n);return{range:s,color:dP(o[0],o[1],o[2],t?o[3]:1)}}function c3(s,e,t){if(!s||e.length!==1)return;const n=e[0].values(),o=ZV(n),r=new G(new Wr(o[0],o[1]/100,o[2]/100,t?o[3]:1));return{range:s,color:dP(r.rgba.r,r.rgba.g,r.rgba.b,r.rgba.a)}}function A_(s,e){return typeof s=="string"?[...s.matchAll(e)]:s.findMatches(e)}function ine(s){const e=[],i=A_(s,/\b(rgb|rgba|hsl|hsla)(\([0-9\s,.\%]*\))|(#)([A-Fa-f0-9]{3})\b|(#)([A-Fa-f0-9]{4})\b|(#)([A-Fa-f0-9]{6})\b|(#)([A-Fa-f0-9]{8})\b/gm);if(i.length>0)for(const n of i){const o=n.filter(d=>d!==void 0),r=o[1],a=o[2];if(!a)continue;let l;if(r==="rgb"){const d=/^\(\s*(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]|[0-9])\s*,\s*(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]|[0-9])\s*,\s*(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]|[0-9])\s*\)$/gm;l=d3(R_(s,n),A_(a,d),!1)}else if(r==="rgba"){const d=/^\(\s*(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]|[0-9])\s*,\s*(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]|[0-9])\s*,\s*(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]|[0-9])\s*,\s*(0[.][0-9]+|[.][0-9]+|[01][.]|[01])\s*\)$/gm;l=d3(R_(s,n),A_(a,d),!0)}else if(r==="hsl"){const d=/^\(\s*(36[0]|3[0-5][0-9]|[12][0-9][0-9]|[1-9]?[0-9])\s*,\s*(100|\d{1,2}[.]\d*|\d{1,2})%\s*,\s*(100|\d{1,2}[.]\d*|\d{1,2})%\s*\)$/gm;l=c3(R_(s,n),A_(a,d),!1)}else if(r==="hsla"){const d=/^\(\s*(36[0]|3[0-5][0-9]|[12][0-9][0-9]|[1-9]?[0-9])\s*,\s*(100|\d{1,2}[.]\d*|\d{1,2})%\s*,\s*(100|\d{1,2}[.]\d*|\d{1,2})%\s*,\s*(0[.][0-9]+|[.][0-9]+|[01][.]|[01])\s*\)$/gm;l=c3(R_(s,n),A_(a,d),!0)}else r==="#"&&(l=tne(R_(s,n),r+a));l&&e.push(l)}return e}function nne(s){return!s||typeof s.getValue!="function"||typeof s.positionAt!="function"?[]:ine(s)}class sne extends oie{get uri(){return this._uri}get eol(){return this._eol}getValue(){return this.getText()}findMatches(e){const t=[];for(let i=0;i<this._lines.length;i++){const n=this._lines[i],o=this.offsetAt(new H(i+1,1)),r=n.matchAll(e);for(const a of r)(a.index||a.index===0)&&(a.index=a.index+o),t.push(a)}return t}getLinesContent(){return this._lines.slice(0)}getLineCount(){return this._lines.length}getLineContent(e){return this._lines[e-1]}getWordAtPosition(e,t){const i=w0(e.column,kA(t),this._lines[e.lineNumber-1],0);return i?new D(e.lineNumber,i.startColumn,e.lineNumber,i.endColumn):null}words(e){const t=this._lines,i=this._wordenize.bind(this);let n=0,o="",r=0,a=[];return{*[Symbol.iterator](){for(;;)if(r<a.length){const l=o.substring(a[r].start,a[r].end);r+=1,yield l}else if(n<t.length)o=t[n],a=i(o,e),r=0,n+=1;else break}}}getLineWords(e,t){const i=this._lines[e-1],n=this._wordenize(i,t),o=[];for(const r of n)o.push({word:i.substring(r.start,r.end),startColumn:r.start+1,endColumn:r.end+1});return o}_wordenize(e,t){const i=[];let n;for(t.lastIndex=0;(n=t.exec(e))&&n[0].length!==0;)i.push({start:n.index,end:n.index+n[0].length});return i}getValueInRange(e){if(e=this._validateRange(e),e.startLineNumber===e.endLineNumber)return this._lines[e.startLineNumber-1].substring(e.startColumn-1,e.endColumn-1);const t=this._eol,i=e.startLineNumber-1,n=e.endLineNumber-1,o=[];o.push(this._lines[i].substring(e.startColumn-1));for(let r=i+1;r<n;r++)o.push(this._lines[r]);return o.push(this._lines[n].substring(0,e.endColumn-1)),o.join(t)}offsetAt(e){return e=this._validatePosition(e),this._ensureLineStarts(),this._lineStarts.getPrefixSum(e.lineNumber-2)+(e.column-1)}positionAt(e){e=Math.floor(e),e=Math.max(0,e),this._ensureLineStarts();const t=this._lineStarts.getIndexOf(e),i=this._lines[t.index].length;return{lineNumber:1+t.index,column:1+Math.min(t.remainder,i)}}_validateRange(e){const t=this._validatePosition({lineNumber:e.startLineNumber,column:e.startColumn}),i=this._validatePosition({lineNumber:e.endLineNumber,column:e.endColumn});return t.lineNumber!==e.startLineNumber||t.column!==e.startColumn||i.lineNumber!==e.endLineNumber||i.column!==e.endColumn?{startLineNumber:t.lineNumber,startColumn:t.column,endLineNumber:i.lineNumber,endColumn:i.column}:e}_validatePosition(e){if(!H.isIPosition(e))throw new Error("bad position");let{lineNumber:t,column:i}=e,n=!1;if(t<1)t=1,i=1,n=!0;else if(t>this._lines.length)t=this._lines.length,i=this._lines[t-1].length+1,n=!0;else{const o=this._lines[t-1].length+1;i<1?(i=1,n=!0):i>o&&(i=o,n=!0)}return n?{lineNumber:t,column:i}:e}}class lu{constructor(e,t){this._host=e,this._models=Object.create(null),this._foreignModuleFactory=t,this._foreignModule=null}dispose(){this._models=Object.create(null)}_getModel(e){return this._models[e]}_getModels(){const e=[];return Object.keys(this._models).forEach(t=>e.push(this._models[t])),e}acceptNewModel(e){this._models[e.url]=new sne(Pe.parse(e.url),e.lines,e.EOL,e.versionId)}acceptModelChanged(e,t){if(!this._models[e])return;this._models[e].onEvents(t)}acceptRemovedModel(e){this._models[e]&&delete this._models[e]}async computeUnicodeHighlights(e,t,i){const n=this._getModel(e);return n?oP.computeUnicodeHighlights(n,t,i):{ranges:[],hasMore:!1,ambiguousCharacterCount:0,invisibleCharacterCount:0,nonBasicAsciiCharacterCount:0}}async computeDiff(e,t,i,n){const o=this._getModel(e),r=this._getModel(t);return!o||!r?null:lu.computeDiff(o,r,i,n)}static computeDiff(e,t,i,n){const o=n==="advanced"?l3.getDefault():l3.getLegacy(),r=e.getLinesContent(),a=t.getLinesContent(),l=o.computeDiff(r,a,i),d=l.changes.length>0?!1:this._modelsAreIdentical(e,t);function c(u){return u.map(h=>{var g;return[h.original.startLineNumber,h.original.endLineNumberExclusive,h.modified.startLineNumber,h.modified.endLineNumberExclusive,(g=h.innerChanges)===null||g===void 0?void 0:g.map(f=>[f.originalRange.startLineNumber,f.originalRange.startColumn,f.originalRange.endLineNumber,f.originalRange.endColumn,f.modifiedRange.startLineNumber,f.modifiedRange.startColumn,f.modifiedRange.endLineNumber,f.modifiedRange.endColumn])]})}return{identical:d,quitEarly:l.hitTimeout,changes:c(l.changes),moves:l.moves.map(u=>[u.lineRangeMapping.original.startLineNumber,u.lineRangeMapping.original.endLineNumberExclusive,u.lineRangeMapping.modified.startLineNumber,u.lineRangeMapping.modified.endLineNumberExclusive,c(u.changes)])}}static _modelsAreIdentical(e,t){const i=e.getLineCount(),n=t.getLineCount();if(i!==n)return!1;for(let o=1;o<=i;o++){const r=e.getLineContent(o),a=t.getLineContent(o);if(r!==a)return!1}return!0}async computeMoreMinimalEdits(e,t,i){const n=this._getModel(e);if(!n)return t;const o=[];let r;t=t.slice(0).sort((l,d)=>{if(l.range&&d.range)return D.compareRangesUsingStarts(l.range,d.range);const c=l.range?0:1,u=d.range?0:1;return c-u});let a=0;for(let l=1;l<t.length;l++)D.getEndPosition(t[a].range).equals(D.getStartPosition(t[l].range))?(t[a].range=D.fromPositions(D.getStartPosition(t[a].range),D.getEndPosition(t[l].range)),t[a].text+=t[l].text):(a++,t[a]=t[l]);t.length=a+1;for(let{range:l,text:d,eol:c}of t){if(typeof c=="number"&&(r=c),D.isEmpty(l)&&!d)continue;const u=n.getValueInRange(l);if(d=d.replace(/\r\n|\n|\r/g,n.eol),u===d)continue;if(Math.max(d.length,u.length)>lu._diffLimit){o.push({range:l,text:d});continue}const h=iie(u,d,i),g=n.offsetAt(D.lift(l).getStartPosition());for(const f of h){const m=n.positionAt(g+f.originalStart),_=n.positionAt(g+f.originalStart+f.originalLength),v={text:d.substr(f.modifiedStart,f.modifiedLength),range:{startLineNumber:m.lineNumber,startColumn:m.column,endLineNumber:_.lineNumber,endColumn:_.column}};n.getValueInRange(v.range)!==v.text&&o.push(v)}}return typeof r=="number"&&o.push({eol:r,text:"",range:{startLineNumber:0,startColumn:0,endLineNumber:0,endColumn:0}}),o}async computeLinks(e){const t=this._getModel(e);return t?cie(t):null}async computeDefaultDocumentColors(e){const t=this._getModel(e);return t?nne(t):null}async textualSuggest(e,t,i,n){const o=new cs,r=new RegExp(i,n),a=new Set;e:for(const l of e){const d=this._getModel(l);if(d){for(const c of d.words(r))if(!(c===t||!isNaN(Number(c)))&&(a.add(c),a.size>lu._suggestionsLimit))break e}}return{words:Array.from(a),duration:o.elapsed()}}async computeWordRanges(e,t,i,n){const o=this._getModel(e);if(!o)return Object.create(null);const r=new RegExp(i,n),a=Object.create(null);for(let l=t.startLineNumber;l<t.endLineNumber;l++){const d=o.getLineWords(l,r);for(const c of d){if(!isNaN(Number(c.word)))continue;let u=a[c.word];u||(u=[],a[c.word]=u),u.push({startLineNumber:l,startColumn:c.startColumn,endLineNumber:l,endColumn:c.endColumn})}}return a}async navigateValueSet(e,t,i,n,o){const r=this._getModel(e);if(!r)return null;const a=new RegExp(n,o);t.startColumn===t.endColumn&&(t={startLineNumber:t.startLineNumber,startColumn:t.startColumn,endLineNumber:t.endLineNumber,endColumn:t.endColumn+1});const l=r.getValueInRange(t),d=r.getWordAtPosition({lineNumber:t.startLineNumber,column:t.startColumn},a);if(!d)return null;const c=r.getValueInRange(d);return iT.INSTANCE.navigateValueSet(t,l,d,c,i)}loadForeignModule(e,t,i){const r={host:dX(i,(a,l)=>this._host.fhr(a,l)),getMirrorModels:()=>this._getModels()};return this._foreignModuleFactory?(this._foreignModule=this._foreignModuleFactory(r,t),Promise.resolve(yA(this._foreignModule))):Promise.reject(new Error("Unexpected usage"))}fmr(e,t){if(!this._foreignModule||typeof this._foreignModule[e]!="function")return Promise.reject(new Error("Missing requestHandler or method: "+e));try{return Promise.resolve(this._foreignModule[e].apply(this._foreignModule,t))}catch(i){return Promise.reject(i)}}}lu._diffLimit=1e5;lu._suggestionsLimit=1e4;typeof importScripts=="function"&&(globalThis.monaco=WW());const cP=ut("textResourceConfigurationService"),YV=ut("textResourcePropertiesService"),xe=ut("ILanguageFeaturesService");var one=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},P_=function(s,e){return function(t,i){e(t,i,s)}};const u3=60*1e3,h3=5*60*1e3;function Uh(s,e){const t=s.getModel(e);return!(!t||t.isTooLargeForSyncing())}let aT=class extends j{constructor(e,t,i,n,o){super(),this._modelService=e,this._workerManager=this._register(new ane(this._modelService,n)),this._logService=i,this._register(o.linkProvider.register({language:"*",hasAccessToAllModels:!0},{provideLinks:(r,a)=>Uh(this._modelService,r.uri)?this._workerManager.withWorker().then(l=>l.computeLinks(r.uri)).then(l=>l&&{links:l}):Promise.resolve({links:[]})})),this._register(o.completionProvider.register("*",new rne(this._workerManager,t,this._modelService,n)))}dispose(){super.dispose()}canComputeUnicodeHighlights(e){return Uh(this._modelService,e)}computedUnicodeHighlights(e,t,i){return this._workerManager.withWorker().then(n=>n.computedUnicodeHighlights(e,t,i))}async computeDiff(e,t,i,n){const o=await this._workerManager.withWorker().then(l=>l.computeDiff(e,t,i,n));if(!o)return null;return{identical:o.identical,quitEarly:o.quitEarly,changes:a(o.changes),moves:o.moves.map(l=>new jV(new Gl(new ft(l[0],l[1]),new ft(l[2],l[3])),a(l[4])))};function a(l){return l.map(d=>{var c;return new Dr(new ft(d[0],d[1]),new ft(d[2],d[3]),(c=d[4])===null||c===void 0?void 0:c.map(u=>new Ru(new D(u[0],u[1],u[2],u[3]),new D(u[4],u[5],u[6],u[7]))))})}}computeMoreMinimalEdits(e,t,i=!1){if(as(t)){if(!Uh(this._modelService,e))return Promise.resolve(t);const n=cs.create(),o=this._workerManager.withWorker().then(r=>r.computeMoreMinimalEdits(e,t,i));return o.finally(()=>this._logService.trace("FORMAT#computeMoreMinimalEdits",e.toString(!0),n.elapsed())),Promise.race([o,Iu(1e3).then(()=>t)])}else return Promise.resolve(void 0)}canNavigateValueSet(e){return Uh(this._modelService,e)}navigateValueSet(e,t,i){return this._workerManager.withWorker().then(n=>n.navigateValueSet(e,t,i))}canComputeWordRanges(e){return Uh(this._modelService,e)}computeWordRanges(e,t){return this._workerManager.withWorker().then(i=>i.computeWordRanges(e,t))}};aT=one([P_(0,vi),P_(1,cP),P_(2,ko),P_(3,Jt),P_(4,xe)],aT);class rne{constructor(e,t,i,n){this.languageConfigurationService=n,this._debugDisplayName="wordbasedCompletions",this._workerManager=e,this._configurationService=t,this._modelService=i}async provideCompletionItems(e,t){const i=this._configurationService.getValue(e.uri,t,"editor");if(i.wordBasedSuggestions==="off")return;const n=[];if(i.wordBasedSuggestions==="currentDocument")Uh(this._modelService,e.uri)&&n.push(e.uri);else for(const u of this._modelService.getModels())Uh(this._modelService,u.uri)&&(u===e?n.unshift(u.uri):(i.wordBasedSuggestions==="allDocuments"||u.getLanguageId()===e.getLanguageId())&&n.push(u.uri));if(n.length===0)return;const o=this.languageConfigurationService.getLanguageConfiguration(e.getLanguageId()).getWordDefinition(),r=e.getWordAtPosition(t),a=r?new D(t.lineNumber,r.startColumn,t.lineNumber,r.endColumn):D.fromPositions(t),l=a.setEndPosition(t.lineNumber,t.column),c=await(await this._workerManager.withWorker()).textualSuggest(n,r==null?void 0:r.word,o);if(c)return{duration:c.duration,suggestions:c.words.map(u=>({kind:18,label:u,insertText:u,range:{insert:l,replace:a}}))}}}class ane extends j{constructor(e,t){super(),this.languageConfigurationService=t,this._modelService=e,this._editorWorkerClient=null,this._lastWorkerUsedTime=new Date().getTime(),this._register(new eP).cancelAndSet(()=>this._checkStopIdleWorker(),Math.round(h3/2),Wl),this._register(this._modelService.onModelRemoved(n=>this._checkStopEmptyWorker()))}dispose(){this._editorWorkerClient&&(this._editorWorkerClient.dispose(),this._editorWorkerClient=null),super.dispose()}_checkStopEmptyWorker(){if(!this._editorWorkerClient)return;this._modelService.getModels().length===0&&(this._editorWorkerClient.dispose(),this._editorWorkerClient=null)}_checkStopIdleWorker(){if(!this._editorWorkerClient)return;new Date().getTime()-this._lastWorkerUsedTime>h3&&(this._editorWorkerClient.dispose(),this._editorWorkerClient=null)}withWorker(){return this._lastWorkerUsedTime=new Date().getTime(),this._editorWorkerClient||(this._editorWorkerClient=new uP(this._modelService,!1,"editorWorkerService",this.languageConfigurationService)),Promise.resolve(this._editorWorkerClient)}}class lne extends j{constructor(e,t,i){if(super(),this._syncedModels=Object.create(null),this._syncedModelsLastUsedTime=Object.create(null),this._proxy=e,this._modelService=t,!i){const n=new ZA;n.cancelAndSet(()=>this._checkStopModelSync(),Math.round(u3/2)),this._register(n)}}dispose(){for(const e in this._syncedModels)Bt(this._syncedModels[e]);this._syncedModels=Object.create(null),this._syncedModelsLastUsedTime=Object.create(null),super.dispose()}ensureSyncedResources(e,t){for(const i of e){const n=i.toString();this._syncedModels[n]||this._beginModelSync(i,t),this._syncedModels[n]&&(this._syncedModelsLastUsedTime[n]=new Date().getTime())}}_checkStopModelSync(){const e=new Date().getTime(),t=[];for(const i in this._syncedModelsLastUsedTime)e-this._syncedModelsLastUsedTime[i]>u3&&t.push(i);for(const i of t)this._stopModelSync(i)}_beginModelSync(e,t){const i=this._modelService.getModel(e);if(!i||!t&&i.isTooLargeForSyncing())return;const n=e.toString();this._proxy.acceptNewModel({url:i.uri.toString(),lines:i.getLinesContent(),EOL:i.getEOL(),versionId:i.getVersionId()});const o=new ie;o.add(i.onDidChangeContent(r=>{this._proxy.acceptModelChanged(n.toString(),r)})),o.add(i.onWillDispose(()=>{this._stopModelSync(n)})),o.add(Fe(()=>{this._proxy.acceptRemovedModel(n)})),this._syncedModels[n]=o}_stopModelSync(e){const t=this._syncedModels[e];delete this._syncedModels[e],delete this._syncedModelsLastUsedTime[e],Bt(t)}}class g3{constructor(e){this._instance=e,this._proxyObj=Promise.resolve(this._instance)}dispose(){this._instance.dispose()}getProxyObject(){return this._proxyObj}}class eI{constructor(e){this._workerClient=e}fhr(e,t){return this._workerClient.fhr(e,t)}}class uP extends j{constructor(e,t,i,n){super(),this.languageConfigurationService=n,this._disposed=!1,this._modelService=e,this._keepIdleModels=t,this._workerFactory=new ux(i),this._worker=null,this._modelManager=null}fhr(e,t){throw new Error("Not implemented!")}_getOrCreateWorker(){if(!this._worker)try{this._worker=this._register(new pte(this._workerFactory,"vs/editor/common/services/editorSimpleWorker",new eI(this)))}catch(e){QN(e),this._worker=new g3(new lu(new eI(this),null))}return this._worker}_getProxy(){return this._getOrCreateWorker().getProxyObject().then(void 0,e=>(QN(e),this._worker=new g3(new lu(new eI(this),null)),this._getOrCreateWorker().getProxyObject()))}_getOrCreateModelManager(e){return this._modelManager||(this._modelManager=this._register(new lne(e,this._modelService,this._keepIdleModels))),this._modelManager}async _withSyncedResources(e,t=!1){return this._disposed?Promise.reject(fQ()):this._getProxy().then(i=>(this._getOrCreateModelManager(i).ensureSyncedResources(e,t),i))}computedUnicodeHighlights(e,t,i){return this._withSyncedResources([e]).then(n=>n.computeUnicodeHighlights(e.toString(),t,i))}computeDiff(e,t,i,n){return this._withSyncedResources([e,t],!0).then(o=>o.computeDiff(e.toString(),t.toString(),i,n))}computeMoreMinimalEdits(e,t,i){return this._withSyncedResources([e]).then(n=>n.computeMoreMinimalEdits(e.toString(),t,i))}computeLinks(e){return this._withSyncedResources([e]).then(t=>t.computeLinks(e.toString()))}computeDefaultDocumentColors(e){return this._withSyncedResources([e]).then(t=>t.computeDefaultDocumentColors(e.toString()))}async textualSuggest(e,t,i){const n=await this._withSyncedResources(e),o=i.source,r=i.flags;return n.textualSuggest(e.map(a=>a.toString()),t,o,r)}computeWordRanges(e,t){return this._withSyncedResources([e]).then(i=>{const n=this._modelService.getModel(e);if(!n)return Promise.resolve(null);const o=this.languageConfigurationService.getLanguageConfiguration(n.getLanguageId()).getWordDefinition(),r=o.source,a=o.flags;return i.computeWordRanges(e.toString(),t,r,a)})}navigateValueSet(e,t,i){return this._withSyncedResources([e]).then(n=>{const o=this._modelService.getModel(e);if(!o)return null;const r=this.languageConfigurationService.getLanguageConfiguration(o.getLanguageId()).getWordDefinition(),a=r.source,l=r.flags;return n.navigateValueSet(e.toString(),t,i,a,l)})}dispose(){super.dispose(),this._disposed=!0}}function dne(s,e,t){return new cne(s,e,t)}class cne extends uP{constructor(e,t,i){super(e,i.keepIdleModels||!1,i.label,t),this._foreignModuleId=i.moduleId,this._foreignModuleCreateData=i.createData||null,this._foreignModuleHost=i.host||null,this._foreignProxy=null}fhr(e,t){if(!this._foreignModuleHost||typeof this._foreignModuleHost[e]!="function")return Promise.reject(new Error("Missing method "+e+" or missing main thread foreign host."));try{return Promise.resolve(this._foreignModuleHost[e].apply(this._foreignModuleHost,t))}catch(i){return Promise.reject(i)}}_getForeignProxy(){return this._foreignProxy||(this._foreignProxy=this._getProxy().then(e=>{const t=this._foreignModuleHost?yA(this._foreignModuleHost):[];return e.loadForeignModule(this._foreignModuleId,this._foreignModuleCreateData,t).then(i=>{this._foreignModuleCreateData=null;const n=(a,l)=>e.fmr(a,l),o=(a,l)=>function(){const d=Array.prototype.slice.call(arguments,0);return l(a,d)},r={};for(const a of i)r[a]=o(a,n);return r})})),this._foreignProxy}getProxy(){return this._getForeignProxy()}withSyncedResources(e){return this._withSyncedResources(e).then(t=>this.getProxy())}}const aC={ICodeEditor:"vs.editor.ICodeEditor",IDiffEditor:"vs.editor.IDiffEditor"},pm=new class{clone(){return this}equals(s){return this===s}};function hP(s,e){return new PA([new S0(0,"",s)],e)}function _x(s,e){const t=new Uint32Array(2);return t[0]=0,t[1]=(s<<0|0|0|32768|2<<24)>>>0,new qL(t,e===null?pm:e)}class Zn{static getLanguageId(e){return(e&255)>>>0}static getTokenType(e){return(e&768)>>>8}static containsBalancedBrackets(e){return(e&1024)!==0}static getFontStyle(e){return(e&30720)>>>11}static getForeground(e){return(e&16744448)>>>15}static getBackground(e){return(e&4278190080)>>>24}static getClassNameFromMetadata(e){let i="mtk"+this.getForeground(e);const n=this.getFontStyle(e);return n&1&&(i+=" mtki"),n&2&&(i+=" mtkb"),n&4&&(i+=" mtku"),n&8&&(i+=" mtks"),i}static getInlineStyleFromMetadata(e,t){const i=this.getForeground(e),n=this.getFontStyle(e);let o=`color: ${t[i]};`;n&1&&(o+="font-style: italic;"),n&2&&(o+="font-weight: bold;");let r="";return n&4&&(r+=" underline"),n&8&&(r+=" line-through"),r&&(o+=`text-decoration:${r};`),o}static getPresentationFromMetadata(e){const t=this.getForeground(e),i=this.getFontStyle(e);return{foreground:t,italic:!!(i&1),bold:!!(i&2),underline:!!(i&4),strikethrough:!!(i&8)}}}class vn{static createEmpty(e,t){const i=vn.defaultTokenMetadata,n=new Uint32Array(2);return n[0]=e.length,n[1]=i,new vn(n,e,t)}constructor(e,t,i){this._lineTokensBrand=void 0,this._tokens=e,this._tokensCount=this._tokens.length>>>1,this._text=t,this._languageIdCodec=i}equals(e){return e instanceof vn?this.slicedEquals(e,0,this._tokensCount):!1}slicedEquals(e,t,i){if(this._text!==e._text||this._tokensCount!==e._tokensCount)return!1;const n=t<<1,o=n+(i<<1);for(let r=n;r<o;r++)if(this._tokens[r]!==e._tokens[r])return!1;return!0}getLineContent(){return this._text}getCount(){return this._tokensCount}getStartOffset(e){return e>0?this._tokens[e-1<<1]:0}getMetadata(e){return this._tokens[(e<<1)+1]}getLanguageId(e){const t=this._tokens[(e<<1)+1],i=Zn.getLanguageId(t);return this._languageIdCodec.decodeLanguageId(i)}getStandardTokenType(e){const t=this._tokens[(e<<1)+1];return Zn.getTokenType(t)}getForeground(e){const t=this._tokens[(e<<1)+1];return Zn.getForeground(t)}getClassName(e){const t=this._tokens[(e<<1)+1];return Zn.getClassNameFromMetadata(t)}getInlineStyle(e,t){const i=this._tokens[(e<<1)+1];return Zn.getInlineStyleFromMetadata(i,t)}getPresentation(e){const t=this._tokens[(e<<1)+1];return Zn.getPresentationFromMetadata(t)}getEndOffset(e){return this._tokens[e<<1]}findTokenIndexAtOffset(e){return vn.findIndexInTokensArray(this._tokens,e)}inflate(){return this}sliceAndInflate(e,t,i){return new gP(this,e,t,i)}static convertToEndOffset(e,t){const n=(e.length>>>1)-1;for(let o=0;o<n;o++)e[o<<1]=e[o+1<<1];e[n<<1]=t}static findIndexInTokensArray(e,t){if(e.length<=2)return 0;let i=0,n=(e.length>>>1)-1;for(;i<n;){const o=i+Math.floor((n-i)/2),r=e[o<<1];if(r===t)return o+1;r<t?i=o+1:r>t&&(n=o)}return i}withInserted(e){if(e.length===0)return this;let t=0,i=0,n="";const o=new Array;let r=0;for(;;){const a=t<this._tokensCount?this._tokens[t<<1]:-1,l=i<e.length?e[i]:null;if(a!==-1&&(l===null||a<=l.offset)){n+=this._text.substring(r,a);const d=this._tokens[(t<<1)+1];o.push(n.length,d),t++,r=a}else if(l){if(l.offset>r){n+=this._text.substring(r,l.offset);const d=this._tokens[(t<<1)+1];o.push(n.length,d),r=l.offset}n+=l.text,o.push(n.length,l.tokenMetadata),i++}else break}return new vn(new Uint32Array(o),n,this._languageIdCodec)}}vn.defaultTokenMetadata=(32768|2<<24)>>>0;class gP{constructor(e,t,i,n){this._source=e,this._startOffset=t,this._endOffset=i,this._deltaOffset=n,this._firstTokenIndex=e.findTokenIndexAtOffset(t),this._tokensCount=0;for(let o=this._firstTokenIndex,r=e.getCount();o<r&&!(e.getStartOffset(o)>=i);o++)this._tokensCount++}getMetadata(e){return this._source.getMetadata(this._firstTokenIndex+e)}getLanguageId(e){return this._source.getLanguageId(this._firstTokenIndex+e)}getLineContent(){return this._source.getLineContent().substring(this._startOffset,this._endOffset)}equals(e){return e instanceof gP?this._startOffset===e._startOffset&&this._endOffset===e._endOffset&&this._deltaOffset===e._deltaOffset&&this._source.slicedEquals(e._source,this._firstTokenIndex,this._tokensCount):!1}getCount(){return this._tokensCount}getForeground(e){return this._source.getForeground(this._firstTokenIndex+e)}getEndOffset(e){const t=this._source.getEndOffset(this._firstTokenIndex+e);return Math.min(this._endOffset,t)-this._startOffset+this._deltaOffset}getClassName(e){return this._source.getClassName(this._firstTokenIndex+e)}getInlineStyle(e,t){return this._source.getInlineStyle(this._firstTokenIndex+e,t)}getPresentation(e){return this._source.getPresentation(this._firstTokenIndex+e)}findTokenIndexAtOffset(e){return this._source.findTokenIndexAtOffset(e+this._startOffset-this._deltaOffset)-this._firstTokenIndex}}class mo{constructor(e,t,i,n){this.startColumn=e,this.endColumn=t,this.className=i,this.type=n,this._lineDecorationBrand=void 0}static _equals(e,t){return e.startColumn===t.startColumn&&e.endColumn===t.endColumn&&e.className===t.className&&e.type===t.type}static equalsArr(e,t){const i=e.length,n=t.length;if(i!==n)return!1;for(let o=0;o<i;o++)if(!mo._equals(e[o],t[o]))return!1;return!0}static extractWrapped(e,t,i){if(e.length===0)return e;const n=t+1,o=i+1,r=i-t,a=[];let l=0;for(const d of e)d.endColumn<=n||d.startColumn>=o||(a[l++]=new mo(Math.max(1,d.startColumn-n+1),Math.min(r+1,d.endColumn-n+1),d.className,d.type));return a}static filter(e,t,i,n){if(e.length===0)return[];const o=[];let r=0;for(let a=0,l=e.length;a<l;a++){const d=e[a],c=d.range;if(c.endLineNumber<t||c.startLineNumber>t||c.isEmpty()&&(d.type===0||d.type===3))continue;const u=c.startLineNumber===t?c.startColumn:i,h=c.endLineNumber===t?c.endColumn:n;o[r++]=new mo(u,h,d.inlineClassName,d.type)}return o}static _typeCompare(e,t){const i=[2,0,1,3];return i[e]-i[t]}static compare(e,t){if(e.startColumn!==t.startColumn)return e.startColumn-t.startColumn;if(e.endColumn!==t.endColumn)return e.endColumn-t.endColumn;const i=mo._typeCompare(e.type,t.type);return i!==0?i:e.className!==t.className?e.className<t.className?-1:1:0}}class f3{constructor(e,t,i,n){this.startOffset=e,this.endOffset=t,this.className=i,this.metadata=n}}class KS{constructor(){this.stopOffsets=[],this.classNames=[],this.metadata=[],this.count=0}static _metadata(e){let t=0;for(let i=0,n=e.length;i<n;i++)t|=e[i];return t}consumeLowerThan(e,t,i){for(;this.count>0&&this.stopOffsets[0]<e;){let n=0;for(;n+1<this.count&&this.stopOffsets[n]===this.stopOffsets[n+1];)n++;i.push(new f3(t,this.stopOffsets[n],this.classNames.join(" "),KS._metadata(this.metadata))),t=this.stopOffsets[n]+1,this.stopOffsets.splice(0,n+1),this.classNames.splice(0,n+1),this.metadata.splice(0,n+1),this.count-=n+1}return this.count>0&&t<e&&(i.push(new f3(t,e-1,this.classNames.join(" "),KS._metadata(this.metadata))),t=e),t}insert(e,t,i){if(this.count===0||this.stopOffsets[this.count-1]<=e)this.stopOffsets.push(e),this.classNames.push(t),this.metadata.push(i);else for(let n=0;n<this.count;n++)if(this.stopOffsets[n]>=e){this.stopOffsets.splice(n,0,e),this.classNames.splice(n,0,t),this.metadata.splice(n,0,i);break}this.count++}}class une{static normalize(e,t){if(t.length===0)return[];const i=[],n=new KS;let o=0;for(let r=0,a=t.length;r<a;r++){const l=t[r];let d=l.startColumn,c=l.endColumn;const u=l.className,h=l.type===1?2:l.type===2?4:0;if(d>1){const m=e.charCodeAt(d-2);_n(m)&&d--}if(c>1){const m=e.charCodeAt(c-2);_n(m)&&c--}const g=d-1,f=c-2;o=n.consumeLowerThan(g,o,i),n.count===0&&(o=g),n.insert(f,u,h)}return n.consumeLowerThan(1073741824,o,i),i}}class Dn{constructor(e,t,i,n){this.endIndex=e,this.type=t,this.metadata=i,this.containsRTL=n,this._linePartBrand=void 0}isWhitespace(){return!!(this.metadata&1)}isPseudoAfter(){return!!(this.metadata&4)}}class XV{constructor(e,t){this.startOffset=e,this.endOffset=t}equals(e){return this.startOffset===e.startOffset&&this.endOffset===e.endOffset}}class sh{constructor(e,t,i,n,o,r,a,l,d,c,u,h,g,f,m,_,v,b,C){this.useMonospaceOptimizations=e,this.canUseHalfwidthRightwardsArrow=t,this.lineContent=i,this.continuesWithWrappedLine=n,this.isBasicASCII=o,this.containsRTL=r,this.fauxIndentLength=a,this.lineTokens=l,this.lineDecorations=d.sort(mo.compare),this.tabSize=c,this.startVisibleColumn=u,this.spaceWidth=h,this.stopRenderingLineAfter=m,this.renderWhitespace=_==="all"?4:_==="boundary"?1:_==="selection"?2:_==="trailing"?3:0,this.renderControlCharacters=v,this.fontLigatures=b,this.selectionsOnLine=C&&C.sort((x,L)=>x.startOffset<L.startOffset?-1:1);const w=Math.abs(f-h),S=Math.abs(g-h);w<S?(this.renderSpaceWidth=f,this.renderSpaceCharCode=11825):(this.renderSpaceWidth=g,this.renderSpaceCharCode=183)}sameSelection(e){if(this.selectionsOnLine===null)return e===null;if(e===null||e.length!==this.selectionsOnLine.length)return!1;for(let t=0;t<this.selectionsOnLine.length;t++)if(!this.selectionsOnLine[t].equals(e[t]))return!1;return!0}equals(e){return this.useMonospaceOptimizations===e.useMonospaceOptimizations&&this.canUseHalfwidthRightwardsArrow===e.canUseHalfwidthRightwardsArrow&&this.lineContent===e.lineContent&&this.continuesWithWrappedLine===e.continuesWithWrappedLine&&this.isBasicASCII===e.isBasicASCII&&this.containsRTL===e.containsRTL&&this.fauxIndentLength===e.fauxIndentLength&&this.tabSize===e.tabSize&&this.startVisibleColumn===e.startVisibleColumn&&this.spaceWidth===e.spaceWidth&&this.renderSpaceWidth===e.renderSpaceWidth&&this.renderSpaceCharCode===e.renderSpaceCharCode&&this.stopRenderingLineAfter===e.stopRenderingLineAfter&&this.renderWhitespace===e.renderWhitespace&&this.renderControlCharacters===e.renderControlCharacters&&this.fontLigatures===e.fontLigatures&&mo.equalsArr(this.lineDecorations,e.lineDecorations)&&this.lineTokens.equals(e.lineTokens)&&this.sameSelection(e.selectionsOnLine)}}class QV{constructor(e,t){this.partIndex=e,this.charIndex=t}}class gl{static getPartIndex(e){return(e&4294901760)>>>16}static getCharIndex(e){return(e&65535)>>>0}constructor(e,t){this.length=e,this._data=new Uint32Array(this.length),this._horizontalOffset=new Uint32Array(this.length)}setColumnInfo(e,t,i,n){const o=(t<<16|i<<0)>>>0;this._data[e-1]=o,this._horizontalOffset[e-1]=n}getHorizontalOffset(e){return this._horizontalOffset.length===0?0:this._horizontalOffset[e-1]}charOffsetToPartData(e){return this.length===0?0:e<0?this._data[0]:e>=this.length?this._data[this.length-1]:this._data[e]}getDomPosition(e){const t=this.charOffsetToPartData(e-1),i=gl.getPartIndex(t),n=gl.getCharIndex(t);return new QV(i,n)}getColumn(e,t){return this.partDataToCharOffset(e.partIndex,t,e.charIndex)+1}partDataToCharOffset(e,t,i){if(this.length===0)return 0;const n=(e<<16|i<<0)>>>0;let o=0,r=this.length-1;for(;o+1<r;){const m=o+r>>>1,_=this._data[m];if(_===n)return m;_>n?r=m:o=m}if(o===r)return o;const a=this._data[o],l=this._data[r];if(a===n)return o;if(l===n)return r;const d=gl.getPartIndex(a),c=gl.getCharIndex(a),u=gl.getPartIndex(l);let h;d!==u?h=t:h=gl.getCharIndex(l);const g=i-c,f=h-i;return g<=f?o:r}}class lT{constructor(e,t,i){this._renderLineOutputBrand=void 0,this.characterMapping=e,this.containsRTL=t,this.containsForeignElements=i}}function lC(s,e){if(s.lineContent.length===0){if(s.lineDecorations.length>0){e.appendString("<span>");let t=0,i=0,n=0;for(const r of s.lineDecorations)(r.type===1||r.type===2)&&(e.appendString('<span class="'),e.appendString(r.className),e.appendString('"></span>'),r.type===1&&(n|=1,t++),r.type===2&&(n|=2,i++));e.appendString("</span>");const o=new gl(1,t+i);return o.setColumnInfo(1,t,0,0),new lT(o,!1,n)}return e.appendString("<span><span></span></span>"),new lT(new gl(0,0),!1,0)}return Cne(fne(s),e)}class hne{constructor(e,t,i,n){this.characterMapping=e,this.html=t,this.containsRTL=i,this.containsForeignElements=n}}function vx(s){const e=new s_(1e4),t=lC(s,e);return new hne(t.characterMapping,e.build(),t.containsRTL,t.containsForeignElements)}class gne{constructor(e,t,i,n,o,r,a,l,d,c,u,h,g,f,m,_){this.fontIsMonospace=e,this.canUseHalfwidthRightwardsArrow=t,this.lineContent=i,this.len=n,this.isOverflowing=o,this.overflowingCharCount=r,this.parts=a,this.containsForeignElements=l,this.fauxIndentLength=d,this.tabSize=c,this.startVisibleColumn=u,this.containsRTL=h,this.spaceWidth=g,this.renderSpaceCharCode=f,this.renderWhitespace=m,this.renderControlCharacters=_}}function fne(s){const e=s.lineContent;let t,i,n;s.stopRenderingLineAfter!==-1&&s.stopRenderingLineAfter<e.length?(t=!0,i=e.length-s.stopRenderingLineAfter,n=s.stopRenderingLineAfter):(t=!1,i=0,n=e.length);let o=pne(e,s.containsRTL,s.lineTokens,s.fauxIndentLength,n);s.renderControlCharacters&&!s.isBasicASCII&&(o=_ne(e,o)),(s.renderWhitespace===4||s.renderWhitespace===1||s.renderWhitespace===2&&s.selectionsOnLine||s.renderWhitespace===3&&!s.continuesWithWrappedLine)&&(o=vne(s,e,n,o));let r=0;if(s.lineDecorations.length>0){for(let a=0,l=s.lineDecorations.length;a<l;a++){const d=s.lineDecorations[a];d.type===3||d.type===1?r|=1:d.type===2&&(r|=2)}o=bne(e,n,o,s.lineDecorations)}return s.containsRTL||(o=mne(e,o,!s.isBasicASCII||s.fontLigatures)),new gne(s.useMonospaceOptimizations,s.canUseHalfwidthRightwardsArrow,e,n,t,i,o,r,s.fauxIndentLength,s.tabSize,s.startVisibleColumn,s.containsRTL,s.spaceWidth,s.renderSpaceCharCode,s.renderWhitespace,s.renderControlCharacters)}function pne(s,e,t,i,n){const o=[];let r=0;i>0&&(o[r++]=new Dn(i,"",0,!1));let a=i;for(let l=0,d=t.getCount();l<d;l++){const c=t.getEndOffset(l);if(c<=i)continue;const u=t.getClassName(l);if(c>=n){const g=e?dm(s.substring(a,n)):!1;o[r++]=new Dn(n,u,0,g);break}const h=e?dm(s.substring(a,c)):!1;o[r++]=new Dn(c,u,0,h),a=c}return o}function mne(s,e,t){let i=0;const n=[];let o=0;if(t)for(let r=0,a=e.length;r<a;r++){const l=e[r],d=l.endIndex;if(i+50<d){const c=l.type,u=l.metadata,h=l.containsRTL;let g=-1,f=i;for(let m=i;m<d;m++)s.charCodeAt(m)===32&&(g=m),g!==-1&&m-f>=50&&(n[o++]=new Dn(g+1,c,u,h),f=g+1,g=-1);f!==d&&(n[o++]=new Dn(d,c,u,h))}else n[o++]=l;i=d}else for(let r=0,a=e.length;r<a;r++){const l=e[r],d=l.endIndex,c=d-i;if(c>50){const u=l.type,h=l.metadata,g=l.containsRTL,f=Math.ceil(c/50);for(let m=1;m<f;m++){const _=i+m*50;n[o++]=new Dn(_,u,h,g)}n[o++]=new Dn(d,u,h,g)}else n[o++]=l;i=d}return n}function JV(s){return s<32?s!==9:s===127||s>=8234&&s<=8238||s>=8294&&s<=8297||s>=8206&&s<=8207||s===1564}function _ne(s,e){const t=[];let i=new Dn(0,"",0,!1),n=0;for(const o of e){const r=o.endIndex;for(;n<r;n++){const a=s.charCodeAt(n);JV(a)&&(n>i.endIndex&&(i=new Dn(n,o.type,o.metadata,o.containsRTL),t.push(i)),i=new Dn(n+1,"mtkcontrol",o.metadata,!1),t.push(i))}n>i.endIndex&&(i=new Dn(r,o.type,o.metadata,o.containsRTL),t.push(i))}return t}function vne(s,e,t,i){const n=s.continuesWithWrappedLine,o=s.fauxIndentLength,r=s.tabSize,a=s.startVisibleColumn,l=s.useMonospaceOptimizations,d=s.selectionsOnLine,c=s.renderWhitespace===1,u=s.renderWhitespace===3,h=s.renderSpaceWidth!==s.spaceWidth,g=[];let f=0,m=0,_=i[m].type,v=i[m].containsRTL,b=i[m].endIndex;const C=i.length;let w=!1,S=ws(e),x;S===-1?(w=!0,S=t,x=t):x=Pa(e);let L=!1,k=0,I=d&&d[k],P=a%r;for(let A=o;A<t;A++){const z=e.charCodeAt(A);I&&A>=I.endOffset&&(k++,I=d&&d[k]);let K;if(A<S||A>x)K=!0;else if(z===9)K=!0;else if(z===32)if(c)if(L)K=!0;else{const Q=A+1<t?e.charCodeAt(A+1):0;K=Q===32||Q===9}else K=!0;else K=!1;if(K&&d&&(K=!!I&&I.startOffset<=A&&I.endOffset>A),K&&u&&(K=w||A>x),K&&v&&A>=S&&A<=x&&(K=!1),L){if(!K||!l&&P>=r){if(h){const Q=f>0?g[f-1].endIndex:o;for(let ne=Q+1;ne<=A;ne++)g[f++]=new Dn(ne,"mtkw",1,!1)}else g[f++]=new Dn(A,"mtkw",1,!1);P=P%r}}else(A===b||K&&A>o)&&(g[f++]=new Dn(A,_,0,v),P=P%r);for(z===9?P=r:ku(z)?P+=2:P++,L=K;A===b&&(m++,m<C);)_=i[m].type,v=i[m].containsRTL,b=i[m].endIndex}let $=!1;if(L)if(n&&c){const A=t>0?e.charCodeAt(t-1):0,z=t>1?e.charCodeAt(t-2):0;A===32&&z!==32&&z!==9||($=!0)}else $=!0;if($)if(h){const A=f>0?g[f-1].endIndex:o;for(let z=A+1;z<=t;z++)g[f++]=new Dn(z,"mtkw",1,!1)}else g[f++]=new Dn(t,"mtkw",1,!1);else g[f++]=new Dn(t,_,0,v);return g}function bne(s,e,t,i){i.sort(mo.compare);const n=une.normalize(s,i),o=n.length;let r=0;const a=[];let l=0,d=0;for(let u=0,h=t.length;u<h;u++){const g=t[u],f=g.endIndex,m=g.type,_=g.metadata,v=g.containsRTL;for(;r<o&&n[r].startOffset<f;){const b=n[r];if(b.startOffset>d&&(d=b.startOffset,a[l++]=new Dn(d,m,_,v)),b.endOffset+1<=f)d=b.endOffset+1,a[l++]=new Dn(d,m+" "+b.className,_|b.metadata,v),r++;else{d=f,a[l++]=new Dn(d,m+" "+b.className,_|b.metadata,v);break}}f>d&&(d=f,a[l++]=new Dn(d,m,_,v))}const c=t[t.length-1].endIndex;if(r<o&&n[r].startOffset===c)for(;r<o&&n[r].startOffset===c;){const u=n[r];a[l++]=new Dn(d,u.className,u.metadata,!1),r++}return a}function Cne(s,e){const t=s.fontIsMonospace,i=s.canUseHalfwidthRightwardsArrow,n=s.containsForeignElements,o=s.lineContent,r=s.len,a=s.isOverflowing,l=s.overflowingCharCount,d=s.parts,c=s.fauxIndentLength,u=s.tabSize,h=s.startVisibleColumn,g=s.containsRTL,f=s.spaceWidth,m=s.renderSpaceCharCode,_=s.renderWhitespace,v=s.renderControlCharacters,b=new gl(r+1,d.length);let C=!1,w=0,S=h,x=0,L=0,k=0;g?e.appendString('<span dir="ltr">'):e.appendString("<span>");for(let I=0,P=d.length;I<P;I++){const $=d[I],A=$.endIndex,z=$.type,K=$.containsRTL,Q=_!==0&&$.isWhitespace(),ne=Q&&!t&&(z==="mtkw"||!n),fe=w===A&&$.isPseudoAfter();if(x=0,e.appendString("<span "),K&&e.appendString('style="unicode-bidi:isolate" '),e.appendString('class="'),e.appendString(ne?"mtkz":z),e.appendASCIICharCode(34),Q){let ve=0;{let ye=w,Be=S;for(;ye<A;ye++){const Ie=(o.charCodeAt(ye)===9?u-Be%u:1)|0;ve+=Ie,ye>=c&&(Be+=Ie)}}for(ne&&(e.appendString(' style="width:'),e.appendString(String(f*ve)),e.appendString('px"')),e.appendASCIICharCode(62);w<A;w++){b.setColumnInfo(w+1,I-k,x,L),k=0;const ye=o.charCodeAt(w);let Be,Ve;if(ye===9){Be=u-S%u|0,Ve=Be,!i||Ve>1?e.appendCharCode(8594):e.appendCharCode(65515);for(let Ie=2;Ie<=Ve;Ie++)e.appendCharCode(160)}else Be=2,Ve=1,e.appendCharCode(m),e.appendCharCode(8204);x+=Be,L+=Ve,w>=c&&(S+=Ve)}}else for(e.appendASCIICharCode(62);w<A;w++){b.setColumnInfo(w+1,I-k,x,L),k=0;const ve=o.charCodeAt(w);let ye=1,Be=1;switch(ve){case 9:ye=u-S%u,Be=ye;for(let Ve=1;Ve<=ye;Ve++)e.appendCharCode(160);break;case 32:e.appendCharCode(160);break;case 60:e.appendString("&lt;");break;case 62:e.appendString("&gt;");break;case 38:e.appendString("&amp;");break;case 0:v?e.appendCharCode(9216):e.appendString("&#00;");break;case 65279:case 8232:case 8233:case 133:e.appendCharCode(65533);break;default:ku(ve)&&Be++,v&&ve<32?e.appendCharCode(9216+ve):v&&ve===127?e.appendCharCode(9249):v&&JV(ve)?(e.appendString("[U+"),e.appendString(wne(ve)),e.appendString("]"),ye=8,Be=ye):e.appendCharCode(ve)}x+=ye,L+=Be,w>=c&&(S+=Be)}fe?k++:k=0,w>=r&&!C&&$.isPseudoAfter()&&(C=!0,b.setColumnInfo(w+1,I,x,L)),e.appendString("</span>")}return C||b.setColumnInfo(r+1,d.length-1,x,L),a&&(e.appendString('<span class="mtkoverflow">'),e.appendString(p("showMore","Show more ({0})",Sne(l))),e.appendString("</span>")),e.appendString("</span>"),new lT(b,g,n)}function wne(s){return s.toString(16).toUpperCase().padStart(4,"0")}function Sne(s){return s<1024?p("overflow.chars","{0} chars",s):s<1024*1024?`${(s/1024).toFixed(1)} KB`:`${(s/1024/1024).toFixed(1)} MB`}class p3{constructor(e,t,i,n){this._viewportBrand=void 0,this.top=e|0,this.left=t|0,this.width=i|0,this.height=n|0}}class yne{constructor(e,t){this.tabSize=e,this.data=t}}class fP{constructor(e,t,i,n,o,r,a){this._viewLineDataBrand=void 0,this.content=e,this.continuesWithWrappedLine=t,this.minColumn=i,this.maxColumn=n,this.startVisibleColumn=o,this.tokens=r,this.inlineDecorations=a}}class sr{constructor(e,t,i,n,o,r,a,l,d,c){this.minColumn=e,this.maxColumn=t,this.content=i,this.continuesWithWrappedLine=n,this.isBasicASCII=sr.isBasicASCII(i,r),this.containsRTL=sr.containsRTL(i,this.isBasicASCII,o),this.tokens=a,this.inlineDecorations=l,this.tabSize=d,this.startVisibleColumn=c}static isBasicASCII(e,t){return t?sC(e):!0}static containsRTL(e,t,i){return!t&&i?dm(e):!1}}class Pv{constructor(e,t,i){this.range=e,this.inlineClassName=t,this.type=i}}class Lne{constructor(e,t,i,n){this.startOffset=e,this.endOffset=t,this.inlineClassName=i,this.inlineClassNameAffectsLetterSpacing=n}toInlineDecoration(e){return new Pv(new D(e,this.startOffset+1,e,this.endOffset+1),this.inlineClassName,this.inlineClassNameAffectsLetterSpacing?3:0)}}class eH{constructor(e,t){this._viewModelDecorationBrand=void 0,this.range=e,this.options=t}}class F0{constructor(e,t,i){this.color=e,this.zIndex=t,this.data=i}static compareByRenderingProps(e,t){return e.zIndex===t.zIndex?e.color<t.color?-1:e.color>t.color?1:0:e.zIndex-t.zIndex}static equals(e,t){return e.color===t.color&&e.zIndex===t.zIndex&&Ai(e.data,t.data)}static equalsArr(e,t){return Ai(e,t,F0.equals)}}function xne(s){return Array.isArray(s)}function Dne(s){return!xne(s)}function tH(s){return typeof s=="string"}function m3(s){return!tH(s)}function qf(s){return!s}function du(s,e){return s.ignoreCase&&e?e.toLowerCase():e}function _3(s){return s.replace(/[&<>'"_]/g,"-")}function kne(s,e){console.log(`${s.languageId}: ${e}`)}function oi(s,e){return new Error(`${s.languageId}: ${e}`)}function Ac(s,e,t,i,n){const o=/\$((\$)|(#)|(\d\d?)|[sS](\d\d?)|@(\w+))/g;let r=null;return e.replace(o,function(a,l,d,c,u,h,g,f,m){return qf(d)?qf(c)?!qf(u)&&u<i.length?du(s,i[u]):!qf(g)&&s&&typeof s[g]=="string"?s[g]:(r===null&&(r=n.split("."),r.unshift(n)),!qf(h)&&h<r.length?du(s,r[h]):""):du(s,t):"$"})}function u1(s,e){let t=e;for(;t&&t.length>0;){const i=s.tokenizer[t];if(i)return i;const n=t.lastIndexOf(".");n<0?t=null:t=t.substr(0,n)}return null}function Ine(s,e){let t=e;for(;t&&t.length>0;){if(s.stateNames[t])return!0;const n=t.lastIndexOf(".");n<0?t=null:t=t.substr(0,n)}return!1}var Ene=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Nne=function(s,e){return function(t,i){e(t,i,s)}},dT;const iH=5;class B0{static create(e,t){return this._INSTANCE.create(e,t)}constructor(e){this._maxCacheDepth=e,this._entries=Object.create(null)}create(e,t){if(e!==null&&e.depth>=this._maxCacheDepth)return new Bp(e,t);let i=Bp.getStackElementId(e);i.length>0&&(i+="|"),i+=t;let n=this._entries[i];return n||(n=new Bp(e,t),this._entries[i]=n,n)}}B0._INSTANCE=new B0(iH);class Bp{constructor(e,t){this.parent=e,this.state=t,this.depth=(this.parent?this.parent.depth:0)+1}static getStackElementId(e){let t="";for(;e!==null;)t.length>0&&(t+="|"),t+=e.state,e=e.parent;return t}static _equals(e,t){for(;e!==null&&t!==null;){if(e===t)return!0;if(e.state!==t.state)return!1;e=e.parent,t=t.parent}return e===null&&t===null}equals(e){return Bp._equals(this,e)}push(e){return B0.create(this,e)}pop(){return this.parent}popall(){let e=this;for(;e.parent;)e=e.parent;return e}switchTo(e){return B0.create(this.parent,e)}}class ap{constructor(e,t){this.languageId=e,this.state=t}equals(e){return this.languageId===e.languageId&&this.state.equals(e.state)}clone(){return this.state.clone()===this.state?this:new ap(this.languageId,this.state)}}class Pc{static create(e,t){return this._INSTANCE.create(e,t)}constructor(e){this._maxCacheDepth=e,this._entries=Object.create(null)}create(e,t){if(t!==null)return new Ov(e,t);if(e!==null&&e.depth>=this._maxCacheDepth)return new Ov(e,t);const i=Bp.getStackElementId(e);let n=this._entries[i];return n||(n=new Ov(e,null),this._entries[i]=n,n)}}Pc._INSTANCE=new Pc(iH);class Ov{constructor(e,t){this.stack=e,this.embeddedLanguageData=t}clone(){return(this.embeddedLanguageData?this.embeddedLanguageData.clone():null)===this.embeddedLanguageData?this:Pc.create(this.stack,this.embeddedLanguageData)}equals(e){return!(e instanceof Ov)||!this.stack.equals(e.stack)?!1:this.embeddedLanguageData===null&&e.embeddedLanguageData===null?!0:this.embeddedLanguageData===null||e.embeddedLanguageData===null?!1:this.embeddedLanguageData.equals(e.embeddedLanguageData)}}class Tne{constructor(){this._tokens=[],this._languageId=null,this._lastTokenType=null,this._lastTokenLanguage=null}enterLanguage(e){this._languageId=e}emit(e,t){this._lastTokenType===t&&this._lastTokenLanguage===this._languageId||(this._lastTokenType=t,this._lastTokenLanguage=this._languageId,this._tokens.push(new S0(e,t,this._languageId)))}nestedLanguageTokenize(e,t,i,n){const o=i.languageId,r=i.state,a=xi.get(o);if(!a)return this.enterLanguage(o),this.emit(n,""),r;const l=a.tokenize(e,t,r);if(n!==0)for(const d of l.tokens)this._tokens.push(new S0(d.offset+n,d.type,d.language));else this._tokens=this._tokens.concat(l.tokens);return this._lastTokenType=null,this._lastTokenLanguage=null,this._languageId=null,l.endState}finalize(e){return new PA(this._tokens,e)}}class qS{constructor(e,t){this._languageService=e,this._theme=t,this._prependTokens=null,this._tokens=[],this._currentLanguageId=0,this._lastTokenMetadata=0}enterLanguage(e){this._currentLanguageId=this._languageService.languageIdCodec.encodeLanguageId(e)}emit(e,t){const i=this._theme.match(this._currentLanguageId,t)|1024;this._lastTokenMetadata!==i&&(this._lastTokenMetadata=i,this._tokens.push(e),this._tokens.push(i))}static _merge(e,t,i){const n=e!==null?e.length:0,o=t.length,r=i!==null?i.length:0;if(n===0&&o===0&&r===0)return new Uint32Array(0);if(n===0&&o===0)return i;if(o===0&&r===0)return e;const a=new Uint32Array(n+o+r);e!==null&&a.set(e);for(let l=0;l<o;l++)a[n+l]=t[l];return i!==null&&a.set(i,n+o),a}nestedLanguageTokenize(e,t,i,n){const o=i.languageId,r=i.state,a=xi.get(o);if(!a)return this.enterLanguage(o),this.emit(n,""),r;const l=a.tokenizeEncoded(e,t,r);if(n!==0)for(let d=0,c=l.tokens.length;d<c;d+=2)l.tokens[d]+=n;return this._prependTokens=qS._merge(this._prependTokens,this._tokens,l.tokens),this._tokens=[],this._currentLanguageId=0,this._lastTokenMetadata=0,l.endState}finalize(e){return new qL(qS._merge(this._prependTokens,this._tokens,null),e)}}let W0=dT=class extends j{constructor(e,t,i,n,o){super(),this._configurationService=o,this._languageService=e,this._standaloneThemeService=t,this._languageId=i,this._lexer=n,this._embeddedLanguages=Object.create(null),this.embeddedLoaded=Promise.resolve(void 0);let r=!1;this._register(xi.onDidChange(a=>{if(r)return;let l=!1;for(let d=0,c=a.changedLanguages.length;d<c;d++){const u=a.changedLanguages[d];if(this._embeddedLanguages[u]){l=!0;break}}l&&(r=!0,xi.handleChange([this._languageId]),r=!1)})),this._maxTokenizationLineLength=this._configurationService.getValue("editor.maxTokenizationLineLength",{overrideIdentifier:this._languageId}),this._register(this._configurationService.onDidChangeConfiguration(a=>{a.affectsConfiguration("editor.maxTokenizationLineLength")&&(this._maxTokenizationLineLength=this._configurationService.getValue("editor.maxTokenizationLineLength",{overrideIdentifier:this._languageId}))}))}getLoadStatus(){const e=[];for(const t in this._embeddedLanguages){const i=xi.get(t);if(i){if(i instanceof dT){const n=i.getLoadStatus();n.loaded===!1&&e.push(n.promise)}continue}xi.isResolved(t)||e.push(xi.getOrCreate(t))}return e.length===0?{loaded:!0}:{loaded:!1,promise:Promise.all(e).then(t=>{})}}getInitialState(){const e=B0.create(null,this._lexer.start);return Pc.create(e,null)}tokenize(e,t,i){if(e.length>=this._maxTokenizationLineLength)return hP(this._languageId,i);const n=new Tne,o=this._tokenize(e,t,i,n);return n.finalize(o)}tokenizeEncoded(e,t,i){if(e.length>=this._maxTokenizationLineLength)return _x(this._languageService.languageIdCodec.encodeLanguageId(this._languageId),i);const n=new qS(this._languageService,this._standaloneThemeService.getColorTheme().tokenTheme),o=this._tokenize(e,t,i,n);return n.finalize(o)}_tokenize(e,t,i,n){return i.embeddedLanguageData?this._nestedTokenize(e,t,i,0,n):this._myTokenize(e,t,i,0,n)}_findLeavingNestedLanguageOffset(e,t){let i=this._lexer.tokenizer[t.stack.state];if(!i&&(i=u1(this._lexer,t.stack.state),!i))throw oi(this._lexer,"tokenizer state is not defined: "+t.stack.state);let n=-1,o=!1;for(const r of i){if(!m3(r.action)||r.action.nextEmbedded!=="@pop")continue;o=!0;let a=r.regex;const l=r.regex.source;if(l.substr(0,4)==="^(?:"&&l.substr(l.length-1,1)===")"){const c=(a.ignoreCase?"i":"")+(a.unicode?"u":"");a=new RegExp(l.substr(4,l.length-5),c)}const d=e.search(a);d===-1||d!==0&&r.matchOnlyAtLineStart||(n===-1||d<n)&&(n=d)}if(!o)throw oi(this._lexer,'no rule containing nextEmbedded: "@pop" in tokenizer embedded state: '+t.stack.state);return n}_nestedTokenize(e,t,i,n,o){const r=this._findLeavingNestedLanguageOffset(e,i);if(r===-1){const d=o.nestedLanguageTokenize(e,t,i.embeddedLanguageData,n);return Pc.create(i.stack,new ap(i.embeddedLanguageData.languageId,d))}const a=e.substring(0,r);a.length>0&&o.nestedLanguageTokenize(a,!1,i.embeddedLanguageData,n);const l=e.substring(r);return this._myTokenize(l,t,i,n+r,o)}_safeRuleName(e){return e?e.name:"(unknown)"}_myTokenize(e,t,i,n,o){o.enterLanguage(this._languageId);const r=e.length,a=t&&this._lexer.includeLF?e+`
`:e,l=a.length;let d=i.embeddedLanguageData,c=i.stack,u=0,h=null,g=!0;for(;g||u<l;){const f=u,m=c.depth,_=h?h.groups.length:0,v=c.state;let b=null,C=null,w=null,S=null,x=null;if(h){b=h.matches;const I=h.groups.shift();C=I.matched,w=I.action,S=h.rule,h.groups.length===0&&(h=null)}else{if(!g&&u>=l)break;g=!1;let I=this._lexer.tokenizer[v];if(!I&&(I=u1(this._lexer,v),!I))throw oi(this._lexer,"tokenizer state is not defined: "+v);const P=a.substr(u);for(const $ of I)if((u===0||!$.matchOnlyAtLineStart)&&(b=P.match($.regex),b)){C=b[0],w=$.action;break}}if(b||(b=[""],C=""),w||(u<l&&(b=[a.charAt(u)],C=b[0]),w=this._lexer.defaultToken),C===null)break;for(u+=C.length;Dne(w)&&m3(w)&&w.test;)w=w.test(C,b,v,u===l);let L=null;if(typeof w=="string"||Array.isArray(w))L=w;else if(w.group)L=w.group;else if(w.token!==null&&w.token!==void 0){if(w.tokenSubst?L=Ac(this._lexer,w.token,C,b,v):L=w.token,w.nextEmbedded)if(w.nextEmbedded==="@pop"){if(!d)throw oi(this._lexer,"cannot pop embedded language if not inside one");d=null}else{if(d)throw oi(this._lexer,"cannot enter embedded language from within an embedded language");x=Ac(this._lexer,w.nextEmbedded,C,b,v)}if(w.goBack&&(u=Math.max(0,u-w.goBack)),w.switchTo&&typeof w.switchTo=="string"){let I=Ac(this._lexer,w.switchTo,C,b,v);if(I[0]==="@"&&(I=I.substr(1)),u1(this._lexer,I))c=c.switchTo(I);else throw oi(this._lexer,"trying to switch to a state '"+I+"' that is undefined in rule: "+this._safeRuleName(S))}else{if(w.transform&&typeof w.transform=="function")throw oi(this._lexer,"action.transform not supported");if(w.next)if(w.next==="@push"){if(c.depth>=this._lexer.maxStack)throw oi(this._lexer,"maximum tokenizer stack size reached: ["+c.state+","+c.parent.state+",...]");c=c.push(v)}else if(w.next==="@pop"){if(c.depth<=1)throw oi(this._lexer,"trying to pop an empty stack in rule: "+this._safeRuleName(S));c=c.pop()}else if(w.next==="@popall")c=c.popall();else{let I=Ac(this._lexer,w.next,C,b,v);if(I[0]==="@"&&(I=I.substr(1)),u1(this._lexer,I))c=c.push(I);else throw oi(this._lexer,"trying to set a next state '"+I+"' that is undefined in rule: "+this._safeRuleName(S))}}w.log&&typeof w.log=="string"&&kne(this._lexer,this._lexer.languageId+": "+Ac(this._lexer,w.log,C,b,v))}if(L===null)throw oi(this._lexer,"lexer rule has no well-defined action in rule: "+this._safeRuleName(S));const k=I=>{const P=this._languageService.getLanguageIdByLanguageName(I)||this._languageService.getLanguageIdByMimeType(I)||I,$=this._getNestedEmbeddedLanguageData(P);if(u<l){const A=e.substr(u);return this._nestedTokenize(A,t,Pc.create(c,$),n+u,o)}else return Pc.create(c,$)};if(Array.isArray(L)){if(h&&h.groups.length>0)throw oi(this._lexer,"groups cannot be nested: "+this._safeRuleName(S));if(b.length!==L.length+1)throw oi(this._lexer,"matched number of groups does not match the number of actions in rule: "+this._safeRuleName(S));let I=0;for(let P=1;P<b.length;P++)I+=b[P].length;if(I!==C.length)throw oi(this._lexer,"with groups, all characters should be matched in consecutive groups in rule: "+this._safeRuleName(S));h={rule:S,matches:b,groups:[]};for(let P=0;P<L.length;P++)h.groups[P]={action:L[P],matched:b[P+1]};u-=C.length;continue}else{if(L==="@rematch"&&(u-=C.length,C="",b=null,L="",x!==null))return k(x);if(C.length===0){if(l===0||m!==c.depth||v!==c.state||(h?h.groups.length:0)!==_)continue;throw oi(this._lexer,"no progress in tokenizer in rule: "+this._safeRuleName(S))}let I=null;if(tH(L)&&L.indexOf("@brackets")===0){const P=L.substr(9),$=Mne(this._lexer,C);if(!$)throw oi(this._lexer,"@brackets token returned but no bracket defined as: "+C);I=_3($.token+P)}else{const P=L===""?"":L+this._lexer.tokenPostfix;I=_3(P)}f<r&&o.emit(f+n,I)}if(x!==null)return k(x)}return Pc.create(c,d)}_getNestedEmbeddedLanguageData(e){if(!this._languageService.isRegisteredLanguageId(e))return new ap(e,pm);e!==this._languageId&&(this._languageService.requestBasicLanguageFeatures(e),xi.getOrCreate(e),this._embeddedLanguages[e]=!0);const t=xi.get(e);return t?new ap(e,t.getInitialState()):new ap(e,pm)}};W0=dT=Ene([Nne(4,mt)],W0);function Mne(s,e){if(!e)return null;e=du(s,e);const t=s.brackets;for(const i of t){if(i.open===e)return{token:i.token,bracketType:1};if(i.close===e)return{token:i.token,bracketType:-1}}return null}const tI=oc("standaloneColorizer",{createHTML:s=>s});class pP{static colorizeElement(e,t,i,n){n=n||{};const o=n.theme||"vs",r=n.mimeType||i.getAttribute("lang")||i.getAttribute("data-lang");if(!r)return console.error("Mode not detected"),Promise.resolve();const a=t.getLanguageIdByMimeType(r)||r;e.setTheme(o);const l=i.firstChild?i.firstChild.nodeValue:"";i.className+=" "+o;const d=c=>{var u;const h=(u=tI==null?void 0:tI.createHTML(c))!==null&&u!==void 0?u:c;i.innerHTML=h};return this.colorize(t,l||"",a,n).then(d,c=>console.error(c))}static async colorize(e,t,i,n){const o=e.languageIdCodec;let r=4;n&&typeof n.tabSize=="number"&&(r=n.tabSize),zA(t)&&(t=t.substr(1));const a=Kl(t);if(!e.isRegisteredLanguageId(i))return v3(a,r,o);const l=await xi.getOrCreate(i);return l?Rne(a,r,l,o):v3(a,r,o)}static colorizeLine(e,t,i,n,o=4){const r=sr.isBasicASCII(e,t),a=sr.containsRTL(e,r,i);return vx(new sh(!1,!0,e,!1,r,a,0,n,[],o,0,0,0,0,-1,"none",!1,!1,null)).html}static colorizeModelLine(e,t,i=4){const n=e.getLineContent(t);e.tokenization.forceTokenization(t);const r=e.tokenization.getLineTokens(t).inflate();return this.colorizeLine(n,e.mightContainNonBasicASCII(),e.mightContainRTL(),r,i)}}function Rne(s,e,t,i){return new Promise((n,o)=>{const r=()=>{const a=Ane(s,e,t,i);if(t instanceof W0){const l=t.getLoadStatus();if(l.loaded===!1){l.promise.then(r,o);return}}n(a)};r()})}function v3(s,e,t){let i=[];const o=new Uint32Array(2);o[0]=0,o[1]=33587200;for(let r=0,a=s.length;r<a;r++){const l=s[r];o[0]=l.length;const d=new vn(o,l,t),c=sr.isBasicASCII(l,!0),u=sr.containsRTL(l,c,!0),h=vx(new sh(!1,!0,l,!1,c,u,0,d,[],e,0,0,0,0,-1,"none",!1,!1,null));i=i.concat(h.html),i.push("<br/>")}return i.join("")}function Ane(s,e,t,i){let n=[],o=t.getInitialState();for(let r=0,a=s.length;r<a;r++){const l=s[r],d=t.tokenizeEncoded(l,!0,o);vn.convertToEndOffset(d.tokens,l.length);const c=new vn(d.tokens,l,i),u=sr.isBasicASCII(l,!0),h=sr.containsRTL(l,u,!0),g=vx(new sh(!1,!0,l,!1,u,h,0,c.inflate(),[],e,0,0,0,0,-1,"none",!1,!1,null));n=n.concat(g.html),n.push("<br/>"),o=d.endState}return n.join("")}const b3=2e4;let $h,Ow,cT,Fw,uT;function Pne(s){$h=document.createElement("div"),$h.className="monaco-aria-container";const e=()=>{const i=document.createElement("div");return i.className="monaco-alert",i.setAttribute("role","alert"),i.setAttribute("aria-atomic","true"),$h.appendChild(i),i};Ow=e(),cT=e();const t=()=>{const i=document.createElement("div");return i.className="monaco-status",i.setAttribute("aria-live","polite"),i.setAttribute("aria-atomic","true"),$h.appendChild(i),i};Fw=t(),uT=t(),s.appendChild($h)}function Lo(s){$h&&(Ow.textContent!==s?(Vn(cT),GS(Ow,s)):(Vn(Ow),GS(cT,s)))}function Au(s){$h&&(Fw.textContent!==s?(Vn(uT),GS(Fw,s)):(Vn(Fw),GS(uT,s)))}function GS(s,e){Vn(s),e.length>b3&&(e=e.substr(0,b3)),s.textContent=e,s.style.visibility="hidden",s.style.visibility="visible"}const mP=ut("markerDecorationsService");var One=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Fne=function(s,e){return function(t,i){e(t,i,s)}};let V0=class{constructor(e,t){}dispose(){}};V0.ID="editor.contrib.markerDecorations";V0=One([Fne(1,mP)],V0);Lt(V0.ID,V0,0);class nH extends j{constructor(e,t){super(),this._onDidChange=this._register(new W),this.onDidChange=this._onDidChange.event,this._referenceDomElement=e,this._width=-1,this._height=-1,this._resizeObserver=null,this.measureReferenceDomElement(!1,t)}dispose(){this.stopObserving(),super.dispose()}getWidth(){return this._width}getHeight(){return this._height}startObserving(){if(!this._resizeObserver&&this._referenceDomElement){let e=null;const t=()=>{e?this.observe({width:e.width,height:e.height}):this.observe()};let i=!1,n=!1;const o=()=>{if(i&&!n)try{i=!1,n=!0,t()}finally{yo(Xe(this._referenceDomElement),()=>{n=!1,o()})}};this._resizeObserver=new ResizeObserver(r=>{e=r&&r[0]&&r[0].contentRect?r[0].contentRect:null,i=!0,o()}),this._resizeObserver.observe(this._referenceDomElement)}}stopObserving(){this._resizeObserver&&(this._resizeObserver.disconnect(),this._resizeObserver=null)}observe(e){this.measureReferenceDomElement(!0,e)}measureReferenceDomElement(e,t){let i=0,n=0;t?(i=t.width,n=t.height):this._referenceDomElement&&(i=this._referenceDomElement.clientWidth,n=this._referenceDomElement.clientHeight),i=Math.max(5,i),n=Math.max(5,n),(this._width!==i||this._height!==n)&&(this._width=i,this._height=n,e&&this._onDidChange.fire())}}class cu{constructor(e,t){this.key=e,this.migrate=t}apply(e){const t=cu._read(e,this.key),i=o=>cu._read(e,o),n=(o,r)=>cu._write(e,o,r);this.migrate(t,i,n)}static _read(e,t){if(typeof e>"u")return;const i=t.indexOf(".");if(i>=0){const n=t.substring(0,i);return this._read(e[n],t.substring(i+1))}return e[t]}static _write(e,t,i){const n=t.indexOf(".");if(n>=0){const o=t.substring(0,n);e[o]=e[o]||{},this._write(e[o],t.substring(n+1),i);return}e[t]=i}}cu.items=[];function rd(s,e){cu.items.push(new cu(s,e))}function Io(s,e){rd(s,(t,i,n)=>{if(typeof t<"u"){for(const[o,r]of e)if(t===o){n(s,r);return}}})}function Bne(s){cu.items.forEach(e=>e.apply(s))}Io("wordWrap",[[!0,"on"],[!1,"off"]]);Io("lineNumbers",[[!0,"on"],[!1,"off"]]);Io("cursorBlinking",[["visible","solid"]]);Io("renderWhitespace",[[!0,"boundary"],[!1,"none"]]);Io("renderLineHighlight",[[!0,"line"],[!1,"none"]]);Io("acceptSuggestionOnEnter",[[!0,"on"],[!1,"off"]]);Io("tabCompletion",[[!1,"off"],[!0,"onlySnippets"]]);Io("hover",[[!0,{enabled:!0}],[!1,{enabled:!1}]]);Io("parameterHints",[[!0,{enabled:!0}],[!1,{enabled:!1}]]);Io("autoIndent",[[!1,"advanced"],[!0,"full"]]);Io("matchBrackets",[[!0,"always"],[!1,"never"]]);Io("renderFinalNewline",[[!0,"on"],[!1,"off"]]);Io("cursorSmoothCaretAnimation",[[!0,"on"],[!1,"off"]]);Io("occurrencesHighlight",[[!0,"singleFile"],[!1,"off"]]);Io("wordBasedSuggestions",[[!0,"matchingDocuments"],[!1,"off"]]);rd("autoClosingBrackets",(s,e,t)=>{s===!1&&(t("autoClosingBrackets","never"),typeof e("autoClosingQuotes")>"u"&&t("autoClosingQuotes","never"),typeof e("autoSurround")>"u"&&t("autoSurround","never"))});rd("renderIndentGuides",(s,e,t)=>{typeof s<"u"&&(t("renderIndentGuides",void 0),typeof e("guides.indentation")>"u"&&t("guides.indentation",!!s))});rd("highlightActiveIndentGuide",(s,e,t)=>{typeof s<"u"&&(t("highlightActiveIndentGuide",void 0),typeof e("guides.highlightActiveIndentation")>"u"&&t("guides.highlightActiveIndentation",!!s))});const Wne={method:"showMethods",function:"showFunctions",constructor:"showConstructors",deprecated:"showDeprecated",field:"showFields",variable:"showVariables",class:"showClasses",struct:"showStructs",interface:"showInterfaces",module:"showModules",property:"showProperties",event:"showEvents",operator:"showOperators",unit:"showUnits",value:"showValues",constant:"showConstants",enum:"showEnums",enumMember:"showEnumMembers",keyword:"showKeywords",text:"showWords",color:"showColors",file:"showFiles",reference:"showReferences",folder:"showFolders",typeParameter:"showTypeParameters",snippet:"showSnippets"};rd("suggest.filteredTypes",(s,e,t)=>{if(s&&typeof s=="object"){for(const i of Object.entries(Wne))s[i[0]]===!1&&typeof e(`suggest.${i[1]}`)>"u"&&t(`suggest.${i[1]}`,!1);t("suggest.filteredTypes",void 0)}});rd("quickSuggestions",(s,e,t)=>{if(typeof s=="boolean"){const i=s?"on":"off";t("quickSuggestions",{comments:i,strings:i,other:i})}});rd("experimental.stickyScroll.enabled",(s,e,t)=>{typeof s=="boolean"&&(t("experimental.stickyScroll.enabled",void 0),typeof e("stickyScroll.enabled")>"u"&&t("stickyScroll.enabled",s))});rd("experimental.stickyScroll.maxLineCount",(s,e,t)=>{typeof s=="number"&&(t("experimental.stickyScroll.maxLineCount",void 0),typeof e("stickyScroll.maxLineCount")>"u"&&t("stickyScroll.maxLineCount",s))});rd("codeActionsOnSave",(s,e,t)=>{if(s&&typeof s=="object"){let i=!1;const n={};for(const o of Object.entries(s))typeof o[1]=="boolean"?(i=!0,n[o[0]]=o[1]?"explicit":"never"):n[o[0]]=o[1];i&&t("codeActionsOnSave",n)}});rd("codeActionWidget.includeNearbyQuickfixes",(s,e,t)=>{typeof s=="boolean"&&(t("codeActionWidget.includeNearbyQuickfixes",void 0),typeof e("codeActionWidget.includeNearbyQuickFixes")>"u"&&t("codeActionWidget.includeNearbyQuickFixes",s))});class Vne{constructor(){this._tabFocus=!1,this._onDidChangeTabFocus=new W,this.onDidChangeTabFocus=this._onDidChangeTabFocus.event}getTabFocusMode(){return this._tabFocus}setTabFocusMode(e){this._tabFocus=e,this._onDidChangeTabFocus.fire(this._tabFocus)}}const mm=new Vne,ad=ut("accessibilityService"),dC=new me("accessibilityModeEnabled",!1),bx=ut("accessibleNotificationService");var Hne=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},zne=function(s,e){return function(t,i){e(t,i,s)}};let hT=class extends j{constructor(e,t,i,n){super(),this._accessibilityService=n,this._onDidChange=this._register(new W),this.onDidChange=this._onDidChange.event,this._onDidChangeFast=this._register(new W),this.onDidChangeFast=this._onDidChangeFast.event,this._isDominatedByLongLines=!1,this._viewLineCount=1,this._lineNumbersDigitCount=1,this._reservedHeight=0,this._glyphMarginDecorationLaneCount=1,this._computeOptionsMemory=new LW,this.isSimpleWidget=e,this._containerObserver=this._register(new nH(i,t.dimension)),this._rawOptions=C3(t),this._validatedOptions=Oc.validateOptions(this._rawOptions),this.options=this._computeOptions(),this.options.get(13)&&this._containerObserver.startObserving(),this._register(fr.onDidChangeZoomLevel(()=>this._recomputeOptions())),this._register(mm.onDidChangeTabFocus(()=>this._recomputeOptions())),this._register(this._containerObserver.onDidChange(()=>this._recomputeOptions())),this._register(zN.onDidChange(()=>this._recomputeOptions())),this._register(D0.onDidChange(()=>this._recomputeOptions())),this._register(this._accessibilityService.onDidChangeScreenReaderOptimized(()=>this._recomputeOptions()))}_recomputeOptions(){const e=this._computeOptions(),t=Oc.checkEquals(this.options,e);t!==null&&(this.options=e,this._onDidChangeFast.fire(t),this._onDidChange.fire(t))}_computeOptions(){const e=this._readEnvConfiguration(),t=hg.createFromValidatedSettings(this._validatedOptions,e.pixelRatio,this.isSimpleWidget),i=this._readFontInfo(t),n={memory:this._computeOptionsMemory,outerWidth:e.outerWidth,outerHeight:e.outerHeight-this._reservedHeight,fontInfo:i,extraEditorClassName:e.extraEditorClassName,isDominatedByLongLines:this._isDominatedByLongLines,viewLineCount:this._viewLineCount,lineNumbersDigitCount:this._lineNumbersDigitCount,emptySelectionClipboard:e.emptySelectionClipboard,pixelRatio:e.pixelRatio,tabFocusMode:mm.getTabFocusMode(),accessibilitySupport:e.accessibilitySupport,glyphMarginDecorationLaneCount:this._glyphMarginDecorationLaneCount};return Oc.computeOptions(this._validatedOptions,n)}_readEnvConfiguration(){return{extraEditorClassName:$ne(),outerWidth:this._containerObserver.getWidth(),outerHeight:this._containerObserver.getHeight(),emptySelectionClipboard:ug||yr,pixelRatio:D0.value,accessibilitySupport:this._accessibilityService.isScreenReaderOptimized()?2:this._accessibilityService.getAccessibilitySupport()}}_readFontInfo(e){return zN.readFontInfo(e)}getRawOptions(){return this._rawOptions}updateOptions(e){const t=C3(e);Oc.applyUpdate(this._rawOptions,t)&&(this._validatedOptions=Oc.validateOptions(this._rawOptions),this._recomputeOptions())}observeContainer(e){this._containerObserver.observe(e)}setIsDominatedByLongLines(e){this._isDominatedByLongLines!==e&&(this._isDominatedByLongLines=e,this._recomputeOptions())}setModelLineCount(e){const t=Une(e);this._lineNumbersDigitCount!==t&&(this._lineNumbersDigitCount=t,this._recomputeOptions())}setViewLineCount(e){this._viewLineCount!==e&&(this._viewLineCount=e,this._recomputeOptions())}setReservedHeight(e){this._reservedHeight!==e&&(this._reservedHeight=e,this._recomputeOptions())}setGlyphMarginDecorationLaneCount(e){this._glyphMarginDecorationLaneCount!==e&&(this._glyphMarginDecorationLaneCount=e,this._recomputeOptions())}};hT=Hne([zne(3,ad)],hT);function Une(s){let e=0;for(;s;)s=Math.floor(s/10),e++;return e||1}function $ne(){let s="";return!Jd&&!ZW&&(s+="no-user-select "),Jd&&(s+="no-minimap-shadow ",s+="enable-user-select "),bt&&(s+="mac "),s}class jne{constructor(){this._values=[]}_read(e){return this._values[e]}get(e){return this._values[e]}_write(e,t){this._values[e]=t}}class Kne{constructor(){this._values=[]}_read(e){if(e>=this._values.length)throw new Error("Cannot read uninitialized value");return this._values[e]}get(e){return this._read(e)}_write(e,t){this._values[e]=t}}class Oc{static validateOptions(e){const t=new jne;for(const i of ip){const n=i.name==="_never_"?void 0:e[i.name];t._write(i.id,i.validate(n))}return t}static computeOptions(e,t){const i=new Kne;for(const n of ip)i._write(n.id,n.compute(t,i,e._read(n.id)));return i}static _deepEquals(e,t){if(typeof e!="object"||typeof t!="object"||!e||!t)return e===t;if(Array.isArray(e)||Array.isArray(t))return Array.isArray(e)&&Array.isArray(t)?Ai(e,t):!1;if(Object.keys(e).length!==Object.keys(t).length)return!1;for(const i in e)if(!Oc._deepEquals(e[i],t[i]))return!1;return!0}static checkEquals(e,t){const i=[];let n=!1;for(const o of ip){const r=!Oc._deepEquals(e._read(o.id),t._read(o.id));i[o.id]=r,r&&(n=!0)}return n?new yW(i):null}static applyUpdate(e,t){let i=!1;for(const n of ip)if(t.hasOwnProperty(n.name)){const o=n.applyUpdate(e[n.name],t[n.name]);e[n.name]=o.newValue,i=i||o.didChange}return i}}function C3(s){const e=yd(s);return Bne(e),e}function Xi(s,e,t){let i=null,n=null;if(typeof t.value=="function"?(i="value",n=t.value,n.length!==0&&console.warn("Memoize should only be used in functions with zero parameters")):typeof t.get=="function"&&(i="get",n=t.get),!n)throw new Error("not supported");const o=`$memoize$${e}`;t[i]=function(...r){return this.hasOwnProperty(o)||Object.defineProperty(this,o,{configurable:!1,enumerable:!1,writable:!1,value:n.apply(this,r)}),this[o]}}var qne=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Qt;(function(s){s.Tap="-monaco-gesturetap",s.Change="-monaco-gesturechange",s.Start="-monaco-gesturestart",s.End="-monaco-gesturesend",s.Contextmenu="-monaco-gesturecontextmenu"})(Qt||(Qt={}));class Xt extends j{constructor(){super(),this.dispatched=!1,this.targets=new Ms,this.ignoreTargets=new Ms,this.activeTouches={},this.handle=null,this._lastSetTapCountTime=0,this._register(ge.runAndSubscribe(JA,({window:e,disposables:t})=>{t.add(Y(e.document,"touchstart",i=>this.onTouchStart(i),{passive:!1})),t.add(Y(e.document,"touchend",i=>this.onTouchEnd(e,i))),t.add(Y(e.document,"touchmove",i=>this.onTouchMove(i),{passive:!1}))},{window:Ci,disposables:this._store}))}static addTarget(e){if(!Xt.isTouchDevice())return j.None;Xt.INSTANCE||(Xt.INSTANCE=new Xt);const t=Xt.INSTANCE.targets.push(e);return Fe(t)}static ignoreTarget(e){if(!Xt.isTouchDevice())return j.None;Xt.INSTANCE||(Xt.INSTANCE=new Xt);const t=Xt.INSTANCE.ignoreTargets.push(e);return Fe(t)}static isTouchDevice(){return"ontouchstart"in Ci||navigator.maxTouchPoints>0}dispose(){this.handle&&(this.handle.dispose(),this.handle=null),super.dispose()}onTouchStart(e){const t=Date.now();this.handle&&(this.handle.dispose(),this.handle=null);for(let i=0,n=e.targetTouches.length;i<n;i++){const o=e.targetTouches.item(i);this.activeTouches[o.identifier]={id:o.identifier,initialTarget:o.target,initialTimeStamp:t,initialPageX:o.pageX,initialPageY:o.pageY,rollingTimestamps:[t],rollingPageX:[o.pageX],rollingPageY:[o.pageY]};const r=this.newGestureEvent(Qt.Start,o.target);r.pageX=o.pageX,r.pageY=o.pageY,this.dispatchEvent(r)}this.dispatched&&(e.preventDefault(),e.stopPropagation(),this.dispatched=!1)}onTouchEnd(e,t){const i=Date.now(),n=Object.keys(this.activeTouches).length;for(let o=0,r=t.changedTouches.length;o<r;o++){const a=t.changedTouches.item(o);if(!this.activeTouches.hasOwnProperty(String(a.identifier))){console.warn("move of an UNKNOWN touch",a);continue}const l=this.activeTouches[a.identifier],d=Date.now()-l.initialTimeStamp;if(d<Xt.HOLD_DELAY&&Math.abs(l.initialPageX-dr(l.rollingPageX))<30&&Math.abs(l.initialPageY-dr(l.rollingPageY))<30){const c=this.newGestureEvent(Qt.Tap,l.initialTarget);c.pageX=dr(l.rollingPageX),c.pageY=dr(l.rollingPageY),this.dispatchEvent(c)}else if(d>=Xt.HOLD_DELAY&&Math.abs(l.initialPageX-dr(l.rollingPageX))<30&&Math.abs(l.initialPageY-dr(l.rollingPageY))<30){const c=this.newGestureEvent(Qt.Contextmenu,l.initialTarget);c.pageX=dr(l.rollingPageX),c.pageY=dr(l.rollingPageY),this.dispatchEvent(c)}else if(n===1){const c=dr(l.rollingPageX),u=dr(l.rollingPageY),h=dr(l.rollingTimestamps)-l.rollingTimestamps[0],g=c-l.rollingPageX[0],f=u-l.rollingPageY[0],m=[...this.targets].filter(_=>l.initialTarget instanceof Node&&_.contains(l.initialTarget));this.inertia(e,m,i,Math.abs(g)/h,g>0?1:-1,c,Math.abs(f)/h,f>0?1:-1,u)}this.dispatchEvent(this.newGestureEvent(Qt.End,l.initialTarget)),delete this.activeTouches[a.identifier]}this.dispatched&&(t.preventDefault(),t.stopPropagation(),this.dispatched=!1)}newGestureEvent(e,t){const i=document.createEvent("CustomEvent");return i.initEvent(e,!1,!0),i.initialTarget=t,i.tapCount=0,i}dispatchEvent(e){if(e.type===Qt.Tap){const t=new Date().getTime();let i=0;t-this._lastSetTapCountTime>Xt.CLEAR_TAP_COUNT_TIME?i=1:i=2,this._lastSetTapCountTime=t,e.tapCount=i}else(e.type===Qt.Change||e.type===Qt.Contextmenu)&&(this._lastSetTapCountTime=0);if(e.initialTarget instanceof Node){for(const t of this.ignoreTargets)if(t.contains(e.initialTarget))return;for(const t of this.targets)t.contains(e.initialTarget)&&(t.dispatchEvent(e),this.dispatched=!0)}}inertia(e,t,i,n,o,r,a,l,d){this.handle=yo(e,()=>{const c=Date.now(),u=c-i;let h=0,g=0,f=!0;n+=Xt.SCROLL_FRICTION*u,a+=Xt.SCROLL_FRICTION*u,n>0&&(f=!1,h=o*n*u),a>0&&(f=!1,g=l*a*u);const m=this.newGestureEvent(Qt.Change);m.translationX=h,m.translationY=g,t.forEach(_=>_.dispatchEvent(m)),f||this.inertia(e,t,c,n,o,r+h,a,l,d+g)})}onTouchMove(e){const t=Date.now();for(let i=0,n=e.changedTouches.length;i<n;i++){const o=e.changedTouches.item(i);if(!this.activeTouches.hasOwnProperty(String(o.identifier))){console.warn("end of an UNKNOWN touch",o);continue}const r=this.activeTouches[o.identifier],a=this.newGestureEvent(Qt.Change,r.initialTarget);a.translationX=o.pageX-dr(r.rollingPageX),a.translationY=o.pageY-dr(r.rollingPageY),a.pageX=o.pageX,a.pageY=o.pageY,this.dispatchEvent(a),r.rollingPageX.length>3&&(r.rollingPageX.shift(),r.rollingPageY.shift(),r.rollingTimestamps.shift()),r.rollingPageX.push(o.pageX),r.rollingPageY.push(o.pageY),r.rollingTimestamps.push(t)}this.dispatched&&(e.preventDefault(),e.stopPropagation(),this.dispatched=!1)}}Xt.SCROLL_FRICTION=-.005;Xt.HOLD_DELAY=700;Xt.CLEAR_TAP_COUNT_TIME=400;qne([Xi],Xt,"isTouchDevice",null);class r_{constructor(){this._hooks=new ie,this._pointerMoveCallback=null,this._onStopCallback=null}dispose(){this.stopMonitoring(!1),this._hooks.dispose()}stopMonitoring(e,t){if(!this.isMonitoring())return;this._hooks.clear(),this._pointerMoveCallback=null;const i=this._onStopCallback;this._onStopCallback=null,e&&i&&i(t)}isMonitoring(){return!!this._pointerMoveCallback}startMonitoring(e,t,i,n,o){this.isMonitoring()&&this.stopMonitoring(!1),this._pointerMoveCallback=n,this._onStopCallback=o;let r=e;try{e.setPointerCapture(t),this._hooks.add(Fe(()=>{try{e.releasePointerCapture(t)}catch{}}))}catch{r=Xe(e)}this._hooks.add(Y(r,he.POINTER_MOVE,a=>{if(a.buttons!==i){this.stopMonitoring(!0);return}a.preventDefault(),this._pointerMoveCallback(a)})),this._hooks.add(Y(r,he.POINTER_UP,a=>this.stopMonitoring(!0)))}}function _P(s){return`--vscode-${s.replace(/\./g,"-")}`}function _e(s){return`var(${_P(s)})`}function Gne(s,e){return`var(${_P(s)}, ${e})`}const sH={ColorContribution:"base.contributions.colors"};class Zne{constructor(){this._onDidChangeSchema=new W,this.onDidChangeSchema=this._onDidChangeSchema.event,this.colorSchema={type:"object",properties:{}},this.colorReferenceSchema={type:"string",enum:[],enumDescriptions:[]},this.colorsById={}}registerColor(e,t,i,n=!1,o){const r={id:e,description:i,defaults:t,needsTransparency:n,deprecationMessage:o};this.colorsById[e]=r;const a={type:"string",description:i,format:"color-hex",defaultSnippets:[{body:"${1:#ff0000}"}]};return o&&(a.deprecationMessage=o),this.colorSchema.properties[e]=a,this.colorReferenceSchema.enum.push(e),this.colorReferenceSchema.enumDescriptions.push(i),this._onDidChangeSchema.fire(),e}getColors(){return Object.keys(this.colorsById).map(e=>this.colorsById[e])}resolveDefaultColor(e,t){const i=this.colorsById[e];if(i&&i.defaults){const n=i.defaults[t.type];return ca(n,t)}}getColorSchema(){return this.colorSchema}toString(){const e=(t,i)=>{const n=t.indexOf(".")===-1?0:1,o=i.indexOf(".")===-1?0:1;return n!==o?n-o:t.localeCompare(i)};return Object.keys(this.colorsById).sort(e).map(t=>`- \`${t}\`: ${this.colorsById[t].description}`).join(`
`)}}const Cx=new Zne;Si.add(sH.ColorContribution,Cx);function R(s,e,t,i,n){return Cx.registerColor(s,e,t,i,n)}const de=R("foreground",{dark:"#CCCCCC",light:"#616161",hcDark:"#FFFFFF",hcLight:"#292929"},p("foreground","Overall foreground color. This color is only used if not overridden by a component."));R("disabledForeground",{dark:"#CCCCCC80",light:"#61616180",hcDark:"#A5A5A5",hcLight:"#7F7F7F"},p("disabledForeground","Overall foreground for disabled elements. This color is only used if not overridden by a component."));const Yne=R("errorForeground",{dark:"#F48771",light:"#A1260D",hcDark:"#F48771",hcLight:"#B5200D"},p("errorForeground","Overall foreground color for error messages. This color is only used if not overridden by a component."));R("descriptionForeground",{light:"#717171",dark:Me(de,.7),hcDark:Me(de,.7),hcLight:Me(de,.7)},p("descriptionForeground","Foreground color for description text providing additional information, for example for a label."));const Ur=R("icon.foreground",{dark:"#C5C5C5",light:"#424242",hcDark:"#FFFFFF",hcLight:"#292929"},p("iconForeground","The default color for icons in the workbench.")),Zo=R("focusBorder",{dark:"#007FD4",light:"#0090F1",hcDark:"#F38518",hcLight:"#006BBD"},p("focusBorder","Overall border color for focused elements. This color is only used if not overridden by a component.")),pt=R("contrastBorder",{light:null,dark:null,hcDark:"#6FC3DF",hcLight:"#0F4A85"},p("contrastBorder","An extra border around elements to separate them from others for greater contrast.")),ai=R("contrastActiveBorder",{light:null,dark:null,hcDark:Zo,hcLight:Zo},p("activeContrastBorder","An extra border around active elements to separate them from others for greater contrast."));R("selection.background",{light:null,dark:null,hcDark:null,hcLight:null},p("selectionBackground","The background color of text selections in the workbench (e.g. for input fields or text areas). Note that this does not apply to selections within the editor."));R("textSeparator.foreground",{light:"#0000002e",dark:"#ffffff2e",hcDark:G.black,hcLight:"#292929"},p("textSeparatorForeground","Color for text separators."));const Xne=R("textLink.foreground",{light:"#006AB1",dark:"#3794FF",hcDark:"#3794FF",hcLight:"#0F4A85"},p("textLinkForeground","Foreground color for links in text."));R("textLink.activeForeground",{light:"#006AB1",dark:"#3794FF",hcDark:"#3794FF",hcLight:"#0F4A85"},p("textLinkActiveForeground","Foreground color for links in text when clicked on and on mouse hover."));R("textPreformat.foreground",{light:"#A31515",dark:"#D7BA7D",hcDark:"#000000",hcLight:"#FFFFFF"},p("textPreformatForeground","Foreground color for preformatted text segments."));R("textPreformat.background",{light:"#0000001A",dark:"#FFFFFF1A",hcDark:"#FFFFFF",hcLight:"#09345f"},p("textPreformatBackground","Background color for preformatted text segments."));R("textBlockQuote.background",{light:"#f2f2f2",dark:"#222222",hcDark:null,hcLight:"#F2F2F2"},p("textBlockQuoteBackground","Background color for block quotes in text."));R("textBlockQuote.border",{light:"#007acc80",dark:"#007acc80",hcDark:G.white,hcLight:"#292929"},p("textBlockQuoteBorder","Border color for block quotes in text."));R("textCodeBlock.background",{light:"#dcdcdc66",dark:"#0a0a0a66",hcDark:G.black,hcLight:"#F2F2F2"},p("textCodeBlockBackground","Background color for code blocks in text."));const Il=R("widget.shadow",{dark:Me(G.black,.36),light:Me(G.black,.16),hcDark:null,hcLight:null},p("widgetShadow","Shadow color of widgets such as find/replace inside the editor.")),vP=R("widget.border",{dark:null,light:null,hcDark:pt,hcLight:pt},p("widgetBorder","Border color of widgets such as find/replace inside the editor.")),oH=R("input.background",{dark:"#3C3C3C",light:G.white,hcDark:G.black,hcLight:G.white},p("inputBoxBackground","Input box background.")),rH=R("input.foreground",{dark:de,light:de,hcDark:de,hcLight:de},p("inputBoxForeground","Input box foreground.")),aH=R("input.border",{dark:null,light:null,hcDark:pt,hcLight:pt},p("inputBoxBorder","Input box border.")),bP=R("inputOption.activeBorder",{dark:"#007ACC",light:"#007ACC",hcDark:pt,hcLight:pt},p("inputBoxActiveOptionBorder","Border color of activated options in input fields."));R("inputOption.hoverBackground",{dark:"#5a5d5e80",light:"#b8b8b850",hcDark:null,hcLight:null},p("inputOption.hoverBackground","Background color of activated options in input fields."));const Jh=R("inputOption.activeBackground",{dark:Me(Zo,.4),light:Me(Zo,.2),hcDark:G.transparent,hcLight:G.transparent},p("inputOption.activeBackground","Background hover color of options in input fields.")),CP=R("inputOption.activeForeground",{dark:G.white,light:G.black,hcDark:de,hcLight:de},p("inputOption.activeForeground","Foreground color of activated options in input fields."));R("input.placeholderForeground",{light:Me(de,.5),dark:Me(de,.5),hcDark:Me(de,.7),hcLight:Me(de,.7)},p("inputPlaceholderForeground","Input box foreground color for placeholder text."));const Qne=R("inputValidation.infoBackground",{dark:"#063B49",light:"#D6ECF2",hcDark:G.black,hcLight:G.white},p("inputValidationInfoBackground","Input validation background color for information severity.")),Jne=R("inputValidation.infoForeground",{dark:null,light:null,hcDark:null,hcLight:de},p("inputValidationInfoForeground","Input validation foreground color for information severity.")),ese=R("inputValidation.infoBorder",{dark:"#007acc",light:"#007acc",hcDark:pt,hcLight:pt},p("inputValidationInfoBorder","Input validation border color for information severity.")),tse=R("inputValidation.warningBackground",{dark:"#352A05",light:"#F6F5D2",hcDark:G.black,hcLight:G.white},p("inputValidationWarningBackground","Input validation background color for warning severity.")),ise=R("inputValidation.warningForeground",{dark:null,light:null,hcDark:null,hcLight:de},p("inputValidationWarningForeground","Input validation foreground color for warning severity.")),nse=R("inputValidation.warningBorder",{dark:"#B89500",light:"#B89500",hcDark:pt,hcLight:pt},p("inputValidationWarningBorder","Input validation border color for warning severity.")),sse=R("inputValidation.errorBackground",{dark:"#5A1D1D",light:"#F2DEDE",hcDark:G.black,hcLight:G.white},p("inputValidationErrorBackground","Input validation background color for error severity.")),ose=R("inputValidation.errorForeground",{dark:null,light:null,hcDark:null,hcLight:de},p("inputValidationErrorForeground","Input validation foreground color for error severity.")),rse=R("inputValidation.errorBorder",{dark:"#BE1100",light:"#BE1100",hcDark:pt,hcLight:pt},p("inputValidationErrorBorder","Input validation border color for error severity.")),El=R("dropdown.background",{dark:"#3C3C3C",light:G.white,hcDark:G.black,hcLight:G.white},p("dropdownBackground","Dropdown background.")),ase=R("dropdown.listBackground",{dark:null,light:null,hcDark:G.black,hcLight:G.white},p("dropdownListBackground","Dropdown list background.")),Od=R("dropdown.foreground",{dark:"#F0F0F0",light:de,hcDark:G.white,hcLight:de},p("dropdownForeground","Dropdown foreground.")),lp=R("dropdown.border",{dark:El,light:"#CECECE",hcDark:pt,hcLight:pt},p("dropdownBorder","Dropdown border.")),rv=R("button.foreground",{dark:G.white,light:G.white,hcDark:G.white,hcLight:G.white},p("buttonForeground","Button foreground color.")),lse=R("button.separator",{dark:Me(rv,.4),light:Me(rv,.4),hcDark:Me(rv,.4),hcLight:Me(rv,.4)},p("buttonSeparator","Button separator color.")),av=R("button.background",{dark:"#0E639C",light:"#007ACC",hcDark:null,hcLight:"#0F4A85"},p("buttonBackground","Button background color.")),dse=R("button.hoverBackground",{dark:Zr(av,.2),light:oh(av,.2),hcDark:av,hcLight:av},p("buttonHoverBackground","Button background color when hovering.")),cse=R("button.border",{dark:pt,light:pt,hcDark:pt,hcLight:pt},p("buttonBorder","Button border color.")),use=R("button.secondaryForeground",{dark:G.white,light:G.white,hcDark:G.white,hcLight:de},p("buttonSecondaryForeground","Secondary button foreground color.")),gT=R("button.secondaryBackground",{dark:"#3A3D41",light:"#5F6A79",hcDark:null,hcLight:G.white},p("buttonSecondaryBackground","Secondary button background color.")),hse=R("button.secondaryHoverBackground",{dark:Zr(gT,.2),light:oh(gT,.2),hcDark:null,hcLight:null},p("buttonSecondaryHoverBackground","Secondary button background color when hovering.")),Bw=R("badge.background",{dark:"#4D4D4D",light:"#C4C4C4",hcDark:G.black,hcLight:"#0F4A85"},p("badgeBackground","Badge background color. Badges are small information labels, e.g. for search results count.")),gse=R("badge.foreground",{dark:G.white,light:"#333",hcDark:G.white,hcLight:G.white},p("badgeForeground","Badge foreground color. Badges are small information labels, e.g. for search results count.")),fse=R("scrollbar.shadow",{dark:"#000000",light:"#DDDDDD",hcDark:null,hcLight:null},p("scrollbarShadow","Scrollbar shadow to indicate that the view is scrolled.")),lv=R("scrollbarSlider.background",{dark:G.fromHex("#797979").transparent(.4),light:G.fromHex("#646464").transparent(.4),hcDark:Me(pt,.6),hcLight:Me(pt,.4)},p("scrollbarSliderBackground","Scrollbar slider background color.")),dv=R("scrollbarSlider.hoverBackground",{dark:G.fromHex("#646464").transparent(.7),light:G.fromHex("#646464").transparent(.7),hcDark:Me(pt,.8),hcLight:Me(pt,.8)},p("scrollbarSliderHoverBackground","Scrollbar slider background color when hovering.")),cv=R("scrollbarSlider.activeBackground",{dark:G.fromHex("#BFBFBF").transparent(.4),light:G.fromHex("#000000").transparent(.6),hcDark:pt,hcLight:pt},p("scrollbarSliderActiveBackground","Scrollbar slider background color when clicked on.")),pse=R("progressBar.background",{dark:G.fromHex("#0E70C0"),light:G.fromHex("#0E70C0"),hcDark:pt,hcLight:pt},p("progressBarBackground","Background color of the progress bar that can show for long running operations."));R("editorError.background",{dark:null,light:null,hcDark:null,hcLight:null},p("editorError.background","Background color of error text in the editor. The color must not be opaque so as not to hide underlying decorations."),!0);const Nl=R("editorError.foreground",{dark:"#F14C4C",light:"#E51400",hcDark:"#F48771",hcLight:"#B5200D"},p("editorError.foreground","Foreground color of error squigglies in the editor.")),mse=R("editorError.border",{dark:null,light:null,hcDark:G.fromHex("#E47777").transparent(.8),hcLight:"#B5200D"},p("errorBorder","If set, color of double underlines for errors in the editor."));R("editorWarning.background",{dark:null,light:null,hcDark:null,hcLight:null},p("editorWarning.background","Background color of warning text in the editor. The color must not be opaque so as not to hide underlying decorations."),!0);const Yo=R("editorWarning.foreground",{dark:"#CCA700",light:"#BF8803",hcDark:"#FFD370",hcLight:"#895503"},p("editorWarning.foreground","Foreground color of warning squigglies in the editor.")),H0=R("editorWarning.border",{dark:null,light:null,hcDark:G.fromHex("#FFCC00").transparent(.8),hcLight:G.fromHex("#FFCC00").transparent(.8)},p("warningBorder","If set, color of double underlines for warnings in the editor."));R("editorInfo.background",{dark:null,light:null,hcDark:null,hcLight:null},p("editorInfo.background","Background color of info text in the editor. The color must not be opaque so as not to hide underlying decorations."),!0);const Xs=R("editorInfo.foreground",{dark:"#3794FF",light:"#1a85ff",hcDark:"#3794FF",hcLight:"#1a85ff"},p("editorInfo.foreground","Foreground color of info squigglies in the editor.")),z0=R("editorInfo.border",{dark:null,light:null,hcDark:G.fromHex("#3794FF").transparent(.8),hcLight:"#292929"},p("infoBorder","If set, color of double underlines for infos in the editor.")),_se=R("editorHint.foreground",{dark:G.fromHex("#eeeeee").transparent(.7),light:"#6c6c6c",hcDark:null,hcLight:null},p("editorHint.foreground","Foreground color of hint squigglies in the editor."));R("editorHint.border",{dark:null,light:null,hcDark:G.fromHex("#eeeeee").transparent(.8),hcLight:"#292929"},p("hintBorder","If set, color of double underlines for hints in the editor."));R("sash.hoverBorder",{dark:Zo,light:Zo,hcDark:Zo,hcLight:Zo},p("sashActiveBorder","Border color of active sashes."));const bn=R("editor.background",{light:"#ffffff",dark:"#1E1E1E",hcDark:G.black,hcLight:G.white},p("editorBackground","Editor background color.")),$r=R("editor.foreground",{light:"#333333",dark:"#BBBBBB",hcDark:G.white,hcLight:de},p("editorForeground","Editor default foreground color."));R("editorStickyScroll.background",{light:bn,dark:bn,hcDark:bn,hcLight:bn},p("editorStickyScrollBackground","Sticky scroll background color for the editor"));R("editorStickyScrollHover.background",{dark:"#2A2D2E",light:"#F0F0F0",hcDark:null,hcLight:G.fromHex("#0F4A85").transparent(.1)},p("editorStickyScrollHoverBackground","Sticky scroll on hover background color for the editor"));const Ri=R("editorWidget.background",{dark:"#252526",light:"#F3F3F3",hcDark:"#0C141F",hcLight:G.white},p("editorWidgetBackground","Background color of editor widgets, such as find/replace.")),Tl=R("editorWidget.foreground",{dark:de,light:de,hcDark:de,hcLight:de},p("editorWidgetForeground","Foreground color of editor widgets, such as find/replace.")),Ml=R("editorWidget.border",{dark:"#454545",light:"#C8C8C8",hcDark:pt,hcLight:pt},p("editorWidgetBorder","Border color of editor widgets. The color is only used if the widget chooses to have a border and if the color is not overridden by a widget.")),vse=R("editorWidget.resizeBorder",{light:null,dark:null,hcDark:null,hcLight:null},p("editorWidgetResizeBorder","Border color of the resize bar of editor widgets. The color is only used if the widget chooses to have a resize border and if the color is not overridden by a widget.")),w3=R("quickInput.background",{dark:Ri,light:Ri,hcDark:Ri,hcLight:Ri},p("pickerBackground","Quick picker background color. The quick picker widget is the container for pickers like the command palette.")),bse=R("quickInput.foreground",{dark:Tl,light:Tl,hcDark:Tl,hcLight:Tl},p("pickerForeground","Quick picker foreground color. The quick picker widget is the container for pickers like the command palette.")),Cse=R("quickInputTitle.background",{dark:new G(new vt(255,255,255,.105)),light:new G(new vt(0,0,0,.06)),hcDark:"#000000",hcLight:G.white},p("pickerTitleBackground","Quick picker title background color. The quick picker widget is the container for pickers like the command palette.")),lH=R("pickerGroup.foreground",{dark:"#3794FF",light:"#0066BF",hcDark:G.white,hcLight:"#0F4A85"},p("pickerGroupForeground","Quick picker color for grouping labels.")),wse=R("pickerGroup.border",{dark:"#3F3F46",light:"#CCCEDB",hcDark:G.white,hcLight:"#0F4A85"},p("pickerGroupBorder","Quick picker color for grouping borders.")),Sse=R("keybindingLabel.background",{dark:new G(new vt(128,128,128,.17)),light:new G(new vt(221,221,221,.4)),hcDark:G.transparent,hcLight:G.transparent},p("keybindingLabelBackground","Keybinding label background color. The keybinding label is used to represent a keyboard shortcut.")),yse=R("keybindingLabel.foreground",{dark:G.fromHex("#CCCCCC"),light:G.fromHex("#555555"),hcDark:G.white,hcLight:de},p("keybindingLabelForeground","Keybinding label foreground color. The keybinding label is used to represent a keyboard shortcut.")),Lse=R("keybindingLabel.border",{dark:new G(new vt(51,51,51,.6)),light:new G(new vt(204,204,204,.4)),hcDark:new G(new vt(111,195,223)),hcLight:pt},p("keybindingLabelBorder","Keybinding label border color. The keybinding label is used to represent a keyboard shortcut.")),xse=R("keybindingLabel.bottomBorder",{dark:new G(new vt(68,68,68,.6)),light:new G(new vt(187,187,187,.4)),hcDark:new G(new vt(111,195,223)),hcLight:de},p("keybindingLabelBottomBorder","Keybinding label border bottom color. The keybinding label is used to represent a keyboard shortcut.")),Uc=R("editor.selectionBackground",{light:"#ADD6FF",dark:"#264F78",hcDark:"#f3f518",hcLight:"#0F4A85"},p("editorSelectionBackground","Color of the editor selection.")),Dse=R("editor.selectionForeground",{light:null,dark:null,hcDark:"#000000",hcLight:G.white},p("editorSelectionForeground","Color of the selected text for high contrast.")),dH=R("editor.inactiveSelectionBackground",{light:Me(Uc,.5),dark:Me(Uc,.5),hcDark:Me(Uc,.7),hcLight:Me(Uc,.5)},p("editorInactiveSelection","Color of the selection in an inactive editor. The color must not be opaque so as not to hide underlying decorations."),!0),wP=R("editor.selectionHighlightBackground",{light:I3(Uc,bn,.3,.6),dark:I3(Uc,bn,.3,.6),hcDark:null,hcLight:null},p("editorSelectionHighlight","Color for regions with the same content as the selection. The color must not be opaque so as not to hide underlying decorations."),!0);R("editor.selectionHighlightBorder",{light:null,dark:null,hcDark:ai,hcLight:ai},p("editorSelectionHighlightBorder","Border color for regions with the same content as the selection."));const kse=R("editor.findMatchBackground",{light:"#A8AC94",dark:"#515C6A",hcDark:null,hcLight:null},p("editorFindMatch","Color of the current search match.")),Rl=R("editor.findMatchHighlightBackground",{light:"#EA5C0055",dark:"#EA5C0055",hcDark:null,hcLight:null},p("findMatchHighlight","Color of the other search matches. The color must not be opaque so as not to hide underlying decorations."),!0),Ise=R("editor.findRangeHighlightBackground",{dark:"#3a3d4166",light:"#b4b4b44d",hcDark:null,hcLight:null},p("findRangeHighlight","Color of the range limiting the search. The color must not be opaque so as not to hide underlying decorations."),!0),Ese=R("editor.findMatchBorder",{light:null,dark:null,hcDark:ai,hcLight:ai},p("editorFindMatchBorder","Border color of the current search match.")),$c=R("editor.findMatchHighlightBorder",{light:null,dark:null,hcDark:ai,hcLight:ai},p("findMatchHighlightBorder","Border color of the other search matches.")),Nse=R("editor.findRangeHighlightBorder",{dark:null,light:null,hcDark:Me(ai,.4),hcLight:Me(ai,.4)},p("findRangeHighlightBorder","Border color of the range limiting the search. The color must not be opaque so as not to hide underlying decorations."),!0);R("searchEditor.findMatchBackground",{light:Me(Rl,.66),dark:Me(Rl,.66),hcDark:Rl,hcLight:Rl},p("searchEditor.queryMatch","Color of the Search Editor query matches."));R("searchEditor.findMatchBorder",{light:Me($c,.66),dark:Me($c,.66),hcDark:$c,hcLight:$c},p("searchEditor.editorFindMatchBorder","Border color of the Search Editor query matches."));R("search.resultsInfoForeground",{light:de,dark:Me(de,.65),hcDark:de,hcLight:de},p("search.resultsInfoForeground","Color of the text in the search viewlet's completion message."));R("editor.hoverHighlightBackground",{light:"#ADD6FF26",dark:"#264f7840",hcDark:"#ADD6FF26",hcLight:null},p("hoverHighlight","Highlight below the word for which a hover is shown. The color must not be opaque so as not to hide underlying decorations."),!0);const ZS=R("editorHoverWidget.background",{light:Ri,dark:Ri,hcDark:Ri,hcLight:Ri},p("hoverBackground","Background color of the editor hover."));R("editorHoverWidget.foreground",{light:Tl,dark:Tl,hcDark:Tl,hcLight:Tl},p("hoverForeground","Foreground color of the editor hover."));const Tse=R("editorHoverWidget.border",{light:Ml,dark:Ml,hcDark:Ml,hcLight:Ml},p("hoverBorder","Border color of the editor hover."));R("editorHoverWidget.statusBarBackground",{dark:Zr(ZS,.2),light:oh(ZS,.05),hcDark:Ri,hcLight:Ri},p("statusBarBackground","Background color of the editor hover status bar."));const Mse=R("editorLink.activeForeground",{dark:"#4E94CE",light:G.blue,hcDark:G.cyan,hcLight:"#292929"},p("activeLinkForeground","Color of active links.")),Fd=R("editorInlayHint.foreground",{dark:"#969696",light:"#969696",hcDark:G.white,hcLight:G.black},p("editorInlayHintForeground","Foreground color of inline hints")),Bd=R("editorInlayHint.background",{dark:Me(Bw,.1),light:Me(Bw,.1),hcDark:Me(G.white,.1),hcLight:Me(Bw,.1)},p("editorInlayHintBackground","Background color of inline hints")),Rse=R("editorInlayHint.typeForeground",{dark:Fd,light:Fd,hcDark:Fd,hcLight:Fd},p("editorInlayHintForegroundTypes","Foreground color of inline hints for types")),Ase=R("editorInlayHint.typeBackground",{dark:Bd,light:Bd,hcDark:Bd,hcLight:Bd},p("editorInlayHintBackgroundTypes","Background color of inline hints for types")),Pse=R("editorInlayHint.parameterForeground",{dark:Fd,light:Fd,hcDark:Fd,hcLight:Fd},p("editorInlayHintForegroundParameter","Foreground color of inline hints for parameters")),Ose=R("editorInlayHint.parameterBackground",{dark:Bd,light:Bd,hcDark:Bd,hcLight:Bd},p("editorInlayHintBackgroundParameter","Background color of inline hints for parameters"));R("editorLightBulb.foreground",{dark:"#FFCC00",light:"#DDB100",hcDark:"#FFCC00",hcLight:"#007ACC"},p("editorLightBulbForeground","The color used for the lightbulb actions icon."));R("editorLightBulbAutoFix.foreground",{dark:"#75BEFF",light:"#007ACC",hcDark:"#75BEFF",hcLight:"#007ACC"},p("editorLightBulbAutoFixForeground","The color used for the lightbulb auto fix actions icon."));R("editorLightBulbAi.foreground",{dark:oh(Ur,.4),light:Zr(Ur,1.7),hcDark:Ur,hcLight:Ur},p("editorLightBulbAiForeground","The color used for the lightbulb AI icon."));const fT=new G(new vt(155,185,85,.2)),pT=new G(new vt(255,0,0,.2)),Fse=R("diffEditor.insertedTextBackground",{dark:"#9ccc2c33",light:"#9ccc2c40",hcDark:null,hcLight:null},p("diffEditorInserted","Background color for text that got inserted. The color must not be opaque so as not to hide underlying decorations."),!0),Bse=R("diffEditor.removedTextBackground",{dark:"#ff000033",light:"#ff000033",hcDark:null,hcLight:null},p("diffEditorRemoved","Background color for text that got removed. The color must not be opaque so as not to hide underlying decorations."),!0);R("diffEditor.insertedLineBackground",{dark:fT,light:fT,hcDark:null,hcLight:null},p("diffEditorInsertedLines","Background color for lines that got inserted. The color must not be opaque so as not to hide underlying decorations."),!0);R("diffEditor.removedLineBackground",{dark:pT,light:pT,hcDark:null,hcLight:null},p("diffEditorRemovedLines","Background color for lines that got removed. The color must not be opaque so as not to hide underlying decorations."),!0);R("diffEditorGutter.insertedLineBackground",{dark:null,light:null,hcDark:null,hcLight:null},p("diffEditorInsertedLineGutter","Background color for the margin where lines got inserted."));R("diffEditorGutter.removedLineBackground",{dark:null,light:null,hcDark:null,hcLight:null},p("diffEditorRemovedLineGutter","Background color for the margin where lines got removed."));const Wse=R("diffEditorOverview.insertedForeground",{dark:null,light:null,hcDark:null,hcLight:null},p("diffEditorOverviewInserted","Diff overview ruler foreground for inserted content.")),Vse=R("diffEditorOverview.removedForeground",{dark:null,light:null,hcDark:null,hcLight:null},p("diffEditorOverviewRemoved","Diff overview ruler foreground for removed content."));R("diffEditor.insertedTextBorder",{dark:null,light:null,hcDark:"#33ff2eff",hcLight:"#374E06"},p("diffEditorInsertedOutline","Outline color for the text that got inserted."));R("diffEditor.removedTextBorder",{dark:null,light:null,hcDark:"#FF008F",hcLight:"#AD0707"},p("diffEditorRemovedOutline","Outline color for text that got removed."));R("diffEditor.border",{dark:null,light:null,hcDark:pt,hcLight:pt},p("diffEditorBorder","Border color between the two text editors."));R("diffEditor.diagonalFill",{dark:"#cccccc33",light:"#22222233",hcDark:null,hcLight:null},p("diffDiagonalFill","Color of the diff editor's diagonal fill. The diagonal fill is used in side-by-side diff views."));R("diffEditor.unchangedRegionBackground",{dark:"sideBar.background",light:"sideBar.background",hcDark:"sideBar.background",hcLight:"sideBar.background"},p("diffEditor.unchangedRegionBackground","The background color of unchanged blocks in the diff editor."));R("diffEditor.unchangedRegionForeground",{dark:"foreground",light:"foreground",hcDark:"foreground",hcLight:"foreground"},p("diffEditor.unchangedRegionForeground","The foreground color of unchanged blocks in the diff editor."));R("diffEditor.unchangedCodeBackground",{dark:"#74747429",light:"#b8b8b829",hcDark:null,hcLight:null},p("diffEditor.unchangedCodeBackground","The background color of unchanged code in the diff editor."));const Hse=R("list.focusBackground",{dark:null,light:null,hcDark:null,hcLight:null},p("listFocusBackground","List/Tree background color for the focused item when the list/tree is active. An active list/tree has keyboard focus, an inactive does not.")),zse=R("list.focusForeground",{dark:null,light:null,hcDark:null,hcLight:null},p("listFocusForeground","List/Tree foreground color for the focused item when the list/tree is active. An active list/tree has keyboard focus, an inactive does not.")),Use=R("list.focusOutline",{dark:Zo,light:Zo,hcDark:ai,hcLight:ai},p("listFocusOutline","List/Tree outline color for the focused item when the list/tree is active. An active list/tree has keyboard focus, an inactive does not.")),$se=R("list.focusAndSelectionOutline",{dark:null,light:null,hcDark:null,hcLight:null},p("listFocusAndSelectionOutline","List/Tree outline color for the focused item when the list/tree is active and selected. An active list/tree has keyboard focus, an inactive does not.")),Wd=R("list.activeSelectionBackground",{dark:"#04395E",light:"#0060C0",hcDark:null,hcLight:G.fromHex("#0F4A85").transparent(.1)},p("listActiveSelectionBackground","List/Tree background color for the selected item when the list/tree is active. An active list/tree has keyboard focus, an inactive does not.")),Al=R("list.activeSelectionForeground",{dark:G.white,light:G.white,hcDark:null,hcLight:null},p("listActiveSelectionForeground","List/Tree foreground color for the selected item when the list/tree is active. An active list/tree has keyboard focus, an inactive does not.")),uv=R("list.activeSelectionIconForeground",{dark:null,light:null,hcDark:null,hcLight:null},p("listActiveSelectionIconForeground","List/Tree icon foreground color for the selected item when the list/tree is active. An active list/tree has keyboard focus, an inactive does not.")),jse=R("list.inactiveSelectionBackground",{dark:"#37373D",light:"#E4E6F1",hcDark:null,hcLight:G.fromHex("#0F4A85").transparent(.1)},p("listInactiveSelectionBackground","List/Tree background color for the selected item when the list/tree is inactive. An active list/tree has keyboard focus, an inactive does not.")),Kse=R("list.inactiveSelectionForeground",{dark:null,light:null,hcDark:null,hcLight:null},p("listInactiveSelectionForeground","List/Tree foreground color for the selected item when the list/tree is inactive. An active list/tree has keyboard focus, an inactive does not.")),qse=R("list.inactiveSelectionIconForeground",{dark:null,light:null,hcDark:null,hcLight:null},p("listInactiveSelectionIconForeground","List/Tree icon foreground color for the selected item when the list/tree is inactive. An active list/tree has keyboard focus, an inactive does not.")),Gse=R("list.inactiveFocusBackground",{dark:null,light:null,hcDark:null,hcLight:null},p("listInactiveFocusBackground","List/Tree background color for the focused item when the list/tree is inactive. An active list/tree has keyboard focus, an inactive does not.")),Zse=R("list.inactiveFocusOutline",{dark:null,light:null,hcDark:null,hcLight:null},p("listInactiveFocusOutline","List/Tree outline color for the focused item when the list/tree is inactive. An active list/tree has keyboard focus, an inactive does not.")),cH=R("list.hoverBackground",{dark:"#2A2D2E",light:"#F0F0F0",hcDark:G.white.transparent(.1),hcLight:G.fromHex("#0F4A85").transparent(.1)},p("listHoverBackground","List/Tree background when hovering over items using the mouse.")),uH=R("list.hoverForeground",{dark:null,light:null,hcDark:null,hcLight:null},p("listHoverForeground","List/Tree foreground when hovering over items using the mouse.")),Yse=R("list.dropBackground",{dark:"#062F4A",light:"#D6EBFF",hcDark:null,hcLight:null},p("listDropBackground","List/Tree drag and drop background when moving items around using the mouse.")),jr=R("list.highlightForeground",{dark:"#2AAAFF",light:"#0066BF",hcDark:Zo,hcLight:Zo},p("highlight","List/Tree foreground color of the match highlights when searching inside the list/tree.")),h1=R("list.focusHighlightForeground",{dark:jr,light:Doe(Wd,jr,"#BBE7FF"),hcDark:jr,hcLight:jr},p("listFocusHighlightForeground","List/Tree foreground color of the match highlights on actively focused items when searching inside the list/tree."));R("list.invalidItemForeground",{dark:"#B89500",light:"#B89500",hcDark:"#B89500",hcLight:"#B5200D"},p("invalidItemForeground","List/Tree foreground color for invalid items, for example an unresolved root in explorer."));R("list.errorForeground",{dark:"#F88070",light:"#B01011",hcDark:null,hcLight:null},p("listErrorForeground","Foreground color of list items containing errors."));R("list.warningForeground",{dark:"#CCA700",light:"#855F00",hcDark:null,hcLight:null},p("listWarningForeground","Foreground color of list items containing warnings."));const Xse=R("listFilterWidget.background",{light:oh(Ri,0),dark:Zr(Ri,0),hcDark:Ri,hcLight:Ri},p("listFilterWidgetBackground","Background color of the type filter widget in lists and trees.")),Qse=R("listFilterWidget.outline",{dark:G.transparent,light:G.transparent,hcDark:"#f38518",hcLight:"#007ACC"},p("listFilterWidgetOutline","Outline color of the type filter widget in lists and trees.")),Jse=R("listFilterWidget.noMatchesOutline",{dark:"#BE1100",light:"#BE1100",hcDark:pt,hcLight:pt},p("listFilterWidgetNoMatchesOutline","Outline color of the type filter widget in lists and trees, when there are no matches.")),eoe=R("listFilterWidget.shadow",{dark:Il,light:Il,hcDark:Il,hcLight:Il},p("listFilterWidgetShadow","Shadow color of the type filter widget in lists and trees."));R("list.filterMatchBackground",{dark:Rl,light:Rl,hcDark:null,hcLight:null},p("listFilterMatchHighlight","Background color of the filtered match."));R("list.filterMatchBorder",{dark:$c,light:$c,hcDark:pt,hcLight:ai},p("listFilterMatchHighlightBorder","Border color of the filtered match."));const hv=R("tree.indentGuidesStroke",{dark:"#585858",light:"#a9a9a9",hcDark:"#a9a9a9",hcLight:"#a5a5a5"},p("treeIndentGuidesStroke","Tree stroke color for the indentation guides.")),toe=R("tree.inactiveIndentGuidesStroke",{dark:Me(hv,.4),light:Me(hv,.4),hcDark:Me(hv,.4),hcLight:Me(hv,.4)},p("treeInactiveIndentGuidesStroke","Tree stroke color for the indentation guides that are not active.")),ioe=R("tree.tableColumnsBorder",{dark:"#CCCCCC20",light:"#61616120",hcDark:null,hcLight:null},p("tableColumnsBorder","Table border color between columns.")),noe=R("tree.tableOddRowsBackground",{dark:Me(de,.04),light:Me(de,.04),hcDark:null,hcLight:null},p("tableOddRowsBackgroundColor","Background color for odd table rows."));R("list.deemphasizedForeground",{dark:"#8C8C8C",light:"#8E8E90",hcDark:"#A7A8A9",hcLight:"#666666"},p("listDeemphasizedForeground","List/Tree foreground color for items that are deemphasized. "));const soe=R("checkbox.background",{dark:El,light:El,hcDark:El,hcLight:El},p("checkbox.background","Background color of checkbox widget."));R("checkbox.selectBackground",{dark:Ri,light:Ri,hcDark:Ri,hcLight:Ri},p("checkbox.select.background","Background color of checkbox widget when the element it's in is selected."));const ooe=R("checkbox.foreground",{dark:Od,light:Od,hcDark:Od,hcLight:Od},p("checkbox.foreground","Foreground color of checkbox widget.")),roe=R("checkbox.border",{dark:lp,light:lp,hcDark:lp,hcLight:lp},p("checkbox.border","Border color of checkbox widget."));R("checkbox.selectBorder",{dark:Ur,light:Ur,hcDark:Ur,hcLight:Ur},p("checkbox.select.border","Border color of checkbox widget when the element it's in is selected."));const S3=R("quickInput.list.focusBackground",{dark:null,light:null,hcDark:null,hcLight:null},"",void 0,p("quickInput.list.focusBackground deprecation","Please use quickInputList.focusBackground instead")),eg=R("quickInputList.focusForeground",{dark:Al,light:Al,hcDark:Al,hcLight:Al},p("quickInput.listFocusForeground","Quick picker foreground color for the focused item.")),dp=R("quickInputList.focusIconForeground",{dark:uv,light:uv,hcDark:uv,hcLight:uv},p("quickInput.listFocusIconForeground","Quick picker icon foreground color for the focused item.")),tg=R("quickInputList.focusBackground",{dark:U0(S3,Wd),light:U0(S3,Wd),hcDark:null,hcLight:null},p("quickInput.listFocusBackground","Quick picker background color for the focused item.")),aoe=R("menu.border",{dark:null,light:null,hcDark:pt,hcLight:pt},p("menuBorder","Border color of menus.")),loe=R("menu.foreground",{dark:Od,light:Od,hcDark:Od,hcLight:Od},p("menuForeground","Foreground color of menu items.")),doe=R("menu.background",{dark:El,light:El,hcDark:El,hcLight:El},p("menuBackground","Background color of menu items.")),coe=R("menu.selectionForeground",{dark:Al,light:Al,hcDark:Al,hcLight:Al},p("menuSelectionForeground","Foreground color of the selected menu item in menus.")),uoe=R("menu.selectionBackground",{dark:Wd,light:Wd,hcDark:Wd,hcLight:Wd},p("menuSelectionBackground","Background color of the selected menu item in menus.")),hoe=R("menu.selectionBorder",{dark:null,light:null,hcDark:ai,hcLight:ai},p("menuSelectionBorder","Border color of the selected menu item in menus.")),goe=R("menu.separatorBackground",{dark:"#606060",light:"#D4D4D4",hcDark:pt,hcLight:pt},p("menuSeparatorBackground","Color of a separator menu item in menus.")),mT=R("toolbar.hoverBackground",{dark:"#5a5d5e50",light:"#b8b8b850",hcDark:null,hcLight:null},p("toolbarHoverBackground","Toolbar background when hovering over actions using the mouse"));R("toolbar.hoverOutline",{dark:null,light:null,hcDark:ai,hcLight:ai},p("toolbarHoverOutline","Toolbar outline when hovering over actions using the mouse"));R("toolbar.activeBackground",{dark:Zr(mT,.1),light:oh(mT,.1),hcDark:null,hcLight:null},p("toolbarActiveBackground","Toolbar background when holding the mouse over actions"));R("editor.snippetTabstopHighlightBackground",{dark:new G(new vt(124,124,124,.3)),light:new G(new vt(10,50,100,.2)),hcDark:new G(new vt(124,124,124,.3)),hcLight:new G(new vt(10,50,100,.2))},p("snippetTabstopHighlightBackground","Highlight background color of a snippet tabstop."));R("editor.snippetTabstopHighlightBorder",{dark:null,light:null,hcDark:null,hcLight:null},p("snippetTabstopHighlightBorder","Highlight border color of a snippet tabstop."));R("editor.snippetFinalTabstopHighlightBackground",{dark:null,light:null,hcDark:null,hcLight:null},p("snippetFinalTabstopHighlightBackground","Highlight background color of the final tabstop of a snippet."));R("editor.snippetFinalTabstopHighlightBorder",{dark:"#525252",light:new G(new vt(10,50,100,.5)),hcDark:"#525252",hcLight:"#292929"},p("snippetFinalTabstopHighlightBorder","Highlight border color of the final tabstop of a snippet."));const foe=R("breadcrumb.foreground",{light:Me(de,.8),dark:Me(de,.8),hcDark:Me(de,.8),hcLight:Me(de,.8)},p("breadcrumbsFocusForeground","Color of focused breadcrumb items.")),poe=R("breadcrumb.background",{light:bn,dark:bn,hcDark:bn,hcLight:bn},p("breadcrumbsBackground","Background color of breadcrumb items.")),y3=R("breadcrumb.focusForeground",{light:oh(de,.2),dark:Zr(de,.1),hcDark:Zr(de,.1),hcLight:Zr(de,.1)},p("breadcrumbsFocusForeground","Color of focused breadcrumb items.")),moe=R("breadcrumb.activeSelectionForeground",{light:oh(de,.2),dark:Zr(de,.1),hcDark:Zr(de,.1),hcLight:Zr(de,.1)},p("breadcrumbsSelectedForeground","Color of selected breadcrumb items."));R("breadcrumbPicker.background",{light:Ri,dark:Ri,hcDark:Ri,hcLight:Ri},p("breadcrumbsSelectedBackground","Background color of breadcrumb item picker."));const hH=.5,L3=G.fromHex("#40C8AE").transparent(hH),x3=G.fromHex("#40A6FF").transparent(hH),D3=G.fromHex("#606060").transparent(.4),Kr=.4,_m=1,cp=R("merge.currentHeaderBackground",{dark:L3,light:L3,hcDark:null,hcLight:null},p("mergeCurrentHeaderBackground","Current header background in inline merge-conflicts. The color must not be opaque so as not to hide underlying decorations."),!0);R("merge.currentContentBackground",{dark:Me(cp,Kr),light:Me(cp,Kr),hcDark:Me(cp,Kr),hcLight:Me(cp,Kr)},p("mergeCurrentContentBackground","Current content background in inline merge-conflicts. The color must not be opaque so as not to hide underlying decorations."),!0);const up=R("merge.incomingHeaderBackground",{dark:x3,light:x3,hcDark:null,hcLight:null},p("mergeIncomingHeaderBackground","Incoming header background in inline merge-conflicts. The color must not be opaque so as not to hide underlying decorations."),!0);R("merge.incomingContentBackground",{dark:Me(up,Kr),light:Me(up,Kr),hcDark:Me(up,Kr),hcLight:Me(up,Kr)},p("mergeIncomingContentBackground","Incoming content background in inline merge-conflicts. The color must not be opaque so as not to hide underlying decorations."),!0);const hp=R("merge.commonHeaderBackground",{dark:D3,light:D3,hcDark:null,hcLight:null},p("mergeCommonHeaderBackground","Common ancestor header background in inline merge-conflicts. The color must not be opaque so as not to hide underlying decorations."),!0);R("merge.commonContentBackground",{dark:Me(hp,Kr),light:Me(hp,Kr),hcDark:Me(hp,Kr),hcLight:Me(hp,Kr)},p("mergeCommonContentBackground","Common ancestor content background in inline merge-conflicts. The color must not be opaque so as not to hide underlying decorations."),!0);const vm=R("merge.border",{dark:null,light:null,hcDark:"#C3DF6F",hcLight:"#007ACC"},p("mergeBorder","Border color on headers and the splitter in inline merge-conflicts."));R("editorOverviewRuler.currentContentForeground",{dark:Me(cp,_m),light:Me(cp,_m),hcDark:vm,hcLight:vm},p("overviewRulerCurrentContentForeground","Current overview ruler foreground for inline merge-conflicts."));R("editorOverviewRuler.incomingContentForeground",{dark:Me(up,_m),light:Me(up,_m),hcDark:vm,hcLight:vm},p("overviewRulerIncomingContentForeground","Incoming overview ruler foreground for inline merge-conflicts."));R("editorOverviewRuler.commonContentForeground",{dark:Me(hp,_m),light:Me(hp,_m),hcDark:vm,hcLight:vm},p("overviewRulerCommonContentForeground","Common ancestor overview ruler foreground for inline merge-conflicts."));const SP=R("editorOverviewRuler.findMatchForeground",{dark:"#d186167e",light:"#d186167e",hcDark:"#AB5A00",hcLight:""},p("overviewRulerFindMatchForeground","Overview ruler marker color for find matches. The color must not be opaque so as not to hide underlying decorations."),!0),gv=R("editorOverviewRuler.selectionHighlightForeground",{dark:"#A0A0A0CC",light:"#A0A0A0CC",hcDark:"#A0A0A0CC",hcLight:"#A0A0A0CC"},p("overviewRulerSelectionHighlightForeground","Overview ruler marker color for selection highlights. The color must not be opaque so as not to hide underlying decorations."),!0),gp=R("minimap.findMatchHighlight",{light:"#d18616",dark:"#d18616",hcDark:"#AB5A00",hcLight:"#0F4A85"},p("minimapFindMatchHighlight","Minimap marker color for find matches."),!0),wx=R("minimap.selectionOccurrenceHighlight",{light:"#c9c9c9",dark:"#676767",hcDark:"#ffffff",hcLight:"#0F4A85"},p("minimapSelectionOccurrenceHighlight","Minimap marker color for repeating editor selections."),!0),k3=R("minimap.selectionHighlight",{light:"#ADD6FF",dark:"#264F78",hcDark:"#ffffff",hcLight:"#0F4A85"},p("minimapSelectionHighlight","Minimap marker color for the editor selection."),!0),_oe=R("minimap.infoHighlight",{dark:Xs,light:Xs,hcDark:z0,hcLight:z0},p("minimapInfo","Minimap marker color for infos.")),voe=R("minimap.warningHighlight",{dark:Yo,light:Yo,hcDark:H0,hcLight:H0},p("overviewRuleWarning","Minimap marker color for warnings.")),boe=R("minimap.errorHighlight",{dark:new G(new vt(255,18,18,.7)),light:new G(new vt(255,18,18,.7)),hcDark:new G(new vt(255,50,50,1)),hcLight:"#B5200D"},p("minimapError","Minimap marker color for errors.")),Coe=R("minimap.background",{dark:null,light:null,hcDark:null,hcLight:null},p("minimapBackground","Minimap background color.")),woe=R("minimap.foregroundOpacity",{dark:G.fromHex("#000f"),light:G.fromHex("#000f"),hcDark:G.fromHex("#000f"),hcLight:G.fromHex("#000f")},p("minimapForegroundOpacity",'Opacity of foreground elements rendered in the minimap. For example, "#000000c0" will render the elements with 75% opacity.'));R("minimapSlider.background",{light:Me(lv,.5),dark:Me(lv,.5),hcDark:Me(lv,.5),hcLight:Me(lv,.5)},p("minimapSliderBackground","Minimap slider background color."));R("minimapSlider.hoverBackground",{light:Me(dv,.5),dark:Me(dv,.5),hcDark:Me(dv,.5),hcLight:Me(dv,.5)},p("minimapSliderHoverBackground","Minimap slider background color when hovering."));R("minimapSlider.activeBackground",{light:Me(cv,.5),dark:Me(cv,.5),hcDark:Me(cv,.5),hcLight:Me(cv,.5)},p("minimapSliderActiveBackground","Minimap slider background color when clicked on."));const Soe=R("problemsErrorIcon.foreground",{dark:Nl,light:Nl,hcDark:Nl,hcLight:Nl},p("problemsErrorIconForeground","The color used for the problems error icon.")),yoe=R("problemsWarningIcon.foreground",{dark:Yo,light:Yo,hcDark:Yo,hcLight:Yo},p("problemsWarningIconForeground","The color used for the problems warning icon.")),Loe=R("problemsInfoIcon.foreground",{dark:Xs,light:Xs,hcDark:Xs,hcLight:Xs},p("problemsInfoIconForeground","The color used for the problems info icon."));R("charts.foreground",{dark:de,light:de,hcDark:de,hcLight:de},p("chartsForeground","The foreground color used in charts."));R("charts.lines",{dark:Me(de,.5),light:Me(de,.5),hcDark:Me(de,.5),hcLight:Me(de,.5)},p("chartsLines","The color used for horizontal lines in charts."));R("charts.red",{dark:Nl,light:Nl,hcDark:Nl,hcLight:Nl},p("chartsRed","The red color used in chart visualizations."));R("charts.blue",{dark:Xs,light:Xs,hcDark:Xs,hcLight:Xs},p("chartsBlue","The blue color used in chart visualizations."));R("charts.yellow",{dark:Yo,light:Yo,hcDark:Yo,hcLight:Yo},p("chartsYellow","The yellow color used in chart visualizations."));R("charts.orange",{dark:gp,light:gp,hcDark:gp,hcLight:gp},p("chartsOrange","The orange color used in chart visualizations."));R("charts.green",{dark:"#89D185",light:"#388A34",hcDark:"#89D185",hcLight:"#374e06"},p("chartsGreen","The green color used in chart visualizations."));R("charts.purple",{dark:"#B180D7",light:"#652D90",hcDark:"#B180D7",hcLight:"#652D90"},p("chartsPurple","The purple color used in chart visualizations."));function xoe(s,e){var t,i,n,o;switch(s.op){case 0:return(t=ca(s.value,e))===null||t===void 0?void 0:t.darken(s.factor);case 1:return(i=ca(s.value,e))===null||i===void 0?void 0:i.lighten(s.factor);case 2:return(n=ca(s.value,e))===null||n===void 0?void 0:n.transparent(s.factor);case 3:{const r=ca(s.background,e);return r?(o=ca(s.value,e))===null||o===void 0?void 0:o.makeOpaque(r):ca(s.value,e)}case 4:for(const r of s.values){const a=ca(r,e);if(a)return a}return;case 6:return ca(e.defines(s.if)?s.then:s.else,e);case 5:{const r=ca(s.value,e);if(!r)return;const a=ca(s.background,e);return a?r.isDarkerThan(a)?G.getLighterColor(r,a,s.factor).transparent(s.transparency):G.getDarkerColor(r,a,s.factor).transparent(s.transparency):r.transparent(s.factor*s.transparency)}default:throw nx()}}function oh(s,e){return{op:0,value:s,factor:e}}function Zr(s,e){return{op:1,value:s,factor:e}}function Me(s,e){return{op:2,value:s,factor:e}}function U0(...s){return{op:4,values:s}}function Doe(s,e,t){return{op:6,if:s,then:e,else:t}}function I3(s,e,t,i){return{op:5,value:s,background:e,factor:t,transparency:i}}function ca(s,e){if(s!==null){if(typeof s=="string")return s[0]==="#"?G.fromHex(s):e.getColor(s);if(s instanceof G)return s;if(typeof s=="object")return xoe(s,e)}}const gH="vscode://schemas/workbench-colors",fH=Si.as(mx.JSONContribution);fH.registerSchema(gH,Cx.getColorSchema());const E3=new jt(()=>fH.notifySchemaChanged(gH),200);Cx.onDidChangeSchema(()=>{E3.isScheduled()||E3.schedule()});class Sx{constructor(e,t){this.x=e,this.y=t,this._pageCoordinatesBrand=void 0}toClientCoordinates(e){return new pH(this.x-e.scrollX,this.y-e.scrollY)}}class pH{constructor(e,t){this.clientX=e,this.clientY=t,this._clientCoordinatesBrand=void 0}toPageCoordinates(e){return new Sx(this.clientX+e.scrollX,this.clientY+e.scrollY)}}class koe{constructor(e,t,i,n){this.x=e,this.y=t,this.width=i,this.height=n,this._editorPagePositionBrand=void 0}}class Ioe{constructor(e,t){this.x=e,this.y=t,this._positionRelativeToEditorBrand=void 0}}function yP(s){const e=ln(s);return new koe(e.left,e.top,e.width,e.height)}function LP(s,e,t){const i=e.width/s.offsetWidth,n=e.height/s.offsetHeight,o=(t.x-e.x)/i,r=(t.y-e.y)/n;return new Ioe(o,r)}class Pu extends zr{constructor(e,t,i){super(Xe(i),e),this._editorMouseEventBrand=void 0,this.isFromPointerCapture=t,this.pos=new Sx(this.posx,this.posy),this.editorPos=yP(i),this.relativePos=LP(i,this.editorPos,this.pos)}}class Eoe{constructor(e){this._editorViewDomNode=e}_create(e){return new Pu(e,!1,this._editorViewDomNode)}onContextMenu(e,t){return Y(e,"contextmenu",i=>{t(this._create(i))})}onMouseUp(e,t){return Y(e,"mouseup",i=>{t(this._create(i))})}onMouseDown(e,t){return Y(e,he.MOUSE_DOWN,i=>{t(this._create(i))})}onPointerDown(e,t){return Y(e,he.POINTER_DOWN,i=>{t(this._create(i),i.pointerId)})}onMouseLeave(e,t){return Y(e,he.MOUSE_LEAVE,i=>{t(this._create(i))})}onMouseMove(e,t){return Y(e,"mousemove",i=>t(this._create(i)))}}class Noe{constructor(e){this._editorViewDomNode=e}_create(e){return new Pu(e,!1,this._editorViewDomNode)}onPointerUp(e,t){return Y(e,"pointerup",i=>{t(this._create(i))})}onPointerDown(e,t){return Y(e,he.POINTER_DOWN,i=>{t(this._create(i),i.pointerId)})}onPointerLeave(e,t){return Y(e,he.POINTER_LEAVE,i=>{t(this._create(i))})}onPointerMove(e,t){return Y(e,"pointermove",i=>t(this._create(i)))}}class Toe extends j{constructor(e){super(),this._editorViewDomNode=e,this._globalPointerMoveMonitor=this._register(new r_),this._keydownListener=null}startMonitoring(e,t,i,n,o){this._keydownListener=Pi(e.ownerDocument,"keydown",r=>{r.toKeyCodeChord().isModifierKey()||this._globalPointerMoveMonitor.stopMonitoring(!0,r.browserEvent)},!0),this._globalPointerMoveMonitor.startMonitoring(e,t,i,r=>{n(new Pu(r,!0,this._editorViewDomNode))},r=>{this._keydownListener.dispose(),o(r)})}stopMonitoring(){this._globalPointerMoveMonitor.stopMonitoring(!0)}}class cC{constructor(e){this._editor=e,this._instanceId=++cC._idPool,this._counter=0,this._rules=new Map,this._garbageCollectionScheduler=new jt(()=>this.garbageCollect(),1e3)}createClassNameRef(e){const t=this.getOrCreateRule(e);return t.increaseRefCount(),{className:t.className,dispose:()=>{t.decreaseRefCount(),this._garbageCollectionScheduler.schedule()}}}getOrCreateRule(e){const t=this.computeUniqueKey(e);let i=this._rules.get(t);if(!i){const n=this._counter++;i=new Moe(t,`dyn-rule-${this._instanceId}-${n}`,FS(this._editor.getContainerDomNode())?this._editor.getContainerDomNode():void 0,e),this._rules.set(t,i)}return i}computeUniqueKey(e){return JSON.stringify(e)}garbageCollect(){for(const e of this._rules.values())e.hasReferences()||(this._rules.delete(e.key),e.dispose())}}cC._idPool=0;class Moe{constructor(e,t,i,n){this.key=e,this.className=t,this.properties=n,this._referenceCount=0,this._styleElementDisposables=new ie,this._styleElement=Lr(i,void 0,this._styleElementDisposables),this._styleElement.textContent=this.getCssText(this.className,this.properties)}getCssText(e,t){let i=`.${e} {`;for(const n in t){const o=t[n];let r;typeof o=="object"?r=_e(o.id):r=o;const a=Roe(n);i+=`
	${a}: ${r};`}return i+=`
}`,i}dispose(){this._styleElementDisposables.dispose(),this._styleElement=void 0}increaseRefCount(){this._referenceCount++}decreaseRefCount(){this._referenceCount--}hasReferences(){return this._referenceCount>0}}function Roe(s){return s.replace(/(^[A-Z])/,([e])=>e.toLowerCase()).replace(/([A-Z])/g,([e])=>`-${e.toLowerCase()}`)}class uC extends j{constructor(){super(),this._shouldRender=!0}shouldRender(){return this._shouldRender}forceShouldRender(){this._shouldRender=!0}setShouldRender(){this._shouldRender=!0}onDidRender(){this._shouldRender=!1}onCompositionStart(e){return!1}onCompositionEnd(e){return!1}onConfigurationChanged(e){return!1}onCursorStateChanged(e){return!1}onDecorationsChanged(e){return!1}onFlushed(e){return!1}onFocusChanged(e){return!1}onLanguageConfigurationChanged(e){return!1}onLineMappingChanged(e){return!1}onLinesChanged(e){return!1}onLinesDeleted(e){return!1}onLinesInserted(e){return!1}onRevealRangeRequest(e){return!1}onScrollChanged(e){return!1}onThemeChanged(e){return!1}onTokensChanged(e){return!1}onTokensColorsChanged(e){return!1}onZonesChanged(e){return!1}handleEvents(e){let t=!1;for(let i=0,n=e.length;i<n;i++){const o=e[i];switch(o.type){case 0:this.onCompositionStart(o)&&(t=!0);break;case 1:this.onCompositionEnd(o)&&(t=!0);break;case 2:this.onConfigurationChanged(o)&&(t=!0);break;case 3:this.onCursorStateChanged(o)&&(t=!0);break;case 4:this.onDecorationsChanged(o)&&(t=!0);break;case 5:this.onFlushed(o)&&(t=!0);break;case 6:this.onFocusChanged(o)&&(t=!0);break;case 7:this.onLanguageConfigurationChanged(o)&&(t=!0);break;case 8:this.onLineMappingChanged(o)&&(t=!0);break;case 9:this.onLinesChanged(o)&&(t=!0);break;case 10:this.onLinesDeleted(o)&&(t=!0);break;case 11:this.onLinesInserted(o)&&(t=!0);break;case 12:this.onRevealRangeRequest(o)&&(t=!0);break;case 13:this.onScrollChanged(o)&&(t=!0);break;case 15:this.onTokensChanged(o)&&(t=!0);break;case 14:this.onThemeChanged(o)&&(t=!0);break;case 16:this.onTokensColorsChanged(o)&&(t=!0);break;case 17:this.onZonesChanged(o)&&(t=!0);break;default:console.info("View received unknown event: "),console.info(o)}}t&&(this._shouldRender=!0)}}class Eo extends uC{constructor(e){super(),this._context=e,this._context.addEventHandler(this)}dispose(){this._context.removeEventHandler(this),super.dispose()}}class Zl{static write(e,t){e.setAttribute("data-mprt",String(t))}static read(e){const t=e.getAttribute("data-mprt");return t===null?0:parseInt(t,10)}static collect(e,t){const i=[];let n=0;for(;e&&e!==e.ownerDocument.body&&e!==t;)e.nodeType===e.ELEMENT_NODE&&(i[n++]=this.read(e)),e=e.parentElement;const o=new Uint8Array(n);for(let r=0;r<n;r++)o[r]=i[n-r-1];return o}}class Aoe{constructor(e,t){this._restrictedRenderingContextBrand=void 0,this._viewLayout=e,this.viewportData=t,this.scrollWidth=this._viewLayout.getScrollWidth(),this.scrollHeight=this._viewLayout.getScrollHeight(),this.visibleRange=this.viewportData.visibleRange,this.bigNumbersDelta=this.viewportData.bigNumbersDelta;const i=this._viewLayout.getCurrentViewport();this.scrollTop=i.top,this.scrollLeft=i.left,this.viewportWidth=i.width,this.viewportHeight=i.height}getScrolledTopFromAbsoluteTop(e){return e-this.scrollTop}getVerticalOffsetForLineNumber(e,t){return this._viewLayout.getVerticalOffsetForLineNumber(e,t)}getVerticalOffsetAfterLineNumber(e,t){return this._viewLayout.getVerticalOffsetAfterLineNumber(e,t)}getDecorationsInViewport(){return this.viewportData.getDecorationsInViewport()}}class Poe extends Aoe{constructor(e,t,i){super(e,t),this._renderingContextBrand=void 0,this._viewLines=i}linesVisibleRangesForRange(e,t){return this._viewLines.linesVisibleRangesForRange(e,t)}visibleRangeForPosition(e){return this._viewLines.visibleRangeForPosition(e)}}class Ooe{constructor(e,t,i,n){this.outsideRenderedLine=e,this.lineNumber=t,this.ranges=i,this.continuesOnNextLine=n}}class yx{static from(e){const t=new Array(e.length);for(let i=0,n=e.length;i<n;i++){const o=e[i];t[i]=new yx(o.left,o.width)}return t}constructor(e,t){this._horizontalRangeBrand=void 0,this.left=Math.round(e),this.width=Math.round(t)}toString(){return`[${this.left},${this.width}]`}}class pg{constructor(e,t){this._floatHorizontalRangeBrand=void 0,this.left=e,this.width=t}toString(){return`[${this.left},${this.width}]`}static compare(e,t){return e.left-t.left}}class Foe{constructor(e,t){this.outsideRenderedLine=e,this.originalLeft=t,this.left=Math.round(this.originalLeft)}}class N3{constructor(e,t){this.outsideRenderedLine=e,this.ranges=t}}class Ww{static _createRange(){return this._handyReadyRange||(this._handyReadyRange=document.createRange()),this._handyReadyRange}static _detachRange(e,t){e.selectNodeContents(t)}static _readClientRects(e,t,i,n,o){const r=this._createRange();try{return r.setStart(e,t),r.setEnd(i,n),r.getClientRects()}catch{return null}finally{this._detachRange(r,o)}}static _mergeAdjacentRanges(e){if(e.length===1)return e;e.sort(pg.compare);const t=[];let i=0,n=e[0];for(let o=1,r=e.length;o<r;o++){const a=e[o];n.left+n.width+.9>=a.left?n.width=Math.max(n.width,a.left+a.width-n.left):(t[i++]=n,n=a)}return t[i++]=n,t}static _createHorizontalRangesFromClientRects(e,t,i){if(!e||e.length===0)return null;const n=[];for(let o=0,r=e.length;o<r;o++){const a=e[o];n[o]=new pg(Math.max(0,(a.left-t)/i),a.width/i)}return this._mergeAdjacentRanges(n)}static readHorizontalRanges(e,t,i,n,o,r){const l=e.children.length-1;if(0>l)return null;if(t=Math.min(l,Math.max(0,t)),n=Math.min(l,Math.max(0,n)),t===n&&i===o&&i===0&&!e.children[t].firstChild){const h=e.children[t].getClientRects();return r.markDidDomLayout(),this._createHorizontalRangesFromClientRects(h,r.clientRectDeltaLeft,r.clientRectScale)}t!==n&&n>0&&o===0&&(n--,o=1073741824);let d=e.children[t].firstChild,c=e.children[n].firstChild;if((!d||!c)&&(!d&&i===0&&t>0&&(d=e.children[t-1].firstChild,i=1073741824),!c&&o===0&&n>0&&(c=e.children[n-1].firstChild,o=1073741824)),!d||!c)return null;i=Math.min(d.textContent.length,Math.max(0,i)),o=Math.min(c.textContent.length,Math.max(0,o));const u=this._readClientRects(d,i,c,o,r.endNode);return r.markDidDomLayout(),this._createHorizontalRangesFromClientRects(u,r.clientRectDeltaLeft,r.clientRectScale)}}var _r;(function(s){s.DARK="dark",s.LIGHT="light",s.HIGH_CONTRAST_DARK="hcDark",s.HIGH_CONTRAST_LIGHT="hcLight"})(_r||(_r={}));function Oa(s){return s===_r.HIGH_CONTRAST_DARK||s===_r.HIGH_CONTRAST_LIGHT}function bm(s){return s===_r.DARK||s===_r.HIGH_CONTRAST_DARK}const Boe=function(){return Ra?!0:!(Ss||yr||Jd)}();let Wp=!0;class T3{constructor(e,t){this.themeType=t;const i=e.options,n=i.get(50);i.get(38)==="off"?this.renderWhitespace=i.get(98):this.renderWhitespace="none",this.renderControlCharacters=i.get(93),this.spaceWidth=n.spaceWidth,this.middotWidth=n.middotWidth,this.wsmiddotWidth=n.wsmiddotWidth,this.useMonospaceOptimizations=n.isMonospace&&!i.get(33),this.canUseHalfwidthRightwardsArrow=n.canUseHalfwidthRightwardsArrow,this.lineHeight=i.get(66),this.stopRenderingLineAfter=i.get(116),this.fontLigatures=i.get(51)}equals(e){return this.themeType===e.themeType&&this.renderWhitespace===e.renderWhitespace&&this.renderControlCharacters===e.renderControlCharacters&&this.spaceWidth===e.spaceWidth&&this.middotWidth===e.middotWidth&&this.wsmiddotWidth===e.wsmiddotWidth&&this.useMonospaceOptimizations===e.useMonospaceOptimizations&&this.canUseHalfwidthRightwardsArrow===e.canUseHalfwidthRightwardsArrow&&this.lineHeight===e.lineHeight&&this.stopRenderingLineAfter===e.stopRenderingLineAfter&&this.fontLigatures===e.fontLigatures}}class bl{constructor(e){this._options=e,this._isMaybeInvalid=!0,this._renderedViewLine=null}getDomNode(){return this._renderedViewLine&&this._renderedViewLine.domNode?this._renderedViewLine.domNode.domNode:null}setDomNode(e){if(this._renderedViewLine)this._renderedViewLine.domNode=Mt(e);else throw new Error("I have no rendered view line to set the dom node to...")}onContentChanged(){this._isMaybeInvalid=!0}onTokensChanged(){this._isMaybeInvalid=!0}onDecorationsChanged(){this._isMaybeInvalid=!0}onOptionsChanged(e){this._isMaybeInvalid=!0,this._options=e}onSelectionChanged(){return Oa(this._options.themeType)||this._options.renderWhitespace==="selection"?(this._isMaybeInvalid=!0,!0):!1}renderLine(e,t,i,n){if(this._isMaybeInvalid===!1)return!1;this._isMaybeInvalid=!1;const o=i.getViewLineRenderingData(e),r=this._options,a=mo.filter(o.inlineDecorations,e,o.minColumn,o.maxColumn);let l=null;if(Oa(r.themeType)||this._options.renderWhitespace==="selection"){const h=i.selections;for(const g of h){if(g.endLineNumber<e||g.startLineNumber>e)continue;const f=g.startLineNumber===e?g.startColumn:o.minColumn,m=g.endLineNumber===e?g.endColumn:o.maxColumn;f<m&&(Oa(r.themeType)&&a.push(new mo(f,m,"inline-selected-text",0)),this._options.renderWhitespace==="selection"&&(l||(l=[]),l.push(new XV(f-1,m-1))))}}const d=new sh(r.useMonospaceOptimizations,r.canUseHalfwidthRightwardsArrow,o.content,o.continuesWithWrappedLine,o.isBasicASCII,o.containsRTL,o.minColumn-1,o.tokens,a,o.tabSize,o.startVisibleColumn,r.spaceWidth,r.middotWidth,r.wsmiddotWidth,r.stopRenderingLineAfter,r.renderWhitespace,r.renderControlCharacters,r.fontLigatures!==$o.OFF,l);if(this._renderedViewLine&&this._renderedViewLine.input.equals(d))return!1;n.appendString('<div style="top:'),n.appendString(String(t)),n.appendString("px;height:"),n.appendString(String(this._options.lineHeight)),n.appendString('px;" class="'),n.appendString(bl.CLASS_NAME),n.appendString('">');const c=lC(d,n);n.appendString("</div>");let u=null;return Wp&&Boe&&o.isBasicASCII&&r.useMonospaceOptimizations&&c.containsForeignElements===0&&(u=new g1(this._renderedViewLine?this._renderedViewLine.domNode:null,d,c.characterMapping)),u||(u=_H(this._renderedViewLine?this._renderedViewLine.domNode:null,d,c.characterMapping,c.containsRTL,c.containsForeignElements)),this._renderedViewLine=u,!0}layoutLine(e,t){this._renderedViewLine&&this._renderedViewLine.domNode&&(this._renderedViewLine.domNode.setTop(t),this._renderedViewLine.domNode.setHeight(this._options.lineHeight))}getWidth(e){return this._renderedViewLine?this._renderedViewLine.getWidth(e):0}getWidthIsFast(){return this._renderedViewLine?this._renderedViewLine.getWidthIsFast():!0}needsMonospaceFontCheck(){return this._renderedViewLine?this._renderedViewLine instanceof g1:!1}monospaceAssumptionsAreValid(){return this._renderedViewLine&&this._renderedViewLine instanceof g1?this._renderedViewLine.monospaceAssumptionsAreValid():Wp}onMonospaceAssumptionsInvalidated(){this._renderedViewLine&&this._renderedViewLine instanceof g1&&(this._renderedViewLine=this._renderedViewLine.toSlowRenderedLine())}getVisibleRangesForRange(e,t,i,n){if(!this._renderedViewLine)return null;t=Math.min(this._renderedViewLine.input.lineContent.length+1,Math.max(1,t)),i=Math.min(this._renderedViewLine.input.lineContent.length+1,Math.max(1,i));const o=this._renderedViewLine.input.stopRenderingLineAfter;if(o!==-1&&t>o+1&&i>o+1)return new N3(!0,[new pg(this.getWidth(n),0)]);o!==-1&&t>o+1&&(t=o+1),o!==-1&&i>o+1&&(i=o+1);const r=this._renderedViewLine.getVisibleRangesForRange(e,t,i,n);return r&&r.length>0?new N3(!1,r):null}getColumnOfNodeOffset(e,t){return this._renderedViewLine?this._renderedViewLine.getColumnOfNodeOffset(e,t):1}}bl.CLASS_NAME="view-line";class g1{constructor(e,t,i){this._cachedWidth=-1,this.domNode=e,this.input=t;const n=Math.floor(t.lineContent.length/300);if(n>0){this._keyColumnPixelOffsetCache=new Float32Array(n);for(let o=0;o<n;o++)this._keyColumnPixelOffsetCache[o]=-1}else this._keyColumnPixelOffsetCache=null;this._characterMapping=i,this._charWidth=t.spaceWidth}getWidth(e){if(!this.domNode||this.input.lineContent.length<300){const t=this._characterMapping.getHorizontalOffset(this._characterMapping.length);return Math.round(this._charWidth*t)}return this._cachedWidth===-1&&(this._cachedWidth=this._getReadingTarget(this.domNode).offsetWidth,e==null||e.markDidDomLayout()),this._cachedWidth}getWidthIsFast(){return this.input.lineContent.length<300||this._cachedWidth!==-1}monospaceAssumptionsAreValid(){if(!this.domNode)return Wp;if(this.input.lineContent.length<300){const e=this.getWidth(null),t=this.domNode.domNode.firstChild.offsetWidth;Math.abs(e-t)>=2&&(console.warn("monospace assumptions have been violated, therefore disabling monospace optimizations!"),Wp=!1)}return Wp}toSlowRenderedLine(){return _H(this.domNode,this.input,this._characterMapping,!1,0)}getVisibleRangesForRange(e,t,i,n){const o=this._getColumnPixelOffset(e,t,n),r=this._getColumnPixelOffset(e,i,n);return[new pg(o,r-o)]}_getColumnPixelOffset(e,t,i){if(t<=300){const d=this._characterMapping.getHorizontalOffset(t);return this._charWidth*d}const n=Math.floor((t-1)/300)-1,o=(n+1)*300+1;let r=-1;if(this._keyColumnPixelOffsetCache&&(r=this._keyColumnPixelOffsetCache[n],r===-1&&(r=this._actualReadPixelOffset(e,o,i),this._keyColumnPixelOffsetCache[n]=r)),r===-1){const d=this._characterMapping.getHorizontalOffset(t);return this._charWidth*d}const a=this._characterMapping.getHorizontalOffset(o),l=this._characterMapping.getHorizontalOffset(t);return r+this._charWidth*(l-a)}_getReadingTarget(e){return e.domNode.firstChild}_actualReadPixelOffset(e,t,i){if(!this.domNode)return-1;const n=this._characterMapping.getDomPosition(t),o=Ww.readHorizontalRanges(this._getReadingTarget(this.domNode),n.partIndex,n.charIndex,n.partIndex,n.charIndex,i);return!o||o.length===0?-1:o[0].left}getColumnOfNodeOffset(e,t){return xP(this._characterMapping,e,t)}}class mH{constructor(e,t,i,n,o){if(this.domNode=e,this.input=t,this._characterMapping=i,this._isWhitespaceOnly=/^\s*$/.test(t.lineContent),this._containsForeignElements=o,this._cachedWidth=-1,this._pixelOffsetCache=null,!n||this._characterMapping.length===0){this._pixelOffsetCache=new Float32Array(Math.max(2,this._characterMapping.length+1));for(let r=0,a=this._characterMapping.length;r<=a;r++)this._pixelOffsetCache[r]=-1}}_getReadingTarget(e){return e.domNode.firstChild}getWidth(e){return this.domNode?(this._cachedWidth===-1&&(this._cachedWidth=this._getReadingTarget(this.domNode).offsetWidth,e==null||e.markDidDomLayout()),this._cachedWidth):0}getWidthIsFast(){return this._cachedWidth!==-1}getVisibleRangesForRange(e,t,i,n){if(!this.domNode)return null;if(this._pixelOffsetCache!==null){const o=this._readPixelOffset(this.domNode,e,t,n);if(o===-1)return null;const r=this._readPixelOffset(this.domNode,e,i,n);return r===-1?null:[new pg(o,r-o)]}return this._readVisibleRangesForRange(this.domNode,e,t,i,n)}_readVisibleRangesForRange(e,t,i,n,o){if(i===n){const r=this._readPixelOffset(e,t,i,o);return r===-1?null:[new pg(r,0)]}else return this._readRawVisibleRangesForRange(e,i,n,o)}_readPixelOffset(e,t,i,n){if(this._characterMapping.length===0){if(this._containsForeignElements===0||this._containsForeignElements===2)return 0;if(this._containsForeignElements===1)return this.getWidth(n);const o=this._getReadingTarget(e);return o.firstChild?(n.markDidDomLayout(),o.firstChild.offsetWidth):0}if(this._pixelOffsetCache!==null){const o=this._pixelOffsetCache[i];if(o!==-1)return o;const r=this._actualReadPixelOffset(e,t,i,n);return this._pixelOffsetCache[i]=r,r}return this._actualReadPixelOffset(e,t,i,n)}_actualReadPixelOffset(e,t,i,n){if(this._characterMapping.length===0){const l=Ww.readHorizontalRanges(this._getReadingTarget(e),0,0,0,0,n);return!l||l.length===0?-1:l[0].left}if(i===this._characterMapping.length&&this._isWhitespaceOnly&&this._containsForeignElements===0)return this.getWidth(n);const o=this._characterMapping.getDomPosition(i),r=Ww.readHorizontalRanges(this._getReadingTarget(e),o.partIndex,o.charIndex,o.partIndex,o.charIndex,n);if(!r||r.length===0)return-1;const a=r[0].left;if(this.input.isBasicASCII){const l=this._characterMapping.getHorizontalOffset(i),d=Math.round(this.input.spaceWidth*l);if(Math.abs(d-a)<=1)return d}return a}_readRawVisibleRangesForRange(e,t,i,n){if(t===1&&i===this._characterMapping.length)return[new pg(0,this.getWidth(n))];const o=this._characterMapping.getDomPosition(t),r=this._characterMapping.getDomPosition(i);return Ww.readHorizontalRanges(this._getReadingTarget(e),o.partIndex,o.charIndex,r.partIndex,r.charIndex,n)}getColumnOfNodeOffset(e,t){return xP(this._characterMapping,e,t)}}class Woe extends mH{_readVisibleRangesForRange(e,t,i,n,o){const r=super._readVisibleRangesForRange(e,t,i,n,o);if(!r||r.length===0||i===n||i===1&&n===this._characterMapping.length)return r;if(!this.input.containsRTL){const a=this._readPixelOffset(e,t,n,o);if(a!==-1){const l=r[r.length-1];l.left<a&&(l.width=a-l.left)}}return r}}const _H=function(){return ug?Voe:Hoe}();function Voe(s,e,t,i,n){return new Woe(s,e,t,i,n)}function Hoe(s,e,t,i,n){return new mH(s,e,t,i,n)}function xP(s,e,t){const i=e.textContent.length;let n=-1;for(;e;)e=e.previousSibling,n++;return s.getColumn(new QV(n,t),i)}class hn{static _nextVisibleColumn(e,t,i){return e===9?hn.nextRenderTabStop(t,i):ku(e)||HA(e)?t+2:t+1}static visibleColumnFromColumn(e,t,i){const n=Math.min(t-1,e.length),o=e.substring(0,n),r=new PS(o);let a=0;for(;!r.eol();){const l=AS(o,n,r.offset);r.nextGraphemeLength(),a=this._nextVisibleColumn(l,a,i)}return a}static columnFromVisibleColumn(e,t,i){if(t<=0)return 1;const n=e.length,o=new PS(e);let r=0,a=1;for(;!o.eol();){const l=AS(e,n,o.offset);o.nextGraphemeLength();const d=this._nextVisibleColumn(l,r,i),c=o.offset+1;if(d>=t){const u=t-r;return d-t<u?c:a}r=d,a=c}return n+1}static nextRenderTabStop(e,t){return e+t-e%t}static nextIndentTabStop(e,t){return e+t-e%t}static prevRenderTabStop(e,t){return Math.max(0,e-1-(e-1)%t)}static prevIndentTabStop(e,t){return Math.max(0,e-1-(e-1)%t)}}class $0{static whitespaceVisibleColumn(e,t,i){const n=e.length;let o=0,r=-1,a=-1;for(let l=0;l<n;l++){if(l===t)return[r,a,o];switch(o%i===0&&(r=l,a=o),e.charCodeAt(l)){case 32:o+=1;break;case 9:o=hn.nextRenderTabStop(o,i);break;default:return[-1,-1,-1]}}return t===n?[r,a,o]:[-1,-1,-1]}static atomicPosition(e,t,i,n){const o=e.length,[r,a,l]=$0.whitespaceVisibleColumn(e,t,i);if(l===-1)return-1;let d;switch(n){case 0:d=!0;break;case 1:d=!1;break;case 2:if(l%i===0)return t;d=l%i<=i/2;break}if(d){if(r===-1)return-1;let h=a;for(let g=r;g<o;++g){if(h===a+i)return r;switch(e.charCodeAt(g)){case 32:h+=1;break;case 9:h=hn.nextRenderTabStop(h,i);break;default:return-1}}return h===a+i?r:-1}const c=hn.nextRenderTabStop(l,i);let u=l;for(let h=t;h<o;h++){if(u===c)return h;switch(e.charCodeAt(h)){case 32:u+=1;break;case 9:u=hn.nextRenderTabStop(u,i);break;default:return-1}}return u===c?o:-1}}class Sc{constructor(e=null){this.hitTarget=e,this.type=0}}class vH{constructor(e,t,i){this.position=e,this.spanNode=t,this.injectedText=i,this.type=1}}var jh;(function(s){function e(t,i,n){const o=t.getPositionFromDOMInfo(i,n);return o?new vH(o,i,null):new Sc(i)}s.createFromDOMInfo=e})(jh||(jh={}));class zoe{constructor(e,t){this.lastViewCursorsRenderData=e,this.lastTextareaPosition=t}}class bs{static _deduceRage(e,t=null){return!t&&e?new D(e.lineNumber,e.column,e.lineNumber,e.column):t??null}static createUnknown(e,t,i){return{type:0,element:e,mouseColumn:t,position:i,range:this._deduceRage(i)}}static createTextarea(e,t){return{type:1,element:e,mouseColumn:t,position:null,range:null}}static createMargin(e,t,i,n,o,r){return{type:e,element:t,mouseColumn:i,position:n,range:o,detail:r}}static createViewZone(e,t,i,n,o){return{type:e,element:t,mouseColumn:i,position:n,range:this._deduceRage(n),detail:o}}static createContentText(e,t,i,n,o){return{type:6,element:e,mouseColumn:t,position:i,range:this._deduceRage(i,n),detail:o}}static createContentEmpty(e,t,i,n){return{type:7,element:e,mouseColumn:t,position:i,range:this._deduceRage(i),detail:n}}static createContentWidget(e,t,i){return{type:9,element:e,mouseColumn:t,position:null,range:null,detail:i}}static createScrollbar(e,t,i){return{type:11,element:e,mouseColumn:t,position:i,range:this._deduceRage(i)}}static createOverlayWidget(e,t,i){return{type:12,element:e,mouseColumn:t,position:null,range:null,detail:i}}static createOutsideEditor(e,t,i,n){return{type:13,element:null,mouseColumn:e,position:t,range:this._deduceRage(t),outsidePosition:i,outsideDistance:n}}static _typeToString(e){return e===1?"TEXTAREA":e===2?"GUTTER_GLYPH_MARGIN":e===3?"GUTTER_LINE_NUMBERS":e===4?"GUTTER_LINE_DECORATIONS":e===5?"GUTTER_VIEW_ZONE":e===6?"CONTENT_TEXT":e===7?"CONTENT_EMPTY":e===8?"CONTENT_VIEW_ZONE":e===9?"CONTENT_WIDGET":e===10?"OVERVIEW_RULER":e===11?"SCROLLBAR":e===12?"OVERLAY_WIDGET":"UNKNOWN"}static toString(e){return this._typeToString(e.type)+": "+e.position+" - "+e.range+" - "+JSON.stringify(e.detail)}}class To{static isTextArea(e){return e.length===2&&e[0]===3&&e[1]===6}static isChildOfViewLines(e){return e.length>=4&&e[0]===3&&e[3]===7}static isStrictChildOfViewLines(e){return e.length>4&&e[0]===3&&e[3]===7}static isChildOfScrollableElement(e){return e.length>=2&&e[0]===3&&e[1]===5}static isChildOfMinimap(e){return e.length>=2&&e[0]===3&&e[1]===8}static isChildOfContentWidgets(e){return e.length>=4&&e[0]===3&&e[3]===1}static isChildOfOverflowGuard(e){return e.length>=1&&e[0]===3}static isChildOfOverflowingContentWidgets(e){return e.length>=1&&e[0]===2}static isChildOfOverlayWidgets(e){return e.length>=2&&e[0]===3&&e[1]===4}}class Cm{constructor(e,t,i){this.viewModel=e.viewModel;const n=e.configuration.options;this.layoutInfo=n.get(143),this.viewDomNode=t.viewDomNode,this.lineHeight=n.get(66),this.stickyTabStops=n.get(115),this.typicalHalfwidthCharacterWidth=n.get(50).typicalHalfwidthCharacterWidth,this.lastRenderData=i,this._context=e,this._viewHelper=t}getZoneAtCoord(e){return Cm.getZoneAtCoord(this._context,e)}static getZoneAtCoord(e,t){const i=e.viewLayout.getWhitespaceAtVerticalOffset(t);if(i){const n=i.verticalOffset+i.height/2,o=e.viewModel.getLineCount();let r=null,a,l=null;return i.afterLineNumber!==o&&(l=new H(i.afterLineNumber+1,1)),i.afterLineNumber>0&&(r=new H(i.afterLineNumber,e.viewModel.getLineMaxColumn(i.afterLineNumber))),l===null?a=r:r===null?a=l:t<n?a=r:a=l,{viewZoneId:i.id,afterLineNumber:i.afterLineNumber,positionBefore:r,positionAfter:l,position:a}}return null}getFullLineRangeAtCoord(e){if(this._context.viewLayout.isAfterLines(e)){const n=this._context.viewModel.getLineCount(),o=this._context.viewModel.getLineMaxColumn(n);return{range:new D(n,o,n,o),isAfterLines:!0}}const t=this._context.viewLayout.getLineNumberAtVerticalOffset(e),i=this._context.viewModel.getLineMaxColumn(t);return{range:new D(t,1,t,i),isAfterLines:!1}}getLineNumberAtVerticalOffset(e){return this._context.viewLayout.getLineNumberAtVerticalOffset(e)}isAfterLines(e){return this._context.viewLayout.isAfterLines(e)}isInTopPadding(e){return this._context.viewLayout.isInTopPadding(e)}isInBottomPadding(e){return this._context.viewLayout.isInBottomPadding(e)}getVerticalOffsetForLineNumber(e){return this._context.viewLayout.getVerticalOffsetForLineNumber(e)}findAttribute(e,t){return Cm._findAttribute(e,t,this._viewHelper.viewDomNode)}static _findAttribute(e,t,i){for(;e&&e!==e.ownerDocument.body;){if(e.hasAttribute&&e.hasAttribute(t))return e.getAttribute(t);if(e===i)return null;e=e.parentNode}return null}getLineWidth(e){return this._viewHelper.getLineWidth(e)}visibleRangeForPosition(e,t){return this._viewHelper.visibleRangeForPosition(e,t)}getPositionFromDOMInfo(e,t){return this._viewHelper.getPositionFromDOMInfo(e,t)}getCurrentScrollTop(){return this._context.viewLayout.getCurrentScrollTop()}getCurrentScrollLeft(){return this._context.viewLayout.getCurrentScrollLeft()}}class Uoe{constructor(e,t,i,n){this.editorPos=t,this.pos=i,this.relativePos=n,this.mouseVerticalOffset=Math.max(0,e.getCurrentScrollTop()+this.relativePos.y),this.mouseContentHorizontalOffset=e.getCurrentScrollLeft()+this.relativePos.x-e.layoutInfo.contentLeft,this.isInMarginArea=this.relativePos.x<e.layoutInfo.contentLeft&&this.relativePos.x>=e.layoutInfo.glyphMarginLeft,this.isInContentArea=!this.isInMarginArea,this.mouseColumn=Math.max(0,$n._getMouseColumn(this.mouseContentHorizontalOffset,e.typicalHalfwidthCharacterWidth))}}class DP extends Uoe{constructor(e,t,i,n,o){super(e,t,i,n),this._ctx=e,o?(this.target=o,this.targetPath=Zl.collect(o,e.viewDomNode)):(this.target=null,this.targetPath=new Uint8Array(0))}toString(){return`pos(${this.pos.x},${this.pos.y}), editorPos(${this.editorPos.x},${this.editorPos.y}), relativePos(${this.relativePos.x},${this.relativePos.y}), mouseVerticalOffset: ${this.mouseVerticalOffset}, mouseContentHorizontalOffset: ${this.mouseContentHorizontalOffset}
	target: ${this.target?this.target.outerHTML:null}`}_getMouseColumn(e=null){return e&&e.column<this._ctx.viewModel.getLineMaxColumn(e.lineNumber)?hn.visibleColumnFromColumn(this._ctx.viewModel.getLineContent(e.lineNumber),e.column,this._ctx.viewModel.model.getOptions().tabSize)+1:this.mouseColumn}fulfillUnknown(e=null){return bs.createUnknown(this.target,this._getMouseColumn(e),e)}fulfillTextarea(){return bs.createTextarea(this.target,this._getMouseColumn())}fulfillMargin(e,t,i,n){return bs.createMargin(e,this.target,this._getMouseColumn(t),t,i,n)}fulfillViewZone(e,t,i){return bs.createViewZone(e,this.target,this._getMouseColumn(t),t,i)}fulfillContentText(e,t,i){return bs.createContentText(this.target,this._getMouseColumn(e),e,t,i)}fulfillContentEmpty(e,t){return bs.createContentEmpty(this.target,this._getMouseColumn(e),e,t)}fulfillContentWidget(e){return bs.createContentWidget(this.target,this._getMouseColumn(),e)}fulfillScrollbar(e){return bs.createScrollbar(this.target,this._getMouseColumn(e),e)}fulfillOverlayWidget(e){return bs.createOverlayWidget(this.target,this._getMouseColumn(),e)}withTarget(e){return new DP(this._ctx,this.editorPos,this.pos,this.relativePos,e)}}const M3={isAfterLines:!0};function iI(s){return{isAfterLines:!1,horizontalDistanceToText:s}}class $n{constructor(e,t){this._context=e,this._viewHelper=t}mouseTargetIsWidget(e){const t=e.target,i=Zl.collect(t,this._viewHelper.viewDomNode);return!!(To.isChildOfContentWidgets(i)||To.isChildOfOverflowingContentWidgets(i)||To.isChildOfOverlayWidgets(i))}createMouseTarget(e,t,i,n,o){const r=new Cm(this._context,this._viewHelper,e),a=new DP(r,t,i,n,o);try{const l=$n._createMouseTarget(r,a,!1);if(l.type===6&&r.stickyTabStops&&l.position!==null){const d=$n._snapToSoftTabBoundary(l.position,r.viewModel),c=D.fromPositions(d,d).plusRange(l.range);return a.fulfillContentText(d,c,l.detail)}return l}catch{return a.fulfillUnknown()}}static _createMouseTarget(e,t,i){if(t.target===null){if(i)return t.fulfillUnknown();const r=$n._doHitTest(e,t);return r.type===1?$n.createMouseTargetFromHitTestPosition(e,t,r.spanNode,r.position,r.injectedText):this._createMouseTarget(e,t.withTarget(r.hitTarget),!0)}const n=t;let o=null;return!To.isChildOfOverflowGuard(t.targetPath)&&!To.isChildOfOverflowingContentWidgets(t.targetPath)&&(o=o||t.fulfillUnknown()),o=o||$n._hitTestContentWidget(e,n),o=o||$n._hitTestOverlayWidget(e,n),o=o||$n._hitTestMinimap(e,n),o=o||$n._hitTestScrollbarSlider(e,n),o=o||$n._hitTestViewZone(e,n),o=o||$n._hitTestMargin(e,n),o=o||$n._hitTestViewCursor(e,n),o=o||$n._hitTestTextArea(e,n),o=o||$n._hitTestViewLines(e,n,i),o=o||$n._hitTestScrollbar(e,n),o||t.fulfillUnknown()}static _hitTestContentWidget(e,t){if(To.isChildOfContentWidgets(t.targetPath)||To.isChildOfOverflowingContentWidgets(t.targetPath)){const i=e.findAttribute(t.target,"widgetId");return i?t.fulfillContentWidget(i):t.fulfillUnknown()}return null}static _hitTestOverlayWidget(e,t){if(To.isChildOfOverlayWidgets(t.targetPath)){const i=e.findAttribute(t.target,"widgetId");return i?t.fulfillOverlayWidget(i):t.fulfillUnknown()}return null}static _hitTestViewCursor(e,t){if(t.target){const i=e.lastRenderData.lastViewCursorsRenderData;for(const n of i)if(t.target===n.domNode)return t.fulfillContentText(n.position,null,{mightBeForeignElement:!1,injectedText:null})}if(t.isInContentArea){const i=e.lastRenderData.lastViewCursorsRenderData,n=t.mouseContentHorizontalOffset,o=t.mouseVerticalOffset;for(const r of i){if(n<r.contentLeft||n>r.contentLeft+r.width)continue;const a=e.getVerticalOffsetForLineNumber(r.position.lineNumber);if(a<=o&&o<=a+r.height)return t.fulfillContentText(r.position,null,{mightBeForeignElement:!1,injectedText:null})}}return null}static _hitTestViewZone(e,t){const i=e.getZoneAtCoord(t.mouseVerticalOffset);if(i){const n=t.isInContentArea?8:5;return t.fulfillViewZone(n,i.position,i)}return null}static _hitTestTextArea(e,t){return To.isTextArea(t.targetPath)?e.lastRenderData.lastTextareaPosition?t.fulfillContentText(e.lastRenderData.lastTextareaPosition,null,{mightBeForeignElement:!1,injectedText:null}):t.fulfillTextarea():null}static _hitTestMargin(e,t){if(t.isInMarginArea){const i=e.getFullLineRangeAtCoord(t.mouseVerticalOffset),n=i.range.getStartPosition();let o=Math.abs(t.relativePos.x);const r={isAfterLines:i.isAfterLines,glyphMarginLeft:e.layoutInfo.glyphMarginLeft,glyphMarginWidth:e.layoutInfo.glyphMarginWidth,lineNumbersWidth:e.layoutInfo.lineNumbersWidth,offsetX:o};return o-=e.layoutInfo.glyphMarginLeft,o<=e.layoutInfo.glyphMarginWidth?t.fulfillMargin(2,n,i.range,r):(o-=e.layoutInfo.glyphMarginWidth,o<=e.layoutInfo.lineNumbersWidth?t.fulfillMargin(3,n,i.range,r):(o-=e.layoutInfo.lineNumbersWidth,t.fulfillMargin(4,n,i.range,r)))}return null}static _hitTestViewLines(e,t,i){if(!To.isChildOfViewLines(t.targetPath))return null;if(e.isInTopPadding(t.mouseVerticalOffset))return t.fulfillContentEmpty(new H(1,1),M3);if(e.isAfterLines(t.mouseVerticalOffset)||e.isInBottomPadding(t.mouseVerticalOffset)){const o=e.viewModel.getLineCount(),r=e.viewModel.getLineMaxColumn(o);return t.fulfillContentEmpty(new H(o,r),M3)}if(i){if(To.isStrictChildOfViewLines(t.targetPath)){const o=e.getLineNumberAtVerticalOffset(t.mouseVerticalOffset);if(e.viewModel.getLineLength(o)===0){const a=e.getLineWidth(o),l=iI(t.mouseContentHorizontalOffset-a);return t.fulfillContentEmpty(new H(o,1),l)}const r=e.getLineWidth(o);if(t.mouseContentHorizontalOffset>=r){const a=iI(t.mouseContentHorizontalOffset-r),l=new H(o,e.viewModel.getLineMaxColumn(o));return t.fulfillContentEmpty(l,a)}}return t.fulfillUnknown()}const n=$n._doHitTest(e,t);return n.type===1?$n.createMouseTargetFromHitTestPosition(e,t,n.spanNode,n.position,n.injectedText):this._createMouseTarget(e,t.withTarget(n.hitTarget),!0)}static _hitTestMinimap(e,t){if(To.isChildOfMinimap(t.targetPath)){const i=e.getLineNumberAtVerticalOffset(t.mouseVerticalOffset),n=e.viewModel.getLineMaxColumn(i);return t.fulfillScrollbar(new H(i,n))}return null}static _hitTestScrollbarSlider(e,t){if(To.isChildOfScrollableElement(t.targetPath)&&t.target&&t.target.nodeType===1){const i=t.target.className;if(i&&/\b(slider|scrollbar)\b/.test(i)){const n=e.getLineNumberAtVerticalOffset(t.mouseVerticalOffset),o=e.viewModel.getLineMaxColumn(n);return t.fulfillScrollbar(new H(n,o))}}return null}static _hitTestScrollbar(e,t){if(To.isChildOfScrollableElement(t.targetPath)){const i=e.getLineNumberAtVerticalOffset(t.mouseVerticalOffset),n=e.viewModel.getLineMaxColumn(i);return t.fulfillScrollbar(new H(i,n))}return null}getMouseColumn(e){const t=this._context.configuration.options,i=t.get(143),n=this._context.viewLayout.getCurrentScrollLeft()+e.x-i.contentLeft;return $n._getMouseColumn(n,t.get(50).typicalHalfwidthCharacterWidth)}static _getMouseColumn(e,t){return e<0?1:Math.round(e/t)+1}static createMouseTargetFromHitTestPosition(e,t,i,n,o){const r=n.lineNumber,a=n.column,l=e.getLineWidth(r);if(t.mouseContentHorizontalOffset>l){const v=iI(t.mouseContentHorizontalOffset-l);return t.fulfillContentEmpty(n,v)}const d=e.visibleRangeForPosition(r,a);if(!d)return t.fulfillUnknown(n);const c=d.left;if(Math.abs(t.mouseContentHorizontalOffset-c)<1)return t.fulfillContentText(n,null,{mightBeForeignElement:!!o,injectedText:o});const u=[];if(u.push({offset:d.left,column:a}),a>1){const v=e.visibleRangeForPosition(r,a-1);v&&u.push({offset:v.left,column:a-1})}const h=e.viewModel.getLineMaxColumn(r);if(a<h){const v=e.visibleRangeForPosition(r,a+1);v&&u.push({offset:v.left,column:a+1})}u.sort((v,b)=>v.offset-b.offset);const g=t.pos.toClientCoordinates(Xe(e.viewDomNode)),f=i.getBoundingClientRect(),m=f.left<=g.clientX&&g.clientX<=f.right;let _=null;for(let v=1;v<u.length;v++){const b=u[v-1],C=u[v];if(b.offset<=t.mouseContentHorizontalOffset&&t.mouseContentHorizontalOffset<=C.offset){_=new D(r,b.column,r,C.column);const w=Math.abs(b.offset-t.mouseContentHorizontalOffset),S=Math.abs(C.offset-t.mouseContentHorizontalOffset);n=w<S?new H(r,b.column):new H(r,C.column);break}}return t.fulfillContentText(n,_,{mightBeForeignElement:!m||!!o,injectedText:o})}static _doHitTestWithCaretRangeFromPoint(e,t){const i=e.getLineNumberAtVerticalOffset(t.mouseVerticalOffset),n=e.getVerticalOffsetForLineNumber(i),o=n+e.lineHeight;if(!(i===e.viewModel.getLineCount()&&t.mouseVerticalOffset>o)){const a=Math.floor((n+o)/2);let l=t.pos.y+(a-t.mouseVerticalOffset);l<=t.editorPos.y&&(l=t.editorPos.y+1),l>=t.editorPos.y+t.editorPos.height&&(l=t.editorPos.y+t.editorPos.height-1);const d=new Sx(t.pos.x,l),c=this._actualDoHitTestWithCaretRangeFromPoint(e,d.toClientCoordinates(Xe(e.viewDomNode)));if(c.type===1)return c}return this._actualDoHitTestWithCaretRangeFromPoint(e,t.pos.toClientCoordinates(Xe(e.viewDomNode)))}static _actualDoHitTestWithCaretRangeFromPoint(e,t){const i=Tg(e.viewDomNode);let n;if(i?typeof i.caretRangeFromPoint>"u"?n=$oe(i,t.clientX,t.clientY):n=i.caretRangeFromPoint(t.clientX,t.clientY):n=e.viewDomNode.ownerDocument.caretRangeFromPoint(t.clientX,t.clientY),!n||!n.startContainer)return new Sc;const o=n.startContainer;if(o.nodeType===o.TEXT_NODE){const r=o.parentNode,a=r?r.parentNode:null,l=a?a.parentNode:null;return(l&&l.nodeType===l.ELEMENT_NODE?l.className:null)===bl.CLASS_NAME?jh.createFromDOMInfo(e,r,n.startOffset):new Sc(o.parentNode)}else if(o.nodeType===o.ELEMENT_NODE){const r=o.parentNode,a=r?r.parentNode:null;return(a&&a.nodeType===a.ELEMENT_NODE?a.className:null)===bl.CLASS_NAME?jh.createFromDOMInfo(e,o,o.textContent.length):new Sc(o)}return new Sc}static _doHitTestWithCaretPositionFromPoint(e,t){const i=e.viewDomNode.ownerDocument.caretPositionFromPoint(t.clientX,t.clientY);if(i.offsetNode.nodeType===i.offsetNode.TEXT_NODE){const n=i.offsetNode.parentNode,o=n?n.parentNode:null,r=o?o.parentNode:null;return(r&&r.nodeType===r.ELEMENT_NODE?r.className:null)===bl.CLASS_NAME?jh.createFromDOMInfo(e,i.offsetNode.parentNode,i.offset):new Sc(i.offsetNode.parentNode)}if(i.offsetNode.nodeType===i.offsetNode.ELEMENT_NODE){const n=i.offsetNode.parentNode,o=n&&n.nodeType===n.ELEMENT_NODE?n.className:null,r=n?n.parentNode:null,a=r&&r.nodeType===r.ELEMENT_NODE?r.className:null;if(o===bl.CLASS_NAME){const l=i.offsetNode.childNodes[Math.min(i.offset,i.offsetNode.childNodes.length-1)];if(l)return jh.createFromDOMInfo(e,l,0)}else if(a===bl.CLASS_NAME)return jh.createFromDOMInfo(e,i.offsetNode,0)}return new Sc(i.offsetNode)}static _snapToSoftTabBoundary(e,t){const i=t.getLineContent(e.lineNumber),{tabSize:n}=t.model.getOptions(),o=$0.atomicPosition(i,e.column-1,n,2);return o!==-1?new H(e.lineNumber,o+1):e}static _doHitTest(e,t){let i=new Sc;if(typeof e.viewDomNode.ownerDocument.caretRangeFromPoint=="function"?i=this._doHitTestWithCaretRangeFromPoint(e,t):e.viewDomNode.ownerDocument.caretPositionFromPoint&&(i=this._doHitTestWithCaretPositionFromPoint(e,t.pos.toClientCoordinates(Xe(e.viewDomNode)))),i.type===1){const n=e.viewModel.getInjectedTextAt(i.position),o=e.viewModel.normalizePosition(i.position,2);(n||!o.equals(i.position))&&(i=new vH(o,i.spanNode,n))}return i}}function $oe(s,e,t){const i=document.createRange();let n=s.elementFromPoint(e,t);if(n!==null){for(;n&&n.firstChild&&n.firstChild.nodeType!==n.firstChild.TEXT_NODE&&n.lastChild&&n.lastChild.firstChild;)n=n.lastChild;const o=n.getBoundingClientRect(),r=Xe(n),a=r.getComputedStyle(n,null).getPropertyValue("font-style"),l=r.getComputedStyle(n,null).getPropertyValue("font-variant"),d=r.getComputedStyle(n,null).getPropertyValue("font-weight"),c=r.getComputedStyle(n,null).getPropertyValue("font-size"),u=r.getComputedStyle(n,null).getPropertyValue("line-height"),h=r.getComputedStyle(n,null).getPropertyValue("font-family"),g=`${a} ${l} ${d} ${c}/${u} ${h}`,f=n.innerText;let m=o.left,_=0,v;if(e>o.left+o.width)_=f.length;else{const b=ig.getInstance();for(let C=0;C<f.length+1;C++){if(v=b.getCharWidth(f.charAt(C),g)/2,m+=v,e<m){_=C;break}m+=v}}i.setStart(n.firstChild,_),i.setEnd(n.firstChild,_)}return i}class ig{static getInstance(){return ig._INSTANCE||(ig._INSTANCE=new ig),ig._INSTANCE}constructor(){this._cache={},this._canvas=document.createElement("canvas")}getCharWidth(e,t){const i=e+t;if(this._cache[i])return this._cache[i];const n=this._canvas.getContext("2d");n.font=t;const r=n.measureText(e).width;return this._cache[i]=r,r}}ig._INSTANCE=null;let ta=class extends j{onclick(e,t){this._register(Y(e,he.CLICK,i=>t(new zr(Xe(e),i))))}onmousedown(e,t){this._register(Y(e,he.MOUSE_DOWN,i=>t(new zr(Xe(e),i))))}onmouseover(e,t){this._register(Y(e,he.MOUSE_OVER,i=>t(new zr(Xe(e),i))))}onmouseleave(e,t){this._register(Y(e,he.MOUSE_LEAVE,i=>t(new zr(Xe(e),i))))}onkeydown(e,t){this._register(Y(e,he.KEY_DOWN,i=>t(new ri(i))))}onkeyup(e,t){this._register(Y(e,he.KEY_UP,i=>t(new ri(i))))}oninput(e,t){this._register(Y(e,he.INPUT,t))}onblur(e,t){this._register(Y(e,he.BLUR,t))}onfocus(e,t){this._register(Y(e,he.FOCUS,t))}ignoreGesture(e){return Xt.ignoreTarget(e)}};const wm=11;class joe extends ta{constructor(e){super(),this._onActivate=e.onActivate,this.bgDomNode=document.createElement("div"),this.bgDomNode.className="arrow-background",this.bgDomNode.style.position="absolute",this.bgDomNode.style.width=e.bgWidth+"px",this.bgDomNode.style.height=e.bgHeight+"px",typeof e.top<"u"&&(this.bgDomNode.style.top="0px"),typeof e.left<"u"&&(this.bgDomNode.style.left="0px"),typeof e.bottom<"u"&&(this.bgDomNode.style.bottom="0px"),typeof e.right<"u"&&(this.bgDomNode.style.right="0px"),this.domNode=document.createElement("div"),this.domNode.className=e.className,this.domNode.classList.add(...Oe.asClassNameArray(e.icon)),this.domNode.style.position="absolute",this.domNode.style.width=wm+"px",this.domNode.style.height=wm+"px",typeof e.top<"u"&&(this.domNode.style.top=e.top+"px"),typeof e.left<"u"&&(this.domNode.style.left=e.left+"px"),typeof e.bottom<"u"&&(this.domNode.style.bottom=e.bottom+"px"),typeof e.right<"u"&&(this.domNode.style.right=e.right+"px"),this._pointerMoveMonitor=this._register(new r_),this._register(Pi(this.bgDomNode,he.POINTER_DOWN,t=>this._arrowPointerDown(t))),this._register(Pi(this.domNode,he.POINTER_DOWN,t=>this._arrowPointerDown(t))),this._pointerdownRepeatTimer=this._register(new eP),this._pointerdownScheduleRepeatTimer=this._register(new ea)}_arrowPointerDown(e){if(!e.target||!(e.target instanceof Element))return;const t=()=>{this._pointerdownRepeatTimer.cancelAndSet(()=>this._onActivate(),1e3/24,Xe(e))};this._onActivate(),this._pointerdownRepeatTimer.cancel(),this._pointerdownScheduleRepeatTimer.cancelAndSet(t,200),this._pointerMoveMonitor.startMonitoring(e.target,e.pointerId,e.buttons,i=>{},()=>{this._pointerdownRepeatTimer.cancel(),this._pointerdownScheduleRepeatTimer.cancel()}),e.preventDefault()}}class Koe extends j{constructor(e,t,i){super(),this._visibility=e,this._visibleClassName=t,this._invisibleClassName=i,this._domNode=null,this._isVisible=!1,this._isNeeded=!1,this._rawShouldBeVisible=!1,this._shouldBeVisible=!1,this._revealTimer=this._register(new ea)}setVisibility(e){this._visibility!==e&&(this._visibility=e,this._updateShouldBeVisible())}setShouldBeVisible(e){this._rawShouldBeVisible=e,this._updateShouldBeVisible()}_applyVisibilitySetting(){return this._visibility===2?!1:this._visibility===3?!0:this._rawShouldBeVisible}_updateShouldBeVisible(){const e=this._applyVisibilitySetting();this._shouldBeVisible!==e&&(this._shouldBeVisible=e,this.ensureVisibility())}setIsNeeded(e){this._isNeeded!==e&&(this._isNeeded=e,this.ensureVisibility())}setDomNode(e){this._domNode=e,this._domNode.setClassName(this._invisibleClassName),this.setShouldBeVisible(!1)}ensureVisibility(){if(!this._isNeeded){this._hide(!1);return}this._shouldBeVisible?this._reveal():this._hide(!0)}_reveal(){this._isVisible||(this._isVisible=!0,this._revealTimer.setIfNotSet(()=>{var e;(e=this._domNode)===null||e===void 0||e.setClassName(this._visibleClassName)},0))}_hide(e){var t;this._revealTimer.cancel(),this._isVisible&&(this._isVisible=!1,(t=this._domNode)===null||t===void 0||t.setClassName(this._invisibleClassName+(e?" fade":"")))}}const qoe=140;class bH extends ta{constructor(e){super(),this._lazyRender=e.lazyRender,this._host=e.host,this._scrollable=e.scrollable,this._scrollByPage=e.scrollByPage,this._scrollbarState=e.scrollbarState,this._visibilityController=this._register(new Koe(e.visibility,"visible scrollbar "+e.extraScrollbarClassName,"invisible scrollbar "+e.extraScrollbarClassName)),this._visibilityController.setIsNeeded(this._scrollbarState.isNeeded()),this._pointerMoveMonitor=this._register(new r_),this._shouldRender=!0,this.domNode=Mt(document.createElement("div")),this.domNode.setAttribute("role","presentation"),this.domNode.setAttribute("aria-hidden","true"),this._visibilityController.setDomNode(this.domNode),this.domNode.setPosition("absolute"),this._register(Y(this.domNode.domNode,he.POINTER_DOWN,t=>this._domNodePointerDown(t)))}_createArrow(e){const t=this._register(new joe(e));this.domNode.domNode.appendChild(t.bgDomNode),this.domNode.domNode.appendChild(t.domNode)}_createSlider(e,t,i,n){this.slider=Mt(document.createElement("div")),this.slider.setClassName("slider"),this.slider.setPosition("absolute"),this.slider.setTop(e),this.slider.setLeft(t),typeof i=="number"&&this.slider.setWidth(i),typeof n=="number"&&this.slider.setHeight(n),this.slider.setLayerHinting(!0),this.slider.setContain("strict"),this.domNode.domNode.appendChild(this.slider.domNode),this._register(Y(this.slider.domNode,he.POINTER_DOWN,o=>{o.button===0&&(o.preventDefault(),this._sliderPointerDown(o))})),this.onclick(this.slider.domNode,o=>{o.leftButton&&o.stopPropagation()})}_onElementSize(e){return this._scrollbarState.setVisibleSize(e)&&(this._visibilityController.setIsNeeded(this._scrollbarState.isNeeded()),this._shouldRender=!0,this._lazyRender||this.render()),this._shouldRender}_onElementScrollSize(e){return this._scrollbarState.setScrollSize(e)&&(this._visibilityController.setIsNeeded(this._scrollbarState.isNeeded()),this._shouldRender=!0,this._lazyRender||this.render()),this._shouldRender}_onElementScrollPosition(e){return this._scrollbarState.setScrollPosition(e)&&(this._visibilityController.setIsNeeded(this._scrollbarState.isNeeded()),this._shouldRender=!0,this._lazyRender||this.render()),this._shouldRender}beginReveal(){this._visibilityController.setShouldBeVisible(!0)}beginHide(){this._visibilityController.setShouldBeVisible(!1)}render(){this._shouldRender&&(this._shouldRender=!1,this._renderDomNode(this._scrollbarState.getRectangleLargeSize(),this._scrollbarState.getRectangleSmallSize()),this._updateSlider(this._scrollbarState.getSliderSize(),this._scrollbarState.getArrowSize()+this._scrollbarState.getSliderPosition()))}_domNodePointerDown(e){e.target===this.domNode.domNode&&this._onPointerDown(e)}delegatePointerDown(e){const t=this.domNode.domNode.getClientRects()[0].top,i=t+this._scrollbarState.getSliderPosition(),n=t+this._scrollbarState.getSliderPosition()+this._scrollbarState.getSliderSize(),o=this._sliderPointerPosition(e);i<=o&&o<=n?e.button===0&&(e.preventDefault(),this._sliderPointerDown(e)):this._onPointerDown(e)}_onPointerDown(e){let t,i;if(e.target===this.domNode.domNode&&typeof e.offsetX=="number"&&typeof e.offsetY=="number")t=e.offsetX,i=e.offsetY;else{const o=ln(this.domNode.domNode);t=e.pageX-o.left,i=e.pageY-o.top}const n=this._pointerDownRelativePosition(t,i);this._setDesiredScrollPositionNow(this._scrollByPage?this._scrollbarState.getDesiredScrollPositionFromOffsetPaged(n):this._scrollbarState.getDesiredScrollPositionFromOffset(n)),e.button===0&&(e.preventDefault(),this._sliderPointerDown(e))}_sliderPointerDown(e){if(!e.target||!(e.target instanceof Element))return;const t=this._sliderPointerPosition(e),i=this._sliderOrthogonalPointerPosition(e),n=this._scrollbarState.clone();this.slider.toggleClassName("active",!0),this._pointerMoveMonitor.startMonitoring(e.target,e.pointerId,e.buttons,o=>{const r=this._sliderOrthogonalPointerPosition(o),a=Math.abs(r-i);if(es&&a>qoe){this._setDesiredScrollPositionNow(n.getScrollPosition());return}const d=this._sliderPointerPosition(o)-t;this._setDesiredScrollPositionNow(n.getDesiredScrollPositionFromDelta(d))},()=>{this.slider.toggleClassName("active",!1),this._host.onDragEnd()}),this._host.onDragStart()}_setDesiredScrollPositionNow(e){const t={};this.writeScrollPosition(t,e),this._scrollable.setScrollPositionNow(t)}updateScrollbarSize(e){this._updateScrollbarSize(e),this._scrollbarState.setScrollbarSize(e),this._shouldRender=!0,this._lazyRender||this.render()}isNeeded(){return this._scrollbarState.isNeeded()}}const Goe=20;class Sm{constructor(e,t,i,n,o,r){this._scrollbarSize=Math.round(t),this._oppositeScrollbarSize=Math.round(i),this._arrowSize=Math.round(e),this._visibleSize=n,this._scrollSize=o,this._scrollPosition=r,this._computedAvailableSize=0,this._computedIsNeeded=!1,this._computedSliderSize=0,this._computedSliderRatio=0,this._computedSliderPosition=0,this._refreshComputedValues()}clone(){return new Sm(this._arrowSize,this._scrollbarSize,this._oppositeScrollbarSize,this._visibleSize,this._scrollSize,this._scrollPosition)}setVisibleSize(e){const t=Math.round(e);return this._visibleSize!==t?(this._visibleSize=t,this._refreshComputedValues(),!0):!1}setScrollSize(e){const t=Math.round(e);return this._scrollSize!==t?(this._scrollSize=t,this._refreshComputedValues(),!0):!1}setScrollPosition(e){const t=Math.round(e);return this._scrollPosition!==t?(this._scrollPosition=t,this._refreshComputedValues(),!0):!1}setScrollbarSize(e){this._scrollbarSize=Math.round(e)}setOppositeScrollbarSize(e){this._oppositeScrollbarSize=Math.round(e)}static _computeValues(e,t,i,n,o){const r=Math.max(0,i-e),a=Math.max(0,r-2*t),l=n>0&&n>i;if(!l)return{computedAvailableSize:Math.round(r),computedIsNeeded:l,computedSliderSize:Math.round(a),computedSliderRatio:0,computedSliderPosition:0};const d=Math.round(Math.max(Goe,Math.floor(i*a/n))),c=(a-d)/(n-i),u=o*c;return{computedAvailableSize:Math.round(r),computedIsNeeded:l,computedSliderSize:Math.round(d),computedSliderRatio:c,computedSliderPosition:Math.round(u)}}_refreshComputedValues(){const e=Sm._computeValues(this._oppositeScrollbarSize,this._arrowSize,this._visibleSize,this._scrollSize,this._scrollPosition);this._computedAvailableSize=e.computedAvailableSize,this._computedIsNeeded=e.computedIsNeeded,this._computedSliderSize=e.computedSliderSize,this._computedSliderRatio=e.computedSliderRatio,this._computedSliderPosition=e.computedSliderPosition}getArrowSize(){return this._arrowSize}getScrollPosition(){return this._scrollPosition}getRectangleLargeSize(){return this._computedAvailableSize}getRectangleSmallSize(){return this._scrollbarSize}isNeeded(){return this._computedIsNeeded}getSliderSize(){return this._computedSliderSize}getSliderPosition(){return this._computedSliderPosition}getDesiredScrollPositionFromOffset(e){if(!this._computedIsNeeded)return 0;const t=e-this._arrowSize-this._computedSliderSize/2;return Math.round(t/this._computedSliderRatio)}getDesiredScrollPositionFromOffsetPaged(e){if(!this._computedIsNeeded)return 0;const t=e-this._arrowSize;let i=this._scrollPosition;return t<this._computedSliderPosition?i-=this._visibleSize:i+=this._visibleSize,i}getDesiredScrollPositionFromDelta(e){if(!this._computedIsNeeded)return 0;const t=this._computedSliderPosition+e;return Math.round(t/this._computedSliderRatio)}}class Zoe extends bH{constructor(e,t,i){const n=e.getScrollDimensions(),o=e.getCurrentScrollPosition();if(super({lazyRender:t.lazyRender,host:i,scrollbarState:new Sm(t.horizontalHasArrows?t.arrowSize:0,t.horizontal===2?0:t.horizontalScrollbarSize,t.vertical===2?0:t.verticalScrollbarSize,n.width,n.scrollWidth,o.scrollLeft),visibility:t.horizontal,extraScrollbarClassName:"horizontal",scrollable:e,scrollByPage:t.scrollByPage}),t.horizontalHasArrows){const r=(t.arrowSize-wm)/2,a=(t.horizontalScrollbarSize-wm)/2;this._createArrow({className:"scra",icon:le.scrollbarButtonLeft,top:a,left:r,bottom:void 0,right:void 0,bgWidth:t.arrowSize,bgHeight:t.horizontalScrollbarSize,onActivate:()=>this._host.onMouseWheel(new Ng(null,1,0))}),this._createArrow({className:"scra",icon:le.scrollbarButtonRight,top:a,left:void 0,bottom:void 0,right:r,bgWidth:t.arrowSize,bgHeight:t.horizontalScrollbarSize,onActivate:()=>this._host.onMouseWheel(new Ng(null,-1,0))})}this._createSlider(Math.floor((t.horizontalScrollbarSize-t.horizontalSliderSize)/2),0,void 0,t.horizontalSliderSize)}_updateSlider(e,t){this.slider.setWidth(e),this.slider.setLeft(t)}_renderDomNode(e,t){this.domNode.setWidth(e),this.domNode.setHeight(t),this.domNode.setLeft(0),this.domNode.setBottom(0)}onDidScroll(e){return this._shouldRender=this._onElementScrollSize(e.scrollWidth)||this._shouldRender,this._shouldRender=this._onElementScrollPosition(e.scrollLeft)||this._shouldRender,this._shouldRender=this._onElementSize(e.width)||this._shouldRender,this._shouldRender}_pointerDownRelativePosition(e,t){return e}_sliderPointerPosition(e){return e.pageX}_sliderOrthogonalPointerPosition(e){return e.pageY}_updateScrollbarSize(e){this.slider.setHeight(e)}writeScrollPosition(e,t){e.scrollLeft=t}updateOptions(e){this.updateScrollbarSize(e.horizontal===2?0:e.horizontalScrollbarSize),this._scrollbarState.setOppositeScrollbarSize(e.vertical===2?0:e.verticalScrollbarSize),this._visibilityController.setVisibility(e.horizontal),this._scrollByPage=e.scrollByPage}}class Yoe extends bH{constructor(e,t,i){const n=e.getScrollDimensions(),o=e.getCurrentScrollPosition();if(super({lazyRender:t.lazyRender,host:i,scrollbarState:new Sm(t.verticalHasArrows?t.arrowSize:0,t.vertical===2?0:t.verticalScrollbarSize,0,n.height,n.scrollHeight,o.scrollTop),visibility:t.vertical,extraScrollbarClassName:"vertical",scrollable:e,scrollByPage:t.scrollByPage}),t.verticalHasArrows){const r=(t.arrowSize-wm)/2,a=(t.verticalScrollbarSize-wm)/2;this._createArrow({className:"scra",icon:le.scrollbarButtonUp,top:r,left:a,bottom:void 0,right:void 0,bgWidth:t.verticalScrollbarSize,bgHeight:t.arrowSize,onActivate:()=>this._host.onMouseWheel(new Ng(null,0,1))}),this._createArrow({className:"scra",icon:le.scrollbarButtonDown,top:void 0,left:a,bottom:r,right:void 0,bgWidth:t.verticalScrollbarSize,bgHeight:t.arrowSize,onActivate:()=>this._host.onMouseWheel(new Ng(null,0,-1))})}this._createSlider(0,Math.floor((t.verticalScrollbarSize-t.verticalSliderSize)/2),t.verticalSliderSize,void 0)}_updateSlider(e,t){this.slider.setHeight(e),this.slider.setTop(t)}_renderDomNode(e,t){this.domNode.setWidth(t),this.domNode.setHeight(e),this.domNode.setRight(0),this.domNode.setTop(0)}onDidScroll(e){return this._shouldRender=this._onElementScrollSize(e.scrollHeight)||this._shouldRender,this._shouldRender=this._onElementScrollPosition(e.scrollTop)||this._shouldRender,this._shouldRender=this._onElementSize(e.height)||this._shouldRender,this._shouldRender}_pointerDownRelativePosition(e,t){return t}_sliderPointerPosition(e){return e.pageY}_sliderOrthogonalPointerPosition(e){return e.pageX}_updateScrollbarSize(e){this.slider.setWidth(e)}writeScrollPosition(e,t){e.scrollTop=t}updateOptions(e){this.updateScrollbarSize(e.vertical===2?0:e.verticalScrollbarSize),this._scrollbarState.setOppositeScrollbarSize(0),this._visibilityController.setVisibility(e.vertical),this._scrollByPage=e.scrollByPage}}class YS{constructor(e,t,i,n,o,r,a){this._forceIntegerValues=e,this._scrollStateBrand=void 0,this._forceIntegerValues&&(t=t|0,i=i|0,n=n|0,o=o|0,r=r|0,a=a|0),this.rawScrollLeft=n,this.rawScrollTop=a,t<0&&(t=0),n+t>i&&(n=i-t),n<0&&(n=0),o<0&&(o=0),a+o>r&&(a=r-o),a<0&&(a=0),this.width=t,this.scrollWidth=i,this.scrollLeft=n,this.height=o,this.scrollHeight=r,this.scrollTop=a}equals(e){return this.rawScrollLeft===e.rawScrollLeft&&this.rawScrollTop===e.rawScrollTop&&this.width===e.width&&this.scrollWidth===e.scrollWidth&&this.scrollLeft===e.scrollLeft&&this.height===e.height&&this.scrollHeight===e.scrollHeight&&this.scrollTop===e.scrollTop}withScrollDimensions(e,t){return new YS(this._forceIntegerValues,typeof e.width<"u"?e.width:this.width,typeof e.scrollWidth<"u"?e.scrollWidth:this.scrollWidth,t?this.rawScrollLeft:this.scrollLeft,typeof e.height<"u"?e.height:this.height,typeof e.scrollHeight<"u"?e.scrollHeight:this.scrollHeight,t?this.rawScrollTop:this.scrollTop)}withScrollPosition(e){return new YS(this._forceIntegerValues,this.width,this.scrollWidth,typeof e.scrollLeft<"u"?e.scrollLeft:this.rawScrollLeft,this.height,this.scrollHeight,typeof e.scrollTop<"u"?e.scrollTop:this.rawScrollTop)}createScrollEvent(e,t){const i=this.width!==e.width,n=this.scrollWidth!==e.scrollWidth,o=this.scrollLeft!==e.scrollLeft,r=this.height!==e.height,a=this.scrollHeight!==e.scrollHeight,l=this.scrollTop!==e.scrollTop;return{inSmoothScrolling:t,oldWidth:e.width,oldScrollWidth:e.scrollWidth,oldScrollLeft:e.scrollLeft,width:this.width,scrollWidth:this.scrollWidth,scrollLeft:this.scrollLeft,oldHeight:e.height,oldScrollHeight:e.scrollHeight,oldScrollTop:e.scrollTop,height:this.height,scrollHeight:this.scrollHeight,scrollTop:this.scrollTop,widthChanged:i,scrollWidthChanged:n,scrollLeftChanged:o,heightChanged:r,scrollHeightChanged:a,scrollTopChanged:l}}}class a_ extends j{constructor(e){super(),this._scrollableBrand=void 0,this._onScroll=this._register(new W),this.onScroll=this._onScroll.event,this._smoothScrollDuration=e.smoothScrollDuration,this._scheduleAtNextAnimationFrame=e.scheduleAtNextAnimationFrame,this._state=new YS(e.forceIntegerValues,0,0,0,0,0,0),this._smoothScrolling=null}dispose(){this._smoothScrolling&&(this._smoothScrolling.dispose(),this._smoothScrolling=null),super.dispose()}setSmoothScrollDuration(e){this._smoothScrollDuration=e}validateScrollPosition(e){return this._state.withScrollPosition(e)}getScrollDimensions(){return this._state}setScrollDimensions(e,t){var i;const n=this._state.withScrollDimensions(e,t);this._setState(n,!!this._smoothScrolling),(i=this._smoothScrolling)===null||i===void 0||i.acceptScrollDimensions(this._state)}getFutureScrollPosition(){return this._smoothScrolling?this._smoothScrolling.to:this._state}getCurrentScrollPosition(){return this._state}setScrollPositionNow(e){const t=this._state.withScrollPosition(e);this._smoothScrolling&&(this._smoothScrolling.dispose(),this._smoothScrolling=null),this._setState(t,!1)}setScrollPositionSmooth(e,t){if(this._smoothScrollDuration===0)return this.setScrollPositionNow(e);if(this._smoothScrolling){e={scrollLeft:typeof e.scrollLeft>"u"?this._smoothScrolling.to.scrollLeft:e.scrollLeft,scrollTop:typeof e.scrollTop>"u"?this._smoothScrolling.to.scrollTop:e.scrollTop};const i=this._state.withScrollPosition(e);if(this._smoothScrolling.to.scrollLeft===i.scrollLeft&&this._smoothScrolling.to.scrollTop===i.scrollTop)return;let n;t?n=new j0(this._smoothScrolling.from,i,this._smoothScrolling.startTime,this._smoothScrolling.duration):n=this._smoothScrolling.combine(this._state,i,this._smoothScrollDuration),this._smoothScrolling.dispose(),this._smoothScrolling=n}else{const i=this._state.withScrollPosition(e);this._smoothScrolling=j0.start(this._state,i,this._smoothScrollDuration)}this._smoothScrolling.animationFrameDisposable=this._scheduleAtNextAnimationFrame(()=>{this._smoothScrolling&&(this._smoothScrolling.animationFrameDisposable=null,this._performSmoothScrolling())})}hasPendingScrollAnimation(){return!!this._smoothScrolling}_performSmoothScrolling(){if(!this._smoothScrolling)return;const e=this._smoothScrolling.tick(),t=this._state.withScrollPosition(e);if(this._setState(t,!0),!!this._smoothScrolling){if(e.isDone){this._smoothScrolling.dispose(),this._smoothScrolling=null;return}this._smoothScrolling.animationFrameDisposable=this._scheduleAtNextAnimationFrame(()=>{this._smoothScrolling&&(this._smoothScrolling.animationFrameDisposable=null,this._performSmoothScrolling())})}}_setState(e,t){const i=this._state;i.equals(e)||(this._state=e,this._onScroll.fire(this._state.createScrollEvent(i,t)))}}class R3{constructor(e,t,i){this.scrollLeft=e,this.scrollTop=t,this.isDone=i}}function nI(s,e){const t=e-s;return function(i){return s+t*Joe(i)}}function Xoe(s,e,t){return function(i){return i<t?s(i/t):e((i-t)/(1-t))}}class j0{constructor(e,t,i,n){this.from=e,this.to=t,this.duration=n,this.startTime=i,this.animationFrameDisposable=null,this._initAnimations()}_initAnimations(){this.scrollLeft=this._initAnimation(this.from.scrollLeft,this.to.scrollLeft,this.to.width),this.scrollTop=this._initAnimation(this.from.scrollTop,this.to.scrollTop,this.to.height)}_initAnimation(e,t,i){if(Math.abs(e-t)>2.5*i){let o,r;return e<t?(o=e+.75*i,r=t-.75*i):(o=e-.75*i,r=t+.75*i),Xoe(nI(e,o),nI(r,t),.33)}return nI(e,t)}dispose(){this.animationFrameDisposable!==null&&(this.animationFrameDisposable.dispose(),this.animationFrameDisposable=null)}acceptScrollDimensions(e){this.to=e.withScrollPosition(this.to),this._initAnimations()}tick(){return this._tick(Date.now())}_tick(e){const t=(e-this.startTime)/this.duration;if(t<1){const i=this.scrollLeft(t),n=this.scrollTop(t);return new R3(i,n,!1)}return new R3(this.to.scrollLeft,this.to.scrollTop,!0)}combine(e,t,i){return j0.start(e,t,i)}static start(e,t,i){i=i+10;const n=Date.now()-10;return new j0(e,t,n,i)}}function Qoe(s){return Math.pow(s,3)}function Joe(s){return 1-Qoe(1-s)}const ere=500,A3=50;class tre{constructor(e,t,i){this.timestamp=e,this.deltaX=t,this.deltaY=i,this.score=0}}class XS{constructor(){this._capacity=5,this._memory=[],this._front=-1,this._rear=-1}isPhysicalMouseWheel(){if(this._front===-1&&this._rear===-1)return!1;let e=1,t=0,i=1,n=this._rear;do{const o=n===this._front?e:Math.pow(2,-i);if(e-=o,t+=this._memory[n].score*o,n===this._front)break;n=(this._capacity+n-1)%this._capacity,i++}while(!0);return t<=.5}acceptStandardWheelEvent(e){const t=Xe(e.browserEvent).devicePixelRatio/vJ();es||Ss?this.accept(Date.now(),e.deltaX/t,e.deltaY/t):this.accept(Date.now(),e.deltaX,e.deltaY)}accept(e,t,i){const n=new tre(e,t,i);n.score=this._computeScore(n),this._front===-1&&this._rear===-1?(this._memory[0]=n,this._front=0,this._rear=0):(this._rear=(this._rear+1)%this._capacity,this._rear===this._front&&(this._front=(this._front+1)%this._capacity),this._memory[this._rear]=n)}_computeScore(e){if(Math.abs(e.deltaX)>0&&Math.abs(e.deltaY)>0)return 1;let t=.5;return this._front===-1&&this._rear===-1||this._memory[this._rear],(!this._isAlmostInt(e.deltaX)||!this._isAlmostInt(e.deltaY))&&(t+=.25),Math.min(Math.max(t,0),1)}_isAlmostInt(e){return Math.abs(Math.round(e)-e)<.01}}XS.INSTANCE=new XS;class kP extends ta{get options(){return this._options}constructor(e,t,i){super(),this._onScroll=this._register(new W),this.onScroll=this._onScroll.event,this._onWillScroll=this._register(new W),e.style.overflow="hidden",this._options=ire(t),this._scrollable=i,this._register(this._scrollable.onScroll(o=>{this._onWillScroll.fire(o),this._onDidScroll(o),this._onScroll.fire(o)}));const n={onMouseWheel:o=>this._onMouseWheel(o),onDragStart:()=>this._onDragStart(),onDragEnd:()=>this._onDragEnd()};this._verticalScrollbar=this._register(new Yoe(this._scrollable,this._options,n)),this._horizontalScrollbar=this._register(new Zoe(this._scrollable,this._options,n)),this._domNode=document.createElement("div"),this._domNode.className="monaco-scrollable-element "+this._options.className,this._domNode.setAttribute("role","presentation"),this._domNode.style.position="relative",this._domNode.style.overflow="hidden",this._domNode.appendChild(e),this._domNode.appendChild(this._horizontalScrollbar.domNode.domNode),this._domNode.appendChild(this._verticalScrollbar.domNode.domNode),this._options.useShadows?(this._leftShadowDomNode=Mt(document.createElement("div")),this._leftShadowDomNode.setClassName("shadow"),this._domNode.appendChild(this._leftShadowDomNode.domNode),this._topShadowDomNode=Mt(document.createElement("div")),this._topShadowDomNode.setClassName("shadow"),this._domNode.appendChild(this._topShadowDomNode.domNode),this._topLeftShadowDomNode=Mt(document.createElement("div")),this._topLeftShadowDomNode.setClassName("shadow"),this._domNode.appendChild(this._topLeftShadowDomNode.domNode)):(this._leftShadowDomNode=null,this._topShadowDomNode=null,this._topLeftShadowDomNode=null),this._listenOnDomNode=this._options.listenOnDomNode||this._domNode,this._mouseWheelToDispose=[],this._setListeningToMouseWheel(this._options.handleMouseWheel),this.onmouseover(this._listenOnDomNode,o=>this._onMouseOver(o)),this.onmouseleave(this._listenOnDomNode,o=>this._onMouseLeave(o)),this._hideTimeout=this._register(new ea),this._isDragging=!1,this._mouseIsOver=!1,this._shouldRender=!0,this._revealOnScroll=!0}dispose(){this._mouseWheelToDispose=Bt(this._mouseWheelToDispose),super.dispose()}getDomNode(){return this._domNode}getOverviewRulerLayoutInfo(){return{parent:this._domNode,insertBefore:this._verticalScrollbar.domNode.domNode}}delegateVerticalScrollbarPointerDown(e){this._verticalScrollbar.delegatePointerDown(e)}getScrollDimensions(){return this._scrollable.getScrollDimensions()}setScrollDimensions(e){this._scrollable.setScrollDimensions(e,!1)}updateClassName(e){this._options.className=e,bt&&(this._options.className+=" mac"),this._domNode.className="monaco-scrollable-element "+this._options.className}updateOptions(e){typeof e.handleMouseWheel<"u"&&(this._options.handleMouseWheel=e.handleMouseWheel,this._setListeningToMouseWheel(this._options.handleMouseWheel)),typeof e.mouseWheelScrollSensitivity<"u"&&(this._options.mouseWheelScrollSensitivity=e.mouseWheelScrollSensitivity),typeof e.fastScrollSensitivity<"u"&&(this._options.fastScrollSensitivity=e.fastScrollSensitivity),typeof e.scrollPredominantAxis<"u"&&(this._options.scrollPredominantAxis=e.scrollPredominantAxis),typeof e.horizontal<"u"&&(this._options.horizontal=e.horizontal),typeof e.vertical<"u"&&(this._options.vertical=e.vertical),typeof e.horizontalScrollbarSize<"u"&&(this._options.horizontalScrollbarSize=e.horizontalScrollbarSize),typeof e.verticalScrollbarSize<"u"&&(this._options.verticalScrollbarSize=e.verticalScrollbarSize),typeof e.scrollByPage<"u"&&(this._options.scrollByPage=e.scrollByPage),this._horizontalScrollbar.updateOptions(this._options),this._verticalScrollbar.updateOptions(this._options),this._options.lazyRender||this._render()}delegateScrollFromMouseWheelEvent(e){this._onMouseWheel(new Ng(e))}_setListeningToMouseWheel(e){if(this._mouseWheelToDispose.length>0!==e&&(this._mouseWheelToDispose=Bt(this._mouseWheelToDispose),e)){const i=n=>{this._onMouseWheel(new Ng(n))};this._mouseWheelToDispose.push(Y(this._listenOnDomNode,he.MOUSE_WHEEL,i,{passive:!1}))}}_onMouseWheel(e){var t;if(!((t=e.browserEvent)===null||t===void 0)&&t.defaultPrevented)return;const i=XS.INSTANCE;i.acceptStandardWheelEvent(e);let n=!1;if(e.deltaY||e.deltaX){let r=e.deltaY*this._options.mouseWheelScrollSensitivity,a=e.deltaX*this._options.mouseWheelScrollSensitivity;this._options.scrollPredominantAxis&&(this._options.scrollYToX&&a+r===0?a=r=0:Math.abs(r)>=Math.abs(a)?a=0:r=0),this._options.flipAxes&&([r,a]=[a,r]);const l=!bt&&e.browserEvent&&e.browserEvent.shiftKey;(this._options.scrollYToX||l)&&!a&&(a=r,r=0),e.browserEvent&&e.browserEvent.altKey&&(a=a*this._options.fastScrollSensitivity,r=r*this._options.fastScrollSensitivity);const d=this._scrollable.getFutureScrollPosition();let c={};if(r){const u=A3*r,h=d.scrollTop-(u<0?Math.floor(u):Math.ceil(u));this._verticalScrollbar.writeScrollPosition(c,h)}if(a){const u=A3*a,h=d.scrollLeft-(u<0?Math.floor(u):Math.ceil(u));this._horizontalScrollbar.writeScrollPosition(c,h)}c=this._scrollable.validateScrollPosition(c),(d.scrollLeft!==c.scrollLeft||d.scrollTop!==c.scrollTop)&&(this._options.mouseWheelSmoothScroll&&i.isPhysicalMouseWheel()?this._scrollable.setScrollPositionSmooth(c):this._scrollable.setScrollPositionNow(c),n=!0)}let o=n;!o&&this._options.alwaysConsumeMouseWheel&&(o=!0),!o&&this._options.consumeMouseWheelIfScrollbarIsNeeded&&(this._verticalScrollbar.isNeeded()||this._horizontalScrollbar.isNeeded())&&(o=!0),o&&(e.preventDefault(),e.stopPropagation())}_onDidScroll(e){this._shouldRender=this._horizontalScrollbar.onDidScroll(e)||this._shouldRender,this._shouldRender=this._verticalScrollbar.onDidScroll(e)||this._shouldRender,this._options.useShadows&&(this._shouldRender=!0),this._revealOnScroll&&this._reveal(),this._options.lazyRender||this._render()}renderNow(){if(!this._options.lazyRender)throw new Error("Please use `lazyRender` together with `renderNow`!");this._render()}_render(){if(this._shouldRender&&(this._shouldRender=!1,this._horizontalScrollbar.render(),this._verticalScrollbar.render(),this._options.useShadows)){const e=this._scrollable.getCurrentScrollPosition(),t=e.scrollTop>0,i=e.scrollLeft>0,n=i?" left":"",o=t?" top":"",r=i||t?" top-left-corner":"";this._leftShadowDomNode.setClassName(`shadow${n}`),this._topShadowDomNode.setClassName(`shadow${o}`),this._topLeftShadowDomNode.setClassName(`shadow${r}${o}${n}`)}}_onDragStart(){this._isDragging=!0,this._reveal()}_onDragEnd(){this._isDragging=!1,this._hide()}_onMouseLeave(e){this._mouseIsOver=!1,this._hide()}_onMouseOver(e){this._mouseIsOver=!0,this._reveal()}_reveal(){this._verticalScrollbar.beginReveal(),this._horizontalScrollbar.beginReveal(),this._scheduleHide()}_hide(){!this._mouseIsOver&&!this._isDragging&&(this._verticalScrollbar.beginHide(),this._horizontalScrollbar.beginHide())}_scheduleHide(){!this._mouseIsOver&&!this._isDragging&&this._hideTimeout.cancelAndSet(()=>this._hide(),ere)}}class CH extends kP{constructor(e,t){t=t||{},t.mouseWheelSmoothScroll=!1;const i=new a_({forceIntegerValues:!0,smoothScrollDuration:0,scheduleAtNextAnimationFrame:n=>yo(Xe(e),n)});super(e,t,i),this._register(i)}setScrollPosition(e){this._scrollable.setScrollPositionNow(e)}}class Lx extends kP{constructor(e,t,i){super(e,t,i)}setScrollPosition(e){e.reuseAnimation?this._scrollable.setScrollPositionSmooth(e,e.reuseAnimation):this._scrollable.setScrollPositionNow(e)}getScrollPosition(){return this._scrollable.getCurrentScrollPosition()}}class hC extends kP{constructor(e,t){t=t||{},t.mouseWheelSmoothScroll=!1;const i=new a_({forceIntegerValues:!1,smoothScrollDuration:0,scheduleAtNextAnimationFrame:n=>yo(Xe(e),n)});super(e,t,i),this._register(i),this._element=e,this._register(this.onScroll(n=>{n.scrollTopChanged&&(this._element.scrollTop=n.scrollTop),n.scrollLeftChanged&&(this._element.scrollLeft=n.scrollLeft)})),this.scanDomNode()}setScrollPosition(e){this._scrollable.setScrollPositionNow(e)}getScrollPosition(){return this._scrollable.getCurrentScrollPosition()}scanDomNode(){this.setScrollDimensions({width:this._element.clientWidth,scrollWidth:this._element.scrollWidth,height:this._element.clientHeight,scrollHeight:this._element.scrollHeight}),this.setScrollPosition({scrollLeft:this._element.scrollLeft,scrollTop:this._element.scrollTop})}}function ire(s){const e={lazyRender:typeof s.lazyRender<"u"?s.lazyRender:!1,className:typeof s.className<"u"?s.className:"",useShadows:typeof s.useShadows<"u"?s.useShadows:!0,handleMouseWheel:typeof s.handleMouseWheel<"u"?s.handleMouseWheel:!0,flipAxes:typeof s.flipAxes<"u"?s.flipAxes:!1,consumeMouseWheelIfScrollbarIsNeeded:typeof s.consumeMouseWheelIfScrollbarIsNeeded<"u"?s.consumeMouseWheelIfScrollbarIsNeeded:!1,alwaysConsumeMouseWheel:typeof s.alwaysConsumeMouseWheel<"u"?s.alwaysConsumeMouseWheel:!1,scrollYToX:typeof s.scrollYToX<"u"?s.scrollYToX:!1,mouseWheelScrollSensitivity:typeof s.mouseWheelScrollSensitivity<"u"?s.mouseWheelScrollSensitivity:1,fastScrollSensitivity:typeof s.fastScrollSensitivity<"u"?s.fastScrollSensitivity:5,scrollPredominantAxis:typeof s.scrollPredominantAxis<"u"?s.scrollPredominantAxis:!0,mouseWheelSmoothScroll:typeof s.mouseWheelSmoothScroll<"u"?s.mouseWheelSmoothScroll:!0,arrowSize:typeof s.arrowSize<"u"?s.arrowSize:11,listenOnDomNode:typeof s.listenOnDomNode<"u"?s.listenOnDomNode:null,horizontal:typeof s.horizontal<"u"?s.horizontal:1,horizontalScrollbarSize:typeof s.horizontalScrollbarSize<"u"?s.horizontalScrollbarSize:10,horizontalSliderSize:typeof s.horizontalSliderSize<"u"?s.horizontalSliderSize:0,horizontalHasArrows:typeof s.horizontalHasArrows<"u"?s.horizontalHasArrows:!1,vertical:typeof s.vertical<"u"?s.vertical:1,verticalScrollbarSize:typeof s.verticalScrollbarSize<"u"?s.verticalScrollbarSize:10,verticalHasArrows:typeof s.verticalHasArrows<"u"?s.verticalHasArrows:!1,verticalSliderSize:typeof s.verticalSliderSize<"u"?s.verticalSliderSize:0,scrollByPage:typeof s.scrollByPage<"u"?s.scrollByPage:!1};return e.horizontalSliderSize=typeof s.horizontalSliderSize<"u"?s.horizontalSliderSize:e.horizontalScrollbarSize,e.verticalSliderSize=typeof s.verticalSliderSize<"u"?s.verticalSliderSize:e.verticalScrollbarSize,bt&&(e.className+=" mac"),e}class IP extends uC{constructor(e,t,i){super(),this._mouseLeaveMonitor=null,this._context=e,this.viewController=t,this.viewHelper=i,this.mouseTargetFactory=new $n(this._context,i),this._mouseDownOperation=this._register(new nre(this._context,this.viewController,this.viewHelper,this.mouseTargetFactory,(r,a)=>this._createMouseTarget(r,a),r=>this._getMouseColumn(r))),this.lastMouseLeaveTime=-1,this._height=this._context.configuration.options.get(143).height;const n=new Eoe(this.viewHelper.viewDomNode);this._register(n.onContextMenu(this.viewHelper.viewDomNode,r=>this._onContextMenu(r,!0))),this._register(n.onMouseMove(this.viewHelper.viewDomNode,r=>{this._onMouseMove(r),this._mouseLeaveMonitor||(this._mouseLeaveMonitor=Y(this.viewHelper.viewDomNode.ownerDocument,"mousemove",a=>{this.viewHelper.viewDomNode.contains(a.target)||this._onMouseLeave(new Pu(a,!1,this.viewHelper.viewDomNode))}))})),this._register(n.onMouseUp(this.viewHelper.viewDomNode,r=>this._onMouseUp(r))),this._register(n.onMouseLeave(this.viewHelper.viewDomNode,r=>this._onMouseLeave(r)));let o=0;this._register(n.onPointerDown(this.viewHelper.viewDomNode,(r,a)=>{o=a})),this._register(Y(this.viewHelper.viewDomNode,he.POINTER_UP,r=>{this._mouseDownOperation.onPointerUp()})),this._register(n.onMouseDown(this.viewHelper.viewDomNode,r=>this._onMouseDown(r,o))),this._setupMouseWheelZoomListener(),this._context.addEventHandler(this)}_setupMouseWheelZoomListener(){const e=XS.INSTANCE;let t=0,i=fr.getZoomLevel(),n=!1,o=0;const r=l=>{if(this.viewController.emitMouseWheel(l),!this._context.configuration.options.get(75))return;const d=new Ng(l);if(e.acceptStandardWheelEvent(d),e.isPhysicalMouseWheel()){if(a(l)){const c=fr.getZoomLevel(),u=d.deltaY>0?1:-1;fr.setZoomLevel(c+u),d.preventDefault(),d.stopPropagation()}}else Date.now()-t>50&&(i=fr.getZoomLevel(),n=a(l),o=0),t=Date.now(),o+=d.deltaY,n&&(fr.setZoomLevel(i+o/5),d.preventDefault(),d.stopPropagation())};this._register(Y(this.viewHelper.viewDomNode,he.MOUSE_WHEEL,r,{capture:!0,passive:!1}));function a(l){return bt?(l.metaKey||l.ctrlKey)&&!l.shiftKey&&!l.altKey:l.ctrlKey&&!l.metaKey&&!l.shiftKey&&!l.altKey}}dispose(){this._context.removeEventHandler(this),this._mouseLeaveMonitor&&(this._mouseLeaveMonitor.dispose(),this._mouseLeaveMonitor=null),super.dispose()}onConfigurationChanged(e){if(e.hasChanged(143)){const t=this._context.configuration.options.get(143).height;this._height!==t&&(this._height=t,this._mouseDownOperation.onHeightChanged())}return!1}onCursorStateChanged(e){return this._mouseDownOperation.onCursorStateChanged(e),!1}onFocusChanged(e){return!1}getTargetAtClientPoint(e,t){const n=new pH(e,t).toPageCoordinates(Xe(this.viewHelper.viewDomNode)),o=yP(this.viewHelper.viewDomNode);if(n.y<o.y||n.y>o.y+o.height||n.x<o.x||n.x>o.x+o.width)return null;const r=LP(this.viewHelper.viewDomNode,o,n);return this.mouseTargetFactory.createMouseTarget(this.viewHelper.getLastRenderData(),o,n,r,null)}_createMouseTarget(e,t){let i=e.target;if(!this.viewHelper.viewDomNode.contains(i)){const n=Tg(this.viewHelper.viewDomNode);n&&(i=n.elementsFromPoint(e.posx,e.posy).find(o=>this.viewHelper.viewDomNode.contains(o)))}return this.mouseTargetFactory.createMouseTarget(this.viewHelper.getLastRenderData(),e.editorPos,e.pos,e.relativePos,t?i:null)}_getMouseColumn(e){return this.mouseTargetFactory.getMouseColumn(e.relativePos)}_onContextMenu(e,t){this.viewController.emitContextMenu({event:e,target:this._createMouseTarget(e,t)})}_onMouseMove(e){this.mouseTargetFactory.mouseTargetIsWidget(e)||e.preventDefault(),!(this._mouseDownOperation.isActive()||e.timestamp<this.lastMouseLeaveTime)&&this.viewController.emitMouseMove({event:e,target:this._createMouseTarget(e,!0)})}_onMouseLeave(e){this._mouseLeaveMonitor&&(this._mouseLeaveMonitor.dispose(),this._mouseLeaveMonitor=null),this.lastMouseLeaveTime=new Date().getTime(),this.viewController.emitMouseLeave({event:e,target:null})}_onMouseUp(e){this.viewController.emitMouseUp({event:e,target:this._createMouseTarget(e,!0)})}_onMouseDown(e,t){const i=this._createMouseTarget(e,!0),n=i.type===6||i.type===7,o=i.type===2||i.type===3||i.type===4,r=i.type===3,a=this._context.configuration.options.get(108),l=i.type===8||i.type===5,d=i.type===9;let c=e.leftButton||e.middleButton;bt&&e.leftButton&&e.ctrlKey&&(c=!1);const u=()=>{e.preventDefault(),this.viewHelper.focusTextArea()};if(c&&(n||r&&a))u(),this._mouseDownOperation.start(i.type,e,t);else if(o)e.preventDefault();else if(l){const h=i.detail;c&&this.viewHelper.shouldSuppressMouseDownOnViewZone(h.viewZoneId)&&(u(),this._mouseDownOperation.start(i.type,e,t),e.preventDefault())}else d&&this.viewHelper.shouldSuppressMouseDownOnWidget(i.detail)&&(u(),e.preventDefault());this.viewController.emitMouseDown({event:e,target:i})}}class nre extends j{constructor(e,t,i,n,o,r){super(),this._context=e,this._viewController=t,this._viewHelper=i,this._mouseTargetFactory=n,this._createMouseTarget=o,this._getMouseColumn=r,this._mouseMoveMonitor=this._register(new Toe(this._viewHelper.viewDomNode)),this._topBottomDragScrolling=this._register(new sre(this._context,this._viewHelper,this._mouseTargetFactory,(a,l,d)=>this._dispatchMouse(a,l,d))),this._mouseState=new xx,this._currentSelection=new De(1,1,1,1),this._isActive=!1,this._lastMouseEvent=null}dispose(){super.dispose()}isActive(){return this._isActive}_onMouseDownThenMove(e){this._lastMouseEvent=e,this._mouseState.setModifiers(e);const t=this._findMousePosition(e,!1);t&&(this._mouseState.isDragAndDrop?this._viewController.emitMouseDrag({event:e,target:t}):t.type===13&&(t.outsidePosition==="above"||t.outsidePosition==="below")?this._topBottomDragScrolling.start(t,e):(this._topBottomDragScrolling.stop(),this._dispatchMouse(t,!0,1)))}start(e,t,i){this._lastMouseEvent=t,this._mouseState.setStartedOnLineNumbers(e===3),this._mouseState.setStartButtons(t),this._mouseState.setModifiers(t);const n=this._findMousePosition(t,!0);if(!n||!n.position)return;this._mouseState.trySetCount(t.detail,n.position),t.detail=this._mouseState.count;const o=this._context.configuration.options;if(!o.get(90)&&o.get(35)&&!o.get(22)&&!this._mouseState.altKey&&t.detail<2&&!this._isActive&&!this._currentSelection.isEmpty()&&n.type===6&&n.position&&this._currentSelection.containsPosition(n.position)){this._mouseState.isDragAndDrop=!0,this._isActive=!0,this._mouseMoveMonitor.startMonitoring(this._viewHelper.viewLinesDomNode,i,t.buttons,r=>this._onMouseDownThenMove(r),r=>{const a=this._findMousePosition(this._lastMouseEvent,!1);SV(r)?this._viewController.emitMouseDropCanceled():this._viewController.emitMouseDrop({event:this._lastMouseEvent,target:a?this._createMouseTarget(this._lastMouseEvent,!0):null}),this._stop()});return}this._mouseState.isDragAndDrop=!1,this._dispatchMouse(n,t.shiftKey,1),this._isActive||(this._isActive=!0,this._mouseMoveMonitor.startMonitoring(this._viewHelper.viewLinesDomNode,i,t.buttons,r=>this._onMouseDownThenMove(r),()=>this._stop()))}_stop(){this._isActive=!1,this._topBottomDragScrolling.stop()}onHeightChanged(){this._mouseMoveMonitor.stopMonitoring()}onPointerUp(){this._mouseMoveMonitor.stopMonitoring()}onCursorStateChanged(e){this._currentSelection=e.selections[0]}_getPositionOutsideEditor(e){const t=e.editorPos,i=this._context.viewModel,n=this._context.viewLayout,o=this._getMouseColumn(e);if(e.posy<t.y){const a=t.y-e.posy,l=Math.max(n.getCurrentScrollTop()-a,0),d=Cm.getZoneAtCoord(this._context,l);if(d){const u=this._helpPositionJumpOverViewZone(d);if(u)return bs.createOutsideEditor(o,u,"above",a)}const c=n.getLineNumberAtVerticalOffset(l);return bs.createOutsideEditor(o,new H(c,1),"above",a)}if(e.posy>t.y+t.height){const a=e.posy-t.y-t.height,l=n.getCurrentScrollTop()+e.relativePos.y,d=Cm.getZoneAtCoord(this._context,l);if(d){const u=this._helpPositionJumpOverViewZone(d);if(u)return bs.createOutsideEditor(o,u,"below",a)}const c=n.getLineNumberAtVerticalOffset(l);return bs.createOutsideEditor(o,new H(c,i.getLineMaxColumn(c)),"below",a)}const r=n.getLineNumberAtVerticalOffset(n.getCurrentScrollTop()+e.relativePos.y);if(e.posx<t.x){const a=t.x-e.posx;return bs.createOutsideEditor(o,new H(r,1),"left",a)}if(e.posx>t.x+t.width){const a=e.posx-t.x-t.width;return bs.createOutsideEditor(o,new H(r,i.getLineMaxColumn(r)),"right",a)}return null}_findMousePosition(e,t){const i=this._getPositionOutsideEditor(e);if(i)return i;const n=this._createMouseTarget(e,t);if(!n.position)return null;if(n.type===8||n.type===5){const r=this._helpPositionJumpOverViewZone(n.detail);if(r)return bs.createViewZone(n.type,n.element,n.mouseColumn,r,n.detail)}return n}_helpPositionJumpOverViewZone(e){const t=new H(this._currentSelection.selectionStartLineNumber,this._currentSelection.selectionStartColumn),i=e.positionBefore,n=e.positionAfter;return i&&n?i.isBefore(t)?i:n:null}_dispatchMouse(e,t,i){e.position&&this._viewController.dispatchMouse({position:e.position,mouseColumn:e.mouseColumn,startedOnLineNumbers:this._mouseState.startedOnLineNumbers,revealType:i,inSelectionMode:t,mouseDownCount:this._mouseState.count,altKey:this._mouseState.altKey,ctrlKey:this._mouseState.ctrlKey,metaKey:this._mouseState.metaKey,shiftKey:this._mouseState.shiftKey,leftButton:this._mouseState.leftButton,middleButton:this._mouseState.middleButton,onInjectedText:e.type===6&&e.detail.injectedText!==null})}}class sre extends j{constructor(e,t,i,n){super(),this._context=e,this._viewHelper=t,this._mouseTargetFactory=i,this._dispatchMouse=n,this._operation=null}dispose(){super.dispose(),this.stop()}start(e,t){this._operation?this._operation.setPosition(e,t):this._operation=new ore(this._context,this._viewHelper,this._mouseTargetFactory,this._dispatchMouse,e,t)}stop(){this._operation&&(this._operation.dispose(),this._operation=null)}}class ore extends j{constructor(e,t,i,n,o,r){super(),this._context=e,this._viewHelper=t,this._mouseTargetFactory=i,this._dispatchMouse=n,this._position=o,this._mouseEvent=r,this._lastTime=Date.now(),this._animationFrameDisposable=yo(Xe(r.browserEvent),()=>this._execute())}dispose(){this._animationFrameDisposable.dispose()}setPosition(e,t){this._position=e,this._mouseEvent=t}_tick(){const e=Date.now(),t=e-this._lastTime;return this._lastTime=e,t}_getScrollSpeed(){const e=this._context.configuration.options.get(66),t=this._context.configuration.options.get(143).height/e,i=this._position.outsideDistance/e;return i<=1.5?Math.max(30,t*(1+i)):i<=3?Math.max(60,t*(2+i)):Math.max(200,t*(7+i))}_execute(){const e=this._context.configuration.options.get(66),t=this._getScrollSpeed(),i=this._tick(),n=t*(i/1e3)*e,o=this._position.outsidePosition==="above"?-n:n;this._context.viewModel.viewLayout.deltaScrollNow(0,o),this._viewHelper.renderNow();const r=this._context.viewLayout.getLinesViewportData(),a=this._position.outsidePosition==="above"?r.startLineNumber:r.endLineNumber;let l;{const d=yP(this._viewHelper.viewDomNode),c=this._context.configuration.options.get(143).horizontalScrollbarHeight,u=new Sx(this._mouseEvent.pos.x,d.y+d.height-c-.1),h=LP(this._viewHelper.viewDomNode,d,u);l=this._mouseTargetFactory.createMouseTarget(this._viewHelper.getLastRenderData(),d,u,h,null)}(!l.position||l.position.lineNumber!==a)&&(this._position.outsidePosition==="above"?l=bs.createOutsideEditor(this._position.mouseColumn,new H(a,1),"above",this._position.outsideDistance):l=bs.createOutsideEditor(this._position.mouseColumn,new H(a,this._context.viewModel.getLineMaxColumn(a)),"below",this._position.outsideDistance)),this._dispatchMouse(l,!0,2),this._animationFrameDisposable=yo(Xe(l.element),()=>this._execute())}}class xx{get altKey(){return this._altKey}get ctrlKey(){return this._ctrlKey}get metaKey(){return this._metaKey}get shiftKey(){return this._shiftKey}get leftButton(){return this._leftButton}get middleButton(){return this._middleButton}get startedOnLineNumbers(){return this._startedOnLineNumbers}constructor(){this._altKey=!1,this._ctrlKey=!1,this._metaKey=!1,this._shiftKey=!1,this._leftButton=!1,this._middleButton=!1,this._startedOnLineNumbers=!1,this._lastMouseDownPosition=null,this._lastMouseDownPositionEqualCount=0,this._lastMouseDownCount=0,this._lastSetMouseDownCountTime=0,this.isDragAndDrop=!1}get count(){return this._lastMouseDownCount}setModifiers(e){this._altKey=e.altKey,this._ctrlKey=e.ctrlKey,this._metaKey=e.metaKey,this._shiftKey=e.shiftKey}setStartButtons(e){this._leftButton=e.leftButton,this._middleButton=e.middleButton}setStartedOnLineNumbers(e){this._startedOnLineNumbers=e}trySetCount(e,t){const i=new Date().getTime();i-this._lastSetMouseDownCountTime>xx.CLEAR_MOUSE_DOWN_COUNT_TIME&&(e=1),this._lastSetMouseDownCountTime=i,e>this._lastMouseDownCount+1&&(e=this._lastMouseDownCount+1),this._lastMouseDownPosition&&this._lastMouseDownPosition.equals(t)?this._lastMouseDownPositionEqualCount++:this._lastMouseDownPositionEqualCount=1,this._lastMouseDownPosition=t,this._lastMouseDownCount=Math.min(e,this._lastMouseDownPositionEqualCount)}}xx.CLEAR_MOUSE_DOWN_COUNT_TIME=400;class gt{get event(){return this.emitter.event}constructor(e,t,i){const n=o=>this.emitter.fire(o);this.emitter=new W({onWillAddFirstListener:()=>e.addEventListener(t,n,i),onDidRemoveLastListener:()=>e.removeEventListener(t,n,i)})}dispose(){this.emitter.dispose()}}var jc;(function(s){const e={total:0,min:Number.MAX_VALUE,max:0},t={...e},i={...e},n={...e};let o=0;const r={keydown:0,input:0,render:0};function a(){v(),performance.mark("inputlatency/start"),performance.mark("keydown/start"),r.keydown=1,queueMicrotask(l)}s.onKeyDown=a;function l(){r.keydown===1&&(performance.mark("keydown/end"),r.keydown=2)}function d(){performance.mark("input/start"),r.input=1,_()}s.onBeforeInput=d;function c(){r.input===0&&d(),queueMicrotask(u)}s.onInput=c;function u(){r.input===1&&(performance.mark("input/end"),r.input=2)}function h(){v()}s.onKeyUp=h;function g(){v()}s.onSelectionChange=g;function f(){r.keydown===2&&r.input===2&&r.render===0&&(performance.mark("render/start"),r.render=1,queueMicrotask(m),_())}s.onRenderStart=f;function m(){r.render===1&&(performance.mark("render/end"),r.render=2)}function _(){setTimeout(v)}function v(){r.keydown===2&&r.input===2&&r.render===2&&(performance.mark("inputlatency/end"),performance.measure("keydown","keydown/start","keydown/end"),performance.measure("input","input/start","input/end"),performance.measure("render","render/start","render/end"),performance.measure("inputlatency","inputlatency/start","inputlatency/end"),b("keydown",e),b("input",t),b("render",i),b("inputlatency",n),o++,C())}function b(L,k){const I=performance.getEntriesByName(L)[0].duration;k.total+=I,k.min=Math.min(k.min,I),k.max=Math.max(k.max,I)}function C(){performance.clearMarks("keydown/start"),performance.clearMarks("keydown/end"),performance.clearMarks("input/start"),performance.clearMarks("input/end"),performance.clearMarks("render/start"),performance.clearMarks("render/end"),performance.clearMarks("inputlatency/start"),performance.clearMarks("inputlatency/end"),performance.clearMeasures("keydown"),performance.clearMeasures("input"),performance.clearMeasures("render"),performance.clearMeasures("inputlatency"),r.keydown=0,r.input=0,r.render=0}function w(){if(o===0)return;const L={keydown:S(e),input:S(t),render:S(i),total:S(n),sampleCount:o};return x(e),x(t),x(i),x(n),o=0,L}s.getAndClearMeasurements=w;function S(L){return{average:L.total/o,max:L.max,min:L.min}}function x(L){L.total=0,L.min=Number.MAX_VALUE,L.max=0}})(jc||(jc={}));class Rn{constructor(e,t,i,n,o){this.value=e,this.selectionStart=t,this.selectionEnd=i,this.selection=n,this.newlineCountBeforeSelection=o}toString(){return`[ <${this.value}>, selectionStart: ${this.selectionStart}, selectionEnd: ${this.selectionEnd}]`}static readFromTextArea(e,t){const i=e.getValue(),n=e.getSelectionStart(),o=e.getSelectionEnd();let r;if(t){const a=i.substring(0,n),l=t.value.substring(0,t.selectionStart);a===l&&(r=t.newlineCountBeforeSelection)}return new Rn(i,n,o,null,r)}collapseSelection(){return this.selectionStart===this.value.length?this:new Rn(this.value,this.value.length,this.value.length,null,void 0)}writeToTextArea(e,t,i){t.setValue(e,this.value),i&&t.setSelectionRange(e,this.selectionStart,this.selectionEnd)}deduceEditorPosition(e){var t,i,n,o,r,a,l,d;if(e<=this.selectionStart){const h=this.value.substring(e,this.selectionStart);return this._finishDeduceEditorPosition((i=(t=this.selection)===null||t===void 0?void 0:t.getStartPosition())!==null&&i!==void 0?i:null,h,-1)}if(e>=this.selectionEnd){const h=this.value.substring(this.selectionEnd,e);return this._finishDeduceEditorPosition((o=(n=this.selection)===null||n===void 0?void 0:n.getEndPosition())!==null&&o!==void 0?o:null,h,1)}const c=this.value.substring(this.selectionStart,e);if(c.indexOf("…")===-1)return this._finishDeduceEditorPosition((a=(r=this.selection)===null||r===void 0?void 0:r.getStartPosition())!==null&&a!==void 0?a:null,c,1);const u=this.value.substring(e,this.selectionEnd);return this._finishDeduceEditorPosition((d=(l=this.selection)===null||l===void 0?void 0:l.getEndPosition())!==null&&d!==void 0?d:null,u,-1)}_finishDeduceEditorPosition(e,t,i){let n=0,o=-1;for(;(o=t.indexOf(`
`,o+1))!==-1;)n++;return[e,i*t.length,n]}static deduceInput(e,t,i){if(!e)return{text:"",replacePrevCharCnt:0,replaceNextCharCnt:0,positionDelta:0};const n=Math.min(Dg(e.value,t.value),e.selectionStart,t.selectionStart),o=Math.min(RS(e.value,t.value),e.value.length-e.selectionEnd,t.value.length-t.selectionEnd);e.value.substring(n,e.value.length-o);const r=t.value.substring(n,t.value.length-o),a=e.selectionStart-n,l=e.selectionEnd-n,d=t.selectionStart-n,c=t.selectionEnd-n;if(d===c){const h=e.selectionStart-n;return{text:r,replacePrevCharCnt:h,replaceNextCharCnt:0,positionDelta:0}}const u=l-a;return{text:r,replacePrevCharCnt:u,replaceNextCharCnt:0,positionDelta:0}}static deduceAndroidCompositionInput(e,t){if(!e)return{text:"",replacePrevCharCnt:0,replaceNextCharCnt:0,positionDelta:0};if(e.value===t.value)return{text:"",replacePrevCharCnt:0,replaceNextCharCnt:0,positionDelta:t.selectionEnd-e.selectionEnd};const i=Math.min(Dg(e.value,t.value),e.selectionEnd),n=Math.min(RS(e.value,t.value),e.value.length-e.selectionEnd),o=e.value.substring(i,e.value.length-n),r=t.value.substring(i,t.value.length-n);e.selectionStart-i;const a=e.selectionEnd-i;t.selectionStart-i;const l=t.selectionEnd-i;return{text:r,replacePrevCharCnt:a,replaceNextCharCnt:o.length-a,positionDelta:l-r.length}}}Rn.EMPTY=new Rn("",0,0,null,void 0);class fp{static _getPageOfLine(e,t){return Math.floor((e-1)/t)}static _getRangeForPage(e,t){const i=e*t,n=i+1,o=i+t;return new D(n,1,o+1,1)}static fromEditorSelection(e,t,i,n){const r=fp._getPageOfLine(t.startLineNumber,i),a=fp._getRangeForPage(r,i),l=fp._getPageOfLine(t.endLineNumber,i),d=fp._getRangeForPage(l,i);let c=a.intersectRanges(new D(1,1,t.startLineNumber,t.startColumn));if(n&&e.getValueLengthInRange(c,1)>500){const v=e.modifyPosition(c.getEndPosition(),-500);c=D.fromPositions(v,c.getEndPosition())}const u=e.getValueInRange(c,1),h=e.getLineCount(),g=e.getLineMaxColumn(h);let f=d.intersectRanges(new D(t.endLineNumber,t.endColumn,h,g));if(n&&e.getValueLengthInRange(f,1)>500){const v=e.modifyPosition(f.getStartPosition(),500);f=D.fromPositions(f.getStartPosition(),v)}const m=e.getValueInRange(f,1);let _;if(r===l||r+1===l)_=e.getValueInRange(t,1);else{const v=a.intersectRanges(t),b=d.intersectRanges(t);_=e.getValueInRange(v,1)+"…"+e.getValueInRange(b,1)}return n&&_.length>2*500&&(_=_.substring(0,500)+"…"+_.substring(_.length-500,_.length)),new Rn(u+_+m,u.length,u.length+_.length,t,c.endLineNumber-c.startLineNumber)}}var rre=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},P3=function(s,e){return function(t,i){e(t,i,s)}},QS;(function(s){s.Tap="-monaco-textarea-synthetic-tap"})(QS||(QS={}));const _T={forceCopyWithSyntaxHighlighting:!1};class K0{constructor(){this._lastState=null}set(e,t){this._lastState={lastCopiedValue:e,data:t}}get(e){return this._lastState&&this._lastState.lastCopiedValue===e?this._lastState.data:(this._lastState=null,null)}}K0.INSTANCE=new K0;class are{constructor(){this._lastTypeTextLength=0}handleCompositionUpdate(e){e=e||"";const t={text:e,replacePrevCharCnt:this._lastTypeTextLength,replaceNextCharCnt:0,positionDelta:0};return this._lastTypeTextLength=e.length,t}}let vT=class extends j{get textAreaState(){return this._textAreaState}constructor(e,t,i,n,o,r){super(),this._host=e,this._textArea=t,this._OS=i,this._browser=n,this._accessibilityService=o,this._logService=r,this._onFocus=this._register(new W),this.onFocus=this._onFocus.event,this._onBlur=this._register(new W),this.onBlur=this._onBlur.event,this._onKeyDown=this._register(new W),this.onKeyDown=this._onKeyDown.event,this._onKeyUp=this._register(new W),this.onKeyUp=this._onKeyUp.event,this._onCut=this._register(new W),this.onCut=this._onCut.event,this._onPaste=this._register(new W),this.onPaste=this._onPaste.event,this._onType=this._register(new W),this.onType=this._onType.event,this._onCompositionStart=this._register(new W),this.onCompositionStart=this._onCompositionStart.event,this._onCompositionUpdate=this._register(new W),this.onCompositionUpdate=this._onCompositionUpdate.event,this._onCompositionEnd=this._register(new W),this.onCompositionEnd=this._onCompositionEnd.event,this._onSelectionChangeRequest=this._register(new W),this.onSelectionChangeRequest=this._onSelectionChangeRequest.event,this._asyncFocusGainWriteScreenReaderContent=this._register(new En),this._asyncTriggerCut=this._register(new jt(()=>this._onCut.fire(),0)),this._textAreaState=Rn.EMPTY,this._selectionChangeListener=null,this._accessibilityService.isScreenReaderOptimized()&&this.writeNativeTextAreaContent("ctor"),this._register(ge.runAndSubscribe(this._accessibilityService.onDidChangeScreenReaderOptimized,()=>{this._accessibilityService.isScreenReaderOptimized()&&!this._asyncFocusGainWriteScreenReaderContent.value?this._asyncFocusGainWriteScreenReaderContent.value=this._register(new jt(()=>this.writeNativeTextAreaContent("asyncFocusGain"),0)):this._asyncFocusGainWriteScreenReaderContent.clear()})),this._hasFocus=!1,this._currentComposition=null;let a=null;this._register(this._textArea.onKeyDown(l=>{const d=new ri(l);(d.keyCode===114||this._currentComposition&&d.keyCode===1)&&d.stopPropagation(),d.equals(9)&&d.preventDefault(),a=d,this._onKeyDown.fire(d)})),this._register(this._textArea.onKeyUp(l=>{const d=new ri(l);this._onKeyUp.fire(d)})),this._register(this._textArea.onCompositionStart(l=>{const d=new are;if(this._currentComposition){this._currentComposition=d;return}if(this._currentComposition=d,this._OS===2&&a&&a.equals(114)&&this._textAreaState.selectionStart===this._textAreaState.selectionEnd&&this._textAreaState.selectionStart>0&&this._textAreaState.value.substr(this._textAreaState.selectionStart-1,1)===l.data&&(a.code==="ArrowRight"||a.code==="ArrowLeft")){d.handleCompositionUpdate("x"),this._onCompositionStart.fire({data:l.data});return}if(this._browser.isAndroid){this._onCompositionStart.fire({data:l.data});return}this._onCompositionStart.fire({data:l.data})})),this._register(this._textArea.onCompositionUpdate(l=>{const d=this._currentComposition;if(!d)return;if(this._browser.isAndroid){const u=Rn.readFromTextArea(this._textArea,this._textAreaState),h=Rn.deduceAndroidCompositionInput(this._textAreaState,u);this._textAreaState=u,this._onType.fire(h),this._onCompositionUpdate.fire(l);return}const c=d.handleCompositionUpdate(l.data);this._textAreaState=Rn.readFromTextArea(this._textArea,this._textAreaState),this._onType.fire(c),this._onCompositionUpdate.fire(l)})),this._register(this._textArea.onCompositionEnd(l=>{const d=this._currentComposition;if(!d)return;if(this._currentComposition=null,this._browser.isAndroid){const u=Rn.readFromTextArea(this._textArea,this._textAreaState),h=Rn.deduceAndroidCompositionInput(this._textAreaState,u);this._textAreaState=u,this._onType.fire(h),this._onCompositionEnd.fire();return}const c=d.handleCompositionUpdate(l.data);this._textAreaState=Rn.readFromTextArea(this._textArea,this._textAreaState),this._onType.fire(c),this._onCompositionEnd.fire()})),this._register(this._textArea.onInput(l=>{if(this._textArea.setIgnoreSelectionChangeTime("received input event"),this._currentComposition)return;const d=Rn.readFromTextArea(this._textArea,this._textAreaState),c=Rn.deduceInput(this._textAreaState,d,this._OS===2);c.replacePrevCharCnt===0&&c.text.length===1&&(_n(c.text.charCodeAt(0))||c.text.charCodeAt(0)===127)||(this._textAreaState=d,(c.text!==""||c.replacePrevCharCnt!==0||c.replaceNextCharCnt!==0||c.positionDelta!==0)&&this._onType.fire(c))})),this._register(this._textArea.onCut(l=>{this._textArea.setIgnoreSelectionChangeTime("received cut event"),this._ensureClipboardGetsEditorSelection(l),this._asyncTriggerCut.schedule()})),this._register(this._textArea.onCopy(l=>{this._ensureClipboardGetsEditorSelection(l)})),this._register(this._textArea.onPaste(l=>{if(this._textArea.setIgnoreSelectionChangeTime("received paste event"),l.preventDefault(),!l.clipboardData)return;let[d,c]=bT.getTextData(l.clipboardData);d&&(c=c||K0.INSTANCE.get(d),this._onPaste.fire({text:d,metadata:c}))})),this._register(this._textArea.onFocus(()=>{const l=this._hasFocus;this._setHasFocus(!0),this._accessibilityService.isScreenReaderOptimized()&&this._browser.isSafari&&!l&&this._hasFocus&&(this._asyncFocusGainWriteScreenReaderContent.value||(this._asyncFocusGainWriteScreenReaderContent.value=new jt(()=>this.writeNativeTextAreaContent("asyncFocusGain"),0)),this._asyncFocusGainWriteScreenReaderContent.value.schedule())})),this._register(this._textArea.onBlur(()=>{this._currentComposition&&(this._currentComposition=null,this.writeNativeTextAreaContent("blurWithoutCompositionEnd"),this._onCompositionEnd.fire()),this._setHasFocus(!1)})),this._register(this._textArea.onSyntheticTap(()=>{this._browser.isAndroid&&this._currentComposition&&(this._currentComposition=null,this.writeNativeTextAreaContent("tapWithoutCompositionEnd"),this._onCompositionEnd.fire())}))}_installSelectionChangeListener(){let e=0;return Y(this._textArea.ownerDocument,"selectionchange",t=>{if(jc.onSelectionChange(),!this._hasFocus||this._currentComposition||!this._browser.isChrome)return;const i=Date.now(),n=i-e;if(e=i,n<5)return;const o=i-this._textArea.getIgnoreSelectionChangeTime();if(this._textArea.resetSelectionChangeTime(),o<100||!this._textAreaState.selection)return;const r=this._textArea.getValue();if(this._textAreaState.value!==r)return;const a=this._textArea.getSelectionStart(),l=this._textArea.getSelectionEnd();if(this._textAreaState.selectionStart===a&&this._textAreaState.selectionEnd===l)return;const d=this._textAreaState.deduceEditorPosition(a),c=this._host.deduceModelPosition(d[0],d[1],d[2]),u=this._textAreaState.deduceEditorPosition(l),h=this._host.deduceModelPosition(u[0],u[1],u[2]),g=new De(c.lineNumber,c.column,h.lineNumber,h.column);this._onSelectionChangeRequest.fire(g)})}dispose(){super.dispose(),this._selectionChangeListener&&(this._selectionChangeListener.dispose(),this._selectionChangeListener=null)}focusTextArea(){this._setHasFocus(!0),this.refreshFocusState()}isFocused(){return this._hasFocus}refreshFocusState(){this._setHasFocus(this._textArea.hasFocus())}_setHasFocus(e){this._hasFocus!==e&&(this._hasFocus=e,this._selectionChangeListener&&(this._selectionChangeListener.dispose(),this._selectionChangeListener=null),this._hasFocus&&(this._selectionChangeListener=this._installSelectionChangeListener()),this._hasFocus&&this.writeNativeTextAreaContent("focusgain"),this._hasFocus?this._onFocus.fire():this._onBlur.fire())}_setAndWriteTextAreaState(e,t){this._hasFocus||(t=t.collapseSelection()),t.writeToTextArea(e,this._textArea,this._hasFocus),this._textAreaState=t}writeNativeTextAreaContent(e){!this._accessibilityService.isScreenReaderOptimized()&&e==="render"||this._currentComposition||(this._logService.trace(`writeTextAreaState(reason: ${e})`),this._setAndWriteTextAreaState(e,this._host.getScreenReaderContent()))}_ensureClipboardGetsEditorSelection(e){const t=this._host.getDataToCopy(),i={version:1,isFromEmptySelection:t.isFromEmptySelection,multicursorText:t.multicursorText,mode:t.mode};K0.INSTANCE.set(this._browser.isFirefox?t.text.replace(/\r\n/g,`
`):t.text,i),e.preventDefault(),e.clipboardData&&bT.setTextData(e.clipboardData,t.text,t.html,i)}};vT=rre([P3(4,ad),P3(5,ko)],vT);const bT={getTextData(s){const e=s.getData(Hi.text);let t=null;const i=s.getData("vscode-editor-data");if(typeof i=="string")try{t=JSON.parse(i),t.version!==1&&(t=null)}catch{}return e.length===0&&t===null&&s.files.length>0?[Array.prototype.slice.call(s.files,0).map(o=>o.name).join(`
`),null]:[e,t]},setTextData(s,e,t,i){s.setData(Hi.text,e),typeof t=="string"&&s.setData("text/html",t),s.setData("vscode-editor-data",JSON.stringify(i))}};class lre extends j{get ownerDocument(){return this._actual.ownerDocument}constructor(e){super(),this._actual=e,this.onKeyDown=this._register(new gt(this._actual,"keydown")).event,this.onKeyUp=this._register(new gt(this._actual,"keyup")).event,this.onCompositionStart=this._register(new gt(this._actual,"compositionstart")).event,this.onCompositionUpdate=this._register(new gt(this._actual,"compositionupdate")).event,this.onCompositionEnd=this._register(new gt(this._actual,"compositionend")).event,this.onBeforeInput=this._register(new gt(this._actual,"beforeinput")).event,this.onInput=this._register(new gt(this._actual,"input")).event,this.onCut=this._register(new gt(this._actual,"cut")).event,this.onCopy=this._register(new gt(this._actual,"copy")).event,this.onPaste=this._register(new gt(this._actual,"paste")).event,this.onFocus=this._register(new gt(this._actual,"focus")).event,this.onBlur=this._register(new gt(this._actual,"blur")).event,this._onSyntheticTap=this._register(new W),this.onSyntheticTap=this._onSyntheticTap.event,this._ignoreSelectionChangeTime=0,this._register(this.onKeyDown(()=>jc.onKeyDown())),this._register(this.onBeforeInput(()=>jc.onBeforeInput())),this._register(this.onInput(()=>jc.onInput())),this._register(this.onKeyUp(()=>jc.onKeyUp())),this._register(Y(this._actual,QS.Tap,()=>this._onSyntheticTap.fire()))}hasFocus(){const e=Tg(this._actual);return e?e.activeElement===this._actual:this._actual.isConnected?this._actual.ownerDocument.activeElement===this._actual:!1}setIgnoreSelectionChangeTime(e){this._ignoreSelectionChangeTime=Date.now()}getIgnoreSelectionChangeTime(){return this._ignoreSelectionChangeTime}resetSelectionChangeTime(){this._ignoreSelectionChangeTime=0}getValue(){return this._actual.value}setValue(e,t){const i=this._actual;i.value!==t&&(this.setIgnoreSelectionChangeTime("setValue"),i.value=t)}getSelectionStart(){return this._actual.selectionDirection==="backward"?this._actual.selectionEnd:this._actual.selectionStart}getSelectionEnd(){return this._actual.selectionDirection==="backward"?this._actual.selectionStart:this._actual.selectionEnd}setSelectionRange(e,t,i){const n=this._actual;let o=null;const r=Tg(n);r?o=r.activeElement:o=n.ownerDocument.activeElement;const a=Xe(o),l=o===n,d=n.selectionStart,c=n.selectionEnd;if(l&&d===t&&c===i){yr&&a.parent!==a&&n.focus();return}if(l){this.setIgnoreSelectionChangeTime("setSelectionRange"),n.setSelectionRange(t,i),yr&&a.parent!==a&&n.focus();return}try{const u=Yee(n);this.setIgnoreSelectionChangeTime("setSelectionRange"),n.focus(),n.setSelectionRange(t,i),Xee(n,u)}catch{}}}class dre extends IP{constructor(e,t,i){super(e,t,i),this._register(Xt.addTarget(this.viewHelper.linesContentDomNode)),this._register(Y(this.viewHelper.linesContentDomNode,Qt.Tap,o=>this.onTap(o))),this._register(Y(this.viewHelper.linesContentDomNode,Qt.Change,o=>this.onChange(o))),this._register(Y(this.viewHelper.linesContentDomNode,Qt.Contextmenu,o=>this._onContextMenu(new Pu(o,!1,this.viewHelper.viewDomNode),!1))),this._lastPointerType="mouse",this._register(Y(this.viewHelper.linesContentDomNode,"pointerdown",o=>{const r=o.pointerType;if(r==="mouse"){this._lastPointerType="mouse";return}else r==="touch"?this._lastPointerType="touch":this._lastPointerType="pen"}));const n=new Noe(this.viewHelper.viewDomNode);this._register(n.onPointerMove(this.viewHelper.viewDomNode,o=>this._onMouseMove(o))),this._register(n.onPointerUp(this.viewHelper.viewDomNode,o=>this._onMouseUp(o))),this._register(n.onPointerLeave(this.viewHelper.viewDomNode,o=>this._onMouseLeave(o))),this._register(n.onPointerDown(this.viewHelper.viewDomNode,(o,r)=>this._onMouseDown(o,r)))}onTap(e){if(!e.initialTarget||!this.viewHelper.linesContentDomNode.contains(e.initialTarget))return;e.preventDefault(),this.viewHelper.focusTextArea();const t=this._createMouseTarget(new Pu(e,!1,this.viewHelper.viewDomNode),!1);t.position&&this.viewController.dispatchMouse({position:t.position,mouseColumn:t.position.column,startedOnLineNumbers:!1,revealType:1,mouseDownCount:e.tapCount,inSelectionMode:!1,altKey:!1,ctrlKey:!1,metaKey:!1,shiftKey:!1,leftButton:!1,middleButton:!1,onInjectedText:t.type===6&&t.detail.injectedText!==null})}onChange(e){this._lastPointerType==="touch"&&this._context.viewModel.viewLayout.deltaScrollNow(-e.translationX,-e.translationY)}_onMouseDown(e,t){e.browserEvent.pointerType!=="touch"&&super._onMouseDown(e,t)}}class cre extends IP{constructor(e,t,i){super(e,t,i),this._register(Xt.addTarget(this.viewHelper.linesContentDomNode)),this._register(Y(this.viewHelper.linesContentDomNode,Qt.Tap,n=>this.onTap(n))),this._register(Y(this.viewHelper.linesContentDomNode,Qt.Change,n=>this.onChange(n))),this._register(Y(this.viewHelper.linesContentDomNode,Qt.Contextmenu,n=>this._onContextMenu(new Pu(n,!1,this.viewHelper.viewDomNode),!1)))}onTap(e){e.preventDefault(),this.viewHelper.focusTextArea();const t=this._createMouseTarget(new Pu(e,!1,this.viewHelper.viewDomNode),!1);if(t.position){const i=document.createEvent("CustomEvent");i.initEvent(QS.Tap,!1,!0),this.viewHelper.dispatchTextAreaEvent(i),this.viewController.moveTo(t.position,1)}}onChange(e){this._context.viewModel.viewLayout.deltaScrollNow(-e.translationX,-e.translationY)}}class ure extends j{constructor(e,t,i){super(),Wa&&qA.pointerEvents?this.handler=this._register(new dre(e,t,i)):Ci.TouchEvent?this.handler=this._register(new cre(e,t,i)):this.handler=this._register(new IP(e,t,i))}getTargetAtClientPoint(e,t){return this.handler.getTargetAtClientPoint(e,t)}}class df extends uC{}const Cn=ut("themeService");function Di(s){return{id:s}}function CT(s){switch(s){case _r.DARK:return"vs-dark";case _r.HIGH_CONTRAST_DARK:return"hc-black";case _r.HIGH_CONTRAST_LIGHT:return"hc-light";default:return"vs"}}const wH={ThemingContribution:"base.contributions.theming"};class hre{constructor(){this.themingParticipants=[],this.themingParticipants=[],this.onThemingParticipantAddedEmitter=new W}onColorThemeChange(e){return this.themingParticipants.push(e),this.onThemingParticipantAddedEmitter.fire(e),Fe(()=>{const t=this.themingParticipants.indexOf(e);this.themingParticipants.splice(t,1)})}getThemingParticipants(){return this.themingParticipants}}const SH=new hre;Si.add(wH.ThemingContribution,SH);function ia(s){return SH.onColorThemeChange(s)}class gre extends j{constructor(e){super(),this.themeService=e,this.theme=e.getColorTheme(),this._register(this.themeService.onDidColorThemeChange(t=>this.onThemeChange(t)))}onThemeChange(e){this.theme=e,this.updateStyles()}updateStyles(){}}const yH=R("editor.lineHighlightBackground",{dark:null,light:null,hcDark:null,hcLight:null},p("lineHighlight","Background color for the highlight of line at the cursor position.")),O3=R("editor.lineHighlightBorder",{dark:"#282828",light:"#eeeeee",hcDark:"#f38518",hcLight:pt},p("lineHighlightBorderBox","Background color for the border around the line at the cursor position."));R("editor.rangeHighlightBackground",{dark:"#ffffff0b",light:"#fdff0033",hcDark:null,hcLight:null},p("rangeHighlight","Background color of highlighted ranges, like by quick open and find features. The color must not be opaque so as not to hide underlying decorations."),!0);R("editor.rangeHighlightBorder",{dark:null,light:null,hcDark:ai,hcLight:ai},p("rangeHighlightBorder","Background color of the border around highlighted ranges."),!0);R("editor.symbolHighlightBackground",{dark:Rl,light:Rl,hcDark:null,hcLight:null},p("symbolHighlight","Background color of highlighted symbol, like for go to definition or go next/previous symbol. The color must not be opaque so as not to hide underlying decorations."),!0);R("editor.symbolHighlightBorder",{dark:null,light:null,hcDark:ai,hcLight:ai},p("symbolHighlightBorder","Background color of the border around highlighted symbols."),!0);const LH=R("editorCursor.foreground",{dark:"#AEAFAD",light:G.black,hcDark:G.white,hcLight:"#0F4A85"},p("caret","Color of the editor cursor.")),fre=R("editorCursor.background",null,p("editorCursorBackground","The background color of the editor cursor. Allows customizing the color of a character overlapped by a block cursor.")),Vd=R("editorWhitespace.foreground",{dark:"#e3e4e229",light:"#33333333",hcDark:"#e3e4e229",hcLight:"#CCCCCC"},p("editorWhitespaces","Color of whitespace characters in the editor.")),pre=R("editorLineNumber.foreground",{dark:"#858585",light:"#237893",hcDark:G.white,hcLight:"#292929"},p("editorLineNumbers","Color of editor line numbers.")),f1=R("editorIndentGuide.background",{dark:Vd,light:Vd,hcDark:Vd,hcLight:Vd},p("editorIndentGuides","Color of the editor indentation guides."),!1,p("deprecatedEditorIndentGuides","'editorIndentGuide.background' is deprecated. Use 'editorIndentGuide.background1' instead.")),p1=R("editorIndentGuide.activeBackground",{dark:Vd,light:Vd,hcDark:Vd,hcLight:Vd},p("editorActiveIndentGuide","Color of the active editor indentation guides."),!1,p("deprecatedEditorActiveIndentGuide","'editorIndentGuide.activeBackground' is deprecated. Use 'editorIndentGuide.activeBackground1' instead.")),gC=R("editorIndentGuide.background1",{dark:f1,light:f1,hcDark:f1,hcLight:f1},p("editorIndentGuides1","Color of the editor indentation guides (1).")),mre=R("editorIndentGuide.background2",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorIndentGuides2","Color of the editor indentation guides (2).")),_re=R("editorIndentGuide.background3",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorIndentGuides3","Color of the editor indentation guides (3).")),vre=R("editorIndentGuide.background4",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorIndentGuides4","Color of the editor indentation guides (4).")),bre=R("editorIndentGuide.background5",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorIndentGuides5","Color of the editor indentation guides (5).")),Cre=R("editorIndentGuide.background6",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorIndentGuides6","Color of the editor indentation guides (6).")),fC=R("editorIndentGuide.activeBackground1",{dark:p1,light:p1,hcDark:p1,hcLight:p1},p("editorActiveIndentGuide1","Color of the active editor indentation guides (1).")),wre=R("editorIndentGuide.activeBackground2",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorActiveIndentGuide2","Color of the active editor indentation guides (2).")),Sre=R("editorIndentGuide.activeBackground3",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorActiveIndentGuide3","Color of the active editor indentation guides (3).")),yre=R("editorIndentGuide.activeBackground4",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorActiveIndentGuide4","Color of the active editor indentation guides (4).")),Lre=R("editorIndentGuide.activeBackground5",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorActiveIndentGuide5","Color of the active editor indentation guides (5).")),xre=R("editorIndentGuide.activeBackground6",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorActiveIndentGuide6","Color of the active editor indentation guides (6).")),m1=R("editorActiveLineNumber.foreground",{dark:"#c6c6c6",light:"#0B216F",hcDark:ai,hcLight:ai},p("editorActiveLineNumber","Color of editor active line number"),!1,p("deprecatedEditorActiveLineNumber","Id is deprecated. Use 'editorLineNumber.activeForeground' instead."));R("editorLineNumber.activeForeground",{dark:m1,light:m1,hcDark:m1,hcLight:m1},p("editorActiveLineNumber","Color of editor active line number"));const Dre=R("editorLineNumber.dimmedForeground",{dark:null,light:null,hcDark:null,hcLight:null},p("editorDimmedLineNumber","Color of the final editor line when editor.renderFinalNewline is set to dimmed."));R("editorRuler.foreground",{dark:"#5A5A5A",light:G.lightgrey,hcDark:G.white,hcLight:"#292929"},p("editorRuler","Color of the editor rulers."));R("editorCodeLens.foreground",{dark:"#999999",light:"#919191",hcDark:"#999999",hcLight:"#292929"},p("editorCodeLensForeground","Foreground color of editor CodeLens"));R("editorBracketMatch.background",{dark:"#0064001a",light:"#0064001a",hcDark:"#0064001a",hcLight:"#0000"},p("editorBracketMatchBackground","Background color behind matching brackets"));R("editorBracketMatch.border",{dark:"#888",light:"#B9B9B9",hcDark:pt,hcLight:pt},p("editorBracketMatchBorder","Color for matching brackets boxes"));const kre=R("editorOverviewRuler.border",{dark:"#7f7f7f4d",light:"#7f7f7f4d",hcDark:"#7f7f7f4d",hcLight:"#666666"},p("editorOverviewRulerBorder","Color of the overview ruler border.")),Ire=R("editorOverviewRuler.background",null,p("editorOverviewRulerBackground","Background color of the editor overview ruler."));R("editorGutter.background",{dark:bn,light:bn,hcDark:bn,hcLight:bn},p("editorGutter","Background color of the editor gutter. The gutter contains the glyph margins and the line numbers."));R("editorUnnecessaryCode.border",{dark:null,light:null,hcDark:G.fromHex("#fff").transparent(.8),hcLight:pt},p("unnecessaryCodeBorder","Border color of unnecessary (unused) source code in the editor."));const Ere=R("editorUnnecessaryCode.opacity",{dark:G.fromHex("#000a"),light:G.fromHex("#0007"),hcDark:null,hcLight:null},p("unnecessaryCodeOpacity",`Opacity of unnecessary (unused) source code in the editor. For example, "#000000c0" will render the code with 75% opacity. For high contrast themes, use the  'editorUnnecessaryCode.border' theme color to underline unnecessary code instead of fading it out.`));R("editorGhostText.border",{dark:null,light:null,hcDark:G.fromHex("#fff").transparent(.8),hcLight:G.fromHex("#292929").transparent(.8)},p("editorGhostTextBorder","Border color of ghost text in the editor."));R("editorGhostText.foreground",{dark:G.fromHex("#ffffff56"),light:G.fromHex("#0007"),hcDark:null,hcLight:null},p("editorGhostTextForeground","Foreground color of the ghost text in the editor."));R("editorGhostText.background",{dark:null,light:null,hcDark:null,hcLight:null},p("editorGhostTextBackground","Background color of the ghost text in the editor."));const _1=new G(new vt(0,122,204,.6)),xH=R("editorOverviewRuler.rangeHighlightForeground",{dark:_1,light:_1,hcDark:_1,hcLight:_1},p("overviewRulerRangeHighlight","Overview ruler marker color for range highlights. The color must not be opaque so as not to hide underlying decorations."),!0),Nre=R("editorOverviewRuler.errorForeground",{dark:new G(new vt(255,18,18,.7)),light:new G(new vt(255,18,18,.7)),hcDark:new G(new vt(255,50,50,1)),hcLight:"#B5200D"},p("overviewRuleError","Overview ruler marker color for errors.")),Tre=R("editorOverviewRuler.warningForeground",{dark:Yo,light:Yo,hcDark:H0,hcLight:H0},p("overviewRuleWarning","Overview ruler marker color for warnings.")),Mre=R("editorOverviewRuler.infoForeground",{dark:Xs,light:Xs,hcDark:z0,hcLight:z0},p("overviewRuleInfo","Overview ruler marker color for infos.")),DH=R("editorBracketHighlight.foreground1",{dark:"#FFD700",light:"#0431FAFF",hcDark:"#FFD700",hcLight:"#0431FAFF"},p("editorBracketHighlightForeground1","Foreground color of brackets (1). Requires enabling bracket pair colorization.")),kH=R("editorBracketHighlight.foreground2",{dark:"#DA70D6",light:"#319331FF",hcDark:"#DA70D6",hcLight:"#319331FF"},p("editorBracketHighlightForeground2","Foreground color of brackets (2). Requires enabling bracket pair colorization.")),IH=R("editorBracketHighlight.foreground3",{dark:"#179FFF",light:"#7B3814FF",hcDark:"#87CEFA",hcLight:"#7B3814FF"},p("editorBracketHighlightForeground3","Foreground color of brackets (3). Requires enabling bracket pair colorization.")),EH=R("editorBracketHighlight.foreground4",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketHighlightForeground4","Foreground color of brackets (4). Requires enabling bracket pair colorization.")),NH=R("editorBracketHighlight.foreground5",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketHighlightForeground5","Foreground color of brackets (5). Requires enabling bracket pair colorization.")),TH=R("editorBracketHighlight.foreground6",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketHighlightForeground6","Foreground color of brackets (6). Requires enabling bracket pair colorization.")),Rre=R("editorBracketHighlight.unexpectedBracket.foreground",{dark:new G(new vt(255,18,18,.8)),light:new G(new vt(255,18,18,.8)),hcDark:new G(new vt(255,50,50,1)),hcLight:""},p("editorBracketHighlightUnexpectedBracketForeground","Foreground color of unexpected brackets.")),Are=R("editorBracketPairGuide.background1",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.background1","Background color of inactive bracket pair guides (1). Requires enabling bracket pair guides.")),Pre=R("editorBracketPairGuide.background2",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.background2","Background color of inactive bracket pair guides (2). Requires enabling bracket pair guides.")),Ore=R("editorBracketPairGuide.background3",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.background3","Background color of inactive bracket pair guides (3). Requires enabling bracket pair guides.")),Fre=R("editorBracketPairGuide.background4",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.background4","Background color of inactive bracket pair guides (4). Requires enabling bracket pair guides.")),Bre=R("editorBracketPairGuide.background5",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.background5","Background color of inactive bracket pair guides (5). Requires enabling bracket pair guides.")),Wre=R("editorBracketPairGuide.background6",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.background6","Background color of inactive bracket pair guides (6). Requires enabling bracket pair guides.")),Vre=R("editorBracketPairGuide.activeBackground1",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.activeBackground1","Background color of active bracket pair guides (1). Requires enabling bracket pair guides.")),Hre=R("editorBracketPairGuide.activeBackground2",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.activeBackground2","Background color of active bracket pair guides (2). Requires enabling bracket pair guides.")),zre=R("editorBracketPairGuide.activeBackground3",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.activeBackground3","Background color of active bracket pair guides (3). Requires enabling bracket pair guides.")),Ure=R("editorBracketPairGuide.activeBackground4",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.activeBackground4","Background color of active bracket pair guides (4). Requires enabling bracket pair guides.")),$re=R("editorBracketPairGuide.activeBackground5",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.activeBackground5","Background color of active bracket pair guides (5). Requires enabling bracket pair guides.")),jre=R("editorBracketPairGuide.activeBackground6",{dark:"#00000000",light:"#00000000",hcDark:"#00000000",hcLight:"#00000000"},p("editorBracketPairGuide.activeBackground6","Background color of active bracket pair guides (6). Requires enabling bracket pair guides."));R("editorUnicodeHighlight.border",{dark:"#BD9B03",light:"#CEA33D",hcDark:"#ff0000",hcLight:"#CEA33D"},p("editorUnicodeHighlight.border","Border color used to highlight unicode characters."));R("editorUnicodeHighlight.background",{dark:"#bd9b0326",light:"#cea33d14",hcDark:"#00000000",hcLight:"#cea33d14"},p("editorUnicodeHighlight.background","Background color used to highlight unicode characters."));ia((s,e)=>{const t=s.getColor(bn),i=s.getColor(yH),n=i&&!i.isTransparent()?i:t;n&&e.addRule(`.monaco-editor .inputarea.ime-input { background-color: ${n}; }`)});class pC extends df{constructor(e){super(),this._context=e,this._readConfig(),this._lastCursorModelPosition=new H(1,1),this._renderResult=null,this._activeLineNumber=1,this._context.addEventHandler(this)}_readConfig(){const e=this._context.configuration.options;this._lineHeight=e.get(66);const t=e.get(67);this._renderLineNumbers=t.renderType,this._renderCustomLineNumbers=t.renderFn,this._renderFinalNewline=e.get(94);const i=e.get(143);this._lineNumbersLeft=i.lineNumbersLeft,this._lineNumbersWidth=i.lineNumbersWidth}dispose(){this._context.removeEventHandler(this),this._renderResult=null,super.dispose()}onConfigurationChanged(e){return this._readConfig(),!0}onCursorStateChanged(e){const t=e.selections[0].getPosition();this._lastCursorModelPosition=this._context.viewModel.coordinatesConverter.convertViewPositionToModelPosition(t);let i=!1;return this._activeLineNumber!==t.lineNumber&&(this._activeLineNumber=t.lineNumber,i=!0),(this._renderLineNumbers===2||this._renderLineNumbers===3)&&(i=!0),i}onFlushed(e){return!0}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return e.scrollTopChanged}onZonesChanged(e){return!0}_getLineRenderLineNumber(e){const t=this._context.viewModel.coordinatesConverter.convertViewPositionToModelPosition(new H(e,1));if(t.column!==1)return"";const i=t.lineNumber;if(this._renderCustomLineNumbers)return this._renderCustomLineNumbers(i);if(this._renderLineNumbers===2){const n=Math.abs(this._lastCursorModelPosition.lineNumber-i);return n===0?'<span class="relative-current-line-number">'+i+"</span>":String(n)}return this._renderLineNumbers===3?this._lastCursorModelPosition.lineNumber===i||i%10===0?String(i):"":String(i)}prepareRender(e){if(this._renderLineNumbers===0){this._renderResult=null;return}const t=Ss?this._lineHeight%2===0?" lh-even":" lh-odd":"",i=e.visibleRange.startLineNumber,n=e.visibleRange.endLineNumber,o=this._context.viewModel.getLineCount(),r=[];for(let a=i;a<=n;a++){const l=a-i,d=this._getLineRenderLineNumber(a);if(!d){r[l]="";continue}let c="";if(a===o&&this._context.viewModel.getLineLength(a)===0){if(this._renderFinalNewline==="off"){r[l]="";continue}this._renderFinalNewline==="dimmed"&&(c=" dimmed-line-number")}a===this._activeLineNumber&&(c=" active-line-number"),r[l]=`<div class="${pC.CLASS_NAME}${t}${c}" style="left:${this._lineNumbersLeft}px;width:${this._lineNumbersWidth}px;">${d}</div>`}this._renderResult=r}render(e,t){if(!this._renderResult)return"";const i=t-e;return i<0||i>=this._renderResult.length?"":this._renderResult[i]}}pC.CLASS_NAME="line-numbers";ia((s,e)=>{const t=s.getColor(pre),i=s.getColor(Dre);i?e.addRule(`.monaco-editor .line-numbers.dimmed-line-number { color: ${i}; }`):t&&e.addRule(`.monaco-editor .line-numbers.dimmed-line-number { color: ${t.transparent(.4)}; }`)});class Mg extends Eo{constructor(e){super(e);const t=this._context.configuration.options,i=t.get(143);this._canUseLayerHinting=!t.get(32),this._contentLeft=i.contentLeft,this._glyphMarginLeft=i.glyphMarginLeft,this._glyphMarginWidth=i.glyphMarginWidth,this._domNode=Mt(document.createElement("div")),this._domNode.setClassName(Mg.OUTER_CLASS_NAME),this._domNode.setPosition("absolute"),this._domNode.setAttribute("role","presentation"),this._domNode.setAttribute("aria-hidden","true"),this._glyphMarginBackgroundDomNode=Mt(document.createElement("div")),this._glyphMarginBackgroundDomNode.setClassName(Mg.CLASS_NAME),this._domNode.appendChild(this._glyphMarginBackgroundDomNode)}dispose(){super.dispose()}getDomNode(){return this._domNode}onConfigurationChanged(e){const t=this._context.configuration.options,i=t.get(143);return this._canUseLayerHinting=!t.get(32),this._contentLeft=i.contentLeft,this._glyphMarginLeft=i.glyphMarginLeft,this._glyphMarginWidth=i.glyphMarginWidth,!0}onScrollChanged(e){return super.onScrollChanged(e)||e.scrollTopChanged}prepareRender(e){}render(e){this._domNode.setLayerHinting(this._canUseLayerHinting),this._domNode.setContain("strict");const t=e.scrollTop-e.bigNumbersDelta;this._domNode.setTop(-t);const i=Math.min(e.scrollHeight,1e6);this._domNode.setHeight(i),this._domNode.setWidth(this._contentLeft),this._glyphMarginBackgroundDomNode.setLeft(this._glyphMarginLeft),this._glyphMarginBackgroundDomNode.setWidth(this._glyphMarginWidth),this._glyphMarginBackgroundDomNode.setHeight(i)}}Mg.CLASS_NAME="glyph-margin";Mg.OUTER_CLASS_NAME="margin";const Vp="monaco-mouse-cursor-text";class Kre{constructor(){this._onDidChange=new W,this.onDidChange=this._onDidChange.event,this._enabled=!0}get enabled(){return this._enabled}enable(){this._enabled=!0,this._onDidChange.fire()}disable(){this._enabled=!1,this._onDidChange.fire()}}const Fv=new Kre,qt=ut("keybindingService");var qre=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},F3=function(s,e){return function(t,i){e(t,i,s)}};class Gre{constructor(e,t,i,n,o){this._context=e,this.modelLineNumber=t,this.distanceToModelLineStart=i,this.widthOfHiddenLineTextBefore=n,this.distanceToModelLineEnd=o,this._visibleTextAreaBrand=void 0,this.startPosition=null,this.endPosition=null,this.visibleTextareaStart=null,this.visibleTextareaEnd=null,this._previousPresentation=null}prepareRender(e){const t=new H(this.modelLineNumber,this.distanceToModelLineStart+1),i=new H(this.modelLineNumber,this._context.viewModel.model.getLineMaxColumn(this.modelLineNumber)-this.distanceToModelLineEnd);this.startPosition=this._context.viewModel.coordinatesConverter.convertModelPositionToViewPosition(t),this.endPosition=this._context.viewModel.coordinatesConverter.convertModelPositionToViewPosition(i),this.startPosition.lineNumber===this.endPosition.lineNumber?(this.visibleTextareaStart=e.visibleRangeForPosition(this.startPosition),this.visibleTextareaEnd=e.visibleRangeForPosition(this.endPosition)):(this.visibleTextareaStart=null,this.visibleTextareaEnd=null)}definePresentation(e){return this._previousPresentation||(e?this._previousPresentation=e:this._previousPresentation={foreground:1,italic:!1,bold:!1,underline:!1,strikethrough:!1}),this._previousPresentation}}const sI=yr;let wT=class extends Eo{constructor(e,t,i,n,o){super(e),this._keybindingService=n,this._instantiationService=o,this._primaryCursorPosition=new H(1,1),this._primaryCursorVisibleRange=null,this._viewController=t,this._visibleRangeProvider=i,this._scrollLeft=0,this._scrollTop=0;const r=this._context.configuration.options,a=r.get(143);this._setAccessibilityOptions(r),this._contentLeft=a.contentLeft,this._contentWidth=a.contentWidth,this._contentHeight=a.height,this._fontInfo=r.get(50),this._lineHeight=r.get(66),this._emptySelectionClipboard=r.get(37),this._copyWithSyntaxHighlighting=r.get(25),this._visibleTextArea=null,this._selections=[new De(1,1,1,1)],this._modelSelections=[new De(1,1,1,1)],this._lastRenderPosition=null,this.textArea=Mt(document.createElement("textarea")),Zl.write(this.textArea,6),this.textArea.setClassName(`inputarea ${Vp}`),this.textArea.setAttribute("wrap",this._textAreaWrapping&&!this._visibleTextArea?"on":"off");const{tabSize:l}=this._context.viewModel.model.getOptions();this.textArea.domNode.style.tabSize=`${l*this._fontInfo.spaceWidth}px`,this.textArea.setAttribute("autocorrect","off"),this.textArea.setAttribute("autocapitalize","off"),this.textArea.setAttribute("autocomplete","off"),this.textArea.setAttribute("spellcheck","false"),this.textArea.setAttribute("aria-label",this._getAriaLabel(r)),this.textArea.setAttribute("aria-required",r.get(5)?"true":"false"),this.textArea.setAttribute("tabindex",String(r.get(123))),this.textArea.setAttribute("role","textbox"),this.textArea.setAttribute("aria-roledescription",p("editor","editor")),this.textArea.setAttribute("aria-multiline","true"),this.textArea.setAttribute("aria-autocomplete",r.get(90)?"none":"both"),this._ensureReadOnlyAttribute(),this.textAreaCover=Mt(document.createElement("div")),this.textAreaCover.setPosition("absolute");const d={getLineCount:()=>this._context.viewModel.getLineCount(),getLineMaxColumn:h=>this._context.viewModel.getLineMaxColumn(h),getValueInRange:(h,g)=>this._context.viewModel.getValueInRange(h,g),getValueLengthInRange:(h,g)=>this._context.viewModel.getValueLengthInRange(h,g),modifyPosition:(h,g)=>this._context.viewModel.modifyPosition(h,g)},c={getDataToCopy:()=>{const h=this._context.viewModel.getPlainTextToCopy(this._modelSelections,this._emptySelectionClipboard,es),g=this._context.viewModel.model.getEOL(),f=this._emptySelectionClipboard&&this._modelSelections.length===1&&this._modelSelections[0].isEmpty(),m=Array.isArray(h)?h:null,_=Array.isArray(h)?h.join(g):h;let v,b=null;if(_T.forceCopyWithSyntaxHighlighting||this._copyWithSyntaxHighlighting&&_.length<65536){const C=this._context.viewModel.getRichTextToCopy(this._modelSelections,this._emptySelectionClipboard);C&&(v=C.html,b=C.mode)}return{isFromEmptySelection:f,multicursorText:m,text:_,html:v,mode:b}},getScreenReaderContent:()=>{if(this._accessibilitySupport===1){const h=this._selections[0];if(bt&&h.isEmpty()){const f=h.getStartPosition();let m=this._getWordBeforePosition(f);if(m.length===0&&(m=this._getCharacterBeforePosition(f)),m.length>0)return new Rn(m,m.length,m.length,D.fromPositions(f),0)}if(bt&&!h.isEmpty()&&d.getValueLengthInRange(h,0)<500){const f=d.getValueInRange(h,0);return new Rn(f,0,f.length,h,0)}if(Jd&&!h.isEmpty()){const f="vscode-placeholder";return new Rn(f,0,f.length,null,void 0)}return Rn.EMPTY}if(l5){const h=this._selections[0];if(h.isEmpty()){const g=h.getStartPosition(),[f,m]=this._getAndroidWordAtPosition(g);if(f.length>0)return new Rn(f,m,m,D.fromPositions(g),0)}return Rn.EMPTY}return fp.fromEditorSelection(d,this._selections[0],this._accessibilityPageSize,this._accessibilitySupport===0)},deduceModelPosition:(h,g,f)=>this._context.viewModel.deduceModelPositionRelativeToViewPosition(h,g,f)},u=this._register(new lre(this.textArea.domNode));this._textAreaInput=this._register(this._instantiationService.createInstance(vT,c,u,Go,{isAndroid:l5,isChrome:UA,isFirefox:yr,isSafari:Jd})),this._register(this._textAreaInput.onKeyDown(h=>{this._viewController.emitKeyDown(h)})),this._register(this._textAreaInput.onKeyUp(h=>{this._viewController.emitKeyUp(h)})),this._register(this._textAreaInput.onPaste(h=>{let g=!1,f=null,m=null;h.metadata&&(g=this._emptySelectionClipboard&&!!h.metadata.isFromEmptySelection,f=typeof h.metadata.multicursorText<"u"?h.metadata.multicursorText:null,m=h.metadata.mode),this._viewController.paste(h.text,g,f,m)})),this._register(this._textAreaInput.onCut(()=>{this._viewController.cut()})),this._register(this._textAreaInput.onType(h=>{h.replacePrevCharCnt||h.replaceNextCharCnt||h.positionDelta?this._viewController.compositionType(h.text,h.replacePrevCharCnt,h.replaceNextCharCnt,h.positionDelta):this._viewController.type(h.text)})),this._register(this._textAreaInput.onSelectionChangeRequest(h=>{this._viewController.setSelection(h)})),this._register(this._textAreaInput.onCompositionStart(h=>{const g=this.textArea.domNode,f=this._modelSelections[0],{distanceToModelLineStart:m,widthOfHiddenTextBefore:_}=(()=>{const b=g.value.substring(0,Math.min(g.selectionStart,g.selectionEnd)),C=b.lastIndexOf(`
`),w=b.substring(C+1),S=w.lastIndexOf("	"),x=w.length-S-1,L=f.getStartPosition(),k=Math.min(L.column-1,x),I=L.column-1-k,P=w.substring(0,w.length-k),{tabSize:$}=this._context.viewModel.model.getOptions(),A=Zre(this.textArea.domNode.ownerDocument,P,this._fontInfo,$);return{distanceToModelLineStart:I,widthOfHiddenTextBefore:A}})(),{distanceToModelLineEnd:v}=(()=>{const b=g.value.substring(Math.max(g.selectionStart,g.selectionEnd)),C=b.indexOf(`
`),w=C===-1?b:b.substring(0,C),S=w.indexOf("	"),x=S===-1?w.length:w.length-S-1,L=f.getEndPosition(),k=Math.min(this._context.viewModel.model.getLineMaxColumn(L.lineNumber)-L.column,x);return{distanceToModelLineEnd:this._context.viewModel.model.getLineMaxColumn(L.lineNumber)-L.column-k}})();this._context.viewModel.revealRange("keyboard",!0,D.fromPositions(this._selections[0].getStartPosition()),0,1),this._visibleTextArea=new Gre(this._context,f.startLineNumber,m,_,v),this.textArea.setAttribute("wrap",this._textAreaWrapping&&!this._visibleTextArea?"on":"off"),this._visibleTextArea.prepareRender(this._visibleRangeProvider),this._render(),this.textArea.setClassName(`inputarea ${Vp} ime-input`),this._viewController.compositionStart(),this._context.viewModel.onCompositionStart()})),this._register(this._textAreaInput.onCompositionUpdate(h=>{this._visibleTextArea&&(this._visibleTextArea.prepareRender(this._visibleRangeProvider),this._render())})),this._register(this._textAreaInput.onCompositionEnd(()=>{this._visibleTextArea=null,this.textArea.setAttribute("wrap",this._textAreaWrapping&&!this._visibleTextArea?"on":"off"),this._render(),this.textArea.setClassName(`inputarea ${Vp}`),this._viewController.compositionEnd(),this._context.viewModel.onCompositionEnd()})),this._register(this._textAreaInput.onFocus(()=>{this._context.viewModel.setHasFocus(!0)})),this._register(this._textAreaInput.onBlur(()=>{this._context.viewModel.setHasFocus(!1)})),this._register(Fv.onDidChange(()=>{this._ensureReadOnlyAttribute()}))}writeScreenReaderContent(e){this._textAreaInput.writeNativeTextAreaContent(e)}dispose(){super.dispose()}_getAndroidWordAtPosition(e){const t='`~!@#$%^&*()-=+[{]}\\|;:",.<>/?',i=this._context.viewModel.getLineContent(e.lineNumber),n=xr(t);let o=!0,r=e.column,a=!0,l=e.column,d=0;for(;d<50&&(o||a);){if(o&&r<=1&&(o=!1),o){const c=i.charCodeAt(r-2);n.get(c)!==0?o=!1:r--}if(a&&l>i.length&&(a=!1),a){const c=i.charCodeAt(l-1);n.get(c)!==0?a=!1:l++}d++}return[i.substring(r-1,l-1),e.column-r]}_getWordBeforePosition(e){const t=this._context.viewModel.getLineContent(e.lineNumber),i=xr(this._context.configuration.options.get(129));let n=e.column,o=0;for(;n>1;){const r=t.charCodeAt(n-2);if(i.get(r)!==0||o>50)return t.substring(n-1,e.column-1);o++,n--}return t.substring(0,e.column-1)}_getCharacterBeforePosition(e){if(e.column>1){const i=this._context.viewModel.getLineContent(e.lineNumber).charAt(e.column-2);if(!_n(i.charCodeAt(0)))return i}return""}_getAriaLabel(e){var t,i,n;if(e.get(2)===1){const r=(t=this._keybindingService.lookupKeybinding("editor.action.toggleScreenReaderAccessibilityMode"))===null||t===void 0?void 0:t.getAriaLabel(),a=(i=this._keybindingService.lookupKeybinding("workbench.action.showCommands"))===null||i===void 0?void 0:i.getAriaLabel(),l=(n=this._keybindingService.lookupKeybinding("workbench.action.openGlobalKeybindings"))===null||n===void 0?void 0:n.getAriaLabel(),d=p("accessibilityModeOff","The editor is not accessible at this time.");return r?p("accessibilityOffAriaLabel","{0} To enable screen reader optimized mode, use {1}",d,r):a?p("accessibilityOffAriaLabelNoKb","{0} To enable screen reader optimized mode, open the quick pick with {1} and run the command Toggle Screen Reader Accessibility Mode, which is currently not triggerable via keyboard.",d,a):l?p("accessibilityOffAriaLabelNoKbs","{0} Please assign a keybinding for the command Toggle Screen Reader Accessibility Mode by accessing the keybindings editor with {1} and run it.",d,l):d}return e.get(4)}_setAccessibilityOptions(e){this._accessibilitySupport=e.get(2);const t=e.get(3);this._accessibilitySupport===2&&t===ja.accessibilityPageSize.defaultValue?this._accessibilityPageSize=500:this._accessibilityPageSize=t;const n=e.get(143).wrappingColumn;if(n!==-1&&this._accessibilitySupport!==1){const o=e.get(50);this._textAreaWrapping=!0,this._textAreaWidth=Math.round(n*o.typicalHalfwidthCharacterWidth)}else this._textAreaWrapping=!1,this._textAreaWidth=sI?0:1}onConfigurationChanged(e){const t=this._context.configuration.options,i=t.get(143);this._setAccessibilityOptions(t),this._contentLeft=i.contentLeft,this._contentWidth=i.contentWidth,this._contentHeight=i.height,this._fontInfo=t.get(50),this._lineHeight=t.get(66),this._emptySelectionClipboard=t.get(37),this._copyWithSyntaxHighlighting=t.get(25),this.textArea.setAttribute("wrap",this._textAreaWrapping&&!this._visibleTextArea?"on":"off");const{tabSize:n}=this._context.viewModel.model.getOptions();return this.textArea.domNode.style.tabSize=`${n*this._fontInfo.spaceWidth}px`,this.textArea.setAttribute("aria-label",this._getAriaLabel(t)),this.textArea.setAttribute("aria-required",t.get(5)?"true":"false"),this.textArea.setAttribute("tabindex",String(t.get(123))),(e.hasChanged(34)||e.hasChanged(90))&&this._ensureReadOnlyAttribute(),e.hasChanged(2)&&this._textAreaInput.writeNativeTextAreaContent("strategy changed"),!0}onCursorStateChanged(e){return this._selections=e.selections.slice(0),this._modelSelections=e.modelSelections.slice(0),this._textAreaInput.writeNativeTextAreaContent("selection changed"),!0}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return this._scrollLeft=e.scrollLeft,this._scrollTop=e.scrollTop,!0}onZonesChanged(e){return!0}isFocused(){return this._textAreaInput.isFocused()}focusTextArea(){this._textAreaInput.focusTextArea()}getLastRenderData(){return this._lastRenderPosition}setAriaOptions(e){e.activeDescendant?(this.textArea.setAttribute("aria-haspopup","true"),this.textArea.setAttribute("aria-autocomplete","list"),this.textArea.setAttribute("aria-activedescendant",e.activeDescendant)):(this.textArea.setAttribute("aria-haspopup","false"),this.textArea.setAttribute("aria-autocomplete","both"),this.textArea.removeAttribute("aria-activedescendant")),e.role&&this.textArea.setAttribute("role",e.role)}_ensureReadOnlyAttribute(){const e=this._context.configuration.options;!Fv.enabled||e.get(34)&&e.get(90)?this.textArea.setAttribute("readonly","true"):this.textArea.removeAttribute("readonly")}prepareRender(e){var t;this._primaryCursorPosition=new H(this._selections[0].positionLineNumber,this._selections[0].positionColumn),this._primaryCursorVisibleRange=e.visibleRangeForPosition(this._primaryCursorPosition),(t=this._visibleTextArea)===null||t===void 0||t.prepareRender(e)}render(e){this._textAreaInput.writeNativeTextAreaContent("render"),this._render()}_render(){var e;if(this._visibleTextArea){const n=this._visibleTextArea.visibleTextareaStart,o=this._visibleTextArea.visibleTextareaEnd,r=this._visibleTextArea.startPosition,a=this._visibleTextArea.endPosition;if(r&&a&&n&&o&&o.left>=this._scrollLeft&&n.left<=this._scrollLeft+this._contentWidth){const l=this._context.viewLayout.getVerticalOffsetForLineNumber(this._primaryCursorPosition.lineNumber)-this._scrollTop,d=this._newlinecount(this.textArea.domNode.value.substr(0,this.textArea.domNode.selectionStart));let c=this._visibleTextArea.widthOfHiddenLineTextBefore,u=this._contentLeft+n.left-this._scrollLeft,h=o.left-n.left+1;if(u<this._contentLeft){const b=this._contentLeft-u;u+=b,c+=b,h-=b}h>this._contentWidth&&(h=this._contentWidth);const g=this._context.viewModel.getViewLineData(r.lineNumber),f=g.tokens.findTokenIndexAtOffset(r.column-1),m=g.tokens.findTokenIndexAtOffset(a.column-1),_=f===m,v=this._visibleTextArea.definePresentation(_?g.tokens.getPresentation(f):null);this.textArea.domNode.scrollTop=d*this._lineHeight,this.textArea.domNode.scrollLeft=c,this._doRender({lastRenderPosition:null,top:l,left:u,width:h,height:this._lineHeight,useCover:!1,color:(xi.getColorMap()||[])[v.foreground],italic:v.italic,bold:v.bold,underline:v.underline,strikethrough:v.strikethrough})}return}if(!this._primaryCursorVisibleRange){this._renderAtTopLeft();return}const t=this._contentLeft+this._primaryCursorVisibleRange.left-this._scrollLeft;if(t<this._contentLeft||t>this._contentLeft+this._contentWidth){this._renderAtTopLeft();return}const i=this._context.viewLayout.getVerticalOffsetForLineNumber(this._selections[0].positionLineNumber)-this._scrollTop;if(i<0||i>this._contentHeight){this._renderAtTopLeft();return}if(bt||this._accessibilitySupport===2){this._doRender({lastRenderPosition:this._primaryCursorPosition,top:i,left:this._textAreaWrapping?this._contentLeft:t,width:this._textAreaWidth,height:this._lineHeight,useCover:!1}),this.textArea.domNode.scrollLeft=this._primaryCursorVisibleRange.left;const n=(e=this._textAreaInput.textAreaState.newlineCountBeforeSelection)!==null&&e!==void 0?e:this._newlinecount(this.textArea.domNode.value.substr(0,this.textArea.domNode.selectionStart));this.textArea.domNode.scrollTop=n*this._lineHeight;return}this._doRender({lastRenderPosition:this._primaryCursorPosition,top:i,left:this._textAreaWrapping?this._contentLeft:t,width:this._textAreaWidth,height:sI?0:1,useCover:!1})}_newlinecount(e){let t=0,i=-1;do{if(i=e.indexOf(`
`,i+1),i===-1)break;t++}while(!0);return t}_renderAtTopLeft(){this._doRender({lastRenderPosition:null,top:0,left:0,width:this._textAreaWidth,height:sI?0:1,useCover:!0})}_doRender(e){this._lastRenderPosition=e.lastRenderPosition;const t=this.textArea,i=this.textAreaCover;Xn(t,this._fontInfo),t.setTop(e.top),t.setLeft(e.left),t.setWidth(e.width),t.setHeight(e.height),t.setColor(e.color?G.Format.CSS.formatHex(e.color):""),t.setFontStyle(e.italic?"italic":""),e.bold&&t.setFontWeight("bold"),t.setTextDecoration(`${e.underline?" underline":""}${e.strikethrough?" line-through":""}`),i.setTop(e.useCover?e.top:0),i.setLeft(e.useCover?e.left:0),i.setWidth(e.useCover?e.width:0),i.setHeight(e.useCover?e.height:0);const n=this._context.configuration.options;n.get(57)?i.setClassName("monaco-editor-background textAreaCover "+Mg.OUTER_CLASS_NAME):n.get(67).renderType!==0?i.setClassName("monaco-editor-background textAreaCover "+pC.CLASS_NAME):i.setClassName("monaco-editor-background textAreaCover")}};wT=qre([F3(3,qt),F3(4,We)],wT);function Zre(s,e,t,i){if(e.length===0)return 0;const n=s.createElement("div");n.style.position="absolute",n.style.top="-50000px",n.style.width="50000px";const o=s.createElement("span");Xn(o,t),o.style.whiteSpace="pre",o.style.tabSize=`${i*t.spaceWidth}px`,o.append(e),n.appendChild(o),s.body.appendChild(n);const r=o.offsetWidth;return s.body.removeChild(n),r}function Yre(s,e,t){let i=0;for(let o=0;o<s.length;o++)s.charAt(o)==="	"?i=hn.nextIndentTabStop(i,e):i++;let n="";if(!t){const o=Math.floor(i/e);i=i%e;for(let r=0;r<o;r++)n+="	"}for(let o=0;o<i;o++)n+=" ";return n}function JS(s,e,t){let i=ws(s);return i===-1&&(i=s.length),Yre(s.substring(0,i),e,t)+s.substring(i)}const Xre=()=>!0,Qre=()=>!1,Jre=s=>s===" "||s==="	";class Ef{static shouldRecreate(e){return e.hasChanged(143)||e.hasChanged(129)||e.hasChanged(37)||e.hasChanged(76)||e.hasChanged(78)||e.hasChanged(79)||e.hasChanged(6)||e.hasChanged(7)||e.hasChanged(11)||e.hasChanged(9)||e.hasChanged(10)||e.hasChanged(14)||e.hasChanged(127)||e.hasChanged(50)||e.hasChanged(90)}constructor(e,t,i,n){var o;this.languageConfigurationService=n,this._cursorMoveConfigurationBrand=void 0,this._languageId=e;const r=i.options,a=r.get(143),l=r.get(50);this.readOnly=r.get(90),this.tabSize=t.tabSize,this.indentSize=t.indentSize,this.insertSpaces=t.insertSpaces,this.stickyTabStops=r.get(115),this.lineHeight=l.lineHeight,this.typicalHalfwidthCharacterWidth=l.typicalHalfwidthCharacterWidth,this.pageSize=Math.max(1,Math.floor(a.height/this.lineHeight)-2),this.useTabStops=r.get(127),this.wordSeparators=r.get(129),this.emptySelectionClipboard=r.get(37),this.copyWithSyntaxHighlighting=r.get(25),this.multiCursorMergeOverlapping=r.get(76),this.multiCursorPaste=r.get(78),this.multiCursorLimit=r.get(79),this.autoClosingBrackets=r.get(6),this.autoClosingComments=r.get(7),this.autoClosingQuotes=r.get(11),this.autoClosingDelete=r.get(9),this.autoClosingOvertype=r.get(10),this.autoSurround=r.get(14),this.autoIndent=r.get(12),this.surroundingPairs={},this._electricChars=null,this.shouldAutoCloseBefore={quote:this._getShouldAutoClose(e,this.autoClosingQuotes,!0),comment:this._getShouldAutoClose(e,this.autoClosingComments,!1),bracket:this._getShouldAutoClose(e,this.autoClosingBrackets,!1)},this.autoClosingPairs=this.languageConfigurationService.getLanguageConfiguration(e).getAutoClosingPairs();const d=this.languageConfigurationService.getLanguageConfiguration(e).getSurroundingPairs();if(d)for(const u of d)this.surroundingPairs[u.open]=u.close;const c=this.languageConfigurationService.getLanguageConfiguration(e).comments;this.blockCommentStartToken=(o=c==null?void 0:c.blockCommentStartToken)!==null&&o!==void 0?o:null}get electricChars(){var e;if(!this._electricChars){this._electricChars={};const t=(e=this.languageConfigurationService.getLanguageConfiguration(this._languageId).electricCharacter)===null||e===void 0?void 0:e.getElectricCharacters();if(t)for(const i of t)this._electricChars[i]=!0}return this._electricChars}onElectricCharacter(e,t,i){const n=hx(t,i-1),o=this.languageConfigurationService.getLanguageConfiguration(n.languageId).electricCharacter;return o?o.onElectricCharacter(e,n,i-n.firstCharOffset):null}normalizeIndentation(e){return JS(e,this.indentSize,this.insertSpaces)}_getShouldAutoClose(e,t,i){switch(t){case"beforeWhitespace":return Jre;case"languageDefined":return this._getLanguageDefinedShouldAutoClose(e,i);case"always":return Xre;case"never":return Qre}}_getLanguageDefinedShouldAutoClose(e,t){const i=this.languageConfigurationService.getLanguageConfiguration(e).getAutoCloseBeforeSet(t);return n=>i.indexOf(n)!==-1}visibleColumnFromColumn(e,t){return hn.visibleColumnFromColumn(e.getLineContent(t.lineNumber),t.column,this.tabSize)}columnFromVisibleColumn(e,t,i){const n=hn.columnFromVisibleColumn(e.getLineContent(t),i,this.tabSize),o=e.getLineMinColumn(t);if(n<o)return o;const r=e.getLineMaxColumn(t);return n>r?r:n}}let yt=class MH{static fromModelState(e){return new eae(e)}static fromViewState(e){return new tae(e)}static fromModelSelection(e){const t=De.liftSelection(e),i=new On(D.fromPositions(t.getSelectionStart()),0,0,t.getPosition(),0);return MH.fromModelState(i)}static fromModelSelections(e){const t=[];for(let i=0,n=e.length;i<n;i++)t[i]=this.fromModelSelection(e[i]);return t}constructor(e,t){this._cursorStateBrand=void 0,this.modelState=e,this.viewState=t}equals(e){return this.viewState.equals(e.viewState)&&this.modelState.equals(e.modelState)}};class eae{constructor(e){this.modelState=e,this.viewState=null}}class tae{constructor(e){this.modelState=null,this.viewState=e}}class On{constructor(e,t,i,n,o){this.selectionStart=e,this.selectionStartKind=t,this.selectionStartLeftoverVisibleColumns=i,this.position=n,this.leftoverVisibleColumns=o,this._singleCursorStateBrand=void 0,this.selection=On._computeSelection(this.selectionStart,this.position)}equals(e){return this.selectionStartLeftoverVisibleColumns===e.selectionStartLeftoverVisibleColumns&&this.leftoverVisibleColumns===e.leftoverVisibleColumns&&this.selectionStartKind===e.selectionStartKind&&this.position.equals(e.position)&&this.selectionStart.equalsRange(e.selectionStart)}hasSelection(){return!this.selection.isEmpty()||!this.selectionStart.isEmpty()}move(e,t,i,n){return e?new On(this.selectionStart,this.selectionStartKind,this.selectionStartLeftoverVisibleColumns,new H(t,i),n):new On(new D(t,i,t,i),0,n,new H(t,i),n)}static _computeSelection(e,t){return e.isEmpty()||!t.isBeforeOrEqual(e.getStartPosition())?De.fromPositions(e.getStartPosition(),t):De.fromPositions(e.getEndPosition(),t)}}class Us{constructor(e,t,i){this._editOperationResultBrand=void 0,this.type=e,this.commands=t,this.shouldPushStackElementBefore=i.shouldPushStackElementBefore,this.shouldPushStackElementAfter=i.shouldPushStackElementAfter}}function yc(s){return s==="'"||s==='"'||s==="`"}class Kh{static columnSelect(e,t,i,n,o,r){const a=Math.abs(o-i)+1,l=i>o,d=n>r,c=n<r,u=[];for(let h=0;h<a;h++){const g=i+(l?-h:h),f=e.columnFromVisibleColumn(t,g,n),m=e.columnFromVisibleColumn(t,g,r),_=e.visibleColumnFromColumn(t,new H(g,f)),v=e.visibleColumnFromColumn(t,new H(g,m));c&&(_>r||v<n)||d&&(v>n||_<r)||u.push(new On(new D(g,f,g,f),0,0,new H(g,m),0))}if(u.length===0)for(let h=0;h<a;h++){const g=i+(l?-h:h),f=t.getLineMaxColumn(g);u.push(new On(new D(g,f,g,f),0,0,new H(g,f),0))}return{viewStates:u,reversed:l,fromLineNumber:i,fromVisualColumn:n,toLineNumber:o,toVisualColumn:r}}static columnSelectLeft(e,t,i){let n=i.toViewVisualColumn;return n>0&&n--,Kh.columnSelect(e,t,i.fromViewLineNumber,i.fromViewVisualColumn,i.toViewLineNumber,n)}static columnSelectRight(e,t,i){let n=0;const o=Math.min(i.fromViewLineNumber,i.toViewLineNumber),r=Math.max(i.fromViewLineNumber,i.toViewLineNumber);for(let l=o;l<=r;l++){const d=t.getLineMaxColumn(l),c=e.visibleColumnFromColumn(t,new H(l,d));n=Math.max(n,c)}let a=i.toViewVisualColumn;return a<n&&a++,this.columnSelect(e,t,i.fromViewLineNumber,i.fromViewVisualColumn,i.toViewLineNumber,a)}static columnSelectUp(e,t,i,n){const o=n?e.pageSize:1,r=Math.max(1,i.toViewLineNumber-o);return this.columnSelect(e,t,i.fromViewLineNumber,i.fromViewVisualColumn,r,i.toViewVisualColumn)}static columnSelectDown(e,t,i,n){const o=n?e.pageSize:1,r=Math.min(t.getLineCount(),i.toViewLineNumber+o);return this.columnSelect(e,t,i.fromViewLineNumber,i.fromViewVisualColumn,r,i.toViewVisualColumn)}}class Kn{constructor(e,t,i=!1){this._range=e,this._text=t,this.insertsAutoWhitespace=i}getEditOperations(e,t){t.addTrackedEditOperation(this._range,this._text)}computeCursorState(e,t){const n=t.getInverseEditOperations()[0].range;return De.fromPositions(n.getEndPosition())}}class iae{constructor(e,t){this._range=e,this._text=t}getEditOperations(e,t){t.addTrackedEditOperation(this._range,this._text)}computeCursorState(e,t){const n=t.getInverseEditOperations()[0].range;return De.fromRange(n,0)}}class v1{constructor(e,t,i=!1){this._range=e,this._text=t,this.insertsAutoWhitespace=i}getEditOperations(e,t){t.addTrackedEditOperation(this._range,this._text)}computeCursorState(e,t){const n=t.getInverseEditOperations()[0].range;return De.fromPositions(n.getStartPosition())}}class Vw{constructor(e,t,i,n,o=!1){this._range=e,this._text=t,this._columnDeltaOffset=n,this._lineNumberDeltaOffset=i,this.insertsAutoWhitespace=o}getEditOperations(e,t){t.addTrackedEditOperation(this._range,this._text)}computeCursorState(e,t){const n=t.getInverseEditOperations()[0].range;return De.fromPositions(n.getEndPosition().delta(this._lineNumberDeltaOffset,this._columnDeltaOffset))}}class EP{constructor(e,t,i,n=!1){this._range=e,this._text=t,this._initialSelection=i,this._forceMoveMarkers=n,this._selectionId=null}getEditOperations(e,t){t.addTrackedEditOperation(this._range,this._text,this._forceMoveMarkers),this._selectionId=t.trackSelection(this._initialSelection)}computeCursorState(e,t){return t.getTrackedSelection(this._selectionId)}}class oI{constructor(e,t,i){this._cursorPositionBrand=void 0,this.lineNumber=e,this.column=t,this.leftoverVisibleColumns=i}}class Pt{static leftPosition(e,t){if(t.column>e.getLineMinColumn(t.lineNumber))return t.delta(void 0,-UW(e.getLineContent(t.lineNumber),t.column-1));if(t.lineNumber>1){const i=t.lineNumber-1;return new H(i,e.getLineMaxColumn(i))}else return t}static leftPositionAtomicSoftTabs(e,t,i){if(t.column<=e.getLineIndentColumn(t.lineNumber)){const n=e.getLineMinColumn(t.lineNumber),o=e.getLineContent(t.lineNumber),r=$0.atomicPosition(o,t.column-1,i,0);if(r!==-1&&r+1>=n)return new H(t.lineNumber,r+1)}return this.leftPosition(e,t)}static left(e,t,i){const n=e.stickyTabStops?Pt.leftPositionAtomicSoftTabs(t,i,e.tabSize):Pt.leftPosition(t,i);return new oI(n.lineNumber,n.column,0)}static moveLeft(e,t,i,n,o){let r,a;if(i.hasSelection()&&!n)r=i.selection.startLineNumber,a=i.selection.startColumn;else{const l=i.position.delta(void 0,-(o-1)),d=t.normalizePosition(Pt.clipPositionColumn(l,t),0),c=Pt.left(e,t,d);r=c.lineNumber,a=c.column}return i.move(n,r,a,0)}static clipPositionColumn(e,t){return new H(e.lineNumber,Pt.clipRange(e.column,t.getLineMinColumn(e.lineNumber),t.getLineMaxColumn(e.lineNumber)))}static clipRange(e,t,i){return e<t?t:e>i?i:e}static rightPosition(e,t,i){return i<e.getLineMaxColumn(t)?i=i+VA(e.getLineContent(t),i-1):t<e.getLineCount()&&(t=t+1,i=e.getLineMinColumn(t)),new H(t,i)}static rightPositionAtomicSoftTabs(e,t,i,n,o){if(i<e.getLineIndentColumn(t)){const r=e.getLineContent(t),a=$0.atomicPosition(r,i-1,n,1);if(a!==-1)return new H(t,a+1)}return this.rightPosition(e,t,i)}static right(e,t,i){const n=e.stickyTabStops?Pt.rightPositionAtomicSoftTabs(t,i.lineNumber,i.column,e.tabSize,e.indentSize):Pt.rightPosition(t,i.lineNumber,i.column);return new oI(n.lineNumber,n.column,0)}static moveRight(e,t,i,n,o){let r,a;if(i.hasSelection()&&!n)r=i.selection.endLineNumber,a=i.selection.endColumn;else{const l=i.position.delta(void 0,o-1),d=t.normalizePosition(Pt.clipPositionColumn(l,t),1),c=Pt.right(e,t,d);r=c.lineNumber,a=c.column}return i.move(n,r,a,0)}static vertical(e,t,i,n,o,r,a,l){const d=hn.visibleColumnFromColumn(t.getLineContent(i),n,e.tabSize)+o,c=t.getLineCount(),u=i===1&&n===1,h=i===c&&n===t.getLineMaxColumn(i),g=r<i?u:h;if(i=r,i<1?(i=1,a?n=t.getLineMinColumn(i):n=Math.min(t.getLineMaxColumn(i),n)):i>c?(i=c,a?n=t.getLineMaxColumn(i):n=Math.min(t.getLineMaxColumn(i),n)):n=e.columnFromVisibleColumn(t,i,d),g?o=0:o=d-hn.visibleColumnFromColumn(t.getLineContent(i),n,e.tabSize),l!==void 0){const f=new H(i,n),m=t.normalizePosition(f,l);o=o+(n-m.column),i=m.lineNumber,n=m.column}return new oI(i,n,o)}static down(e,t,i,n,o,r,a){return this.vertical(e,t,i,n,o,i+r,a,4)}static moveDown(e,t,i,n,o){let r,a;i.hasSelection()&&!n?(r=i.selection.endLineNumber,a=i.selection.endColumn):(r=i.position.lineNumber,a=i.position.column);let l=0,d;do if(d=Pt.down(e,t,r+l,a,i.leftoverVisibleColumns,o,!0),t.normalizePosition(new H(d.lineNumber,d.column),2).lineNumber>r)break;while(l++<10&&r+l<t.getLineCount());return i.move(n,d.lineNumber,d.column,d.leftoverVisibleColumns)}static translateDown(e,t,i){const n=i.selection,o=Pt.down(e,t,n.selectionStartLineNumber,n.selectionStartColumn,i.selectionStartLeftoverVisibleColumns,1,!1),r=Pt.down(e,t,n.positionLineNumber,n.positionColumn,i.leftoverVisibleColumns,1,!1);return new On(new D(o.lineNumber,o.column,o.lineNumber,o.column),0,o.leftoverVisibleColumns,new H(r.lineNumber,r.column),r.leftoverVisibleColumns)}static up(e,t,i,n,o,r,a){return this.vertical(e,t,i,n,o,i-r,a,3)}static moveUp(e,t,i,n,o){let r,a;i.hasSelection()&&!n?(r=i.selection.startLineNumber,a=i.selection.startColumn):(r=i.position.lineNumber,a=i.position.column);const l=Pt.up(e,t,r,a,i.leftoverVisibleColumns,o,!0);return i.move(n,l.lineNumber,l.column,l.leftoverVisibleColumns)}static translateUp(e,t,i){const n=i.selection,o=Pt.up(e,t,n.selectionStartLineNumber,n.selectionStartColumn,i.selectionStartLeftoverVisibleColumns,1,!1),r=Pt.up(e,t,n.positionLineNumber,n.positionColumn,i.leftoverVisibleColumns,1,!1);return new On(new D(o.lineNumber,o.column,o.lineNumber,o.column),0,o.leftoverVisibleColumns,new H(r.lineNumber,r.column),r.leftoverVisibleColumns)}static _isBlankLine(e,t){return e.getLineFirstNonWhitespaceColumn(t)===0}static moveToPrevBlankLine(e,t,i,n){let o=i.position.lineNumber;for(;o>1&&this._isBlankLine(t,o);)o--;for(;o>1&&!this._isBlankLine(t,o);)o--;return i.move(n,o,t.getLineMinColumn(o),0)}static moveToNextBlankLine(e,t,i,n){const o=t.getLineCount();let r=i.position.lineNumber;for(;r<o&&this._isBlankLine(t,r);)r++;for(;r<o&&!this._isBlankLine(t,r);)r++;return i.move(n,r,t.getLineMinColumn(r),0)}static moveToBeginningOfLine(e,t,i,n){const o=i.position.lineNumber,r=t.getLineMinColumn(o),a=t.getLineFirstNonWhitespaceColumn(o)||r;let l;return i.position.column===a?l=r:l=a,i.move(n,o,l,0)}static moveToEndOfLine(e,t,i,n,o){const r=i.position.lineNumber,a=t.getLineMaxColumn(r);return i.move(n,r,a,o?1073741824-a:0)}static moveToBeginningOfBuffer(e,t,i,n){return i.move(n,1,1,0)}static moveToEndOfBuffer(e,t,i,n){const o=t.getLineCount(),r=t.getLineMaxColumn(o);return i.move(n,o,r,0)}}class Rg{static deleteRight(e,t,i,n){const o=[];let r=e!==3;for(let a=0,l=n.length;a<l;a++){const d=n[a];let c=d;if(c.isEmpty()){const u=d.getPosition(),h=Pt.right(t,i,u);c=new D(h.lineNumber,h.column,u.lineNumber,u.column)}if(c.isEmpty()){o[a]=null;continue}c.startLineNumber!==c.endLineNumber&&(r=!0),o[a]=new Kn(c,"")}return[r,o]}static isAutoClosingPairDelete(e,t,i,n,o,r,a){if(t==="never"&&i==="never"||e==="never")return!1;for(let l=0,d=r.length;l<d;l++){const c=r[l],u=c.getPosition();if(!c.isEmpty())return!1;const h=o.getLineContent(u.lineNumber);if(u.column<2||u.column>=h.length+1)return!1;const g=h.charAt(u.column-2),f=n.get(g);if(!f)return!1;if(yc(g)){if(i==="never")return!1}else if(t==="never")return!1;const m=h.charAt(u.column-1);let _=!1;for(const v of f)v.open===g&&v.close===m&&(_=!0);if(!_)return!1;if(e==="auto"){let v=!1;for(let b=0,C=a.length;b<C;b++){const w=a[b];if(u.lineNumber===w.startLineNumber&&u.column===w.startColumn){v=!0;break}}if(!v)return!1}}return!0}static _runAutoClosingPairDelete(e,t,i){const n=[];for(let o=0,r=i.length;o<r;o++){const a=i[o].getPosition(),l=new D(a.lineNumber,a.column-1,a.lineNumber,a.column+1);n[o]=new Kn(l,"")}return[!0,n]}static deleteLeft(e,t,i,n,o){if(this.isAutoClosingPairDelete(t.autoClosingDelete,t.autoClosingBrackets,t.autoClosingQuotes,t.autoClosingPairs.autoClosingPairsOpenByEnd,i,n,o))return this._runAutoClosingPairDelete(t,i,n);const r=[];let a=e!==2;for(let l=0,d=n.length;l<d;l++){const c=Rg.getDeleteRange(n[l],i,t);if(c.isEmpty()){r[l]=null;continue}c.startLineNumber!==c.endLineNumber&&(a=!0),r[l]=new Kn(c,"")}return[a,r]}static getDeleteRange(e,t,i){if(!e.isEmpty())return e;const n=e.getPosition();if(i.useTabStops&&n.column>1){const o=t.getLineContent(n.lineNumber),r=ws(o),a=r===-1?o.length+1:r+1;if(n.column<=a){const l=i.visibleColumnFromColumn(t,n),d=hn.prevIndentTabStop(l,i.indentSize),c=i.columnFromVisibleColumn(t,n.lineNumber,d);return new D(n.lineNumber,c,n.lineNumber,n.column)}}return D.fromPositions(Rg.getPositionAfterDeleteLeft(n,t),n)}static getPositionAfterDeleteLeft(e,t){if(e.column>1){const i=hJ(e.column-1,t.getLineContent(e.lineNumber));return e.with(void 0,i+1)}else if(e.lineNumber>1){const i=e.lineNumber-1;return new H(i,t.getLineMaxColumn(i))}else return e}static cut(e,t,i){const n=[];let o=null;i.sort((r,a)=>H.compare(r.getStartPosition(),a.getEndPosition()));for(let r=0,a=i.length;r<a;r++){const l=i[r];if(l.isEmpty())if(e.emptySelectionClipboard){const d=l.getPosition();let c,u,h,g;d.lineNumber<t.getLineCount()?(c=d.lineNumber,u=1,h=d.lineNumber+1,g=1):d.lineNumber>1&&(o==null?void 0:o.endLineNumber)!==d.lineNumber?(c=d.lineNumber-1,u=t.getLineMaxColumn(d.lineNumber-1),h=d.lineNumber,g=t.getLineMaxColumn(d.lineNumber)):(c=d.lineNumber,u=1,h=d.lineNumber,g=t.getLineMaxColumn(d.lineNumber));const f=new D(c,u,h,g);o=f,f.isEmpty()?n[r]=null:n[r]=new Kn(f,"")}else n[r]=null;else n[r]=new Kn(l,"")}return new Us(0,n,{shouldPushStackElementBefore:!0,shouldPushStackElementAfter:!0})}}class Nt{static _createWord(e,t,i,n,o){return{start:n,end:o,wordType:t,nextCharClass:i}}static _findPreviousWordOnLine(e,t,i){const n=t.getLineContent(i.lineNumber);return this._doFindPreviousWordOnLine(n,e,i)}static _doFindPreviousWordOnLine(e,t,i){let n=0;for(let o=i.column-2;o>=0;o--){const r=e.charCodeAt(o),a=t.get(r);if(a===0){if(n===2)return this._createWord(e,n,a,o+1,this._findEndOfWord(e,t,n,o+1));n=1}else if(a===2){if(n===1)return this._createWord(e,n,a,o+1,this._findEndOfWord(e,t,n,o+1));n=2}else if(a===1&&n!==0)return this._createWord(e,n,a,o+1,this._findEndOfWord(e,t,n,o+1))}return n!==0?this._createWord(e,n,1,0,this._findEndOfWord(e,t,n,0)):null}static _findEndOfWord(e,t,i,n){const o=e.length;for(let r=n;r<o;r++){const a=e.charCodeAt(r),l=t.get(a);if(l===1||i===1&&l===2||i===2&&l===0)return r}return o}static _findNextWordOnLine(e,t,i){const n=t.getLineContent(i.lineNumber);return this._doFindNextWordOnLine(n,e,i)}static _doFindNextWordOnLine(e,t,i){let n=0;const o=e.length;for(let r=i.column-1;r<o;r++){const a=e.charCodeAt(r),l=t.get(a);if(l===0){if(n===2)return this._createWord(e,n,l,this._findStartOfWord(e,t,n,r-1),r);n=1}else if(l===2){if(n===1)return this._createWord(e,n,l,this._findStartOfWord(e,t,n,r-1),r);n=2}else if(l===1&&n!==0)return this._createWord(e,n,l,this._findStartOfWord(e,t,n,r-1),r)}return n!==0?this._createWord(e,n,1,this._findStartOfWord(e,t,n,o-1),o):null}static _findStartOfWord(e,t,i,n){for(let o=n;o>=0;o--){const r=e.charCodeAt(o),a=t.get(r);if(a===1||i===1&&a===2||i===2&&a===0)return o+1}return 0}static moveWordLeft(e,t,i,n){let o=i.lineNumber,r=i.column;r===1&&o>1&&(o=o-1,r=t.getLineMaxColumn(o));let a=Nt._findPreviousWordOnLine(e,t,new H(o,r));if(n===0)return new H(o,a?a.start+1:1);if(n===1)return a&&a.wordType===2&&a.end-a.start===1&&a.nextCharClass===0&&(a=Nt._findPreviousWordOnLine(e,t,new H(o,a.start+1))),new H(o,a?a.start+1:1);if(n===3){for(;a&&a.wordType===2;)a=Nt._findPreviousWordOnLine(e,t,new H(o,a.start+1));return new H(o,a?a.start+1:1)}return a&&r<=a.end+1&&(a=Nt._findPreviousWordOnLine(e,t,new H(o,a.start+1))),new H(o,a?a.end+1:1)}static _moveWordPartLeft(e,t){const i=t.lineNumber,n=e.getLineMaxColumn(i);if(t.column===1)return i>1?new H(i-1,e.getLineMaxColumn(i-1)):t;const o=e.getLineContent(i);for(let r=t.column-1;r>1;r--){const a=o.charCodeAt(r-2),l=o.charCodeAt(r-1);if(a===95&&l!==95)return new H(i,r);if(a===45&&l!==45)return new H(i,r);if((Hc(a)||o1(a))&&ul(l))return new H(i,r);if(ul(a)&&ul(l)&&r+1<n){const d=o.charCodeAt(r);if(Hc(d)||o1(d))return new H(i,r)}}return new H(i,1)}static moveWordRight(e,t,i,n){let o=i.lineNumber,r=i.column,a=!1;r===t.getLineMaxColumn(o)&&o<t.getLineCount()&&(a=!0,o=o+1,r=1);let l=Nt._findNextWordOnLine(e,t,new H(o,r));if(n===2)l&&l.wordType===2&&l.end-l.start===1&&l.nextCharClass===0&&(l=Nt._findNextWordOnLine(e,t,new H(o,l.end+1))),l?r=l.end+1:r=t.getLineMaxColumn(o);else if(n===3){for(a&&(r=0);l&&(l.wordType===2||l.start+1<=r);)l=Nt._findNextWordOnLine(e,t,new H(o,l.end+1));l?r=l.start+1:r=t.getLineMaxColumn(o)}else l&&!a&&r>=l.start+1&&(l=Nt._findNextWordOnLine(e,t,new H(o,l.end+1))),l?r=l.start+1:r=t.getLineMaxColumn(o);return new H(o,r)}static _moveWordPartRight(e,t){const i=t.lineNumber,n=e.getLineMaxColumn(i);if(t.column===n)return i<e.getLineCount()?new H(i+1,1):t;const o=e.getLineContent(i);for(let r=t.column+1;r<n;r++){const a=o.charCodeAt(r-2),l=o.charCodeAt(r-1);if(a!==95&&l===95)return new H(i,r);if(a!==45&&l===45)return new H(i,r);if((Hc(a)||o1(a))&&ul(l))return new H(i,r);if(ul(a)&&ul(l)&&r+1<n){const d=o.charCodeAt(r);if(Hc(d)||o1(d))return new H(i,r)}}return new H(i,n)}static _deleteWordLeftWhitespace(e,t){const i=e.getLineContent(t.lineNumber),n=t.column-2,o=Pa(i,n);return o+1<n?new D(t.lineNumber,o+2,t.lineNumber,t.column):null}static deleteWordLeft(e,t){const i=e.wordSeparators,n=e.model,o=e.selection,r=e.whitespaceHeuristics;if(!o.isEmpty())return o;if(Rg.isAutoClosingPairDelete(e.autoClosingDelete,e.autoClosingBrackets,e.autoClosingQuotes,e.autoClosingPairs.autoClosingPairsOpenByEnd,e.model,[e.selection],e.autoClosedCharacters)){const u=e.selection.getPosition();return new D(u.lineNumber,u.column-1,u.lineNumber,u.column+1)}const a=new H(o.positionLineNumber,o.positionColumn);let l=a.lineNumber,d=a.column;if(l===1&&d===1)return null;if(r){const u=this._deleteWordLeftWhitespace(n,a);if(u)return u}let c=Nt._findPreviousWordOnLine(i,n,a);return t===0?c?d=c.start+1:d>1?d=1:(l--,d=n.getLineMaxColumn(l)):(c&&d<=c.end+1&&(c=Nt._findPreviousWordOnLine(i,n,new H(l,c.start+1))),c?d=c.end+1:d>1?d=1:(l--,d=n.getLineMaxColumn(l))),new D(l,d,a.lineNumber,a.column)}static deleteInsideWord(e,t,i){if(!i.isEmpty())return i;const n=new H(i.positionLineNumber,i.positionColumn),o=this._deleteInsideWordWhitespace(t,n);return o||this._deleteInsideWordDetermineDeleteRange(e,t,n)}static _charAtIsWhitespace(e,t){const i=e.charCodeAt(t);return i===32||i===9}static _deleteInsideWordWhitespace(e,t){const i=e.getLineContent(t.lineNumber),n=i.length;if(n===0)return null;let o=Math.max(t.column-2,0);if(!this._charAtIsWhitespace(i,o))return null;let r=Math.min(t.column-1,n-1);if(!this._charAtIsWhitespace(i,r))return null;for(;o>0&&this._charAtIsWhitespace(i,o-1);)o--;for(;r+1<n&&this._charAtIsWhitespace(i,r+1);)r++;return new D(t.lineNumber,o+1,t.lineNumber,r+2)}static _deleteInsideWordDetermineDeleteRange(e,t,i){const n=t.getLineContent(i.lineNumber),o=n.length;if(o===0)return i.lineNumber>1?new D(i.lineNumber-1,t.getLineMaxColumn(i.lineNumber-1),i.lineNumber,1):i.lineNumber<t.getLineCount()?new D(i.lineNumber,1,i.lineNumber+1,1):new D(i.lineNumber,1,i.lineNumber,1);const r=u=>u.start+1<=i.column&&i.column<=u.end+1,a=(u,h)=>(u=Math.min(u,i.column),h=Math.max(h,i.column),new D(i.lineNumber,u,i.lineNumber,h)),l=u=>{let h=u.start+1,g=u.end+1,f=!1;for(;g-1<o&&this._charAtIsWhitespace(n,g-1);)f=!0,g++;if(!f)for(;h>1&&this._charAtIsWhitespace(n,h-2);)h--;return a(h,g)},d=Nt._findPreviousWordOnLine(e,t,i);if(d&&r(d))return l(d);const c=Nt._findNextWordOnLine(e,t,i);return c&&r(c)?l(c):d&&c?a(d.end+1,c.start+1):d?a(d.start+1,d.end+1):c?a(c.start+1,c.end+1):a(1,o+1)}static _deleteWordPartLeft(e,t){if(!t.isEmpty())return t;const i=t.getPosition(),n=Nt._moveWordPartLeft(e,i);return new D(i.lineNumber,i.column,n.lineNumber,n.column)}static _findFirstNonWhitespaceChar(e,t){const i=e.length;for(let n=t;n<i;n++){const o=e.charAt(n);if(o!==" "&&o!=="	")return n}return i}static _deleteWordRightWhitespace(e,t){const i=e.getLineContent(t.lineNumber),n=t.column-1,o=this._findFirstNonWhitespaceChar(i,n);return n+1<o?new D(t.lineNumber,t.column,t.lineNumber,o+1):null}static deleteWordRight(e,t){const i=e.wordSeparators,n=e.model,o=e.selection,r=e.whitespaceHeuristics;if(!o.isEmpty())return o;const a=new H(o.positionLineNumber,o.positionColumn);let l=a.lineNumber,d=a.column;const c=n.getLineCount(),u=n.getLineMaxColumn(l);if(l===c&&d===u)return null;if(r){const g=this._deleteWordRightWhitespace(n,a);if(g)return g}let h=Nt._findNextWordOnLine(i,n,a);return t===2?h?d=h.end+1:d<u||l===c?d=u:(l++,h=Nt._findNextWordOnLine(i,n,new H(l,1)),h?d=h.start+1:d=n.getLineMaxColumn(l)):(h&&d>=h.start+1&&(h=Nt._findNextWordOnLine(i,n,new H(l,h.end+1))),h?d=h.start+1:d<u||l===c?d=u:(l++,h=Nt._findNextWordOnLine(i,n,new H(l,1)),h?d=h.start+1:d=n.getLineMaxColumn(l))),new D(l,d,a.lineNumber,a.column)}static _deleteWordPartRight(e,t){if(!t.isEmpty())return t;const i=t.getPosition(),n=Nt._moveWordPartRight(e,i);return new D(i.lineNumber,i.column,n.lineNumber,n.column)}static _createWordAtPosition(e,t,i){const n=new D(t,i.start+1,t,i.end+1);return{word:e.getValueInRange(n),startColumn:n.startColumn,endColumn:n.endColumn}}static getWordAtPosition(e,t,i){const n=xr(t),o=Nt._findPreviousWordOnLine(n,e,i);if(o&&o.wordType===1&&o.start<=i.column-1&&i.column-1<=o.end)return Nt._createWordAtPosition(e,i.lineNumber,o);const r=Nt._findNextWordOnLine(n,e,i);return r&&r.wordType===1&&r.start<=i.column-1&&i.column-1<=r.end?Nt._createWordAtPosition(e,i.lineNumber,r):null}static word(e,t,i,n,o){const r=xr(e.wordSeparators),a=Nt._findPreviousWordOnLine(r,t,o),l=Nt._findNextWordOnLine(r,t,o);if(!n){let g,f;return a&&a.wordType===1&&a.start<=o.column-1&&o.column-1<=a.end?(g=a.start+1,f=a.end+1):l&&l.wordType===1&&l.start<=o.column-1&&o.column-1<=l.end?(g=l.start+1,f=l.end+1):(a?g=a.end+1:g=1,l?f=l.start+1:f=t.getLineMaxColumn(o.lineNumber)),new On(new D(o.lineNumber,g,o.lineNumber,f),1,0,new H(o.lineNumber,f),0)}let d,c;a&&a.wordType===1&&a.start<o.column-1&&o.column-1<a.end?(d=a.start+1,c=a.end+1):l&&l.wordType===1&&l.start<o.column-1&&o.column-1<l.end?(d=l.start+1,c=l.end+1):(d=o.column,c=o.column);const u=o.lineNumber;let h;if(i.selectionStart.containsPosition(o))h=i.selectionStart.endColumn;else if(o.isBeforeOrEqual(i.selectionStart.getStartPosition())){h=d;const g=new H(u,h);i.selectionStart.containsPosition(g)&&(h=i.selectionStart.endColumn)}else{h=c;const g=new H(u,h);i.selectionStart.containsPosition(g)&&(h=i.selectionStart.startColumn)}return i.move(!0,u,h,0)}}class Dx extends Nt{static deleteWordPartLeft(e){const t=b1([Nt.deleteWordLeft(e,0),Nt.deleteWordLeft(e,2),Nt._deleteWordPartLeft(e.model,e.selection)]);return t.sort(D.compareRangesUsingEnds),t[2]}static deleteWordPartRight(e){const t=b1([Nt.deleteWordRight(e,0),Nt.deleteWordRight(e,2),Nt._deleteWordPartRight(e.model,e.selection)]);return t.sort(D.compareRangesUsingStarts),t[0]}static moveWordPartLeft(e,t,i){const n=b1([Nt.moveWordLeft(e,t,i,0),Nt.moveWordLeft(e,t,i,2),Nt._moveWordPartLeft(t,i)]);return n.sort(H.compare),n[2]}static moveWordPartRight(e,t,i){const n=b1([Nt.moveWordRight(e,t,i,0),Nt.moveWordRight(e,t,i,2),Nt._moveWordPartRight(t,i)]);return n.sort(H.compare),n[0]}}function b1(s){return s.filter(e=>!!e)}class Mn{static addCursorDown(e,t,i){const n=[];let o=0;for(let r=0,a=t.length;r<a;r++){const l=t[r];n[o++]=new yt(l.modelState,l.viewState),i?n[o++]=yt.fromModelState(Pt.translateDown(e.cursorConfig,e.model,l.modelState)):n[o++]=yt.fromViewState(Pt.translateDown(e.cursorConfig,e,l.viewState))}return n}static addCursorUp(e,t,i){const n=[];let o=0;for(let r=0,a=t.length;r<a;r++){const l=t[r];n[o++]=new yt(l.modelState,l.viewState),i?n[o++]=yt.fromModelState(Pt.translateUp(e.cursorConfig,e.model,l.modelState)):n[o++]=yt.fromViewState(Pt.translateUp(e.cursorConfig,e,l.viewState))}return n}static moveToBeginningOfLine(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o];n[o]=this._moveToLineStart(e,a,i)}return n}static _moveToLineStart(e,t,i){const n=t.viewState.position.column,o=t.modelState.position.column,r=n===o,a=t.viewState.position.lineNumber,l=e.getLineFirstNonWhitespaceColumn(a);return!r&&!(n===l)?this._moveToLineStartByView(e,t,i):this._moveToLineStartByModel(e,t,i)}static _moveToLineStartByView(e,t,i){return yt.fromViewState(Pt.moveToBeginningOfLine(e.cursorConfig,e,t.viewState,i))}static _moveToLineStartByModel(e,t,i){return yt.fromModelState(Pt.moveToBeginningOfLine(e.cursorConfig,e.model,t.modelState,i))}static moveToEndOfLine(e,t,i,n){const o=[];for(let r=0,a=t.length;r<a;r++){const l=t[r];o[r]=this._moveToLineEnd(e,l,i,n)}return o}static _moveToLineEnd(e,t,i,n){const o=t.viewState.position,r=e.getLineMaxColumn(o.lineNumber),a=o.column===r,l=t.modelState.position,d=e.model.getLineMaxColumn(l.lineNumber),c=r-o.column===d-l.column;return a||c?this._moveToLineEndByModel(e,t,i,n):this._moveToLineEndByView(e,t,i,n)}static _moveToLineEndByView(e,t,i,n){return yt.fromViewState(Pt.moveToEndOfLine(e.cursorConfig,e,t.viewState,i,n))}static _moveToLineEndByModel(e,t,i,n){return yt.fromModelState(Pt.moveToEndOfLine(e.cursorConfig,e.model,t.modelState,i,n))}static expandLineSelection(e,t){const i=[];for(let n=0,o=t.length;n<o;n++){const r=t[n],a=r.modelState.selection.startLineNumber,l=e.model.getLineCount();let d=r.modelState.selection.endLineNumber,c;d===l?c=e.model.getLineMaxColumn(l):(d++,c=1),i[n]=yt.fromModelState(new On(new D(a,1,a,1),0,0,new H(d,c),0))}return i}static moveToBeginningOfBuffer(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o];n[o]=yt.fromModelState(Pt.moveToBeginningOfBuffer(e.cursorConfig,e.model,a.modelState,i))}return n}static moveToEndOfBuffer(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o];n[o]=yt.fromModelState(Pt.moveToEndOfBuffer(e.cursorConfig,e.model,a.modelState,i))}return n}static selectAll(e,t){const i=e.model.getLineCount(),n=e.model.getLineMaxColumn(i);return yt.fromModelState(new On(new D(1,1,1,1),0,0,new H(i,n),0))}static line(e,t,i,n,o){const r=e.model.validatePosition(n),a=o?e.coordinatesConverter.validateViewPosition(new H(o.lineNumber,o.column),r):e.coordinatesConverter.convertModelPositionToViewPosition(r);if(!i){const d=e.model.getLineCount();let c=r.lineNumber+1,u=1;return c>d&&(c=d,u=e.model.getLineMaxColumn(c)),yt.fromModelState(new On(new D(r.lineNumber,1,c,u),2,0,new H(c,u),0))}const l=t.modelState.selectionStart.getStartPosition().lineNumber;if(r.lineNumber<l)return yt.fromViewState(t.viewState.move(!0,a.lineNumber,1,0));if(r.lineNumber>l){const d=e.getLineCount();let c=a.lineNumber+1,u=1;return c>d&&(c=d,u=e.getLineMaxColumn(c)),yt.fromViewState(t.viewState.move(!0,c,u,0))}else{const d=t.modelState.selectionStart.getEndPosition();return yt.fromModelState(t.modelState.move(!0,d.lineNumber,d.column,0))}}static word(e,t,i,n){const o=e.model.validatePosition(n);return yt.fromModelState(Nt.word(e.cursorConfig,e.model,t.modelState,i,o))}static cancelSelection(e,t){if(!t.modelState.hasSelection())return new yt(t.modelState,t.viewState);const i=t.viewState.position.lineNumber,n=t.viewState.position.column;return yt.fromViewState(new On(new D(i,n,i,n),0,0,new H(i,n),0))}static moveTo(e,t,i,n,o){if(i){if(t.modelState.selectionStartKind===1)return this.word(e,t,i,n);if(t.modelState.selectionStartKind===2)return this.line(e,t,i,n,o)}const r=e.model.validatePosition(n),a=o?e.coordinatesConverter.validateViewPosition(new H(o.lineNumber,o.column),r):e.coordinatesConverter.convertModelPositionToViewPosition(r);return yt.fromViewState(t.viewState.move(i,a.lineNumber,a.column,0))}static simpleMove(e,t,i,n,o,r){switch(i){case 0:return r===4?this._moveHalfLineLeft(e,t,n):this._moveLeft(e,t,n,o);case 1:return r===4?this._moveHalfLineRight(e,t,n):this._moveRight(e,t,n,o);case 2:return r===2?this._moveUpByViewLines(e,t,n,o):this._moveUpByModelLines(e,t,n,o);case 3:return r===2?this._moveDownByViewLines(e,t,n,o):this._moveDownByModelLines(e,t,n,o);case 4:return r===2?t.map(a=>yt.fromViewState(Pt.moveToPrevBlankLine(e.cursorConfig,e,a.viewState,n))):t.map(a=>yt.fromModelState(Pt.moveToPrevBlankLine(e.cursorConfig,e.model,a.modelState,n)));case 5:return r===2?t.map(a=>yt.fromViewState(Pt.moveToNextBlankLine(e.cursorConfig,e,a.viewState,n))):t.map(a=>yt.fromModelState(Pt.moveToNextBlankLine(e.cursorConfig,e.model,a.modelState,n)));case 6:return this._moveToViewMinColumn(e,t,n);case 7:return this._moveToViewFirstNonWhitespaceColumn(e,t,n);case 8:return this._moveToViewCenterColumn(e,t,n);case 9:return this._moveToViewMaxColumn(e,t,n);case 10:return this._moveToViewLastNonWhitespaceColumn(e,t,n);default:return null}}static viewportMove(e,t,i,n,o){const r=e.getCompletelyVisibleViewRange(),a=e.coordinatesConverter.convertViewRangeToModelRange(r);switch(i){case 11:{const l=this._firstLineNumberInRange(e.model,a,o),d=e.model.getLineFirstNonWhitespaceColumn(l);return[this._moveToModelPosition(e,t[0],n,l,d)]}case 13:{const l=this._lastLineNumberInRange(e.model,a,o),d=e.model.getLineFirstNonWhitespaceColumn(l);return[this._moveToModelPosition(e,t[0],n,l,d)]}case 12:{const l=Math.round((a.startLineNumber+a.endLineNumber)/2),d=e.model.getLineFirstNonWhitespaceColumn(l);return[this._moveToModelPosition(e,t[0],n,l,d)]}case 14:{const l=[];for(let d=0,c=t.length;d<c;d++){const u=t[d];l[d]=this.findPositionInViewportIfOutside(e,u,r,n)}return l}default:return null}}static findPositionInViewportIfOutside(e,t,i,n){const o=t.viewState.position.lineNumber;if(i.startLineNumber<=o&&o<=i.endLineNumber-1)return new yt(t.modelState,t.viewState);{let r;o>i.endLineNumber-1?r=i.endLineNumber-1:o<i.startLineNumber?r=i.startLineNumber:r=o;const a=Pt.vertical(e.cursorConfig,e,o,t.viewState.position.column,t.viewState.leftoverVisibleColumns,r,!1);return yt.fromViewState(t.viewState.move(n,a.lineNumber,a.column,a.leftoverVisibleColumns))}}static _firstLineNumberInRange(e,t,i){let n=t.startLineNumber;return t.startColumn!==e.getLineMinColumn(n)&&n++,Math.min(t.endLineNumber,n+i-1)}static _lastLineNumberInRange(e,t,i){let n=t.startLineNumber;return t.startColumn!==e.getLineMinColumn(n)&&n++,Math.max(n,t.endLineNumber-i+1)}static _moveLeft(e,t,i,n){return t.map(o=>yt.fromViewState(Pt.moveLeft(e.cursorConfig,e,o.viewState,i,n)))}static _moveHalfLineLeft(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o],l=a.viewState.position.lineNumber,d=Math.round(e.getLineLength(l)/2);n[o]=yt.fromViewState(Pt.moveLeft(e.cursorConfig,e,a.viewState,i,d))}return n}static _moveRight(e,t,i,n){return t.map(o=>yt.fromViewState(Pt.moveRight(e.cursorConfig,e,o.viewState,i,n)))}static _moveHalfLineRight(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o],l=a.viewState.position.lineNumber,d=Math.round(e.getLineLength(l)/2);n[o]=yt.fromViewState(Pt.moveRight(e.cursorConfig,e,a.viewState,i,d))}return n}static _moveDownByViewLines(e,t,i,n){const o=[];for(let r=0,a=t.length;r<a;r++){const l=t[r];o[r]=yt.fromViewState(Pt.moveDown(e.cursorConfig,e,l.viewState,i,n))}return o}static _moveDownByModelLines(e,t,i,n){const o=[];for(let r=0,a=t.length;r<a;r++){const l=t[r];o[r]=yt.fromModelState(Pt.moveDown(e.cursorConfig,e.model,l.modelState,i,n))}return o}static _moveUpByViewLines(e,t,i,n){const o=[];for(let r=0,a=t.length;r<a;r++){const l=t[r];o[r]=yt.fromViewState(Pt.moveUp(e.cursorConfig,e,l.viewState,i,n))}return o}static _moveUpByModelLines(e,t,i,n){const o=[];for(let r=0,a=t.length;r<a;r++){const l=t[r];o[r]=yt.fromModelState(Pt.moveUp(e.cursorConfig,e.model,l.modelState,i,n))}return o}static _moveToViewPosition(e,t,i,n,o){return yt.fromViewState(t.viewState.move(i,n,o,0))}static _moveToModelPosition(e,t,i,n,o){return yt.fromModelState(t.modelState.move(i,n,o,0))}static _moveToViewMinColumn(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o],l=a.viewState.position.lineNumber,d=e.getLineMinColumn(l);n[o]=this._moveToViewPosition(e,a,i,l,d)}return n}static _moveToViewFirstNonWhitespaceColumn(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o],l=a.viewState.position.lineNumber,d=e.getLineFirstNonWhitespaceColumn(l);n[o]=this._moveToViewPosition(e,a,i,l,d)}return n}static _moveToViewCenterColumn(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o],l=a.viewState.position.lineNumber,d=Math.round((e.getLineMaxColumn(l)+e.getLineMinColumn(l))/2);n[o]=this._moveToViewPosition(e,a,i,l,d)}return n}static _moveToViewMaxColumn(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o],l=a.viewState.position.lineNumber,d=e.getLineMaxColumn(l);n[o]=this._moveToViewPosition(e,a,i,l,d)}return n}static _moveToViewLastNonWhitespaceColumn(e,t,i){const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o],l=a.viewState.position.lineNumber,d=e.getLineLastNonWhitespaceColumn(l);n[o]=this._moveToViewPosition(e,a,i,l,d)}return n}}var ey;(function(s){const e=function(i){if(!Ts(i))return!1;const n=i;return!(!Ps(n.to)||!fo(n.select)&&!hW(n.select)||!fo(n.by)&&!Ps(n.by)||!fo(n.value)&&!xu(n.value))};s.metadata={description:"Move cursor to a logical position in the view",args:[{name:"Cursor move argument object",description:`Property-value pairs that can be passed through this argument:
					* 'to': A mandatory logical position value providing where to move the cursor.
						\`\`\`
						'left', 'right', 'up', 'down', 'prevBlankLine', 'nextBlankLine',
						'wrappedLineStart', 'wrappedLineEnd', 'wrappedLineColumnCenter'
						'wrappedLineFirstNonWhitespaceCharacter', 'wrappedLineLastNonWhitespaceCharacter'
						'viewPortTop', 'viewPortCenter', 'viewPortBottom', 'viewPortIfOutside'
						\`\`\`
					* 'by': Unit to move. Default is computed based on 'to' value.
						\`\`\`
						'line', 'wrappedLine', 'character', 'halfLine'
						\`\`\`
					* 'value': Number of units to move. Default is '1'.
					* 'select': If 'true' makes the selection. Default is 'false'.
				`,constraint:e,schema:{type:"object",required:["to"],properties:{to:{type:"string",enum:["left","right","up","down","prevBlankLine","nextBlankLine","wrappedLineStart","wrappedLineEnd","wrappedLineColumnCenter","wrappedLineFirstNonWhitespaceCharacter","wrappedLineLastNonWhitespaceCharacter","viewPortTop","viewPortCenter","viewPortBottom","viewPortIfOutside"]},by:{type:"string",enum:["line","wrappedLine","character","halfLine"]},value:{type:"number",default:1},select:{type:"boolean",default:!1}}}}]},s.RawDirection={Left:"left",Right:"right",Up:"up",Down:"down",PrevBlankLine:"prevBlankLine",NextBlankLine:"nextBlankLine",WrappedLineStart:"wrappedLineStart",WrappedLineFirstNonWhitespaceCharacter:"wrappedLineFirstNonWhitespaceCharacter",WrappedLineColumnCenter:"wrappedLineColumnCenter",WrappedLineEnd:"wrappedLineEnd",WrappedLineLastNonWhitespaceCharacter:"wrappedLineLastNonWhitespaceCharacter",ViewPortTop:"viewPortTop",ViewPortCenter:"viewPortCenter",ViewPortBottom:"viewPortBottom",ViewPortIfOutside:"viewPortIfOutside"},s.RawUnit={Line:"line",WrappedLine:"wrappedLine",Character:"character",HalfLine:"halfLine"};function t(i){if(!i.to)return null;let n;switch(i.to){case s.RawDirection.Left:n=0;break;case s.RawDirection.Right:n=1;break;case s.RawDirection.Up:n=2;break;case s.RawDirection.Down:n=3;break;case s.RawDirection.PrevBlankLine:n=4;break;case s.RawDirection.NextBlankLine:n=5;break;case s.RawDirection.WrappedLineStart:n=6;break;case s.RawDirection.WrappedLineFirstNonWhitespaceCharacter:n=7;break;case s.RawDirection.WrappedLineColumnCenter:n=8;break;case s.RawDirection.WrappedLineEnd:n=9;break;case s.RawDirection.WrappedLineLastNonWhitespaceCharacter:n=10;break;case s.RawDirection.ViewPortTop:n=11;break;case s.RawDirection.ViewPortBottom:n=13;break;case s.RawDirection.ViewPortCenter:n=12;break;case s.RawDirection.ViewPortIfOutside:n=14;break;default:return null}let o=0;switch(i.by){case s.RawUnit.Line:o=1;break;case s.RawUnit.WrappedLine:o=2;break;case s.RawUnit.Character:o=3;break;case s.RawUnit.HalfLine:o=4;break}return{direction:n,unit:o,select:!!i.select,value:i.value||1}}s.parse=t})(ey||(ey={}));function Hp(s,e,t,i){const n=Pp(e,t.startLineNumber,t.startColumn),o=i.getLanguageConfiguration(n.languageId);if(!o)return null;const r=n.getLineContent(),a=r.substr(0,t.startColumn-1-n.firstCharOffset);let l;t.isEmpty()?l=r.substr(t.startColumn-1-n.firstCharOffset):l=Pp(e,t.endLineNumber,t.endColumn).getLineContent().substr(t.endColumn-1-n.firstCharOffset);let d="";if(t.startLineNumber>1&&n.firstCharOffset===0){const m=Pp(e,t.startLineNumber-1);m.languageId===n.languageId&&(d=m.getLineContent())}const c=o.onEnter(s,d,a,l);if(!c)return null;const u=c.indentAction;let h=c.appendText;const g=c.removeText||0;h?u===nn.Indent&&(h="	"+h):u===nn.Indent||u===nn.IndentOutdent?h="	":h="";let f=zV(e,t.startLineNumber,t.startColumn);return g&&(f=f.substring(0,f.length-g)),{indentAction:u,appendText:h,removeText:g,indentation:f}}var nae=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},sae=function(s,e){return function(t,i){e(t,i,s)}},Hw;const rI=Object.create(null);function Ch(s,e){if(e<=0)return"";rI[s]||(rI[s]=["",s]);const t=rI[s];for(let i=t.length;i<=e;i++)t[i]=t[i-1]+s;return t[e]}let mr=Hw=class{static unshiftIndent(e,t,i,n,o){const r=hn.visibleColumnFromColumn(e,t,i);if(o){const a=Ch(" ",n),d=hn.prevIndentTabStop(r,n)/n;return Ch(a,d)}else{const a="	",d=hn.prevRenderTabStop(r,i)/i;return Ch(a,d)}}static shiftIndent(e,t,i,n,o){const r=hn.visibleColumnFromColumn(e,t,i);if(o){const a=Ch(" ",n),d=hn.nextIndentTabStop(r,n)/n;return Ch(a,d)}else{const a="	",d=hn.nextRenderTabStop(r,i)/i;return Ch(a,d)}}constructor(e,t,i){this._languageConfigurationService=i,this._opts=t,this._selection=e,this._selectionId=null,this._useLastEditRangeForCursorEndPosition=!1,this._selectionStartColumnStaysPut=!1}_addEditOperation(e,t,i){this._useLastEditRangeForCursorEndPosition?e.addTrackedEditOperation(t,i):e.addEditOperation(t,i)}getEditOperations(e,t){const i=this._selection.startLineNumber;let n=this._selection.endLineNumber;this._selection.endColumn===1&&i!==n&&(n=n-1);const{tabSize:o,indentSize:r,insertSpaces:a}=this._opts,l=i===n;if(this._opts.useTabStops){this._selection.isEmpty()&&/^\s*$/.test(e.getLineContent(i))&&(this._useLastEditRangeForCursorEndPosition=!0);let d=0,c=0;for(let u=i;u<=n;u++,d=c){c=0;const h=e.getLineContent(u);let g=ws(h);if(this._opts.isUnshift&&(h.length===0||g===0)||!l&&!this._opts.isUnshift&&h.length===0)continue;if(g===-1&&(g=h.length),u>1&&hn.visibleColumnFromColumn(h,g+1,o)%r!==0&&e.tokenization.isCheapToTokenize(u-1)){const _=Hp(this._opts.autoIndent,e,new D(u-1,e.getLineMaxColumn(u-1),u-1,e.getLineMaxColumn(u-1)),this._languageConfigurationService);if(_){if(c=d,_.appendText)for(let v=0,b=_.appendText.length;v<b&&c<r&&_.appendText.charCodeAt(v)===32;v++)c++;_.removeText&&(c=Math.max(0,c-_.removeText));for(let v=0;v<c&&!(g===0||h.charCodeAt(g-1)!==32);v++)g--}}if(this._opts.isUnshift&&g===0)continue;let f;this._opts.isUnshift?f=Hw.unshiftIndent(h,g+1,o,r,a):f=Hw.shiftIndent(h,g+1,o,r,a),this._addEditOperation(t,new D(u,1,u,g+1),f),u===i&&!this._selection.isEmpty()&&(this._selectionStartColumnStaysPut=this._selection.startColumn<=g+1)}}else{!this._opts.isUnshift&&this._selection.isEmpty()&&e.getLineLength(i)===0&&(this._useLastEditRangeForCursorEndPosition=!0);const d=a?Ch(" ",r):"	";for(let c=i;c<=n;c++){const u=e.getLineContent(c);let h=ws(u);if(!(this._opts.isUnshift&&(u.length===0||h===0))&&!(!l&&!this._opts.isUnshift&&u.length===0)&&(h===-1&&(h=u.length),!(this._opts.isUnshift&&h===0)))if(this._opts.isUnshift){h=Math.min(h,r);for(let g=0;g<h;g++)if(u.charCodeAt(g)===9){h=g+1;break}this._addEditOperation(t,new D(c,1,c,h+1),"")}else this._addEditOperation(t,new D(c,1,c,1),d),c===i&&!this._selection.isEmpty()&&(this._selectionStartColumnStaysPut=this._selection.startColumn===1)}}this._selectionId=t.trackSelection(this._selection)}computeCursorState(e,t){if(this._useLastEditRangeForCursorEndPosition){const n=t.getInverseEditOperations()[0];return new De(n.range.endLineNumber,n.range.endColumn,n.range.endLineNumber,n.range.endColumn)}const i=t.getTrackedSelection(this._selectionId);if(this._selectionStartColumnStaysPut){const n=this._selection.startColumn;return i.startColumn<=n?i:i.getDirection()===0?new De(i.startLineNumber,n,i.endLineNumber,i.endColumn):new De(i.endLineNumber,i.endColumn,i.startLineNumber,n)}return i}};mr=Hw=nae([sae(2,Jt)],mr);class oae{constructor(e,t,i){this._range=e,this._charBeforeSelection=t,this._charAfterSelection=i}getEditOperations(e,t){t.addTrackedEditOperation(new D(this._range.startLineNumber,this._range.startColumn,this._range.startLineNumber,this._range.startColumn),this._charBeforeSelection),t.addTrackedEditOperation(new D(this._range.endLineNumber,this._range.endColumn,this._range.endLineNumber,this._range.endColumn),this._charAfterSelection)}computeCursorState(e,t){const i=t.getInverseEditOperations(),n=i[0].range,o=i[1].range;return new De(n.endLineNumber,n.endColumn,o.endLineNumber,o.endColumn-this._charAfterSelection.length)}}class rae{constructor(e,t,i){this._position=e,this._text=t,this._charAfter=i}getEditOperations(e,t){t.addTrackedEditOperation(new D(this._position.lineNumber,this._position.column,this._position.lineNumber,this._position.column),this._text+this._charAfter)}computeCursorState(e,t){const n=t.getInverseEditOperations()[0].range;return new De(n.endLineNumber,n.startColumn,n.endLineNumber,n.endColumn-this._charAfter.length)}}function aae(s,e,t){const i=s.tokenization.getLanguageIdAtPosition(e,0);if(e>1){let n,o=-1;for(n=e-1;n>=1;n--){if(s.tokenization.getLanguageIdAtPosition(n,0)!==i)return o;const r=s.getLineContent(n);if(t.shouldIgnore(r)||/^\s+$/.test(r)||r===""){o=n;continue}return n}}return-1}function kx(s,e,t,i=!0,n){if(s<4)return null;const o=n.getLanguageConfiguration(e.tokenization.getLanguageId()).indentRulesSupport;if(!o)return null;if(t<=1)return{indentation:"",action:null};for(let l=t-1;l>0&&e.getLineContent(l)==="";l--)if(l===1)return{indentation:"",action:null};const r=aae(e,t,o);if(r<0)return null;if(r<1)return{indentation:"",action:null};const a=e.getLineContent(r);if(o.shouldIncrease(a)||o.shouldIndentNextLine(a))return{indentation:Zt(a),action:nn.Indent,line:r};if(o.shouldDecrease(a))return{indentation:Zt(a),action:null,line:r};{if(r===1)return{indentation:Zt(e.getLineContent(r)),action:null,line:r};const l=r-1,d=o.getIndentMetadata(e.getLineContent(l));if(!(d&3)&&d&4){let c=0;for(let u=l-1;u>0;u--)if(!o.shouldIndentNextLine(e.getLineContent(u))){c=u;break}return{indentation:Zt(e.getLineContent(c+1)),action:null,line:c+1}}if(i)return{indentation:Zt(e.getLineContent(r)),action:null,line:r};for(let c=r;c>0;c--){const u=e.getLineContent(c);if(o.shouldIncrease(u))return{indentation:Zt(u),action:nn.Indent,line:c};if(o.shouldIndentNextLine(u)){let h=0;for(let g=c-1;g>0;g--)if(!o.shouldIndentNextLine(e.getLineContent(c))){h=g;break}return{indentation:Zt(e.getLineContent(h+1)),action:null,line:h+1}}else if(o.shouldDecrease(u))return{indentation:Zt(u),action:null,line:c}}return{indentation:Zt(e.getLineContent(1)),action:null,line:1}}}function Bv(s,e,t,i,n,o){if(s<4)return null;const r=o.getLanguageConfiguration(t);if(!r)return null;const a=o.getLanguageConfiguration(t).indentRulesSupport;if(!a)return null;const l=kx(s,e,i,void 0,o),d=e.getLineContent(i);if(l){const c=l.line;if(c!==void 0){let u=!0;for(let h=c;h<i-1;h++)if(!/^\s*$/.test(e.getLineContent(h))){u=!1;break}if(u){const h=r.onEnter(s,"",e.getLineContent(c),"");if(h){let g=Zt(e.getLineContent(c));return h.removeText&&(g=g.substring(0,g.length-h.removeText)),h.indentAction===nn.Indent||h.indentAction===nn.IndentOutdent?g=n.shiftIndent(g):h.indentAction===nn.Outdent&&(g=n.unshiftIndent(g)),a.shouldDecrease(d)&&(g=n.unshiftIndent(g)),h.appendText&&(g+=h.appendText),Zt(g)}}}return a.shouldDecrease(d)?l.action===nn.Indent?l.indentation:n.unshiftIndent(l.indentation):l.action===nn.Indent?n.shiftIndent(l.indentation):l.indentation}return null}function lae(s,e,t,i,n){if(s<4)return null;e.tokenization.forceTokenization(t.startLineNumber);const o=e.tokenization.getLineTokens(t.startLineNumber),r=hx(o,t.startColumn-1),a=r.getLineContent();let l=!1,d;r.firstCharOffset>0&&o.getLanguageId(0)!==r.languageId?(l=!0,d=a.substr(0,t.startColumn-1-r.firstCharOffset)):d=o.getLineContent().substring(0,t.startColumn-1);let c;t.isEmpty()?c=a.substr(t.startColumn-1-r.firstCharOffset):c=Pp(e,t.endLineNumber,t.endColumn).getLineContent().substr(t.endColumn-1-r.firstCharOffset);const u=n.getLanguageConfiguration(r.languageId).indentRulesSupport;if(!u)return null;const h=d,g=Zt(d),f={tokenization:{getLineTokens:b=>e.tokenization.getLineTokens(b),getLanguageId:()=>e.getLanguageId(),getLanguageIdAtPosition:(b,C)=>e.getLanguageIdAtPosition(b,C)},getLineContent:b=>b===t.startLineNumber?h:e.getLineContent(b)},m=Zt(o.getLineContent()),_=kx(s,f,t.startLineNumber+1,void 0,n);if(!_){const b=l?m:g;return{beforeEnter:b,afterEnter:b}}let v=l?m:_.indentation;return _.action===nn.Indent&&(v=i.shiftIndent(v)),u.shouldDecrease(c)&&(v=i.unshiftIndent(v)),{beforeEnter:l?m:g,afterEnter:v}}function dae(s,e,t,i,n,o){if(s<4)return null;const r=Pp(e,t.startLineNumber,t.startColumn);if(r.firstCharOffset)return null;const a=o.getLanguageConfiguration(r.languageId).indentRulesSupport;if(!a)return null;const l=r.getLineContent(),d=l.substr(0,t.startColumn-1-r.firstCharOffset);let c;if(t.isEmpty()?c=l.substr(t.startColumn-1-r.firstCharOffset):c=Pp(e,t.endLineNumber,t.endColumn).getLineContent().substr(t.endColumn-1-r.firstCharOffset),!a.shouldDecrease(d+c)&&a.shouldDecrease(d+i+c)){const u=kx(s,e,t.startLineNumber,!1,o);if(!u)return null;let h=u.indentation;return u.action!==nn.Indent&&(h=n.unshiftIndent(h)),h}return null}function RH(s,e,t){const i=t.getLanguageConfiguration(s.getLanguageId()).indentRulesSupport;return!i||e<1||e>s.getLineCount()?null:i.getIndentMetadata(s.getLineContent(e))}class bi{static indent(e,t,i){if(t===null||i===null)return[];const n=[];for(let o=0,r=i.length;o<r;o++)n[o]=new mr(i[o],{isUnshift:!1,tabSize:e.tabSize,indentSize:e.indentSize,insertSpaces:e.insertSpaces,useTabStops:e.useTabStops,autoIndent:e.autoIndent},e.languageConfigurationService);return n}static outdent(e,t,i){const n=[];for(let o=0,r=i.length;o<r;o++)n[o]=new mr(i[o],{isUnshift:!0,tabSize:e.tabSize,indentSize:e.indentSize,insertSpaces:e.insertSpaces,useTabStops:e.useTabStops,autoIndent:e.autoIndent},e.languageConfigurationService);return n}static shiftIndent(e,t,i){return i=i||1,mr.shiftIndent(t,t.length+i,e.tabSize,e.indentSize,e.insertSpaces)}static unshiftIndent(e,t,i){return i=i||1,mr.unshiftIndent(t,t.length+i,e.tabSize,e.indentSize,e.insertSpaces)}static _distributedPaste(e,t,i,n){const o=[];for(let r=0,a=i.length;r<a;r++)o[r]=new Kn(i[r],n[r]);return new Us(0,o,{shouldPushStackElementBefore:!0,shouldPushStackElementAfter:!0})}static _simplePaste(e,t,i,n,o){const r=[];for(let a=0,l=i.length;a<l;a++){const d=i[a],c=d.getPosition();if(o&&!d.isEmpty()&&(o=!1),o&&n.indexOf(`
`)!==n.length-1&&(o=!1),o){const u=new D(c.lineNumber,1,c.lineNumber,1);r[a]=new EP(u,n,d,!0)}else r[a]=new Kn(d,n)}return new Us(0,r,{shouldPushStackElementBefore:!0,shouldPushStackElementAfter:!0})}static _distributePasteToCursors(e,t,i,n,o){if(n||t.length===1)return null;if(o&&o.length===t.length)return o;if(e.multiCursorPaste==="spread"){i.charCodeAt(i.length-1)===10&&(i=i.substr(0,i.length-1)),i.charCodeAt(i.length-1)===13&&(i=i.substr(0,i.length-1));const r=Kl(i);if(r.length===t.length)return r}return null}static paste(e,t,i,n,o,r){const a=this._distributePasteToCursors(e,i,n,o,r);return a?(i=i.sort(D.compareRangesUsingStarts),this._distributedPaste(e,t,i,a)):this._simplePaste(e,t,i,n,o)}static _goodIndentForLine(e,t,i){let n=null,o="";const r=kx(e.autoIndent,t,i,!1,e.languageConfigurationService);if(r)n=r.action,o=r.indentation;else if(i>1){let a;for(a=i-1;a>=1;a--){const c=t.getLineContent(a);if(Pa(c)>=0)break}if(a<1)return null;const l=t.getLineMaxColumn(a),d=Hp(e.autoIndent,t,new D(a,l,a,l),e.languageConfigurationService);d&&(o=d.indentation+d.appendText)}return n&&(n===nn.Indent&&(o=bi.shiftIndent(e,o)),n===nn.Outdent&&(o=bi.unshiftIndent(e,o)),o=e.normalizeIndentation(o)),o||null}static _replaceJumpToNextIndent(e,t,i,n){let o="";const r=i.getStartPosition();if(e.insertSpaces){const a=e.visibleColumnFromColumn(t,r),l=e.indentSize,d=l-a%l;for(let c=0;c<d;c++)o+=" "}else o="	";return new Kn(i,o,n)}static tab(e,t,i){const n=[];for(let o=0,r=i.length;o<r;o++){const a=i[o];if(a.isEmpty()){const l=t.getLineContent(a.startLineNumber);if(/^\s*$/.test(l)&&t.tokenization.isCheapToTokenize(a.startLineNumber)){let d=this._goodIndentForLine(e,t,a.startLineNumber);d=d||"	";const c=e.normalizeIndentation(d);if(!l.startsWith(c)){n[o]=new Kn(new D(a.startLineNumber,1,a.startLineNumber,l.length+1),c,!0);continue}}n[o]=this._replaceJumpToNextIndent(e,t,a,!0)}else{if(a.startLineNumber===a.endLineNumber){const l=t.getLineMaxColumn(a.startLineNumber);if(a.startColumn!==1||a.endColumn!==l){n[o]=this._replaceJumpToNextIndent(e,t,a,!1);continue}}n[o]=new mr(a,{isUnshift:!1,tabSize:e.tabSize,indentSize:e.indentSize,insertSpaces:e.insertSpaces,useTabStops:e.useTabStops,autoIndent:e.autoIndent},e.languageConfigurationService)}}return n}static compositionType(e,t,i,n,o,r,a,l){const d=n.map(c=>this._compositionType(i,c,o,r,a,l));return new Us(4,d,{shouldPushStackElementBefore:C1(e,4),shouldPushStackElementAfter:!1})}static _compositionType(e,t,i,n,o,r){if(!t.isEmpty())return null;const a=t.getPosition(),l=Math.max(1,a.column-n),d=Math.min(e.getLineMaxColumn(a.lineNumber),a.column+o),c=new D(a.lineNumber,l,a.lineNumber,d);return e.getValueInRange(c)===i&&r===0?null:new Vw(c,i,0,r)}static _typeCommand(e,t,i){return i?new v1(e,t,!0):new Kn(e,t,!0)}static _enter(e,t,i,n){if(e.autoIndent===0)return bi._typeCommand(n,`
`,i);if(!t.tokenization.isCheapToTokenize(n.getStartPosition().lineNumber)||e.autoIndent===1){const l=t.getLineContent(n.startLineNumber),d=Zt(l).substring(0,n.startColumn-1);return bi._typeCommand(n,`
`+e.normalizeIndentation(d),i)}const o=Hp(e.autoIndent,t,n,e.languageConfigurationService);if(o){if(o.indentAction===nn.None)return bi._typeCommand(n,`
`+e.normalizeIndentation(o.indentation+o.appendText),i);if(o.indentAction===nn.Indent)return bi._typeCommand(n,`
`+e.normalizeIndentation(o.indentation+o.appendText),i);if(o.indentAction===nn.IndentOutdent){const l=e.normalizeIndentation(o.indentation),d=e.normalizeIndentation(o.indentation+o.appendText),c=`
`+d+`
`+l;return i?new v1(n,c,!0):new Vw(n,c,-1,d.length-l.length,!0)}else if(o.indentAction===nn.Outdent){const l=bi.unshiftIndent(e,o.indentation);return bi._typeCommand(n,`
`+e.normalizeIndentation(l+o.appendText),i)}}const r=t.getLineContent(n.startLineNumber),a=Zt(r).substring(0,n.startColumn-1);if(e.autoIndent>=4){const l=lae(e.autoIndent,t,n,{unshiftIndent:d=>bi.unshiftIndent(e,d),shiftIndent:d=>bi.shiftIndent(e,d),normalizeIndentation:d=>e.normalizeIndentation(d)},e.languageConfigurationService);if(l){let d=e.visibleColumnFromColumn(t,n.getEndPosition());const c=n.endColumn,u=t.getLineContent(n.endLineNumber),h=ws(u);if(h>=0?n=n.setEndPosition(n.endLineNumber,Math.max(n.endColumn,h+1)):n=n.setEndPosition(n.endLineNumber,t.getLineMaxColumn(n.endLineNumber)),i)return new v1(n,`
`+e.normalizeIndentation(l.afterEnter),!0);{let g=0;return c<=h+1&&(e.insertSpaces||(d=Math.ceil(d/e.indentSize)),g=Math.min(d+1-e.normalizeIndentation(l.afterEnter).length-1,0)),new Vw(n,`
`+e.normalizeIndentation(l.afterEnter),0,g,!0)}}}return bi._typeCommand(n,`
`+e.normalizeIndentation(a),i)}static _isAutoIndentType(e,t,i){if(e.autoIndent<4)return!1;for(let n=0,o=i.length;n<o;n++)if(!t.tokenization.isCheapToTokenize(i[n].getEndPosition().lineNumber))return!1;return!0}static _runAutoIndentType(e,t,i,n){const o=zV(t,i.startLineNumber,i.startColumn),r=dae(e.autoIndent,t,i,n,{shiftIndent:a=>bi.shiftIndent(e,a),unshiftIndent:a=>bi.unshiftIndent(e,a)},e.languageConfigurationService);if(r===null)return null;if(r!==e.normalizeIndentation(o)){const a=t.getLineFirstNonWhitespaceColumn(i.startLineNumber);return a===0?bi._typeCommand(new D(i.startLineNumber,1,i.endLineNumber,i.endColumn),e.normalizeIndentation(r)+n,!1):bi._typeCommand(new D(i.startLineNumber,1,i.endLineNumber,i.endColumn),e.normalizeIndentation(r)+t.getLineContent(i.startLineNumber).substring(a-1,i.startColumn-1)+n,!1)}return null}static _isAutoClosingOvertype(e,t,i,n,o){if(e.autoClosingOvertype==="never"||!e.autoClosingPairs.autoClosingPairsCloseSingleChar.has(o))return!1;for(let r=0,a=i.length;r<a;r++){const l=i[r];if(!l.isEmpty())return!1;const d=l.getPosition(),c=t.getLineContent(d.lineNumber);if(c.charAt(d.column-1)!==o)return!1;const h=yc(o);if((d.column>2?c.charCodeAt(d.column-2):0)===92&&h)return!1;if(e.autoClosingOvertype==="auto"){let f=!1;for(let m=0,_=n.length;m<_;m++){const v=n[m];if(d.lineNumber===v.startLineNumber&&d.column===v.startColumn){f=!0;break}}if(!f)return!1}}return!0}static _runAutoClosingOvertype(e,t,i,n,o){const r=[];for(let a=0,l=n.length;a<l;a++){const c=n[a].getPosition(),u=new D(c.lineNumber,c.column,c.lineNumber,c.column+1);r[a]=new Kn(u,o)}return new Us(4,r,{shouldPushStackElementBefore:C1(e,4),shouldPushStackElementAfter:!1})}static _isBeforeClosingBrace(e,t){const i=t.charAt(0),n=e.autoClosingPairs.autoClosingPairsOpenByStart.get(i)||[],o=e.autoClosingPairs.autoClosingPairsCloseByStart.get(i)||[],r=n.some(l=>t.startsWith(l.open)),a=o.some(l=>t.startsWith(l.close));return!r&&a}static _findAutoClosingPairOpen(e,t,i,n){const o=e.autoClosingPairs.autoClosingPairsOpenByEnd.get(n);if(!o)return null;let r=null;for(const a of o)if(r===null||a.open.length>r.open.length){let l=!0;for(const d of i)if(t.getValueInRange(new D(d.lineNumber,d.column-a.open.length+1,d.lineNumber,d.column))+n!==a.open){l=!1;break}l&&(r=a)}return r}static _findContainedAutoClosingPair(e,t){if(t.open.length<=1)return null;const i=t.close.charAt(t.close.length-1),n=e.autoClosingPairs.autoClosingPairsCloseByEnd.get(i)||[];let o=null;for(const r of n)r.open!==t.open&&t.open.includes(r.open)&&t.close.endsWith(r.close)&&(!o||r.open.length>o.open.length)&&(o=r);return o}static _getAutoClosingPairClose(e,t,i,n,o){for(const f of i)if(!f.isEmpty())return null;const r=i.map(f=>{const m=f.getPosition();return o?{lineNumber:m.lineNumber,beforeColumn:m.column-n.length,afterColumn:m.column}:{lineNumber:m.lineNumber,beforeColumn:m.column,afterColumn:m.column}}),a=this._findAutoClosingPairOpen(e,t,r.map(f=>new H(f.lineNumber,f.beforeColumn)),n);if(!a)return null;let l,d;if(yc(n)?(l=e.autoClosingQuotes,d=e.shouldAutoCloseBefore.quote):(e.blockCommentStartToken?a.open.includes(e.blockCommentStartToken):!1)?(l=e.autoClosingComments,d=e.shouldAutoCloseBefore.comment):(l=e.autoClosingBrackets,d=e.shouldAutoCloseBefore.bracket),l==="never")return null;const u=this._findContainedAutoClosingPair(e,a),h=u?u.close:"";let g=!0;for(const f of r){const{lineNumber:m,beforeColumn:_,afterColumn:v}=f,b=t.getLineContent(m),C=b.substring(0,_-1),w=b.substring(v-1);if(w.startsWith(h)||(g=!1),w.length>0){const k=w.charAt(0);if(!bi._isBeforeClosingBrace(e,w)&&!d(k))return null}if(a.open.length===1&&(n==="'"||n==='"')&&l!=="always"){const k=xr(e.wordSeparators);if(C.length>0){const I=C.charCodeAt(C.length-1);if(k.get(I)===0)return null}}if(!t.tokenization.isCheapToTokenize(m))return null;t.tokenization.forceTokenization(m);const S=t.tokenization.getLineTokens(m),x=hx(S,_-1);if(!a.shouldAutoClose(x,_-x.firstCharOffset))return null;const L=a.findNeutralCharacter();if(L){const k=t.tokenization.getTokenTypeIfInsertingCharacter(m,_,L);if(!a.isOK(k))return null}}return g?a.close.substring(0,a.close.length-h.length):a.close}static _runAutoClosingOpenCharType(e,t,i,n,o,r,a){const l=[];for(let d=0,c=n.length;d<c;d++){const u=n[d];l[d]=new AH(u,o,!r,a)}return new Us(4,l,{shouldPushStackElementBefore:!0,shouldPushStackElementAfter:!1})}static _shouldSurroundChar(e,t){return yc(t)?e.autoSurround==="quotes"||e.autoSurround==="languageDefined":e.autoSurround==="brackets"||e.autoSurround==="languageDefined"}static _isSurroundSelectionType(e,t,i,n){if(!bi._shouldSurroundChar(e,n)||!e.surroundingPairs.hasOwnProperty(n))return!1;const o=yc(n);for(const r of i){if(r.isEmpty())return!1;let a=!0;for(let l=r.startLineNumber;l<=r.endLineNumber;l++){const d=t.getLineContent(l),c=l===r.startLineNumber?r.startColumn-1:0,u=l===r.endLineNumber?r.endColumn-1:d.length,h=d.substring(c,u);if(/[^ \t]/.test(h)){a=!1;break}}if(a)return!1;if(o&&r.startLineNumber===r.endLineNumber&&r.startColumn+1===r.endColumn){const l=t.getValueInRange(r);if(yc(l))return!1}}return!0}static _runSurroundSelectionType(e,t,i,n,o){const r=[];for(let a=0,l=n.length;a<l;a++){const d=n[a],c=t.surroundingPairs[o];r[a]=new oae(d,o,c)}return new Us(0,r,{shouldPushStackElementBefore:!0,shouldPushStackElementAfter:!0})}static _isTypeInterceptorElectricChar(e,t,i){return!!(i.length===1&&t.tokenization.isCheapToTokenize(i[0].getEndPosition().lineNumber))}static _typeInterceptorElectricChar(e,t,i,n,o){if(!t.electricChars.hasOwnProperty(o)||!n.isEmpty())return null;const r=n.getPosition();i.tokenization.forceTokenization(r.lineNumber);const a=i.tokenization.getLineTokens(r.lineNumber);let l;try{l=t.onElectricCharacter(o,a,r.column)}catch(d){return et(d),null}if(!l)return null;if(l.matchOpenBracket){const d=(a.getLineContent()+o).lastIndexOf(l.matchOpenBracket)+1,c=i.bracketPairs.findMatchingBracketUp(l.matchOpenBracket,{lineNumber:r.lineNumber,column:d},500);if(c){if(c.startLineNumber===r.lineNumber)return null;const u=i.getLineContent(c.startLineNumber),h=Zt(u),g=t.normalizeIndentation(h),f=i.getLineContent(r.lineNumber),m=i.getLineFirstNonWhitespaceColumn(r.lineNumber)||r.column,_=f.substring(m-1,r.column-1),v=g+_+o,b=new D(r.lineNumber,1,r.lineNumber,r.column),C=new Kn(b,v);return new Us(aI(v,e),[C],{shouldPushStackElementBefore:!1,shouldPushStackElementAfter:!0})}}return null}static compositionEndWithInterceptors(e,t,i,n,o,r){if(!n)return null;let a=null;for(const u of n)if(a===null)a=u.insertedText;else if(a!==u.insertedText)return null;if(!a||a.length!==1)return null;const l=a;let d=!1;for(const u of n)if(u.deletedText.length!==0){d=!0;break}if(d){if(!bi._shouldSurroundChar(t,l)||!t.surroundingPairs.hasOwnProperty(l))return null;const u=yc(l);for(const f of n)if(f.deletedSelectionStart!==0||f.deletedSelectionEnd!==f.deletedText.length||/^[ \t]+$/.test(f.deletedText)||u&&yc(f.deletedText))return null;const h=[];for(const f of o){if(!f.isEmpty())return null;h.push(f.getPosition())}if(h.length!==n.length)return null;const g=[];for(let f=0,m=h.length;f<m;f++)g.push(new rae(h[f],n[f].deletedText,t.surroundingPairs[l]));return new Us(4,g,{shouldPushStackElementBefore:!0,shouldPushStackElementAfter:!1})}if(this._isAutoClosingOvertype(t,i,o,r,l)){const u=o.map(h=>new Kn(new D(h.positionLineNumber,h.positionColumn,h.positionLineNumber,h.positionColumn+1),"",!1));return new Us(4,u,{shouldPushStackElementBefore:!0,shouldPushStackElementAfter:!1})}const c=this._getAutoClosingPairClose(t,i,o,l,!0);return c!==null?this._runAutoClosingOpenCharType(e,t,i,o,l,!0,c):null}static typeWithInterceptors(e,t,i,n,o,r,a){if(!e&&a===`
`){const c=[];for(let u=0,h=o.length;u<h;u++)c[u]=bi._enter(i,n,!1,o[u]);return new Us(4,c,{shouldPushStackElementBefore:!0,shouldPushStackElementAfter:!1})}if(!e&&this._isAutoIndentType(i,n,o)){const c=[];let u=!1;for(let h=0,g=o.length;h<g;h++)if(c[h]=this._runAutoIndentType(i,n,o[h],a),!c[h]){u=!0;break}if(!u)return new Us(4,c,{shouldPushStackElementBefore:!0,shouldPushStackElementAfter:!1})}if(this._isAutoClosingOvertype(i,n,o,r,a))return this._runAutoClosingOvertype(t,i,n,o,a);if(!e){const c=this._getAutoClosingPairClose(i,n,o,a,!1);if(c)return this._runAutoClosingOpenCharType(t,i,n,o,a,!1,c)}if(!e&&this._isSurroundSelectionType(i,n,o,a))return this._runSurroundSelectionType(t,i,n,o,a);if(!e&&this._isTypeInterceptorElectricChar(i,n,o)){const c=this._typeInterceptorElectricChar(t,i,n,o[0],a);if(c)return c}const l=[];for(let c=0,u=o.length;c<u;c++)l[c]=new Kn(o[c],a);const d=aI(a,t);return new Us(d,l,{shouldPushStackElementBefore:C1(t,d),shouldPushStackElementAfter:!1})}static typeWithoutInterceptors(e,t,i,n,o){const r=[];for(let l=0,d=n.length;l<d;l++)r[l]=new Kn(n[l],o);const a=aI(o,e);return new Us(a,r,{shouldPushStackElementBefore:C1(e,a),shouldPushStackElementAfter:!1})}static lineInsertBefore(e,t,i){if(t===null||i===null)return[];const n=[];for(let o=0,r=i.length;o<r;o++){let a=i[o].positionLineNumber;if(a===1)n[o]=new v1(new D(1,1,1,1),`
`);else{a--;const l=t.getLineMaxColumn(a);n[o]=this._enter(e,t,!1,new D(a,l,a,l))}}return n}static lineInsertAfter(e,t,i){if(t===null||i===null)return[];const n=[];for(let o=0,r=i.length;o<r;o++){const a=i[o].positionLineNumber,l=t.getLineMaxColumn(a);n[o]=this._enter(e,t,!1,new D(a,l,a,l))}return n}static lineBreakInsert(e,t,i){const n=[];for(let o=0,r=i.length;o<r;o++)n[o]=this._enter(e,t,!0,i[o]);return n}}class AH extends Vw{constructor(e,t,i,n){super(e,(i?t:"")+n,0,-n.length),this._openCharacter=t,this._closeCharacter=n,this.closeCharacterRange=null,this.enclosingRange=null}computeCursorState(e,t){const n=t.getInverseEditOperations()[0].range;return this.closeCharacterRange=new D(n.startLineNumber,n.endColumn-this._closeCharacter.length,n.endLineNumber,n.endColumn),this.enclosingRange=new D(n.startLineNumber,n.endColumn-this._openCharacter.length-this._closeCharacter.length,n.endLineNumber,n.endColumn),super.computeCursorState(e,t)}}class cae{constructor(e,t,i,n,o,r){this.deletedText=e,this.deletedSelectionStart=t,this.deletedSelectionEnd=i,this.insertedText=n,this.insertedSelectionStart=o,this.insertedSelectionEnd=r}}function aI(s,e){return s===" "?e===5||e===6?6:5:4}function C1(s,e){return W3(s)&&!W3(e)?!0:s===5?!1:B3(s)!==B3(e)}function B3(s){return s===6||s===5?"space":s}function W3(s){return s===4||s===5||s===6}var T;(function(s){s.editorSimpleInput=new me("editorSimpleInput",!1,!0),s.editorTextFocus=new me("editorTextFocus",!1,p("editorTextFocus","Whether the editor text has focus (cursor is blinking)")),s.focus=new me("editorFocus",!1,p("editorFocus","Whether the editor or an editor widget has focus (e.g. focus is in the find widget)")),s.textInputFocus=new me("textInputFocus",!1,p("textInputFocus","Whether an editor or a rich text input has focus (cursor is blinking)")),s.readOnly=new me("editorReadonly",!1,p("editorReadonly","Whether the editor is read-only")),s.inDiffEditor=new me("inDiffEditor",!1,p("inDiffEditor","Whether the context is a diff editor")),s.isEmbeddedDiffEditor=new me("isEmbeddedDiffEditor",!1,p("isEmbeddedDiffEditor","Whether the context is an embedded diff editor")),s.inMultiDiffEditor=new me("inMultiDiffEditor",!1,p("inMultiDiffEditor","Whether the context is a multi diff editor")),s.multiDiffEditorAllCollapsed=new me("multiDiffEditorAllCollapsed",void 0,p("multiDiffEditorAllCollapsed","Whether all files in multi diff editor are collapsed")),s.hasChanges=new me("diffEditorHasChanges",!1,p("diffEditorHasChanges","Whether the diff editor has changes")),s.comparingMovedCode=new me("comparingMovedCode",!1,p("comparingMovedCode","Whether a moved code block is selected for comparison")),s.accessibleDiffViewerVisible=new me("accessibleDiffViewerVisible",!1,p("accessibleDiffViewerVisible","Whether the accessible diff viewer is visible")),s.diffEditorRenderSideBySideInlineBreakpointReached=new me("diffEditorRenderSideBySideInlineBreakpointReached",!1,p("diffEditorRenderSideBySideInlineBreakpointReached","Whether the diff editor render side by side inline breakpoint is reached")),s.columnSelection=new me("editorColumnSelection",!1,p("editorColumnSelection","Whether `editor.columnSelection` is enabled")),s.writable=s.readOnly.toNegated(),s.hasNonEmptySelection=new me("editorHasSelection",!1,p("editorHasSelection","Whether the editor has text selected")),s.hasOnlyEmptySelection=s.hasNonEmptySelection.toNegated(),s.hasMultipleSelections=new me("editorHasMultipleSelections",!1,p("editorHasMultipleSelections","Whether the editor has multiple selections")),s.hasSingleSelection=s.hasMultipleSelections.toNegated(),s.tabMovesFocus=new me("editorTabMovesFocus",!1,p("editorTabMovesFocus","Whether `Tab` will move focus out of the editor")),s.tabDoesNotMoveFocus=s.tabMovesFocus.toNegated(),s.isInWalkThroughSnippet=new me("isInEmbeddedEditor",!1,!0),s.canUndo=new me("canUndo",!1,!0),s.canRedo=new me("canRedo",!1,!0),s.hoverVisible=new me("editorHoverVisible",!1,p("editorHoverVisible","Whether the editor hover is visible")),s.hoverFocused=new me("editorHoverFocused",!1,p("editorHoverFocused","Whether the editor hover is focused")),s.stickyScrollFocused=new me("stickyScrollFocused",!1,p("stickyScrollFocused","Whether the sticky scroll is focused")),s.stickyScrollVisible=new me("stickyScrollVisible",!1,p("stickyScrollVisible","Whether the sticky scroll is visible")),s.standaloneColorPickerVisible=new me("standaloneColorPickerVisible",!1,p("standaloneColorPickerVisible","Whether the standalone color picker is visible")),s.standaloneColorPickerFocused=new me("standaloneColorPickerFocused",!1,p("standaloneColorPickerFocused","Whether the standalone color picker is focused")),s.inCompositeEditor=new me("inCompositeEditor",void 0,p("inCompositeEditor","Whether the editor is part of a larger editor (e.g. notebooks)")),s.notInCompositeEditor=s.inCompositeEditor.toNegated(),s.languageId=new me("editorLangId","",p("editorLangId","The language identifier of the editor")),s.hasCompletionItemProvider=new me("editorHasCompletionItemProvider",!1,p("editorHasCompletionItemProvider","Whether the editor has a completion item provider")),s.hasCodeActionsProvider=new me("editorHasCodeActionsProvider",!1,p("editorHasCodeActionsProvider","Whether the editor has a code actions provider")),s.hasCodeLensProvider=new me("editorHasCodeLensProvider",!1,p("editorHasCodeLensProvider","Whether the editor has a code lens provider")),s.hasDefinitionProvider=new me("editorHasDefinitionProvider",!1,p("editorHasDefinitionProvider","Whether the editor has a definition provider")),s.hasDeclarationProvider=new me("editorHasDeclarationProvider",!1,p("editorHasDeclarationProvider","Whether the editor has a declaration provider")),s.hasImplementationProvider=new me("editorHasImplementationProvider",!1,p("editorHasImplementationProvider","Whether the editor has an implementation provider")),s.hasTypeDefinitionProvider=new me("editorHasTypeDefinitionProvider",!1,p("editorHasTypeDefinitionProvider","Whether the editor has a type definition provider")),s.hasHoverProvider=new me("editorHasHoverProvider",!1,p("editorHasHoverProvider","Whether the editor has a hover provider")),s.hasDocumentHighlightProvider=new me("editorHasDocumentHighlightProvider",!1,p("editorHasDocumentHighlightProvider","Whether the editor has a document highlight provider")),s.hasDocumentSymbolProvider=new me("editorHasDocumentSymbolProvider",!1,p("editorHasDocumentSymbolProvider","Whether the editor has a document symbol provider")),s.hasReferenceProvider=new me("editorHasReferenceProvider",!1,p("editorHasReferenceProvider","Whether the editor has a reference provider")),s.hasRenameProvider=new me("editorHasRenameProvider",!1,p("editorHasRenameProvider","Whether the editor has a rename provider")),s.hasSignatureHelpProvider=new me("editorHasSignatureHelpProvider",!1,p("editorHasSignatureHelpProvider","Whether the editor has a signature help provider")),s.hasInlayHintsProvider=new me("editorHasInlayHintsProvider",!1,p("editorHasInlayHintsProvider","Whether the editor has an inline hints provider")),s.hasDocumentFormattingProvider=new me("editorHasDocumentFormattingProvider",!1,p("editorHasDocumentFormattingProvider","Whether the editor has a document formatting provider")),s.hasDocumentSelectionFormattingProvider=new me("editorHasDocumentSelectionFormattingProvider",!1,p("editorHasDocumentSelectionFormattingProvider","Whether the editor has a document selection formatting provider")),s.hasMultipleDocumentFormattingProvider=new me("editorHasMultipleDocumentFormattingProvider",!1,p("editorHasMultipleDocumentFormattingProvider","Whether the editor has multiple document formatting providers")),s.hasMultipleDocumentSelectionFormattingProvider=new me("editorHasMultipleDocumentSelectionFormattingProvider",!1,p("editorHasMultipleDocumentSelectionFormattingProvider","Whether the editor has multiple document selection formatting providers"))})(T||(T={}));const Et=0;class Ti extends Nn{runEditorCommand(e,t,i){const n=t._getViewModel();n&&this.runCoreEditorCommand(n,i||{})}}var Un;(function(s){const e=function(i){if(!Ts(i))return!1;const n=i;return!(!Ps(n.to)||!fo(n.by)&&!Ps(n.by)||!fo(n.value)&&!xu(n.value)||!fo(n.revealCursor)&&!hW(n.revealCursor))};s.metadata={description:"Scroll editor in the given direction",args:[{name:"Editor scroll argument object",description:"Property-value pairs that can be passed through this argument:\n					* 'to': A mandatory direction value.\n						```\n						'up', 'down'\n						```\n					* 'by': Unit to move. Default is computed based on 'to' value.\n						```\n						'line', 'wrappedLine', 'page', 'halfPage', 'editor'\n						```\n					* 'value': Number of units to move. Default is '1'.\n					* 'revealCursor': If 'true' reveals the cursor if it is outside view port.\n				",constraint:e,schema:{type:"object",required:["to"],properties:{to:{type:"string",enum:["up","down"]},by:{type:"string",enum:["line","wrappedLine","page","halfPage","editor"]},value:{type:"number",default:1},revealCursor:{type:"boolean"}}}}]},s.RawDirection={Up:"up",Right:"right",Down:"down",Left:"left"},s.RawUnit={Line:"line",WrappedLine:"wrappedLine",Page:"page",HalfPage:"halfPage",Editor:"editor",Column:"column"};function t(i){let n;switch(i.to){case s.RawDirection.Up:n=1;break;case s.RawDirection.Right:n=2;break;case s.RawDirection.Down:n=3;break;case s.RawDirection.Left:n=4;break;default:return null}let o;switch(i.by){case s.RawUnit.Line:o=1;break;case s.RawUnit.WrappedLine:o=2;break;case s.RawUnit.Page:o=3;break;case s.RawUnit.HalfPage:o=4;break;case s.RawUnit.Editor:o=5;break;case s.RawUnit.Column:o=6;break;default:o=2}const r=Math.floor(i.value||1),a=!!i.revealCursor;return{direction:n,unit:o,value:r,revealCursor:a,select:!!i.select}}s.parse=t})(Un||(Un={}));var pp;(function(s){const e=function(t){if(!Ts(t))return!1;const i=t;return!(!xu(i.lineNumber)&&!Ps(i.lineNumber)||!fo(i.at)&&!Ps(i.at))};s.metadata={description:"Reveal the given line at the given logical position",args:[{name:"Reveal line argument object",description:"Property-value pairs that can be passed through this argument:\n					* 'lineNumber': A mandatory line number value.\n					* 'at': Logical position at which line has to be revealed.\n						```\n						'top', 'center', 'bottom'\n						```\n				",constraint:e,schema:{type:"object",required:["lineNumber"],properties:{lineNumber:{type:["number","string"]},at:{type:"string",enum:["top","center","bottom"]}}}}]},s.RawAtArgument={Top:"top",Center:"center",Bottom:"bottom"}})(pp||(pp={}));class ST{constructor(e){e.addImplementation(1e4,"code-editor",(t,i)=>{const n=t.get(It).getFocusedCodeEditor();return n&&n.hasTextFocus()?this._runEditorCommand(t,n,i):!1}),e.addImplementation(1e3,"generic-dom-input-textarea",(t,i)=>{const n=Jo();return n&&["input","textarea"].indexOf(n.tagName.toLowerCase())>=0?(this.runDOMCommand(n),!0):!1}),e.addImplementation(0,"generic-dom",(t,i)=>{const n=t.get(It).getActiveCodeEditor();return n?(n.focus(),this._runEditorCommand(t,n,i)):!1})}_runEditorCommand(e,t,i){const n=this.runEditorCommand(e,t,i);return n||!0}}var Sn;(function(s){class e extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){if(!C.position)return;b.model.pushStackElement(),b.setCursorStates(C.source,3,[Mn.moveTo(b,b.getPrimaryCursorState(),this._inSelectionMode,C.position,C.viewPosition)])&&C.revealType!==2&&b.revealPrimaryCursor(C.source,!0,!0)}}s.MoveTo=ue(new e({id:"_moveTo",inSelectionMode:!1,precondition:void 0})),s.MoveToSelect=ue(new e({id:"_moveToSelect",inSelectionMode:!0,precondition:void 0}));class t extends Ti{runCoreEditorCommand(b,C){b.model.pushStackElement();const w=this._getColumnSelectResult(b,b.getPrimaryCursorState(),b.getCursorColumnSelectData(),C);w!==null&&(b.setCursorStates(C.source,3,w.viewStates.map(S=>yt.fromViewState(S))),b.setCursorColumnSelectData({isReal:!0,fromViewLineNumber:w.fromLineNumber,fromViewVisualColumn:w.fromVisualColumn,toViewLineNumber:w.toLineNumber,toViewVisualColumn:w.toVisualColumn}),w.reversed?b.revealTopMostCursor(C.source):b.revealBottomMostCursor(C.source))}}s.ColumnSelect=ue(new class extends t{constructor(){super({id:"columnSelect",precondition:void 0})}_getColumnSelectResult(v,b,C,w){if(typeof w.position>"u"||typeof w.viewPosition>"u"||typeof w.mouseColumn>"u")return null;const S=v.model.validatePosition(w.position),x=v.coordinatesConverter.validateViewPosition(new H(w.viewPosition.lineNumber,w.viewPosition.column),S),L=w.doColumnSelect?C.fromViewLineNumber:x.lineNumber,k=w.doColumnSelect?C.fromViewVisualColumn:w.mouseColumn-1;return Kh.columnSelect(v.cursorConfig,v,L,k,x.lineNumber,w.mouseColumn-1)}}),s.CursorColumnSelectLeft=ue(new class extends t{constructor(){super({id:"cursorColumnSelectLeft",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:3599,linux:{primary:0}}})}_getColumnSelectResult(v,b,C,w){return Kh.columnSelectLeft(v.cursorConfig,v,C)}}),s.CursorColumnSelectRight=ue(new class extends t{constructor(){super({id:"cursorColumnSelectRight",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:3601,linux:{primary:0}}})}_getColumnSelectResult(v,b,C,w){return Kh.columnSelectRight(v.cursorConfig,v,C)}});class i extends t{constructor(b){super(b),this._isPaged=b.isPaged}_getColumnSelectResult(b,C,w,S){return Kh.columnSelectUp(b.cursorConfig,b,w,this._isPaged)}}s.CursorColumnSelectUp=ue(new i({isPaged:!1,id:"cursorColumnSelectUp",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:3600,linux:{primary:0}}})),s.CursorColumnSelectPageUp=ue(new i({isPaged:!0,id:"cursorColumnSelectPageUp",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:3595,linux:{primary:0}}}));class n extends t{constructor(b){super(b),this._isPaged=b.isPaged}_getColumnSelectResult(b,C,w,S){return Kh.columnSelectDown(b.cursorConfig,b,w,this._isPaged)}}s.CursorColumnSelectDown=ue(new n({isPaged:!1,id:"cursorColumnSelectDown",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:3602,linux:{primary:0}}})),s.CursorColumnSelectPageDown=ue(new n({isPaged:!0,id:"cursorColumnSelectPageDown",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:3596,linux:{primary:0}}}));class o extends Ti{constructor(){super({id:"cursorMove",precondition:void 0,metadata:ey.metadata})}runCoreEditorCommand(b,C){const w=ey.parse(C);w&&this._runCursorMove(b,C.source,w)}_runCursorMove(b,C,w){b.model.pushStackElement(),b.setCursorStates(C,3,o._move(b,b.getCursorStates(),w)),b.revealPrimaryCursor(C,!0)}static _move(b,C,w){const S=w.select,x=w.value;switch(w.direction){case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 9:case 10:return Mn.simpleMove(b,C,w.direction,S,x,w.unit);case 11:case 13:case 12:case 14:return Mn.viewportMove(b,C,w.direction,S,x);default:return null}}}s.CursorMoveImpl=o,s.CursorMove=ue(new o);class r extends Ti{constructor(b){super(b),this._staticArgs=b.args}runCoreEditorCommand(b,C){let w=this._staticArgs;this._staticArgs.value===-1&&(w={direction:this._staticArgs.direction,unit:this._staticArgs.unit,select:this._staticArgs.select,value:C.pageSize||b.cursorConfig.pageSize}),b.model.pushStackElement(),b.setCursorStates(C.source,3,Mn.simpleMove(b,b.getCursorStates(),w.direction,w.select,w.value,w.unit)),b.revealPrimaryCursor(C.source,!0)}}s.CursorLeft=ue(new r({args:{direction:0,unit:0,select:!1,value:1},id:"cursorLeft",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:15,mac:{primary:15,secondary:[288]}}})),s.CursorLeftSelect=ue(new r({args:{direction:0,unit:0,select:!0,value:1},id:"cursorLeftSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:1039}})),s.CursorRight=ue(new r({args:{direction:1,unit:0,select:!1,value:1},id:"cursorRight",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:17,mac:{primary:17,secondary:[292]}}})),s.CursorRightSelect=ue(new r({args:{direction:1,unit:0,select:!0,value:1},id:"cursorRightSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:1041}})),s.CursorUp=ue(new r({args:{direction:2,unit:2,select:!1,value:1},id:"cursorUp",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:16,mac:{primary:16,secondary:[302]}}})),s.CursorUpSelect=ue(new r({args:{direction:2,unit:2,select:!0,value:1},id:"cursorUpSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:1040,secondary:[3088],mac:{primary:1040},linux:{primary:1040}}})),s.CursorPageUp=ue(new r({args:{direction:2,unit:2,select:!1,value:-1},id:"cursorPageUp",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:11}})),s.CursorPageUpSelect=ue(new r({args:{direction:2,unit:2,select:!0,value:-1},id:"cursorPageUpSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:1035}})),s.CursorDown=ue(new r({args:{direction:3,unit:2,select:!1,value:1},id:"cursorDown",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:18,mac:{primary:18,secondary:[300]}}})),s.CursorDownSelect=ue(new r({args:{direction:3,unit:2,select:!0,value:1},id:"cursorDownSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:1042,secondary:[3090],mac:{primary:1042},linux:{primary:1042}}})),s.CursorPageDown=ue(new r({args:{direction:3,unit:2,select:!1,value:-1},id:"cursorPageDown",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:12}})),s.CursorPageDownSelect=ue(new r({args:{direction:3,unit:2,select:!0,value:-1},id:"cursorPageDownSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:1036}})),s.CreateCursor=ue(new class extends Ti{constructor(){super({id:"createCursor",precondition:void 0})}runCoreEditorCommand(v,b){if(!b.position)return;let C;b.wholeLine?C=Mn.line(v,v.getPrimaryCursorState(),!1,b.position,b.viewPosition):C=Mn.moveTo(v,v.getPrimaryCursorState(),!1,b.position,b.viewPosition);const w=v.getCursorStates();if(w.length>1){const S=C.modelState?C.modelState.position:null,x=C.viewState?C.viewState.position:null;for(let L=0,k=w.length;L<k;L++){const I=w[L];if(!(S&&!I.modelState.selection.containsPosition(S))&&!(x&&!I.viewState.selection.containsPosition(x))){w.splice(L,1),v.model.pushStackElement(),v.setCursorStates(b.source,3,w);return}}}w.push(C),v.model.pushStackElement(),v.setCursorStates(b.source,3,w)}}),s.LastCursorMoveToSelect=ue(new class extends Ti{constructor(){super({id:"_lastCursorMoveToSelect",precondition:void 0})}runCoreEditorCommand(v,b){if(!b.position)return;const C=v.getLastAddedCursorIndex(),w=v.getCursorStates(),S=w.slice(0);S[C]=Mn.moveTo(v,w[C],!0,b.position,b.viewPosition),v.model.pushStackElement(),v.setCursorStates(b.source,3,S)}});class a extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){b.model.pushStackElement(),b.setCursorStates(C.source,3,Mn.moveToBeginningOfLine(b,b.getCursorStates(),this._inSelectionMode)),b.revealPrimaryCursor(C.source,!0)}}s.CursorHome=ue(new a({inSelectionMode:!1,id:"cursorHome",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:14,mac:{primary:14,secondary:[2063]}}})),s.CursorHomeSelect=ue(new a({inSelectionMode:!0,id:"cursorHomeSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:1038,mac:{primary:1038,secondary:[3087]}}}));class l extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){b.model.pushStackElement(),b.setCursorStates(C.source,3,this._exec(b.getCursorStates())),b.revealPrimaryCursor(C.source,!0)}_exec(b){const C=[];for(let w=0,S=b.length;w<S;w++){const x=b[w],L=x.modelState.position.lineNumber;C[w]=yt.fromModelState(x.modelState.move(this._inSelectionMode,L,1,0))}return C}}s.CursorLineStart=ue(new l({inSelectionMode:!1,id:"cursorLineStart",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:0,mac:{primary:287}}})),s.CursorLineStartSelect=ue(new l({inSelectionMode:!0,id:"cursorLineStartSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:0,mac:{primary:1311}}}));class d extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){b.model.pushStackElement(),b.setCursorStates(C.source,3,Mn.moveToEndOfLine(b,b.getCursorStates(),this._inSelectionMode,C.sticky||!1)),b.revealPrimaryCursor(C.source,!0)}}s.CursorEnd=ue(new d({inSelectionMode:!1,id:"cursorEnd",precondition:void 0,kbOpts:{args:{sticky:!1},weight:Et,kbExpr:T.textInputFocus,primary:13,mac:{primary:13,secondary:[2065]}},metadata:{description:"Go to End",args:[{name:"args",schema:{type:"object",properties:{sticky:{description:p("stickydesc","Stick to the end even when going to longer lines"),type:"boolean",default:!1}}}}]}})),s.CursorEndSelect=ue(new d({inSelectionMode:!0,id:"cursorEndSelect",precondition:void 0,kbOpts:{args:{sticky:!1},weight:Et,kbExpr:T.textInputFocus,primary:1037,mac:{primary:1037,secondary:[3089]}},metadata:{description:"Select to End",args:[{name:"args",schema:{type:"object",properties:{sticky:{description:p("stickydesc","Stick to the end even when going to longer lines"),type:"boolean",default:!1}}}}]}}));class c extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){b.model.pushStackElement(),b.setCursorStates(C.source,3,this._exec(b,b.getCursorStates())),b.revealPrimaryCursor(C.source,!0)}_exec(b,C){const w=[];for(let S=0,x=C.length;S<x;S++){const L=C[S],k=L.modelState.position.lineNumber,I=b.model.getLineMaxColumn(k);w[S]=yt.fromModelState(L.modelState.move(this._inSelectionMode,k,I,0))}return w}}s.CursorLineEnd=ue(new c({inSelectionMode:!1,id:"cursorLineEnd",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:0,mac:{primary:291}}})),s.CursorLineEndSelect=ue(new c({inSelectionMode:!0,id:"cursorLineEndSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:0,mac:{primary:1315}}}));class u extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){b.model.pushStackElement(),b.setCursorStates(C.source,3,Mn.moveToBeginningOfBuffer(b,b.getCursorStates(),this._inSelectionMode)),b.revealPrimaryCursor(C.source,!0)}}s.CursorTop=ue(new u({inSelectionMode:!1,id:"cursorTop",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:2062,mac:{primary:2064}}})),s.CursorTopSelect=ue(new u({inSelectionMode:!0,id:"cursorTopSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:3086,mac:{primary:3088}}}));class h extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){b.model.pushStackElement(),b.setCursorStates(C.source,3,Mn.moveToEndOfBuffer(b,b.getCursorStates(),this._inSelectionMode)),b.revealPrimaryCursor(C.source,!0)}}s.CursorBottom=ue(new h({inSelectionMode:!1,id:"cursorBottom",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:2061,mac:{primary:2066}}})),s.CursorBottomSelect=ue(new h({inSelectionMode:!0,id:"cursorBottomSelect",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:3085,mac:{primary:3090}}}));class g extends Ti{constructor(){super({id:"editorScroll",precondition:void 0,metadata:Un.metadata})}determineScrollMethod(b){const C=[6],w=[1,2,3,4,5,6],S=[4,2],x=[1,3];return C.includes(b.unit)&&S.includes(b.direction)?this._runHorizontalEditorScroll.bind(this):w.includes(b.unit)&&x.includes(b.direction)?this._runVerticalEditorScroll.bind(this):null}runCoreEditorCommand(b,C){const w=Un.parse(C);if(!w)return;const S=this.determineScrollMethod(w);S&&S(b,C.source,w)}_runVerticalEditorScroll(b,C,w){const S=this._computeDesiredScrollTop(b,w);if(w.revealCursor){const x=b.getCompletelyVisibleViewRangeAtScrollTop(S);b.setCursorStates(C,3,[Mn.findPositionInViewportIfOutside(b,b.getPrimaryCursorState(),x,w.select)])}b.viewLayout.setScrollPosition({scrollTop:S},0)}_computeDesiredScrollTop(b,C){if(C.unit===1){const x=b.viewLayout.getFutureViewport(),L=b.getCompletelyVisibleViewRangeAtScrollTop(x.top),k=b.coordinatesConverter.convertViewRangeToModelRange(L);let I;C.direction===1?I=Math.max(1,k.startLineNumber-C.value):I=Math.min(b.model.getLineCount(),k.startLineNumber+C.value);const P=b.coordinatesConverter.convertModelPositionToViewPosition(new H(I,1));return b.viewLayout.getVerticalOffsetForLineNumber(P.lineNumber)}if(C.unit===5){let x=0;return C.direction===3&&(x=b.model.getLineCount()-b.cursorConfig.pageSize),b.viewLayout.getVerticalOffsetForLineNumber(x)}let w;C.unit===3?w=b.cursorConfig.pageSize*C.value:C.unit===4?w=Math.round(b.cursorConfig.pageSize/2)*C.value:w=C.value;const S=(C.direction===1?-1:1)*w;return b.viewLayout.getCurrentScrollTop()+S*b.cursorConfig.lineHeight}_runHorizontalEditorScroll(b,C,w){const S=this._computeDesiredScrollLeft(b,w);b.viewLayout.setScrollPosition({scrollLeft:S},0)}_computeDesiredScrollLeft(b,C){const w=(C.direction===4?-1:1)*C.value;return b.viewLayout.getCurrentScrollLeft()+w*b.cursorConfig.typicalHalfwidthCharacterWidth}}s.EditorScrollImpl=g,s.EditorScroll=ue(new g),s.ScrollLineUp=ue(new class extends Ti{constructor(){super({id:"scrollLineUp",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:2064,mac:{primary:267}}})}runCoreEditorCommand(v,b){s.EditorScroll.runCoreEditorCommand(v,{to:Un.RawDirection.Up,by:Un.RawUnit.WrappedLine,value:1,revealCursor:!1,select:!1,source:b.source})}}),s.ScrollPageUp=ue(new class extends Ti{constructor(){super({id:"scrollPageUp",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:2059,win:{primary:523},linux:{primary:523}}})}runCoreEditorCommand(v,b){s.EditorScroll.runCoreEditorCommand(v,{to:Un.RawDirection.Up,by:Un.RawUnit.Page,value:1,revealCursor:!1,select:!1,source:b.source})}}),s.ScrollEditorTop=ue(new class extends Ti{constructor(){super({id:"scrollEditorTop",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus}})}runCoreEditorCommand(v,b){s.EditorScroll.runCoreEditorCommand(v,{to:Un.RawDirection.Up,by:Un.RawUnit.Editor,value:1,revealCursor:!1,select:!1,source:b.source})}}),s.ScrollLineDown=ue(new class extends Ti{constructor(){super({id:"scrollLineDown",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:2066,mac:{primary:268}}})}runCoreEditorCommand(v,b){s.EditorScroll.runCoreEditorCommand(v,{to:Un.RawDirection.Down,by:Un.RawUnit.WrappedLine,value:1,revealCursor:!1,select:!1,source:b.source})}}),s.ScrollPageDown=ue(new class extends Ti{constructor(){super({id:"scrollPageDown",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:2060,win:{primary:524},linux:{primary:524}}})}runCoreEditorCommand(v,b){s.EditorScroll.runCoreEditorCommand(v,{to:Un.RawDirection.Down,by:Un.RawUnit.Page,value:1,revealCursor:!1,select:!1,source:b.source})}}),s.ScrollEditorBottom=ue(new class extends Ti{constructor(){super({id:"scrollEditorBottom",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus}})}runCoreEditorCommand(v,b){s.EditorScroll.runCoreEditorCommand(v,{to:Un.RawDirection.Down,by:Un.RawUnit.Editor,value:1,revealCursor:!1,select:!1,source:b.source})}}),s.ScrollLeft=ue(new class extends Ti{constructor(){super({id:"scrollLeft",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus}})}runCoreEditorCommand(v,b){s.EditorScroll.runCoreEditorCommand(v,{to:Un.RawDirection.Left,by:Un.RawUnit.Column,value:2,revealCursor:!1,select:!1,source:b.source})}}),s.ScrollRight=ue(new class extends Ti{constructor(){super({id:"scrollRight",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus}})}runCoreEditorCommand(v,b){s.EditorScroll.runCoreEditorCommand(v,{to:Un.RawDirection.Right,by:Un.RawUnit.Column,value:2,revealCursor:!1,select:!1,source:b.source})}});class f extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){C.position&&(b.model.pushStackElement(),b.setCursorStates(C.source,3,[Mn.word(b,b.getPrimaryCursorState(),this._inSelectionMode,C.position)]),C.revealType!==2&&b.revealPrimaryCursor(C.source,!0,!0))}}s.WordSelect=ue(new f({inSelectionMode:!1,id:"_wordSelect",precondition:void 0})),s.WordSelectDrag=ue(new f({inSelectionMode:!0,id:"_wordSelectDrag",precondition:void 0})),s.LastCursorWordSelect=ue(new class extends Ti{constructor(){super({id:"lastCursorWordSelect",precondition:void 0})}runCoreEditorCommand(v,b){if(!b.position)return;const C=v.getLastAddedCursorIndex(),w=v.getCursorStates(),S=w.slice(0),x=w[C];S[C]=Mn.word(v,x,x.modelState.hasSelection(),b.position),v.model.pushStackElement(),v.setCursorStates(b.source,3,S)}});class m extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){C.position&&(b.model.pushStackElement(),b.setCursorStates(C.source,3,[Mn.line(b,b.getPrimaryCursorState(),this._inSelectionMode,C.position,C.viewPosition)]),C.revealType!==2&&b.revealPrimaryCursor(C.source,!1,!0))}}s.LineSelect=ue(new m({inSelectionMode:!1,id:"_lineSelect",precondition:void 0})),s.LineSelectDrag=ue(new m({inSelectionMode:!0,id:"_lineSelectDrag",precondition:void 0}));class _ extends Ti{constructor(b){super(b),this._inSelectionMode=b.inSelectionMode}runCoreEditorCommand(b,C){if(!C.position)return;const w=b.getLastAddedCursorIndex(),S=b.getCursorStates(),x=S.slice(0);x[w]=Mn.line(b,S[w],this._inSelectionMode,C.position,C.viewPosition),b.model.pushStackElement(),b.setCursorStates(C.source,3,x)}}s.LastCursorLineSelect=ue(new _({inSelectionMode:!1,id:"lastCursorLineSelect",precondition:void 0})),s.LastCursorLineSelectDrag=ue(new _({inSelectionMode:!0,id:"lastCursorLineSelectDrag",precondition:void 0})),s.CancelSelection=ue(new class extends Ti{constructor(){super({id:"cancelSelection",precondition:T.hasNonEmptySelection,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:9,secondary:[1033]}})}runCoreEditorCommand(v,b){v.model.pushStackElement(),v.setCursorStates(b.source,3,[Mn.cancelSelection(v,v.getPrimaryCursorState())]),v.revealPrimaryCursor(b.source,!0)}}),s.RemoveSecondaryCursors=ue(new class extends Ti{constructor(){super({id:"removeSecondaryCursors",precondition:T.hasMultipleSelections,kbOpts:{weight:Et+1,kbExpr:T.textInputFocus,primary:9,secondary:[1033]}})}runCoreEditorCommand(v,b){v.model.pushStackElement(),v.setCursorStates(b.source,3,[v.getPrimaryCursorState()]),v.revealPrimaryCursor(b.source,!0),Au(p("removedCursor","Removed secondary cursors"))}}),s.RevealLine=ue(new class extends Ti{constructor(){super({id:"revealLine",precondition:void 0,metadata:pp.metadata})}runCoreEditorCommand(v,b){const C=b,w=C.lineNumber||0;let S=typeof w=="number"?w+1:parseInt(w)+1;S<1&&(S=1);const x=v.model.getLineCount();S>x&&(S=x);const L=new D(S,1,S,v.model.getLineMaxColumn(S));let k=0;if(C.at)switch(C.at){case pp.RawAtArgument.Top:k=3;break;case pp.RawAtArgument.Center:k=1;break;case pp.RawAtArgument.Bottom:k=4;break}const I=v.coordinatesConverter.convertModelRangeToViewRange(L);v.revealRange(b.source,!1,I,k,0)}}),s.SelectAll=new class extends ST{constructor(){super(lte)}runDOMCommand(v){yr&&(v.focus(),v.select()),v.ownerDocument.execCommand("selectAll")}runEditorCommand(v,b,C){const w=b._getViewModel();w&&this.runCoreEditorCommand(w,C)}runCoreEditorCommand(v,b){v.model.pushStackElement(),v.setCursorStates("keyboard",3,[Mn.selectAll(v,v.getPrimaryCursorState())])}},s.SetSelection=ue(new class extends Ti{constructor(){super({id:"setSelection",precondition:void 0})}runCoreEditorCommand(v,b){b.selection&&(v.model.pushStackElement(),v.setCursorStates(b.source,3,[yt.fromModelSelection(b.selection)]))}})})(Sn||(Sn={}));const uae=ee.and(T.textInputFocus,T.columnSelection);function l_(s,e){Js.registerKeybindingRule({id:s,primary:e,when:uae,weight:Et+1})}l_(Sn.CursorColumnSelectLeft.id,1039);l_(Sn.CursorColumnSelectRight.id,1041);l_(Sn.CursorColumnSelectUp.id,1040);l_(Sn.CursorColumnSelectPageUp.id,1035);l_(Sn.CursorColumnSelectDown.id,1042);l_(Sn.CursorColumnSelectPageDown.id,1036);function V3(s){return s.register(),s}var zp;(function(s){class e extends Nn{runEditorCommand(i,n,o){const r=n._getViewModel();r&&this.runCoreEditingCommand(n,r,o||{})}}s.CoreEditingCommand=e,s.LineBreakInsert=ue(new class extends e{constructor(){super({id:"lineBreakInsert",precondition:T.writable,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:0,mac:{primary:301}}})}runCoreEditingCommand(t,i,n){t.pushUndoStop(),t.executeCommands(this.id,bi.lineBreakInsert(i.cursorConfig,i.model,i.getCursorStates().map(o=>o.modelState.selection)))}}),s.Outdent=ue(new class extends e{constructor(){super({id:"outdent",precondition:T.writable,kbOpts:{weight:Et,kbExpr:ee.and(T.editorTextFocus,T.tabDoesNotMoveFocus),primary:1026}})}runCoreEditingCommand(t,i,n){t.pushUndoStop(),t.executeCommands(this.id,bi.outdent(i.cursorConfig,i.model,i.getCursorStates().map(o=>o.modelState.selection))),t.pushUndoStop()}}),s.Tab=ue(new class extends e{constructor(){super({id:"tab",precondition:T.writable,kbOpts:{weight:Et,kbExpr:ee.and(T.editorTextFocus,T.tabDoesNotMoveFocus),primary:2}})}runCoreEditingCommand(t,i,n){t.pushUndoStop(),t.executeCommands(this.id,bi.tab(i.cursorConfig,i.model,i.getCursorStates().map(o=>o.modelState.selection))),t.pushUndoStop()}}),s.DeleteLeft=ue(new class extends e{constructor(){super({id:"deleteLeft",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:1,secondary:[1025],mac:{primary:1,secondary:[1025,294,257]}}})}runCoreEditingCommand(t,i,n){const[o,r]=Rg.deleteLeft(i.getPrevEditOperationType(),i.cursorConfig,i.model,i.getCursorStates().map(a=>a.modelState.selection),i.getCursorAutoClosedCharacters());o&&t.pushUndoStop(),t.executeCommands(this.id,r),i.setPrevEditOperationType(2)}}),s.DeleteRight=ue(new class extends e{constructor(){super({id:"deleteRight",precondition:void 0,kbOpts:{weight:Et,kbExpr:T.textInputFocus,primary:20,mac:{primary:20,secondary:[290,276]}}})}runCoreEditingCommand(t,i,n){const[o,r]=Rg.deleteRight(i.getPrevEditOperationType(),i.cursorConfig,i.model,i.getCursorStates().map(a=>a.modelState.selection));o&&t.pushUndoStop(),t.executeCommands(this.id,r),i.setPrevEditOperationType(3)}}),s.Undo=new class extends ST{constructor(){super(EV)}runDOMCommand(t){t.ownerDocument.execCommand("undo")}runEditorCommand(t,i,n){if(!(!i.hasModel()||i.getOption(90)===!0))return i.getModel().undo()}},s.Redo=new class extends ST{constructor(){super(NV)}runDOMCommand(t){t.ownerDocument.execCommand("redo")}runEditorCommand(t,i,n){if(!(!i.hasModel()||i.getOption(90)===!0))return i.getModel().redo()}}})(zp||(zp={}));class H3 extends cx{constructor(e,t,i){super({id:e,precondition:void 0,metadata:i}),this._handlerId=t}runCommand(e,t){const i=e.get(It).getFocusedCodeEditor();i&&i.trigger("keyboard",this._handlerId,t)}}function cf(s,e){V3(new H3("default:"+s,s)),V3(new H3(s,s,e))}cf("type",{description:"Type",args:[{name:"args",schema:{type:"object",required:["text"],properties:{text:{type:"string"}}}}]});cf("replacePreviousChar");cf("compositionType");cf("compositionStart");cf("compositionEnd");cf("paste");cf("cut");class hae{constructor(e,t,i,n){this.configuration=e,this.viewModel=t,this.userInputEvents=i,this.commandDelegate=n}paste(e,t,i,n){this.commandDelegate.paste(e,t,i,n)}type(e){this.commandDelegate.type(e)}compositionType(e,t,i,n){this.commandDelegate.compositionType(e,t,i,n)}compositionStart(){this.commandDelegate.startComposition()}compositionEnd(){this.commandDelegate.endComposition()}cut(){this.commandDelegate.cut()}setSelection(e){Sn.SetSelection.runCoreEditorCommand(this.viewModel,{source:"keyboard",selection:e})}_validateViewColumn(e){const t=this.viewModel.getLineMinColumn(e.lineNumber);return e.column<t?new H(e.lineNumber,t):e}_hasMulticursorModifier(e){switch(this.configuration.options.get(77)){case"altKey":return e.altKey;case"ctrlKey":return e.ctrlKey;case"metaKey":return e.metaKey;default:return!1}}_hasNonMulticursorModifier(e){switch(this.configuration.options.get(77)){case"altKey":return e.ctrlKey||e.metaKey;case"ctrlKey":return e.altKey||e.metaKey;case"metaKey":return e.ctrlKey||e.altKey;default:return!1}}dispatchMouse(e){const t=this.configuration.options,i=Ss&&t.get(106),n=t.get(22);e.middleButton&&!i?this._columnSelect(e.position,e.mouseColumn,e.inSelectionMode):e.startedOnLineNumbers?this._hasMulticursorModifier(e)?e.inSelectionMode?this._lastCursorLineSelect(e.position,e.revealType):this._createCursor(e.position,!0):e.inSelectionMode?this._lineSelectDrag(e.position,e.revealType):this._lineSelect(e.position,e.revealType):e.mouseDownCount>=4?this._selectAll():e.mouseDownCount===3?this._hasMulticursorModifier(e)?e.inSelectionMode?this._lastCursorLineSelectDrag(e.position,e.revealType):this._lastCursorLineSelect(e.position,e.revealType):e.inSelectionMode?this._lineSelectDrag(e.position,e.revealType):this._lineSelect(e.position,e.revealType):e.mouseDownCount===2?e.onInjectedText||(this._hasMulticursorModifier(e)?this._lastCursorWordSelect(e.position,e.revealType):e.inSelectionMode?this._wordSelectDrag(e.position,e.revealType):this._wordSelect(e.position,e.revealType)):this._hasMulticursorModifier(e)?this._hasNonMulticursorModifier(e)||(e.shiftKey?this._columnSelect(e.position,e.mouseColumn,!0):e.inSelectionMode?this._lastCursorMoveToSelect(e.position,e.revealType):this._createCursor(e.position,!1)):e.inSelectionMode?e.altKey?this._columnSelect(e.position,e.mouseColumn,!0):n?this._columnSelect(e.position,e.mouseColumn,!0):this._moveToSelect(e.position,e.revealType):this.moveTo(e.position,e.revealType)}_usualArgs(e,t){return e=this._validateViewColumn(e),{source:"mouse",position:this._convertViewToModelPosition(e),viewPosition:e,revealType:t}}moveTo(e,t){Sn.MoveTo.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_moveToSelect(e,t){Sn.MoveToSelect.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_columnSelect(e,t,i){e=this._validateViewColumn(e),Sn.ColumnSelect.runCoreEditorCommand(this.viewModel,{source:"mouse",position:this._convertViewToModelPosition(e),viewPosition:e,mouseColumn:t,doColumnSelect:i})}_createCursor(e,t){e=this._validateViewColumn(e),Sn.CreateCursor.runCoreEditorCommand(this.viewModel,{source:"mouse",position:this._convertViewToModelPosition(e),viewPosition:e,wholeLine:t})}_lastCursorMoveToSelect(e,t){Sn.LastCursorMoveToSelect.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_wordSelect(e,t){Sn.WordSelect.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_wordSelectDrag(e,t){Sn.WordSelectDrag.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_lastCursorWordSelect(e,t){Sn.LastCursorWordSelect.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_lineSelect(e,t){Sn.LineSelect.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_lineSelectDrag(e,t){Sn.LineSelectDrag.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_lastCursorLineSelect(e,t){Sn.LastCursorLineSelect.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_lastCursorLineSelectDrag(e,t){Sn.LastCursorLineSelectDrag.runCoreEditorCommand(this.viewModel,this._usualArgs(e,t))}_selectAll(){Sn.SelectAll.runCoreEditorCommand(this.viewModel,{source:"mouse"})}_convertViewToModelPosition(e){return this.viewModel.coordinatesConverter.convertViewPositionToModelPosition(e)}emitKeyDown(e){this.userInputEvents.emitKeyDown(e)}emitKeyUp(e){this.userInputEvents.emitKeyUp(e)}emitContextMenu(e){this.userInputEvents.emitContextMenu(e)}emitMouseMove(e){this.userInputEvents.emitMouseMove(e)}emitMouseLeave(e){this.userInputEvents.emitMouseLeave(e)}emitMouseUp(e){this.userInputEvents.emitMouseUp(e)}emitMouseDown(e){this.userInputEvents.emitMouseDown(e)}emitMouseDrag(e){this.userInputEvents.emitMouseDrag(e)}emitMouseDrop(e){this.userInputEvents.emitMouseDrop(e)}emitMouseDropCanceled(){this.userInputEvents.emitMouseDropCanceled()}emitMouseWheel(e){this.userInputEvents.emitMouseWheel(e)}}class Ix{constructor(e){this.onKeyDown=null,this.onKeyUp=null,this.onContextMenu=null,this.onMouseMove=null,this.onMouseLeave=null,this.onMouseDown=null,this.onMouseUp=null,this.onMouseDrag=null,this.onMouseDrop=null,this.onMouseDropCanceled=null,this.onMouseWheel=null,this._coordinatesConverter=e}emitKeyDown(e){var t;(t=this.onKeyDown)===null||t===void 0||t.call(this,e)}emitKeyUp(e){var t;(t=this.onKeyUp)===null||t===void 0||t.call(this,e)}emitContextMenu(e){var t;(t=this.onContextMenu)===null||t===void 0||t.call(this,this._convertViewToModelMouseEvent(e))}emitMouseMove(e){var t;(t=this.onMouseMove)===null||t===void 0||t.call(this,this._convertViewToModelMouseEvent(e))}emitMouseLeave(e){var t;(t=this.onMouseLeave)===null||t===void 0||t.call(this,this._convertViewToModelMouseEvent(e))}emitMouseDown(e){var t;(t=this.onMouseDown)===null||t===void 0||t.call(this,this._convertViewToModelMouseEvent(e))}emitMouseUp(e){var t;(t=this.onMouseUp)===null||t===void 0||t.call(this,this._convertViewToModelMouseEvent(e))}emitMouseDrag(e){var t;(t=this.onMouseDrag)===null||t===void 0||t.call(this,this._convertViewToModelMouseEvent(e))}emitMouseDrop(e){var t;(t=this.onMouseDrop)===null||t===void 0||t.call(this,this._convertViewToModelMouseEvent(e))}emitMouseDropCanceled(){var e;(e=this.onMouseDropCanceled)===null||e===void 0||e.call(this)}emitMouseWheel(e){var t;(t=this.onMouseWheel)===null||t===void 0||t.call(this,e)}_convertViewToModelMouseEvent(e){return e.target?{event:e.event,target:this._convertViewToModelMouseTarget(e.target)}:e}_convertViewToModelMouseTarget(e){return Ix.convertViewToModelMouseTarget(e,this._coordinatesConverter)}static convertViewToModelMouseTarget(e,t){const i={...e};return i.position&&(i.position=t.convertViewPositionToModelPosition(i.position)),i.range&&(i.range=t.convertViewRangeToModelRange(i.range)),(i.type===5||i.type===8)&&(i.detail=this.convertViewToModelViewZoneData(i.detail,t)),i}static convertViewToModelViewZoneData(e,t){return{viewZoneId:e.viewZoneId,positionBefore:e.positionBefore?t.convertViewPositionToModelPosition(e.positionBefore):e.positionBefore,positionAfter:e.positionAfter?t.convertViewPositionToModelPosition(e.positionAfter):e.positionAfter,position:t.convertViewPositionToModelPosition(e.position),afterLineNumber:t.convertViewPositionToModelPosition(new H(e.afterLineNumber,1)).lineNumber}}}class PH{constructor(e){this._createLine=e,this._set(1,[])}flush(){this._set(1,[])}_set(e,t){this._lines=t,this._rendLineNumberStart=e}_get(){return{rendLineNumberStart:this._rendLineNumberStart,lines:this._lines}}getStartLineNumber(){return this._rendLineNumberStart}getEndLineNumber(){return this._rendLineNumberStart+this._lines.length-1}getCount(){return this._lines.length}getLine(e){const t=e-this._rendLineNumberStart;if(t<0||t>=this._lines.length)throw new pi("Illegal value for lineNumber");return this._lines[t]}onLinesDeleted(e,t){if(this.getCount()===0)return null;const i=this.getStartLineNumber(),n=this.getEndLineNumber();if(t<i){const l=t-e+1;return this._rendLineNumberStart-=l,null}if(e>n)return null;let o=0,r=0;for(let l=i;l<=n;l++){const d=l-this._rendLineNumberStart;e<=l&&l<=t&&(r===0?(o=d,r=1):r++)}if(e<i){let l=0;t<i?l=t-e+1:l=i-e,this._rendLineNumberStart-=l}return this._lines.splice(o,r)}onLinesChanged(e,t){const i=e+t-1;if(this.getCount()===0)return!1;const n=this.getStartLineNumber(),o=this.getEndLineNumber();let r=!1;for(let a=e;a<=i;a++)a>=n&&a<=o&&(this._lines[a-this._rendLineNumberStart].onContentChanged(),r=!0);return r}onLinesInserted(e,t){if(this.getCount()===0)return null;const i=t-e+1,n=this.getStartLineNumber(),o=this.getEndLineNumber();if(e<=n)return this._rendLineNumberStart+=i,null;if(e>o)return null;if(i+e>o)return this._lines.splice(e-this._rendLineNumberStart,o-e+1);const r=[];for(let u=0;u<i;u++)r[u]=this._createLine();const a=e-this._rendLineNumberStart,l=this._lines.slice(0,a),d=this._lines.slice(a,this._lines.length-i),c=this._lines.slice(this._lines.length-i,this._lines.length);return this._lines=l.concat(r).concat(d),c}onTokensChanged(e){if(this.getCount()===0)return!1;const t=this.getStartLineNumber(),i=this.getEndLineNumber();let n=!1;for(let o=0,r=e.length;o<r;o++){const a=e[o];if(a.toLineNumber<t||a.fromLineNumber>i)continue;const l=Math.max(t,a.fromLineNumber),d=Math.min(i,a.toLineNumber);for(let c=l;c<=d;c++){const u=c-this._rendLineNumberStart;this._lines[u].onTokensChanged(),n=!0}}return n}}class OH{constructor(e){this._host=e,this.domNode=this._createDomNode(),this._linesCollection=new PH(()=>this._host.createVisibleLine())}_createDomNode(){const e=Mt(document.createElement("div"));return e.setClassName("view-layer"),e.setPosition("absolute"),e.domNode.setAttribute("role","presentation"),e.domNode.setAttribute("aria-hidden","true"),e}onConfigurationChanged(e){return!!e.hasChanged(143)}onFlushed(e){return this._linesCollection.flush(),!0}onLinesChanged(e){return this._linesCollection.onLinesChanged(e.fromLineNumber,e.count)}onLinesDeleted(e){const t=this._linesCollection.onLinesDeleted(e.fromLineNumber,e.toLineNumber);if(t)for(let i=0,n=t.length;i<n;i++){const o=t[i].getDomNode();o&&this.domNode.domNode.removeChild(o)}return!0}onLinesInserted(e){const t=this._linesCollection.onLinesInserted(e.fromLineNumber,e.toLineNumber);if(t)for(let i=0,n=t.length;i<n;i++){const o=t[i].getDomNode();o&&this.domNode.domNode.removeChild(o)}return!0}onScrollChanged(e){return e.scrollTopChanged}onTokensChanged(e){return this._linesCollection.onTokensChanged(e.ranges)}onZonesChanged(e){return!0}getStartLineNumber(){return this._linesCollection.getStartLineNumber()}getEndLineNumber(){return this._linesCollection.getEndLineNumber()}getVisibleLine(e){return this._linesCollection.getLine(e)}renderLines(e){const t=this._linesCollection._get(),i=new Td(this.domNode.domNode,this._host,e),n={rendLineNumberStart:t.rendLineNumberStart,lines:t.lines,linesLength:t.lines.length},o=i.render(n,e.startLineNumber,e.endLineNumber,e.relativeVerticalOffset);this._linesCollection._set(o.rendLineNumberStart,o.lines)}}class Td{constructor(e,t,i){this.domNode=e,this.host=t,this.viewportData=i}render(e,t,i,n){const o={rendLineNumberStart:e.rendLineNumberStart,lines:e.lines.slice(0),linesLength:e.linesLength};if(o.rendLineNumberStart+o.linesLength-1<t||i<o.rendLineNumberStart){o.rendLineNumberStart=t,o.linesLength=i-t+1,o.lines=[];for(let r=t;r<=i;r++)o.lines[r-t]=this.host.createVisibleLine();return this._finishRendering(o,!0,n),o}if(this._renderUntouchedLines(o,Math.max(t-o.rendLineNumberStart,0),Math.min(i-o.rendLineNumberStart,o.linesLength-1),n,t),o.rendLineNumberStart>t){const r=t,a=Math.min(i,o.rendLineNumberStart-1);r<=a&&(this._insertLinesBefore(o,r,a,n,t),o.linesLength+=a-r+1)}else if(o.rendLineNumberStart<t){const r=Math.min(o.linesLength,t-o.rendLineNumberStart);r>0&&(this._removeLinesBefore(o,r),o.linesLength-=r)}if(o.rendLineNumberStart=t,o.rendLineNumberStart+o.linesLength-1<i){const r=o.rendLineNumberStart+o.linesLength,a=i;r<=a&&(this._insertLinesAfter(o,r,a,n,t),o.linesLength+=a-r+1)}else if(o.rendLineNumberStart+o.linesLength-1>i){const r=Math.max(0,i-o.rendLineNumberStart+1),l=o.linesLength-1-r+1;l>0&&(this._removeLinesAfter(o,l),o.linesLength-=l)}return this._finishRendering(o,!1,n),o}_renderUntouchedLines(e,t,i,n,o){const r=e.rendLineNumberStart,a=e.lines;for(let l=t;l<=i;l++){const d=r+l;a[l].layoutLine(d,n[d-o])}}_insertLinesBefore(e,t,i,n,o){const r=[];let a=0;for(let l=t;l<=i;l++)r[a++]=this.host.createVisibleLine();e.lines=r.concat(e.lines)}_removeLinesBefore(e,t){for(let i=0;i<t;i++){const n=e.lines[i].getDomNode();n&&this.domNode.removeChild(n)}e.lines.splice(0,t)}_insertLinesAfter(e,t,i,n,o){const r=[];let a=0;for(let l=t;l<=i;l++)r[a++]=this.host.createVisibleLine();e.lines=e.lines.concat(r)}_removeLinesAfter(e,t){const i=e.linesLength-t;for(let n=0;n<t;n++){const o=e.lines[i+n].getDomNode();o&&this.domNode.removeChild(o)}e.lines.splice(i,t)}_finishRenderingNewLines(e,t,i,n){Td._ttPolicy&&(i=Td._ttPolicy.createHTML(i));const o=this.domNode.lastChild;t||!o?this.domNode.innerHTML=i:o.insertAdjacentHTML("afterend",i);let r=this.domNode.lastChild;for(let a=e.linesLength-1;a>=0;a--){const l=e.lines[a];n[a]&&(l.setDomNode(r),r=r.previousSibling)}}_finishRenderingInvalidLines(e,t,i){const n=document.createElement("div");Td._ttPolicy&&(t=Td._ttPolicy.createHTML(t)),n.innerHTML=t;for(let o=0;o<e.linesLength;o++){const r=e.lines[o];if(i[o]){const a=n.firstChild,l=r.getDomNode();l.parentNode.replaceChild(a,l),r.setDomNode(a)}}}_finishRendering(e,t,i){const n=Td._sb,o=e.linesLength,r=e.lines,a=e.rendLineNumberStart,l=[];{n.reset();let d=!1;for(let c=0;c<o;c++){const u=r[c];l[c]=!1,!(u.getDomNode()||!u.renderLine(c+a,i[c],this.viewportData,n))&&(l[c]=!0,d=!0)}d&&this._finishRenderingNewLines(e,t,n.build(),l)}{n.reset();let d=!1;const c=[];for(let u=0;u<o;u++){const h=r[u];c[u]=!1,!(l[u]||!h.renderLine(u+a,i[u],this.viewportData,n))&&(c[u]=!0,d=!0)}d&&this._finishRenderingInvalidLines(e,n.build(),c)}}}Td._ttPolicy=oc("editorViewLayer",{createHTML:s=>s});Td._sb=new s_(1e5);class FH extends Eo{constructor(e){super(e),this._visibleLines=new OH(this),this.domNode=this._visibleLines.domNode;const i=this._context.configuration.options.get(50);Xn(this.domNode,i),this._dynamicOverlays=[],this._isFocused=!1,this.domNode.setClassName("view-overlays")}shouldRender(){if(super.shouldRender())return!0;for(let e=0,t=this._dynamicOverlays.length;e<t;e++)if(this._dynamicOverlays[e].shouldRender())return!0;return!1}dispose(){super.dispose();for(let e=0,t=this._dynamicOverlays.length;e<t;e++)this._dynamicOverlays[e].dispose();this._dynamicOverlays=[]}getDomNode(){return this.domNode}createVisibleLine(){return new gae(this._context.configuration,this._dynamicOverlays)}addDynamicOverlay(e){this._dynamicOverlays.push(e)}onConfigurationChanged(e){this._visibleLines.onConfigurationChanged(e);const t=this._visibleLines.getStartLineNumber(),i=this._visibleLines.getEndLineNumber();for(let r=t;r<=i;r++)this._visibleLines.getVisibleLine(r).onConfigurationChanged(e);const o=this._context.configuration.options.get(50);return Xn(this.domNode,o),!0}onFlushed(e){return this._visibleLines.onFlushed(e)}onFocusChanged(e){return this._isFocused=e.isFocused,!0}onLinesChanged(e){return this._visibleLines.onLinesChanged(e)}onLinesDeleted(e){return this._visibleLines.onLinesDeleted(e)}onLinesInserted(e){return this._visibleLines.onLinesInserted(e)}onScrollChanged(e){return this._visibleLines.onScrollChanged(e)||!0}onTokensChanged(e){return this._visibleLines.onTokensChanged(e)}onZonesChanged(e){return this._visibleLines.onZonesChanged(e)}prepareRender(e){const t=this._dynamicOverlays.filter(i=>i.shouldRender());for(let i=0,n=t.length;i<n;i++){const o=t[i];o.prepareRender(e),o.onDidRender()}}render(e){this._viewOverlaysRender(e),this.domNode.toggleClassName("focused",this._isFocused)}_viewOverlaysRender(e){this._visibleLines.renderLines(e.viewportData)}}class gae{constructor(e,t){this._configuration=e,this._lineHeight=this._configuration.options.get(66),this._dynamicOverlays=t,this._domNode=null,this._renderedContent=null}getDomNode(){return this._domNode?this._domNode.domNode:null}setDomNode(e){this._domNode=Mt(e)}onContentChanged(){}onTokensChanged(){}onConfigurationChanged(e){this._lineHeight=this._configuration.options.get(66)}renderLine(e,t,i,n){let o="";for(let r=0,a=this._dynamicOverlays.length;r<a;r++){const l=this._dynamicOverlays[r];o+=l.render(i.startLineNumber,e)}return this._renderedContent===o?!1:(this._renderedContent=o,n.appendString('<div style="position:absolute;top:'),n.appendString(String(t)),n.appendString("px;width:100%;height:"),n.appendString(String(this._lineHeight)),n.appendString('px;">'),n.appendString(o),n.appendString("</div>"),!0)}layoutLine(e,t){this._domNode&&(this._domNode.setTop(t),this._domNode.setHeight(this._lineHeight))}}class fae extends FH{constructor(e){super(e);const i=this._context.configuration.options.get(143);this._contentWidth=i.contentWidth,this.domNode.setHeight(0)}onConfigurationChanged(e){const i=this._context.configuration.options.get(143);return this._contentWidth=i.contentWidth,super.onConfigurationChanged(e)||!0}onScrollChanged(e){return super.onScrollChanged(e)||e.scrollWidthChanged}_viewOverlaysRender(e){super._viewOverlaysRender(e),this.domNode.setWidth(Math.max(e.scrollWidth,this._contentWidth))}}class pae extends FH{constructor(e){super(e);const t=this._context.configuration.options,i=t.get(143);this._contentLeft=i.contentLeft,this.domNode.setClassName("margin-view-overlays"),this.domNode.setWidth(1),Xn(this.domNode,t.get(50))}onConfigurationChanged(e){const t=this._context.configuration.options;Xn(this.domNode,t.get(50));const i=t.get(143);return this._contentLeft=i.contentLeft,super.onConfigurationChanged(e)||!0}onScrollChanged(e){return super.onScrollChanged(e)||e.scrollHeightChanged}_viewOverlaysRender(e){super._viewOverlaysRender(e);const t=Math.min(e.scrollHeight,1e6);this.domNode.setHeight(t),this.domNode.setWidth(this._contentLeft)}}class mae extends Eo{constructor(e,t){super(e),this._viewDomNode=t,this._widgets={},this.domNode=Mt(document.createElement("div")),Zl.write(this.domNode,1),this.domNode.setClassName("contentWidgets"),this.domNode.setPosition("absolute"),this.domNode.setTop(0),this.overflowingContentWidgetsDomNode=Mt(document.createElement("div")),Zl.write(this.overflowingContentWidgetsDomNode,2),this.overflowingContentWidgetsDomNode.setClassName("overflowingContentWidgets")}dispose(){super.dispose(),this._widgets={}}onConfigurationChanged(e){const t=Object.keys(this._widgets);for(const i of t)this._widgets[i].onConfigurationChanged(e);return!0}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onLineMappingChanged(e){return this._updateAnchorsViewPositions(),!0}onLinesChanged(e){return this._updateAnchorsViewPositions(),!0}onLinesDeleted(e){return this._updateAnchorsViewPositions(),!0}onLinesInserted(e){return this._updateAnchorsViewPositions(),!0}onScrollChanged(e){return!0}onZonesChanged(e){return!0}_updateAnchorsViewPositions(){const e=Object.keys(this._widgets);for(const t of e)this._widgets[t].updateAnchorViewPosition()}addWidget(e){const t=new _ae(this._context,this._viewDomNode,e);this._widgets[t.id]=t,t.allowEditorOverflow?this.overflowingContentWidgetsDomNode.appendChild(t.domNode):this.domNode.appendChild(t.domNode),this.setShouldRender()}setWidgetPosition(e,t,i,n,o){this._widgets[e.getId()].setPosition(t,i,n,o),this.setShouldRender()}removeWidget(e){const t=e.getId();if(this._widgets.hasOwnProperty(t)){const i=this._widgets[t];delete this._widgets[t];const n=i.domNode.domNode;n.parentNode.removeChild(n),n.removeAttribute("monaco-visible-content-widget"),this.setShouldRender()}}shouldSuppressMouseDownOnWidget(e){return this._widgets.hasOwnProperty(e)?this._widgets[e].suppressMouseDown:!1}onBeforeRender(e){const t=Object.keys(this._widgets);for(const i of t)this._widgets[i].onBeforeRender(e)}prepareRender(e){const t=Object.keys(this._widgets);for(const i of t)this._widgets[i].prepareRender(e)}render(e){const t=Object.keys(this._widgets);for(const i of t)this._widgets[i].render(e)}}class _ae{constructor(e,t,i){this._primaryAnchor=new O_(null,null),this._secondaryAnchor=new O_(null,null),this._context=e,this._viewDomNode=t,this._actual=i,this.domNode=Mt(this._actual.getDomNode()),this.id=this._actual.getId(),this.allowEditorOverflow=this._actual.allowEditorOverflow||!1,this.suppressMouseDown=this._actual.suppressMouseDown||!1;const n=this._context.configuration.options,o=n.get(143);this._fixedOverflowWidgets=n.get(42),this._contentWidth=o.contentWidth,this._contentLeft=o.contentLeft,this._lineHeight=n.get(66),this._affinity=null,this._preference=[],this._cachedDomNodeOffsetWidth=-1,this._cachedDomNodeOffsetHeight=-1,this._maxWidth=this._getMaxWidth(),this._isVisible=!1,this._renderData=null,this.domNode.setPosition(this._fixedOverflowWidgets&&this.allowEditorOverflow?"fixed":"absolute"),this.domNode.setDisplay("none"),this.domNode.setVisibility("hidden"),this.domNode.setAttribute("widgetId",this.id),this.domNode.setMaxWidth(this._maxWidth)}onConfigurationChanged(e){const t=this._context.configuration.options;if(this._lineHeight=t.get(66),e.hasChanged(143)){const i=t.get(143);this._contentLeft=i.contentLeft,this._contentWidth=i.contentWidth,this._maxWidth=this._getMaxWidth()}}updateAnchorViewPosition(){this._setPosition(this._affinity,this._primaryAnchor.modelPosition,this._secondaryAnchor.modelPosition)}_setPosition(e,t,i){this._affinity=e,this._primaryAnchor=n(t,this._context.viewModel,this._affinity),this._secondaryAnchor=n(i,this._context.viewModel,this._affinity);function n(o,r,a){if(!o)return new O_(null,null);const l=r.model.validatePosition(o);if(r.coordinatesConverter.modelPositionIsVisible(l)){const d=r.coordinatesConverter.convertModelPositionToViewPosition(l,a??void 0);return new O_(o,d)}return new O_(o,null)}}_getMaxWidth(){const e=this.domNode.domNode.ownerDocument,t=e.defaultView;return this.allowEditorOverflow?(t==null?void 0:t.innerWidth)||e.documentElement.offsetWidth||e.body.offsetWidth:this._contentWidth}setPosition(e,t,i,n){this._setPosition(n,e,t),this._preference=i,this._primaryAnchor.viewPosition&&this._preference&&this._preference.length>0?this.domNode.setDisplay("block"):this.domNode.setDisplay("none"),this._cachedDomNodeOffsetWidth=-1,this._cachedDomNodeOffsetHeight=-1}_layoutBoxInViewport(e,t,i,n){const o=e.top,r=o,a=e.top+e.height,l=n.viewportHeight-a,d=o-i,c=r>=i,u=a,h=l>=i;let g=e.left;return g+t>n.scrollLeft+n.viewportWidth&&(g=n.scrollLeft+n.viewportWidth-t),g<n.scrollLeft&&(g=n.scrollLeft),{fitsAbove:c,aboveTop:d,fitsBelow:h,belowTop:u,left:g}}_layoutHorizontalSegmentInPage(e,t,i,n){var o;const l=Math.max(15,t.left-n),d=Math.min(t.left+t.width+n,e.width-15),u=this._viewDomNode.domNode.ownerDocument.defaultView;let h=t.left+i-((o=u==null?void 0:u.scrollX)!==null&&o!==void 0?o:0);if(h+n>d){const g=h-(d-n);h-=g,i-=g}if(h<l){const g=h-l;h-=g,i-=g}return[i,h]}_layoutBoxInPage(e,t,i,n){var o,r;const a=e.top-i,l=e.top+e.height,d=ln(this._viewDomNode.domNode),c=this._viewDomNode.domNode.ownerDocument,u=c.defaultView,h=d.top+a-((o=u==null?void 0:u.scrollY)!==null&&o!==void 0?o:0),g=d.top+l-((r=u==null?void 0:u.scrollY)!==null&&r!==void 0?r:0),f=Nu(c.body),[m,_]=this._layoutHorizontalSegmentInPage(f,d,e.left-n.scrollLeft+this._contentLeft,t),v=22,b=22,C=h>=v,w=g+i<=f.height-b;return this._fixedOverflowWidgets?{fitsAbove:C,aboveTop:Math.max(h,v),fitsBelow:w,belowTop:g,left:_}:{fitsAbove:C,aboveTop:a,fitsBelow:w,belowTop:l,left:m}}_prepareRenderWidgetAtExactPositionOverflowing(e){return new F_(e.top,e.left+this._contentLeft)}_getAnchorsCoordinates(e){var t,i;const n=a(this._primaryAnchor.viewPosition,this._affinity,this._lineHeight),o=((t=this._secondaryAnchor.viewPosition)===null||t===void 0?void 0:t.lineNumber)===((i=this._primaryAnchor.viewPosition)===null||i===void 0?void 0:i.lineNumber)?this._secondaryAnchor.viewPosition:null,r=a(o,this._affinity,this._lineHeight);return{primary:n,secondary:r};function a(l,d,c){if(!l)return null;const u=e.visibleRangeForPosition(l);if(!u)return null;const h=l.column===1&&d===3?0:u.left,g=e.getVerticalOffsetForLineNumber(l.lineNumber)-e.scrollTop;return new z3(g,h,c)}}_reduceAnchorCoordinates(e,t,i){if(!t)return e;const n=this._context.configuration.options.get(50);let o=t.left;return o<e.left?o=Math.max(o,e.left-i+n.typicalFullwidthCharacterWidth):o=Math.min(o,e.left+i-n.typicalFullwidthCharacterWidth),new z3(e.top,o,e.height)}_prepareRenderWidget(e){if(!this._preference||this._preference.length===0)return null;const{primary:t,secondary:i}=this._getAnchorsCoordinates(e);if(!t)return null;if(this._cachedDomNodeOffsetWidth===-1||this._cachedDomNodeOffsetHeight===-1){let r=null;if(typeof this._actual.beforeRender=="function"&&(r=lI(this._actual.beforeRender,this._actual)),r)this._cachedDomNodeOffsetWidth=r.width,this._cachedDomNodeOffsetHeight=r.height;else{const l=this.domNode.domNode.getBoundingClientRect();this._cachedDomNodeOffsetWidth=Math.round(l.width),this._cachedDomNodeOffsetHeight=Math.round(l.height)}}const n=this._reduceAnchorCoordinates(t,i,this._cachedDomNodeOffsetWidth);let o;this.allowEditorOverflow?o=this._layoutBoxInPage(n,this._cachedDomNodeOffsetWidth,this._cachedDomNodeOffsetHeight,e):o=this._layoutBoxInViewport(n,this._cachedDomNodeOffsetWidth,this._cachedDomNodeOffsetHeight,e);for(let r=1;r<=2;r++)for(const a of this._preference)if(a===1){if(!o)return null;if(r===2||o.fitsAbove)return{coordinate:new F_(o.aboveTop,o.left),position:1}}else if(a===2){if(!o)return null;if(r===2||o.fitsBelow)return{coordinate:new F_(o.belowTop,o.left),position:2}}else return this.allowEditorOverflow?{coordinate:this._prepareRenderWidgetAtExactPositionOverflowing(new F_(n.top,n.left)),position:0}:{coordinate:new F_(n.top,n.left),position:0};return null}onBeforeRender(e){!this._primaryAnchor.viewPosition||!this._preference||this._primaryAnchor.viewPosition.lineNumber<e.startLineNumber||this._primaryAnchor.viewPosition.lineNumber>e.endLineNumber||this.domNode.setMaxWidth(this._maxWidth)}prepareRender(e){this._renderData=this._prepareRenderWidget(e)}render(e){if(!this._renderData){this._isVisible&&(this.domNode.removeAttribute("monaco-visible-content-widget"),this._isVisible=!1,this.domNode.setVisibility("hidden")),typeof this._actual.afterRender=="function"&&lI(this._actual.afterRender,this._actual,null);return}this.allowEditorOverflow?(this.domNode.setTop(this._renderData.coordinate.top),this.domNode.setLeft(this._renderData.coordinate.left)):(this.domNode.setTop(this._renderData.coordinate.top+e.scrollTop-e.bigNumbersDelta),this.domNode.setLeft(this._renderData.coordinate.left)),this._isVisible||(this.domNode.setVisibility("inherit"),this.domNode.setAttribute("monaco-visible-content-widget","true"),this._isVisible=!0),typeof this._actual.afterRender=="function"&&lI(this._actual.afterRender,this._actual,this._renderData.position)}}class O_{constructor(e,t){this.modelPosition=e,this.viewPosition=t}}class F_{constructor(e,t){this.top=e,this.left=t,this._coordinateBrand=void 0}}class z3{constructor(e,t,i){this.top=e,this.left=t,this.height=i,this._anchorCoordinateBrand=void 0}}function lI(s,e,...t){try{return s.call(e,...t)}catch{return null}}class BH extends df{constructor(e){super(),this._context=e;const t=this._context.configuration.options,i=t.get(143);this._lineHeight=t.get(66),this._renderLineHighlight=t.get(95),this._renderLineHighlightOnlyWhenFocus=t.get(96),this._contentLeft=i.contentLeft,this._contentWidth=i.contentWidth,this._selectionIsEmpty=!0,this._focused=!1,this._cursorLineNumbers=[1],this._selections=[new De(1,1,1,1)],this._renderData=null,this._context.addEventHandler(this)}dispose(){this._context.removeEventHandler(this),super.dispose()}_readFromSelections(){let e=!1;const t=this._selections.map(n=>n.positionLineNumber);t.sort((n,o)=>n-o),Ai(this._cursorLineNumbers,t)||(this._cursorLineNumbers=t,e=!0);const i=this._selections.every(n=>n.isEmpty());return this._selectionIsEmpty!==i&&(this._selectionIsEmpty=i,e=!0),e}onThemeChanged(e){return this._readFromSelections()}onConfigurationChanged(e){const t=this._context.configuration.options,i=t.get(143);return this._lineHeight=t.get(66),this._renderLineHighlight=t.get(95),this._renderLineHighlightOnlyWhenFocus=t.get(96),this._contentLeft=i.contentLeft,this._contentWidth=i.contentWidth,!0}onCursorStateChanged(e){return this._selections=e.selections,this._readFromSelections()}onFlushed(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return e.scrollWidthChanged||e.scrollTopChanged}onZonesChanged(e){return!0}onFocusChanged(e){return this._renderLineHighlightOnlyWhenFocus?(this._focused=e.isFocused,!0):!1}prepareRender(e){if(!this._shouldRenderThis()){this._renderData=null;return}const t=this._renderOne(e),i=e.visibleRange.startLineNumber,n=e.visibleRange.endLineNumber,o=this._cursorLineNumbers.length;let r=0;const a=[];for(let l=i;l<=n;l++){const d=l-i;for(;r<o&&this._cursorLineNumbers[r]<l;)r++;r<o&&this._cursorLineNumbers[r]===l?a[d]=t:a[d]=""}this._renderData=a}render(e,t){if(!this._renderData)return"";const i=t-e;return i>=this._renderData.length?"":this._renderData[i]}_shouldRenderInMargin(){return(this._renderLineHighlight==="gutter"||this._renderLineHighlight==="all")&&(!this._renderLineHighlightOnlyWhenFocus||this._focused)}_shouldRenderInContent(){return(this._renderLineHighlight==="line"||this._renderLineHighlight==="all")&&this._selectionIsEmpty&&(!this._renderLineHighlightOnlyWhenFocus||this._focused)}}class vae extends BH{_renderOne(e){return`<div class="${"current-line"+(this._shouldRenderOther()?" current-line-both":"")}" style="width:${Math.max(e.scrollWidth,this._contentWidth)}px; height:${this._lineHeight}px;"></div>`}_shouldRenderThis(){return this._shouldRenderInContent()}_shouldRenderOther(){return this._shouldRenderInMargin()}}class bae extends BH{_renderOne(e){return`<div class="${"current-line"+(this._shouldRenderInMargin()?" current-line-margin":"")+(this._shouldRenderOther()?" current-line-margin-both":"")}" style="width:${this._contentLeft}px; height:${this._lineHeight}px;"></div>`}_shouldRenderThis(){return!0}_shouldRenderOther(){return this._shouldRenderInContent()}}ia((s,e)=>{const t=s.getColor(yH);if(t&&(e.addRule(`.monaco-editor .view-overlays .current-line { background-color: ${t}; }`),e.addRule(`.monaco-editor .margin-view-overlays .current-line-margin { background-color: ${t}; border: none; }`)),!t||t.isTransparent()||s.defines(O3)){const i=s.getColor(O3);i&&(e.addRule(`.monaco-editor .view-overlays .current-line { border: 2px solid ${i}; }`),e.addRule(`.monaco-editor .margin-view-overlays .current-line-margin { border: 2px solid ${i}; }`),Oa(s.type)&&(e.addRule(".monaco-editor .view-overlays .current-line { border-width: 1px; }"),e.addRule(".monaco-editor .margin-view-overlays .current-line-margin { border-width: 1px; }")))}});class Cae extends df{constructor(e){super(),this._context=e;const t=this._context.configuration.options;this._lineHeight=t.get(66),this._typicalHalfwidthCharacterWidth=t.get(50).typicalHalfwidthCharacterWidth,this._renderResult=null,this._context.addEventHandler(this)}dispose(){this._context.removeEventHandler(this),this._renderResult=null,super.dispose()}onConfigurationChanged(e){const t=this._context.configuration.options;return this._lineHeight=t.get(66),this._typicalHalfwidthCharacterWidth=t.get(50).typicalHalfwidthCharacterWidth,!0}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return e.scrollTopChanged||e.scrollWidthChanged}onZonesChanged(e){return!0}prepareRender(e){const t=e.getDecorationsInViewport();let i=[],n=0;for(let l=0,d=t.length;l<d;l++){const c=t[l];c.options.className&&(i[n++]=c)}i=i.sort((l,d)=>{if(l.options.zIndex<d.options.zIndex)return-1;if(l.options.zIndex>d.options.zIndex)return 1;const c=l.options.className,u=d.options.className;return c<u?-1:c>u?1:D.compareRangesUsingStarts(l.range,d.range)});const o=e.visibleRange.startLineNumber,r=e.visibleRange.endLineNumber,a=[];for(let l=o;l<=r;l++){const d=l-o;a[d]=""}this._renderWholeLineDecorations(e,i,a),this._renderNormalDecorations(e,i,a),this._renderResult=a}_renderWholeLineDecorations(e,t,i){const n=String(this._lineHeight),o=e.visibleRange.startLineNumber,r=e.visibleRange.endLineNumber;for(let a=0,l=t.length;a<l;a++){const d=t[a];if(!d.options.isWholeLine)continue;const c='<div class="cdr '+d.options.className+'" style="left:0;width:100%;height:'+n+'px;"></div>',u=Math.max(d.range.startLineNumber,o),h=Math.min(d.range.endLineNumber,r);for(let g=u;g<=h;g++){const f=g-o;i[f]+=c}}}_renderNormalDecorations(e,t,i){var n;const o=String(this._lineHeight),r=e.visibleRange.startLineNumber;let a=null,l=!1,d=null,c=!1;for(let u=0,h=t.length;u<h;u++){const g=t[u];if(g.options.isWholeLine)continue;const f=g.options.className,m=!!g.options.showIfCollapsed;let _=g.range;if(m&&_.endColumn===1&&_.endLineNumber!==_.startLineNumber&&(_=new D(_.startLineNumber,_.startColumn,_.endLineNumber-1,this._context.viewModel.getLineMaxColumn(_.endLineNumber-1))),a===f&&l===m&&D.areIntersectingOrTouching(d,_)){d=D.plusRange(d,_);continue}a!==null&&this._renderNormalDecoration(e,d,a,c,l,o,r,i),a=f,l=m,d=_,c=(n=g.options.shouldFillLineOnLineBreak)!==null&&n!==void 0?n:!1}a!==null&&this._renderNormalDecoration(e,d,a,c,l,o,r,i)}_renderNormalDecoration(e,t,i,n,o,r,a,l){const d=e.linesVisibleRangesForRange(t,i==="findMatch");if(d)for(let c=0,u=d.length;c<u;c++){const h=d[c];if(h.outsideRenderedLine)continue;const g=h.lineNumber-a;if(o&&h.ranges.length===1){const f=h.ranges[0];if(f.width<this._typicalHalfwidthCharacterWidth){const m=Math.round(f.left+f.width/2),_=Math.max(0,Math.round(m-this._typicalHalfwidthCharacterWidth/2));h.ranges[0]=new yx(_,this._typicalHalfwidthCharacterWidth)}}for(let f=0,m=h.ranges.length;f<m;f++){const _=n&&h.continuesOnNextLine&&m===1,v=h.ranges[f],b='<div class="cdr '+i+'" style="left:'+String(v.left)+(_?"px;width:100%;height:":"px;width:"+String(v.width)+"px;height:")+r+'px;"></div>';l[g]+=b}}}render(e,t){if(!this._renderResult)return"";const i=t-e;return i<0||i>=this._renderResult.length?"":this._renderResult[i]}}class wae extends Eo{constructor(e,t,i,n){super(e);const o=this._context.configuration.options,r=o.get(102),a=o.get(74),l=o.get(40),d=o.get(105),c={listenOnDomNode:i.domNode,className:"editor-scrollable "+CT(e.theme.type),useShadows:!1,lazyRender:!0,vertical:r.vertical,horizontal:r.horizontal,verticalHasArrows:r.verticalHasArrows,horizontalHasArrows:r.horizontalHasArrows,verticalScrollbarSize:r.verticalScrollbarSize,verticalSliderSize:r.verticalSliderSize,horizontalScrollbarSize:r.horizontalScrollbarSize,horizontalSliderSize:r.horizontalSliderSize,handleMouseWheel:r.handleMouseWheel,alwaysConsumeMouseWheel:r.alwaysConsumeMouseWheel,arrowSize:r.arrowSize,mouseWheelScrollSensitivity:a,fastScrollSensitivity:l,scrollPredominantAxis:d,scrollByPage:r.scrollByPage};this.scrollbar=this._register(new Lx(t.domNode,c,this._context.viewLayout.getScrollable())),Zl.write(this.scrollbar.getDomNode(),5),this.scrollbarDomNode=Mt(this.scrollbar.getDomNode()),this.scrollbarDomNode.setPosition("absolute"),this._setLayout();const u=(h,g,f)=>{const m={};if(g){const _=h.scrollTop;_&&(m.scrollTop=this._context.viewLayout.getCurrentScrollTop()+_,h.scrollTop=0)}if(f){const _=h.scrollLeft;_&&(m.scrollLeft=this._context.viewLayout.getCurrentScrollLeft()+_,h.scrollLeft=0)}this._context.viewModel.viewLayout.setScrollPosition(m,1)};this._register(Y(i.domNode,"scroll",h=>u(i.domNode,!0,!0))),this._register(Y(t.domNode,"scroll",h=>u(t.domNode,!0,!1))),this._register(Y(n.domNode,"scroll",h=>u(n.domNode,!0,!1))),this._register(Y(this.scrollbarDomNode.domNode,"scroll",h=>u(this.scrollbarDomNode.domNode,!0,!1)))}dispose(){super.dispose()}_setLayout(){const e=this._context.configuration.options,t=e.get(143);this.scrollbarDomNode.setLeft(t.contentLeft),e.get(72).side==="right"?this.scrollbarDomNode.setWidth(t.contentWidth+t.minimap.minimapWidth):this.scrollbarDomNode.setWidth(t.contentWidth),this.scrollbarDomNode.setHeight(t.height)}getOverviewRulerLayoutInfo(){return this.scrollbar.getOverviewRulerLayoutInfo()}getDomNode(){return this.scrollbarDomNode}delegateVerticalScrollbarPointerDown(e){this.scrollbar.delegateVerticalScrollbarPointerDown(e)}delegateScrollFromMouseWheelEvent(e){this.scrollbar.delegateScrollFromMouseWheelEvent(e)}onConfigurationChanged(e){if(e.hasChanged(102)||e.hasChanged(74)||e.hasChanged(40)){const t=this._context.configuration.options,i=t.get(102),n=t.get(74),o=t.get(40),r=t.get(105),a={vertical:i.vertical,horizontal:i.horizontal,verticalScrollbarSize:i.verticalScrollbarSize,horizontalScrollbarSize:i.horizontalScrollbarSize,scrollByPage:i.scrollByPage,handleMouseWheel:i.handleMouseWheel,mouseWheelScrollSensitivity:n,fastScrollSensitivity:o,scrollPredominantAxis:r};this.scrollbar.updateOptions(a)}return e.hasChanged(143)&&this._setLayout(),!0}onScrollChanged(e){return!0}onThemeChanged(e){return this.scrollbar.updateClassName("editor-scrollable "+CT(this._context.theme.type)),!0}prepareRender(e){}render(e){this.scrollbar.renderNow()}}class WH extends j{constructor(){super(...arguments),this._isDisposed=!1}dispose(){super.dispose(),this._isDisposed=!0}assertNotDisposed(){if(this._isDisposed)throw new Error("TextModelPart is disposed!")}}function Ex(s,e){let t=0,i=0;const n=s.length;for(;i<n;){const o=s.charCodeAt(i);if(o===32)t++;else if(o===9)t=t-t%e+e;else break;i++}return i===n?-1:t}var mg;(function(s){s[s.Disabled=0]="Disabled",s[s.EnabledForActive=1]="EnabledForActive",s[s.Enabled=2]="Enabled"})(mg||(mg={}));class ng{constructor(e,t,i,n,o,r){if(this.visibleColumn=e,this.column=t,this.className=i,this.horizontalLine=n,this.forWrappedLinesAfterColumn=o,this.forWrappedLinesBeforeOrAtColumn=r,e!==-1==(t!==-1))throw new Error}}class Wv{constructor(e,t){this.top=e,this.endColumn=t}}class Sae extends WH{constructor(e,t){super(),this.textModel=e,this.languageConfigurationService=t}getLanguageConfiguration(e){return this.languageConfigurationService.getLanguageConfiguration(e)}_computeIndentLevel(e){return Ex(this.textModel.getLineContent(e+1),this.textModel.getOptions().tabSize)}getActiveIndentGuide(e,t,i){this.assertNotDisposed();const n=this.textModel.getLineCount();if(e<1||e>n)throw new pi("Illegal value for lineNumber");const o=this.getLanguageConfiguration(this.textModel.getLanguageId()).foldingRules,r=!!(o&&o.offSide);let a=-2,l=-1,d=-2,c=-1;const u=L=>{if(a!==-1&&(a===-2||a>L-1)){a=-1,l=-1;for(let k=L-2;k>=0;k--){const I=this._computeIndentLevel(k);if(I>=0){a=k,l=I;break}}}if(d===-2){d=-1,c=-1;for(let k=L;k<n;k++){const I=this._computeIndentLevel(k);if(I>=0){d=k,c=I;break}}}};let h=-2,g=-1,f=-2,m=-1;const _=L=>{if(h===-2){h=-1,g=-1;for(let k=L-2;k>=0;k--){const I=this._computeIndentLevel(k);if(I>=0){h=k,g=I;break}}}if(f!==-1&&(f===-2||f<L-1)){f=-1,m=-1;for(let k=L;k<n;k++){const I=this._computeIndentLevel(k);if(I>=0){f=k,m=I;break}}}};let v=0,b=!0,C=0,w=!0,S=0,x=0;for(let L=0;b||w;L++){const k=e-L,I=e+L;L>1&&(k<1||k<t)&&(b=!1),L>1&&(I>n||I>i)&&(w=!1),L>5e4&&(b=!1,w=!1);let P=-1;if(b&&k>=1){const A=this._computeIndentLevel(k-1);A>=0?(d=k-1,c=A,P=Math.ceil(A/this.textModel.getOptions().indentSize)):(u(k),P=this._getIndentLevelForWhitespaceLine(r,l,c))}let $=-1;if(w&&I<=n){const A=this._computeIndentLevel(I-1);A>=0?(h=I-1,g=A,$=Math.ceil(A/this.textModel.getOptions().indentSize)):(_(I),$=this._getIndentLevelForWhitespaceLine(r,g,m))}if(L===0){x=P;continue}if(L===1){if(I<=n&&$>=0&&x+1===$){b=!1,v=I,C=I,S=$;continue}if(k>=1&&P>=0&&P-1===x){w=!1,v=k,C=k,S=P;continue}if(v=e,C=e,S=x,S===0)return{startLineNumber:v,endLineNumber:C,indent:S}}b&&(P>=S?v=k:b=!1),w&&($>=S?C=I:w=!1)}return{startLineNumber:v,endLineNumber:C,indent:S}}getLinesBracketGuides(e,t,i,n){var o;const r=[];for(let h=e;h<=t;h++)r.push([]);const a=!0,l=this.textModel.bracketPairs.getBracketPairsInRangeWithMinIndentation(new D(e,1,t,this.textModel.getLineMaxColumn(t))).toArray();let d;if(i&&l.length>0){const h=(e<=i.lineNumber&&i.lineNumber<=t?l:this.textModel.bracketPairs.getBracketPairsInRange(D.fromPositions(i)).toArray()).filter(g=>D.strictContainsPosition(g.range,i));d=(o=R0(h,g=>a))===null||o===void 0?void 0:o.range}const c=this.textModel.getOptions().bracketPairColorizationOptions.independentColorPoolPerBracketType,u=new VH;for(const h of l){if(!h.closingBracketRange)continue;const g=d&&h.range.equalsRange(d);if(!g&&!n.includeInactive)continue;const f=u.getInlineClassName(h.nestingLevel,h.nestingLevelOfEqualBracketType,c)+(n.highlightActive&&g?" "+u.activeClassName:""),m=h.openingBracketRange.getStartPosition(),_=h.closingBracketRange.getStartPosition(),v=n.horizontalGuides===mg.Enabled||n.horizontalGuides===mg.EnabledForActive&&g;if(h.range.startLineNumber===h.range.endLineNumber){v&&r[h.range.startLineNumber-e].push(new ng(-1,h.openingBracketRange.getEndPosition().column,f,new Wv(!1,_.column),-1,-1));continue}const b=this.getVisibleColumnFromPosition(_),C=this.getVisibleColumnFromPosition(h.openingBracketRange.getStartPosition()),w=Math.min(C,b,h.minVisibleColumnIndentation+1);let S=!1;ws(this.textModel.getLineContent(h.closingBracketRange.startLineNumber))<h.closingBracketRange.startColumn-1&&(S=!0);const k=Math.max(m.lineNumber,e),I=Math.min(_.lineNumber,t),P=S?1:0;for(let $=k;$<I+P;$++)r[$-e].push(new ng(w,-1,f,null,$===m.lineNumber?m.column:-1,$===_.lineNumber?_.column:-1));v&&(m.lineNumber>=e&&C>w&&r[m.lineNumber-e].push(new ng(w,-1,f,new Wv(!1,m.column),-1,-1)),_.lineNumber<=t&&b>w&&r[_.lineNumber-e].push(new ng(w,-1,f,new Wv(!S,_.column),-1,-1)))}for(const h of r)h.sort((g,f)=>g.visibleColumn-f.visibleColumn);return r}getVisibleColumnFromPosition(e){return hn.visibleColumnFromColumn(this.textModel.getLineContent(e.lineNumber),e.column,this.textModel.getOptions().tabSize)+1}getLinesIndentGuides(e,t){this.assertNotDisposed();const i=this.textModel.getLineCount();if(e<1||e>i)throw new Error("Illegal value for startLineNumber");if(t<1||t>i)throw new Error("Illegal value for endLineNumber");const n=this.textModel.getOptions(),o=this.getLanguageConfiguration(this.textModel.getLanguageId()).foldingRules,r=!!(o&&o.offSide),a=new Array(t-e+1);let l=-2,d=-1,c=-2,u=-1;for(let h=e;h<=t;h++){const g=h-e,f=this._computeIndentLevel(h-1);if(f>=0){l=h-1,d=f,a[g]=Math.ceil(f/n.indentSize);continue}if(l===-2){l=-1,d=-1;for(let m=h-2;m>=0;m--){const _=this._computeIndentLevel(m);if(_>=0){l=m,d=_;break}}}if(c!==-1&&(c===-2||c<h-1)){c=-1,u=-1;for(let m=h;m<i;m++){const _=this._computeIndentLevel(m);if(_>=0){c=m,u=_;break}}}a[g]=this._getIndentLevelForWhitespaceLine(r,d,u)}return a}_getIndentLevelForWhitespaceLine(e,t,i){const n=this.textModel.getOptions();return t===-1||i===-1?0:t<i?1+Math.floor(t/n.indentSize):t===i||e?Math.ceil(i/n.indentSize):1+Math.floor(i/n.indentSize)}}class VH{constructor(){this.activeClassName="indent-active"}getInlineClassName(e,t,i){return this.getInlineClassNameOfLevel(i?t:e)}getInlineClassNameOfLevel(e){return`bracket-indent-guide lvl-${e%30}`}}class yae extends df{constructor(e){super(),this._context=e,this._primaryPosition=null;const t=this._context.configuration.options,i=t.get(144),n=t.get(50);this._lineHeight=t.get(66),this._spaceWidth=n.spaceWidth,this._maxIndentLeft=i.wrappingColumn===-1?-1:i.wrappingColumn*n.typicalHalfwidthCharacterWidth,this._bracketPairGuideOptions=t.get(16),this._renderResult=null,this._context.addEventHandler(this)}dispose(){this._context.removeEventHandler(this),this._renderResult=null,super.dispose()}onConfigurationChanged(e){const t=this._context.configuration.options,i=t.get(144),n=t.get(50);return this._lineHeight=t.get(66),this._spaceWidth=n.spaceWidth,this._maxIndentLeft=i.wrappingColumn===-1?-1:i.wrappingColumn*n.typicalHalfwidthCharacterWidth,this._bracketPairGuideOptions=t.get(16),!0}onCursorStateChanged(e){var t;const n=e.selections[0].getPosition();return!((t=this._primaryPosition)===null||t===void 0)&&t.equals(n)?!1:(this._primaryPosition=n,!0)}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return e.scrollTopChanged}onZonesChanged(e){return!0}onLanguageConfigurationChanged(e){return!0}prepareRender(e){var t,i,n,o;if(!this._bracketPairGuideOptions.indentation&&this._bracketPairGuideOptions.bracketPairs===!1){this._renderResult=null;return}const r=e.visibleRange.startLineNumber,a=e.visibleRange.endLineNumber,l=e.scrollWidth,d=this._lineHeight,c=this._primaryPosition,u=this.getGuidesByLine(r,Math.min(a+1,this._context.viewModel.getLineCount()),c),h=[];for(let g=r;g<=a;g++){const f=g-r,m=u[f];let _="";const v=(i=(t=e.visibleRangeForPosition(new H(g,1)))===null||t===void 0?void 0:t.left)!==null&&i!==void 0?i:0;for(const b of m){const C=b.column===-1?v+(b.visibleColumn-1)*this._spaceWidth:e.visibleRangeForPosition(new H(g,b.column)).left;if(C>l||this._maxIndentLeft>0&&C>this._maxIndentLeft)break;const w=b.horizontalLine?b.horizontalLine.top?"horizontal-top":"horizontal-bottom":"vertical",S=b.horizontalLine?((o=(n=e.visibleRangeForPosition(new H(g,b.horizontalLine.endColumn)))===null||n===void 0?void 0:n.left)!==null&&o!==void 0?o:C+this._spaceWidth)-C:this._spaceWidth;_+=`<div class="core-guide ${b.className} ${w}" style="left:${C}px;height:${d}px;width:${S}px"></div>`}h[f]=_}this._renderResult=h}getGuidesByLine(e,t,i){const n=this._bracketPairGuideOptions.bracketPairs!==!1?this._context.viewModel.getBracketGuidesInRangeByLine(e,t,i,{highlightActive:this._bracketPairGuideOptions.highlightActiveBracketPair,horizontalGuides:this._bracketPairGuideOptions.bracketPairsHorizontal===!0?mg.Enabled:this._bracketPairGuideOptions.bracketPairsHorizontal==="active"?mg.EnabledForActive:mg.Disabled,includeInactive:this._bracketPairGuideOptions.bracketPairs===!0}):null,o=this._bracketPairGuideOptions.indentation?this._context.viewModel.getLinesIndentGuides(e,t):null;let r=0,a=0,l=0;if(this._bracketPairGuideOptions.highlightActiveIndentation!==!1&&i){const u=this._context.viewModel.getActiveIndentGuide(i.lineNumber,e,t);r=u.startLineNumber,a=u.endLineNumber,l=u.indent}const{indentSize:d}=this._context.viewModel.model.getOptions(),c=[];for(let u=e;u<=t;u++){const h=new Array;c.push(h);const g=n?n[u-e]:[],f=new Qd(g),m=o?o[u-e]:0;for(let _=1;_<=m;_++){const v=(_-1)*d+1,b=(this._bracketPairGuideOptions.highlightActiveIndentation==="always"||g.length===0)&&r<=u&&u<=a&&_===l;h.push(...f.takeWhile(w=>w.visibleColumn<v)||[]);const C=f.peek();(!C||C.visibleColumn!==v||C.horizontalLine)&&h.push(new ng(v,-1,`core-guide-indent lvl-${(_-1)%30}`+(b?" indent-active":""),null,-1,-1))}h.push(...f.takeWhile(_=>!0)||[])}return c}render(e,t){if(!this._renderResult)return"";const i=t-e;return i<0||i>=this._renderResult.length?"":this._renderResult[i]}}function Nf(s){if(!(s&&s.isTransparent()))return s}ia((s,e)=>{const t=[{bracketColor:DH,guideColor:Are,guideColorActive:Vre},{bracketColor:kH,guideColor:Pre,guideColorActive:Hre},{bracketColor:IH,guideColor:Ore,guideColorActive:zre},{bracketColor:EH,guideColor:Fre,guideColorActive:Ure},{bracketColor:NH,guideColor:Bre,guideColorActive:$re},{bracketColor:TH,guideColor:Wre,guideColorActive:jre}],i=new VH,n=[{indentColor:gC,indentColorActive:fC},{indentColor:mre,indentColorActive:wre},{indentColor:_re,indentColorActive:Sre},{indentColor:vre,indentColorActive:yre},{indentColor:bre,indentColorActive:Lre},{indentColor:Cre,indentColorActive:xre}],o=t.map(a=>{var l,d;const c=s.getColor(a.bracketColor),u=s.getColor(a.guideColor),h=s.getColor(a.guideColorActive),g=Nf((l=Nf(u))!==null&&l!==void 0?l:c==null?void 0:c.transparent(.3)),f=Nf((d=Nf(h))!==null&&d!==void 0?d:c);if(!(!g||!f))return{guideColor:g,guideColorActive:f}}).filter(b0),r=n.map(a=>{const l=s.getColor(a.indentColor),d=s.getColor(a.indentColorActive),c=Nf(l),u=Nf(d);if(!(!c||!u))return{indentColor:c,indentColorActive:u}}).filter(b0);if(o.length>0){for(let a=0;a<30;a++){const l=o[a%o.length];e.addRule(`.monaco-editor .${i.getInlineClassNameOfLevel(a).replace(/ /g,".")} { --guide-color: ${l.guideColor}; --guide-color-active: ${l.guideColorActive}; }`)}e.addRule(".monaco-editor .vertical { box-shadow: 1px 0 0 0 var(--guide-color) inset; }"),e.addRule(".monaco-editor .horizontal-top { border-top: 1px solid var(--guide-color); }"),e.addRule(".monaco-editor .horizontal-bottom { border-bottom: 1px solid var(--guide-color); }"),e.addRule(`.monaco-editor .vertical.${i.activeClassName} { box-shadow: 1px 0 0 0 var(--guide-color-active) inset; }`),e.addRule(`.monaco-editor .horizontal-top.${i.activeClassName} { border-top: 1px solid var(--guide-color-active); }`),e.addRule(`.monaco-editor .horizontal-bottom.${i.activeClassName} { border-bottom: 1px solid var(--guide-color-active); }`)}if(r.length>0){for(let a=0;a<30;a++){const l=r[a%r.length];e.addRule(`.monaco-editor .lines-content .core-guide-indent.lvl-${a} { --indent-color: ${l.indentColor}; --indent-color-active: ${l.indentColorActive}; }`)}e.addRule(".monaco-editor .lines-content .core-guide-indent { box-shadow: 1px 0 0 0 var(--indent-color) inset; }"),e.addRule(".monaco-editor .lines-content .core-guide-indent.indent-active { box-shadow: 1px 0 0 0 var(--indent-color-active) inset; }")}});class dI{get didDomLayout(){return this._didDomLayout}readClientRect(){if(!this._clientRectRead){this._clientRectRead=!0;const e=this._domNode.getBoundingClientRect();this.markDidDomLayout(),this._clientRectDeltaLeft=e.left,this._clientRectScale=e.width/this._domNode.offsetWidth}}get clientRectDeltaLeft(){return this._clientRectRead||this.readClientRect(),this._clientRectDeltaLeft}get clientRectScale(){return this._clientRectRead||this.readClientRect(),this._clientRectScale}constructor(e,t){this._domNode=e,this.endNode=t,this._didDomLayout=!1,this._clientRectDeltaLeft=0,this._clientRectScale=1,this._clientRectRead=!1}markDidDomLayout(){this._didDomLayout=!0}}class Lae{constructor(){this._currentVisibleRange=new D(1,1,1,1)}getCurrentVisibleRange(){return this._currentVisibleRange}setCurrentVisibleRange(e){this._currentVisibleRange=e}}class xae{constructor(e,t,i,n,o,r,a){this.minimalReveal=e,this.lineNumber=t,this.startColumn=i,this.endColumn=n,this.startScrollTop=o,this.stopScrollTop=r,this.scrollType=a,this.type="range",this.minLineNumber=t,this.maxLineNumber=t}}class Dae{constructor(e,t,i,n,o){this.minimalReveal=e,this.selections=t,this.startScrollTop=i,this.stopScrollTop=n,this.scrollType=o,this.type="selections";let r=t[0].startLineNumber,a=t[0].endLineNumber;for(let l=1,d=t.length;l<d;l++){const c=t[l];r=Math.min(r,c.startLineNumber),a=Math.max(a,c.endLineNumber)}this.minLineNumber=r,this.maxLineNumber=a}}class Nx extends Eo{constructor(e,t){super(e),this._linesContent=t,this._textRangeRestingSpot=document.createElement("div"),this._visibleLines=new OH(this),this.domNode=this._visibleLines.domNode;const i=this._context.configuration,n=this._context.configuration.options,o=n.get(50),r=n.get(144);this._lineHeight=n.get(66),this._typicalHalfwidthCharacterWidth=o.typicalHalfwidthCharacterWidth,this._isViewportWrapping=r.isViewportWrapping,this._revealHorizontalRightPadding=n.get(99),this._cursorSurroundingLines=n.get(29),this._cursorSurroundingLinesStyle=n.get(30),this._canUseLayerHinting=!n.get(32),this._viewLineOptions=new T3(i,this._context.theme.type),Zl.write(this.domNode,7),this.domNode.setClassName(`view-lines ${Vp}`),Xn(this.domNode,o),this._maxLineWidth=0,this._asyncUpdateLineWidths=new jt(()=>{this._updateLineWidthsSlow()},200),this._asyncCheckMonospaceFontAssumptions=new jt(()=>{this._checkMonospaceFontAssumptions()},2e3),this._lastRenderedData=new Lae,this._horizontalRevealRequest=null,this._stickyScrollEnabled=n.get(114).enabled,this._maxNumberStickyLines=n.get(114).maxLineCount}dispose(){this._asyncUpdateLineWidths.dispose(),this._asyncCheckMonospaceFontAssumptions.dispose(),super.dispose()}getDomNode(){return this.domNode}createVisibleLine(){return new bl(this._viewLineOptions)}onConfigurationChanged(e){this._visibleLines.onConfigurationChanged(e),e.hasChanged(144)&&(this._maxLineWidth=0);const t=this._context.configuration.options,i=t.get(50),n=t.get(144);return this._lineHeight=t.get(66),this._typicalHalfwidthCharacterWidth=i.typicalHalfwidthCharacterWidth,this._isViewportWrapping=n.isViewportWrapping,this._revealHorizontalRightPadding=t.get(99),this._cursorSurroundingLines=t.get(29),this._cursorSurroundingLinesStyle=t.get(30),this._canUseLayerHinting=!t.get(32),this._stickyScrollEnabled=t.get(114).enabled,this._maxNumberStickyLines=t.get(114).maxLineCount,Xn(this.domNode,i),this._onOptionsMaybeChanged(),e.hasChanged(143)&&(this._maxLineWidth=0),!0}_onOptionsMaybeChanged(){const e=this._context.configuration,t=new T3(e,this._context.theme.type);if(!this._viewLineOptions.equals(t)){this._viewLineOptions=t;const i=this._visibleLines.getStartLineNumber(),n=this._visibleLines.getEndLineNumber();for(let o=i;o<=n;o++)this._visibleLines.getVisibleLine(o).onOptionsChanged(this._viewLineOptions);return!0}return!1}onCursorStateChanged(e){const t=this._visibleLines.getStartLineNumber(),i=this._visibleLines.getEndLineNumber();let n=!1;for(let o=t;o<=i;o++)n=this._visibleLines.getVisibleLine(o).onSelectionChanged()||n;return n}onDecorationsChanged(e){{const t=this._visibleLines.getStartLineNumber(),i=this._visibleLines.getEndLineNumber();for(let n=t;n<=i;n++)this._visibleLines.getVisibleLine(n).onDecorationsChanged()}return!0}onFlushed(e){const t=this._visibleLines.onFlushed(e);return this._maxLineWidth=0,t}onLinesChanged(e){return this._visibleLines.onLinesChanged(e)}onLinesDeleted(e){return this._visibleLines.onLinesDeleted(e)}onLinesInserted(e){return this._visibleLines.onLinesInserted(e)}onRevealRangeRequest(e){const t=this._computeScrollTopToRevealRange(this._context.viewLayout.getFutureViewport(),e.source,e.minimalReveal,e.range,e.selections,e.verticalType);if(t===-1)return!1;let i=this._context.viewLayout.validateScrollPosition({scrollTop:t});e.revealHorizontal?e.range&&e.range.startLineNumber!==e.range.endLineNumber?i={scrollTop:i.scrollTop,scrollLeft:0}:e.range?this._horizontalRevealRequest=new xae(e.minimalReveal,e.range.startLineNumber,e.range.startColumn,e.range.endColumn,this._context.viewLayout.getCurrentScrollTop(),i.scrollTop,e.scrollType):e.selections&&e.selections.length>0&&(this._horizontalRevealRequest=new Dae(e.minimalReveal,e.selections,this._context.viewLayout.getCurrentScrollTop(),i.scrollTop,e.scrollType)):this._horizontalRevealRequest=null;const o=Math.abs(this._context.viewLayout.getCurrentScrollTop()-i.scrollTop)<=this._lineHeight?1:e.scrollType;return this._context.viewModel.viewLayout.setScrollPosition(i,o),!0}onScrollChanged(e){if(this._horizontalRevealRequest&&e.scrollLeftChanged&&(this._horizontalRevealRequest=null),this._horizontalRevealRequest&&e.scrollTopChanged){const t=Math.min(this._horizontalRevealRequest.startScrollTop,this._horizontalRevealRequest.stopScrollTop),i=Math.max(this._horizontalRevealRequest.startScrollTop,this._horizontalRevealRequest.stopScrollTop);(e.scrollTop<t||e.scrollTop>i)&&(this._horizontalRevealRequest=null)}return this.domNode.setWidth(e.scrollWidth),this._visibleLines.onScrollChanged(e)||!0}onTokensChanged(e){return this._visibleLines.onTokensChanged(e)}onZonesChanged(e){return this._context.viewModel.viewLayout.setMaxLineWidth(this._maxLineWidth),this._visibleLines.onZonesChanged(e)}onThemeChanged(e){return this._onOptionsMaybeChanged()}getPositionFromDOMInfo(e,t){const i=this._getViewLineDomNode(e);if(i===null)return null;const n=this._getLineNumberFor(i);if(n===-1||n<1||n>this._context.viewModel.getLineCount())return null;if(this._context.viewModel.getLineMaxColumn(n)===1)return new H(n,1);const o=this._visibleLines.getStartLineNumber(),r=this._visibleLines.getEndLineNumber();if(n<o||n>r)return null;let a=this._visibleLines.getVisibleLine(n).getColumnOfNodeOffset(e,t);const l=this._context.viewModel.getLineMinColumn(n);return a<l&&(a=l),new H(n,a)}_getViewLineDomNode(e){for(;e&&e.nodeType===1;){if(e.className===bl.CLASS_NAME)return e;e=e.parentElement}return null}_getLineNumberFor(e){const t=this._visibleLines.getStartLineNumber(),i=this._visibleLines.getEndLineNumber();for(let n=t;n<=i;n++){const o=this._visibleLines.getVisibleLine(n);if(e===o.getDomNode())return n}return-1}getLineWidth(e){const t=this._visibleLines.getStartLineNumber(),i=this._visibleLines.getEndLineNumber();if(e<t||e>i)return-1;const n=new dI(this.domNode.domNode,this._textRangeRestingSpot),o=this._visibleLines.getVisibleLine(e).getWidth(n);return this._updateLineWidthsSlowIfDomDidLayout(n),o}linesVisibleRangesForRange(e,t){if(this.shouldRender())return null;const i=e.endLineNumber,n=D.intersectRanges(e,this._lastRenderedData.getCurrentVisibleRange());if(!n)return null;const o=[];let r=0;const a=new dI(this.domNode.domNode,this._textRangeRestingSpot);let l=0;t&&(l=this._context.viewModel.coordinatesConverter.convertViewPositionToModelPosition(new H(n.startLineNumber,1)).lineNumber);const d=this._visibleLines.getStartLineNumber(),c=this._visibleLines.getEndLineNumber();for(let u=n.startLineNumber;u<=n.endLineNumber;u++){if(u<d||u>c)continue;const h=u===n.startLineNumber?n.startColumn:1,g=u!==n.endLineNumber,f=g?this._context.viewModel.getLineMaxColumn(u):n.endColumn,m=this._visibleLines.getVisibleLine(u).getVisibleRangesForRange(u,h,f,a);if(m){if(t&&u<i){const _=l;l=this._context.viewModel.coordinatesConverter.convertViewPositionToModelPosition(new H(u+1,1)).lineNumber,_!==l&&(m.ranges[m.ranges.length-1].width+=this._typicalHalfwidthCharacterWidth)}o[r++]=new Ooe(m.outsideRenderedLine,u,yx.from(m.ranges),g)}}return this._updateLineWidthsSlowIfDomDidLayout(a),r===0?null:o}_visibleRangesForLineRange(e,t,i){if(this.shouldRender()||e<this._visibleLines.getStartLineNumber()||e>this._visibleLines.getEndLineNumber())return null;const n=new dI(this.domNode.domNode,this._textRangeRestingSpot),o=this._visibleLines.getVisibleLine(e).getVisibleRangesForRange(e,t,i,n);return this._updateLineWidthsSlowIfDomDidLayout(n),o}visibleRangeForPosition(e){const t=this._visibleRangesForLineRange(e.lineNumber,e.column,e.column);return t?new Foe(t.outsideRenderedLine,t.ranges[0].left):null}_updateLineWidthsFast(){return this._updateLineWidths(!0)}_updateLineWidthsSlow(){this._updateLineWidths(!1)}_updateLineWidthsSlowIfDomDidLayout(e){e.didDomLayout&&(this._asyncUpdateLineWidths.isScheduled()||(this._asyncUpdateLineWidths.cancel(),this._updateLineWidthsSlow()))}_updateLineWidths(e){const t=this._visibleLines.getStartLineNumber(),i=this._visibleLines.getEndLineNumber();let n=1,o=!0;for(let r=t;r<=i;r++){const a=this._visibleLines.getVisibleLine(r);if(e&&!a.getWidthIsFast()){o=!1;continue}n=Math.max(n,a.getWidth(null))}return o&&t===1&&i===this._context.viewModel.getLineCount()&&(this._maxLineWidth=0),this._ensureMaxLineWidth(n),o}_checkMonospaceFontAssumptions(){let e=-1,t=-1;const i=this._visibleLines.getStartLineNumber(),n=this._visibleLines.getEndLineNumber();for(let o=i;o<=n;o++){const r=this._visibleLines.getVisibleLine(o);if(r.needsMonospaceFontCheck()){const a=r.getWidth(null);a>t&&(t=a,e=o)}}if(e!==-1&&!this._visibleLines.getVisibleLine(e).monospaceAssumptionsAreValid())for(let o=i;o<=n;o++)this._visibleLines.getVisibleLine(o).onMonospaceAssumptionsInvalidated()}prepareRender(){throw new Error("Not supported")}render(){throw new Error("Not supported")}renderText(e){if(this._visibleLines.renderLines(e),this._lastRenderedData.setCurrentVisibleRange(e.visibleRange),this.domNode.setWidth(this._context.viewLayout.getScrollWidth()),this.domNode.setHeight(Math.min(this._context.viewLayout.getScrollHeight(),1e6)),this._horizontalRevealRequest){const i=this._horizontalRevealRequest;if(e.startLineNumber<=i.minLineNumber&&i.maxLineNumber<=e.endLineNumber){this._horizontalRevealRequest=null,this.onDidRender();const n=this._computeScrollLeftToReveal(i);n&&(this._isViewportWrapping||this._ensureMaxLineWidth(n.maxHorizontalOffset),this._context.viewModel.viewLayout.setScrollPosition({scrollLeft:n.scrollLeft},i.scrollType))}}if(this._updateLineWidthsFast()?this._asyncUpdateLineWidths.cancel():this._asyncUpdateLineWidths.schedule(),Ss&&!this._asyncCheckMonospaceFontAssumptions.isScheduled()){const i=this._visibleLines.getStartLineNumber(),n=this._visibleLines.getEndLineNumber();for(let o=i;o<=n;o++)if(this._visibleLines.getVisibleLine(o).needsMonospaceFontCheck()){this._asyncCheckMonospaceFontAssumptions.schedule();break}}this._linesContent.setLayerHinting(this._canUseLayerHinting),this._linesContent.setContain("strict");const t=this._context.viewLayout.getCurrentScrollTop()-e.bigNumbersDelta;this._linesContent.setTop(-t),this._linesContent.setLeft(-this._context.viewLayout.getCurrentScrollLeft())}_ensureMaxLineWidth(e){const t=Math.ceil(e);this._maxLineWidth<t&&(this._maxLineWidth=t,this._context.viewModel.viewLayout.setMaxLineWidth(this._maxLineWidth))}_computeScrollTopToRevealRange(e,t,i,n,o,r){const a=e.top,l=e.height,d=a+l;let c,u,h;if(o&&o.length>0){let v=o[0].startLineNumber,b=o[0].endLineNumber;for(let C=1,w=o.length;C<w;C++){const S=o[C];v=Math.min(v,S.startLineNumber),b=Math.max(b,S.endLineNumber)}c=!1,u=this._context.viewLayout.getVerticalOffsetForLineNumber(v),h=this._context.viewLayout.getVerticalOffsetForLineNumber(b)+this._lineHeight}else if(n)c=!0,u=this._context.viewLayout.getVerticalOffsetForLineNumber(n.startLineNumber),h=this._context.viewLayout.getVerticalOffsetForLineNumber(n.endLineNumber)+this._lineHeight;else return-1;const g=(t==="mouse"||i)&&this._cursorSurroundingLinesStyle==="default";let f=0,m=0;if(g)i||(f=this._lineHeight);else{const v=Math.min(l/this._lineHeight/2,this._cursorSurroundingLines);this._stickyScrollEnabled?f=Math.max(v,this._maxNumberStickyLines)*this._lineHeight:f=v*this._lineHeight,m=Math.max(0,v-1)*this._lineHeight}i||(r===0||r===4)&&(m+=this._lineHeight),u-=f,h+=m;let _;if(h-u>l){if(!c)return-1;_=u}else if(r===5||r===6)if(r===6&&a<=u&&h<=d)_=a;else{const v=Math.max(5*this._lineHeight,l*.2),b=u-v,C=h-l;_=Math.max(C,b)}else if(r===1||r===2)if(r===2&&a<=u&&h<=d)_=a;else{const v=(u+h)/2;_=Math.max(0,v-l/2)}else _=this._computeMinimumScrolling(a,d,u,h,r===3,r===4);return _}_computeScrollLeftToReveal(e){const t=this._context.viewLayout.getCurrentViewport(),i=this._context.configuration.options.get(143),n=t.left,o=n+t.width-i.verticalScrollbarWidth;let r=1073741824,a=0;if(e.type==="range"){const d=this._visibleRangesForLineRange(e.lineNumber,e.startColumn,e.endColumn);if(!d)return null;for(const c of d.ranges)r=Math.min(r,Math.round(c.left)),a=Math.max(a,Math.round(c.left+c.width))}else for(const d of e.selections){if(d.startLineNumber!==d.endLineNumber)return null;const c=this._visibleRangesForLineRange(d.startLineNumber,d.startColumn,d.endColumn);if(!c)return null;for(const u of c.ranges)r=Math.min(r,Math.round(u.left)),a=Math.max(a,Math.round(u.left+u.width))}return e.minimalReveal||(r=Math.max(0,r-Nx.HORIZONTAL_EXTRA_PX),a+=this._revealHorizontalRightPadding),e.type==="selections"&&a-r>t.width?null:{scrollLeft:this._computeMinimumScrolling(n,o,r,a),maxHorizontalOffset:a}}_computeMinimumScrolling(e,t,i,n,o,r){e=e|0,t=t|0,i=i|0,n=n|0,o=!!o,r=!!r;const a=t-e;if(n-i<a){if(o)return i;if(r)return Math.max(0,n-a);if(i<e)return i;if(n>t)return Math.max(0,n-a)}else return i;return e}}Nx.HORIZONTAL_EXTRA_PX=30;class yT{constructor(e,t,i,n){this._decorationToRenderBrand=void 0,this.startLineNumber=+e,this.endLineNumber=+t,this.className=String(i),this.zIndex=n??0}}class kae{constructor(e,t){this.className=e,this.zIndex=t}}class Iae{constructor(){this.decorations=[]}add(e){this.decorations.push(e)}getDecorations(){return this.decorations}}class HH extends df{_render(e,t,i){const n=[];for(let a=e;a<=t;a++){const l=a-e;n[l]=new Iae}if(i.length===0)return n;i.sort((a,l)=>a.className===l.className?a.startLineNumber===l.startLineNumber?a.endLineNumber-l.endLineNumber:a.startLineNumber-l.startLineNumber:a.className<l.className?-1:1);let o=null,r=0;for(let a=0,l=i.length;a<l;a++){const d=i[a],c=d.className,u=d.zIndex;let h=Math.max(d.startLineNumber,e)-e;const g=Math.min(d.endLineNumber,t)-e;o===c?(h=Math.max(r+1,h),r=Math.max(r,g)):(o=c,r=g);for(let f=h;f<=r;f++)n[f].add(new kae(c,u))}return n}}class Eae extends Eo{constructor(e){super(e),this._widgets={},this._context=e;const t=this._context.configuration.options,i=t.get(143);this.domNode=Mt(document.createElement("div")),this.domNode.setClassName("glyph-margin-widgets"),this.domNode.setPosition("absolute"),this.domNode.setTop(0),this._lineHeight=t.get(66),this._glyphMargin=t.get(57),this._glyphMarginLeft=i.glyphMarginLeft,this._glyphMarginWidth=i.glyphMarginWidth,this._glyphMarginDecorationLaneCount=i.glyphMarginDecorationLaneCount,this._managedDomNodes=[],this._decorationGlyphsToRender=[]}dispose(){this._managedDomNodes=[],this._decorationGlyphsToRender=[],this._widgets={},super.dispose()}getWidgets(){return Object.values(this._widgets)}onConfigurationChanged(e){const t=this._context.configuration.options,i=t.get(143);return this._lineHeight=t.get(66),this._glyphMargin=t.get(57),this._glyphMarginLeft=i.glyphMarginLeft,this._glyphMarginWidth=i.glyphMarginWidth,this._glyphMarginDecorationLaneCount=i.glyphMarginDecorationLaneCount,!0}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return e.scrollTopChanged}onZonesChanged(e){return!0}addWidget(e){const t=Mt(e.getDomNode());this._widgets[e.getId()]={widget:e,preference:e.getPosition(),domNode:t,renderInfo:null},t.setPosition("absolute"),t.setDisplay("none"),t.setAttribute("widgetId",e.getId()),this.domNode.appendChild(t),this.setShouldRender()}setWidgetPosition(e,t){const i=this._widgets[e.getId()];return i.preference.lane===t.lane&&i.preference.zIndex===t.zIndex&&D.equalsRange(i.preference.range,t.range)?!1:(i.preference=t,this.setShouldRender(),!0)}removeWidget(e){var t;const i=e.getId();if(this._widgets[i]){const o=this._widgets[i].domNode.domNode;delete this._widgets[i],(t=o.parentNode)===null||t===void 0||t.removeChild(o),this.setShouldRender()}}_collectDecorationBasedGlyphRenderRequest(e,t){var i,n,o;const r=e.visibleRange.startLineNumber,a=e.visibleRange.endLineNumber,l=e.getDecorationsInViewport();for(const d of l){const c=d.options.glyphMarginClassName;if(!c)continue;const u=Math.max(d.range.startLineNumber,r),h=Math.min(d.range.endLineNumber,a),g=Math.min((n=(i=d.options.glyphMargin)===null||i===void 0?void 0:i.position)!==null&&n!==void 0?n:1,this._glyphMarginDecorationLaneCount),f=(o=d.options.zIndex)!==null&&o!==void 0?o:0;for(let m=u;m<=h;m++)t.push(new Nae(m,g,f,c))}}_collectWidgetBasedGlyphRenderRequest(e,t){const i=e.visibleRange.startLineNumber,n=e.visibleRange.endLineNumber;for(const o of Object.values(this._widgets)){const r=o.preference.range,{startLineNumber:a,endLineNumber:l}=this._context.viewModel.coordinatesConverter.convertModelRangeToViewRange(D.lift(r));if(!a||!l||l<i||a>n)continue;const d=Math.max(a,i),c=Math.min(o.preference.lane,this._glyphMarginDecorationLaneCount);t.push(new Tae(d,c,o.preference.zIndex,o))}}_collectSortedGlyphRenderRequests(e){const t=[];return this._collectDecorationBasedGlyphRenderRequest(e,t),this._collectWidgetBasedGlyphRenderRequest(e,t),t.sort((i,n)=>i.lineNumber===n.lineNumber?i.lane===n.lane?i.zIndex===n.zIndex?n.type===i.type?i.type===0&&n.type===0?i.className<n.className?-1:1:0:n.type-i.type:n.zIndex-i.zIndex:i.lane-n.lane:i.lineNumber-n.lineNumber),t}prepareRender(e){if(!this._glyphMargin){this._decorationGlyphsToRender=[];return}for(const n of Object.values(this._widgets))n.renderInfo=null;const t=new Qd(this._collectSortedGlyphRenderRequests(e)),i=[];for(;t.length>0;){const n=t.peek();if(!n)break;const o=t.takeWhile(a=>a.lineNumber===n.lineNumber&&a.lane===n.lane);if(!o||o.length===0)break;const r=o[0];if(r.type===0){const a=[];for(const l of o){if(l.zIndex!==r.zIndex||l.type!==r.type)break;(a.length===0||a[a.length-1]!==l.className)&&a.push(l.className)}i.push(r.accept(a.join(" ")))}else r.widget.renderInfo={lineNumber:r.lineNumber,lane:r.lane}}this._decorationGlyphsToRender=i}render(e){if(!this._glyphMargin){for(const i of Object.values(this._widgets))i.domNode.setDisplay("none");for(;this._managedDomNodes.length>0;){const i=this._managedDomNodes.pop();i==null||i.domNode.remove()}return}const t=Math.round(this._glyphMarginWidth/this._glyphMarginDecorationLaneCount);for(const i of Object.values(this._widgets))if(!i.renderInfo)i.domNode.setDisplay("none");else{const n=e.viewportData.relativeVerticalOffset[i.renderInfo.lineNumber-e.viewportData.startLineNumber],o=this._glyphMarginLeft+(i.renderInfo.lane-1)*this._lineHeight;i.domNode.setDisplay("block"),i.domNode.setTop(n),i.domNode.setLeft(o),i.domNode.setWidth(t),i.domNode.setHeight(this._lineHeight)}for(let i=0;i<this._decorationGlyphsToRender.length;i++){const n=this._decorationGlyphsToRender[i],o=e.viewportData.relativeVerticalOffset[n.lineNumber-e.viewportData.startLineNumber],r=this._glyphMarginLeft+(n.lane-1)*this._lineHeight;let a;i<this._managedDomNodes.length?a=this._managedDomNodes[i]:(a=Mt(document.createElement("div")),this._managedDomNodes.push(a),this.domNode.appendChild(a)),a.setClassName("cgmr codicon "+n.combinedClassName),a.setPosition("absolute"),a.setTop(o),a.setLeft(r),a.setWidth(t),a.setHeight(this._lineHeight)}for(;this._managedDomNodes.length>this._decorationGlyphsToRender.length;){const i=this._managedDomNodes.pop();i==null||i.domNode.remove()}}}class Nae{constructor(e,t,i,n){this.lineNumber=e,this.lane=t,this.zIndex=i,this.className=n,this.type=0}accept(e){return new Mae(this.lineNumber,this.lane,e)}}class Tae{constructor(e,t,i,n){this.lineNumber=e,this.lane=t,this.zIndex=i,this.widget=n,this.type=1}}class Mae{constructor(e,t,i){this.lineNumber=e,this.lane=t,this.combinedClassName=i}}class Rae extends HH{constructor(e){super(),this._context=e;const i=this._context.configuration.options.get(143);this._decorationsLeft=i.decorationsLeft,this._decorationsWidth=i.decorationsWidth,this._renderResult=null,this._context.addEventHandler(this)}dispose(){this._context.removeEventHandler(this),this._renderResult=null,super.dispose()}onConfigurationChanged(e){const i=this._context.configuration.options.get(143);return this._decorationsLeft=i.decorationsLeft,this._decorationsWidth=i.decorationsWidth,!0}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return e.scrollTopChanged}onZonesChanged(e){return!0}_getDecorations(e){const t=e.getDecorationsInViewport(),i=[];let n=0;for(let o=0,r=t.length;o<r;o++){const a=t[o],l=a.options.linesDecorationsClassName,d=a.options.zIndex;l&&(i[n++]=new yT(a.range.startLineNumber,a.range.endLineNumber,l,d));const c=a.options.firstLineDecorationClassName;c&&(i[n++]=new yT(a.range.startLineNumber,a.range.startLineNumber,c,d))}return i}prepareRender(e){const t=e.visibleRange.startLineNumber,i=e.visibleRange.endLineNumber,n=this._render(t,i,this._getDecorations(e)),o=this._decorationsLeft.toString(),r=this._decorationsWidth.toString(),a='" style="left:'+o+"px;width:"+r+'px;"></div>',l=[];for(let d=t;d<=i;d++){const c=d-t,u=n[c].getDecorations();let h="";for(const g of u)h+='<div class="cldr '+g.className+a;l[c]=h}this._renderResult=l}render(e,t){return this._renderResult?this._renderResult[t-e]:""}}class Aae extends HH{constructor(e){super(),this._context=e,this._renderResult=null,this._context.addEventHandler(this)}dispose(){this._context.removeEventHandler(this),this._renderResult=null,super.dispose()}onConfigurationChanged(e){return!0}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return e.scrollTopChanged}onZonesChanged(e){return!0}_getDecorations(e){const t=e.getDecorationsInViewport(),i=[];let n=0;for(let o=0,r=t.length;o<r;o++){const a=t[o],l=a.options.marginClassName,d=a.options.zIndex;l&&(i[n++]=new yT(a.range.startLineNumber,a.range.endLineNumber,l,d))}return i}prepareRender(e){const t=e.visibleRange.startLineNumber,i=e.visibleRange.endLineNumber,n=this._render(t,i,this._getDecorations(e)),o=[];for(let r=t;r<=i;r++){const a=r-t,l=n[a].getDecorations();let d="";for(const c of l)d+='<div class="cmdr '+c.className+'" style=""></div>';o[a]=d}this._renderResult=o}render(e,t){return this._renderResult?this._renderResult[t-e]:""}}class vr{constructor(e,t,i,n){this._rgba8Brand=void 0,this.r=vr._clamp(e),this.g=vr._clamp(t),this.b=vr._clamp(i),this.a=vr._clamp(n)}equals(e){return this.r===e.r&&this.g===e.g&&this.b===e.b&&this.a===e.a}static _clamp(e){return e<0?0:e>255?255:e|0}}vr.Empty=new vr(0,0,0,0);class mC extends j{static getInstance(){return this._INSTANCE||(this._INSTANCE=new mC),this._INSTANCE}constructor(){super(),this._onDidChange=new W,this.onDidChange=this._onDidChange.event,this._updateColorMap(),this._register(xi.onDidChange(e=>{e.changedColorMap&&this._updateColorMap()}))}_updateColorMap(){const e=xi.getColorMap();if(!e){this._colors=[vr.Empty],this._backgroundIsLight=!0;return}this._colors=[vr.Empty];for(let i=1;i<e.length;i++){const n=e[i].rgba;this._colors[i]=new vr(n.r,n.g,n.b,Math.round(n.a*255))}const t=e[2].getRelativeLuminance();this._backgroundIsLight=t>=.5,this._onDidChange.fire(void 0)}getColor(e){return(e<1||e>=this._colors.length)&&(e=2),this._colors[e]}backgroundIsLight(){return this._backgroundIsLight}}mC._INSTANCE=null;const Pae=(()=>{const s=[];for(let e=32;e<=126;e++)s.push(e);return s.push(65533),s})(),Oae=(s,e)=>(s-=32,s<0||s>96?e<=2?(s+96)%96:95:s);class q0{constructor(e,t){this.scale=t,this._minimapCharRendererBrand=void 0,this.charDataNormal=q0.soften(e,12/15),this.charDataLight=q0.soften(e,50/60)}static soften(e,t){const i=new Uint8ClampedArray(e.length);for(let n=0,o=e.length;n<o;n++)i[n]=zS(e[n]*t);return i}renderChar(e,t,i,n,o,r,a,l,d,c,u){const h=1*this.scale,g=2*this.scale,f=u?1:g;if(t+h>e.width||i+f>e.height){console.warn("bad render request outside image data");return}const m=c?this.charDataLight:this.charDataNormal,_=Oae(n,d),v=e.width*4,b=a.r,C=a.g,w=a.b,S=o.r-b,x=o.g-C,L=o.b-w,k=Math.max(r,l),I=e.data;let P=_*h*g,$=i*v+t*4;for(let A=0;A<f;A++){let z=$;for(let K=0;K<h;K++){const Q=m[P++]/255*(r/255);I[z++]=b+S*Q,I[z++]=C+x*Q,I[z++]=w+L*Q,I[z++]=k}$+=v}}blockRenderChar(e,t,i,n,o,r,a,l){const d=1*this.scale,c=2*this.scale,u=l?1:c;if(t+d>e.width||i+u>e.height){console.warn("bad render request outside image data");return}const h=e.width*4,g=.5*(o/255),f=r.r,m=r.g,_=r.b,v=n.r-f,b=n.g-m,C=n.b-_,w=f+v*g,S=m+b*g,x=_+C*g,L=Math.max(o,a),k=e.data;let I=i*h+t*4;for(let P=0;P<u;P++){let $=I;for(let A=0;A<d;A++)k[$++]=w,k[$++]=S,k[$++]=x,k[$++]=L;I+=h}}}const U3={0:0,1:1,2:2,3:3,4:4,5:5,6:6,7:7,8:8,9:9,A:10,B:11,C:12,D:13,E:14,F:15},$3=s=>{const e=new Uint8ClampedArray(s.length/2);for(let t=0;t<s.length;t+=2)e[t>>1]=U3[s[t]]<<4|U3[s[t+1]]&15;return e},j3={1:Du(()=>$3("0000511D6300CF609C709645A78432005642574171487021003C451900274D35D762755E8B629C5BA856AF57BA649530C167D1512A272A3F6038604460398526BCA2A968DB6F8957C768BE5FBE2FB467CF5D8D5B795DC7625B5DFF50DE64C466DB2FC47CD860A65E9A2EB96CB54CE06DA763AB2EA26860524D3763536601005116008177A8705E53AB738E6A982F88BAA35B5F5B626D9C636B449B737E5B7B678598869A662F6B5B8542706C704C80736A607578685B70594A49715A4522E792")),2:Du(()=>$3("000000000000000055394F383D2800008B8B1F210002000081B1CBCBCC820000847AAF6B9AAF2119BE08B8881AD60000A44FD07DCCF107015338130C00000000385972265F390B406E2437634B4B48031B12B8A0847000001E15B29A402F0000000000004B33460B00007A752C2A0000000000004D3900000084394B82013400ABA5CFC7AD9C0302A45A3E5A98AB000089A43382D97900008BA54AA087A70A0248A6A7AE6DBE0000BF6F94987EA40A01A06DCFA7A7A9030496C32F77891D0000A99FB1A0AFA80603B29AB9CA75930D010C0948354D3900000C0948354F37460D0028BE673D8400000000AF9D7B6E00002B007AA8933400007AA642675C2700007984CFB9C3985B768772A8A6B7B20000CAAECAAFC4B700009F94A6009F840009D09F9BA4CA9C0000CC8FC76DC87F0000C991C472A2000000A894A48CA7B501079BA2C9C69BA20000B19A5D3FA89000005CA6009DA2960901B0A7F0669FB200009D009E00B7890000DAD0F5D092820000D294D4C48BD10000B5A7A4A3B1A50402CAB6CBA6A2000000B5A7A4A3B1A8044FCDADD19D9CB00000B7778F7B8AAE0803C9AB5D3F5D3F00009EA09EA0BAB006039EA0989A8C7900009B9EF4D6B7C00000A9A7816CACA80000ABAC84705D3F000096DA635CDC8C00006F486F266F263D4784006124097B00374F6D2D6D2D6D4A3A95872322000000030000000000008D8939130000000000002E22A5C9CBC70600AB25C0B5C9B400061A2DB04CA67001082AA6BEBEBFC606002321DACBC19E03087AA08B6768380000282FBAC0B8CA7A88AD25BBA5A29900004C396C5894A6000040485A6E356E9442A32CD17EADA70000B4237923628600003E2DE9C1D7B500002F25BBA5A2990000231DB6AFB4A804023025C0B5CAB588062B2CBDBEC0C706882435A75CA20000002326BD6A82A908048B4B9A5A668000002423A09CB4BB060025259C9D8A7900001C1FCAB2C7C700002A2A9387ABA200002626A4A47D6E9D14333163A0C87500004B6F9C2D643A257049364936493647358A34438355497F1A0000A24C1D590000D38DFFBDD4CD3126"))};class Vv{static create(e,t){if(this.lastCreated&&e===this.lastCreated.scale&&t===this.lastFontFamily)return this.lastCreated;let i;return j3[e]?i=new q0(j3[e](),e):i=Vv.createFromSampleData(Vv.createSampleData(t).data,e),this.lastFontFamily=t,this.lastCreated=i,i}static createSampleData(e){const t=document.createElement("canvas"),i=t.getContext("2d");t.style.height="16px",t.height=16,t.width=96*10,t.style.width=96*10+"px",i.fillStyle="#ffffff",i.font=`bold 16px ${e}`,i.textBaseline="middle";let n=0;for(const o of Pae)i.fillText(String.fromCharCode(o),n,16/2),n+=10;return i.getImageData(0,0,96*10,16)}static createFromSampleData(e,t){if(e.length!==61440)throw new Error("Unexpected source in MinimapCharRenderer");const n=Vv._downsample(e,t);return new q0(n,t)}static _downsampleChar(e,t,i,n,o){const r=1*o,a=2*o;let l=n,d=0;for(let c=0;c<a;c++){const u=c/a*16,h=(c+1)/a*16;for(let g=0;g<r;g++){const f=g/r*10,m=(g+1)/r*10;let _=0,v=0;for(let C=u;C<h;C++){const w=t+Math.floor(C)*3840,S=1-(C-Math.floor(C));for(let x=f;x<m;x++){const L=1-(x-Math.floor(x)),k=w+Math.floor(x)*4,I=L*S;v+=I,_+=e[k]*e[k+3]/255*I}}const b=_/v;d=Math.max(d,b),i[l++]=zS(b)}}return d}static _downsample(e,t){const i=2*t*1*t,n=i*96,o=new Uint8ClampedArray(n);let r=0,a=0,l=0;for(let d=0;d<96;d++)l=Math.max(l,this._downsampleChar(e,a,o,r,t)),r+=i,a+=10*4;if(l>0){const d=255/l;for(let c=0;c<n;c++)o[c]*=d}return o}}const Fae=140,Bae=2;class G0{constructor(e,t,i){const n=e.options,o=n.get(141),r=n.get(143),a=r.minimap,l=n.get(50),d=n.get(72);this.renderMinimap=a.renderMinimap,this.size=d.size,this.minimapHeightIsEditorHeight=a.minimapHeightIsEditorHeight,this.scrollBeyondLastLine=n.get(104),this.paddingTop=n.get(83).top,this.paddingBottom=n.get(83).bottom,this.showSlider=d.showSlider,this.autohide=d.autohide,this.pixelRatio=o,this.typicalHalfwidthCharacterWidth=l.typicalHalfwidthCharacterWidth,this.lineHeight=n.get(66),this.minimapLeft=a.minimapLeft,this.minimapWidth=a.minimapWidth,this.minimapHeight=r.height,this.canvasInnerWidth=a.minimapCanvasInnerWidth,this.canvasInnerHeight=a.minimapCanvasInnerHeight,this.canvasOuterWidth=a.minimapCanvasOuterWidth,this.canvasOuterHeight=a.minimapCanvasOuterHeight,this.isSampling=a.minimapIsSampling,this.editorHeight=r.height,this.fontScale=a.minimapScale,this.minimapLineHeight=a.minimapLineHeight,this.minimapCharWidth=1*this.fontScale,this.charRenderer=Du(()=>Vv.create(this.fontScale,l.fontFamily)),this.defaultBackgroundColor=i.getColor(2),this.backgroundColor=G0._getMinimapBackground(t,this.defaultBackgroundColor),this.foregroundAlpha=G0._getMinimapForegroundOpacity(t)}static _getMinimapBackground(e,t){const i=e.getColor(Coe);return i?new vr(i.rgba.r,i.rgba.g,i.rgba.b,Math.round(255*i.rgba.a)):t}static _getMinimapForegroundOpacity(e){const t=e.getColor(woe);return t?vr._clamp(Math.round(255*t.rgba.a)):255}equals(e){return this.renderMinimap===e.renderMinimap&&this.size===e.size&&this.minimapHeightIsEditorHeight===e.minimapHeightIsEditorHeight&&this.scrollBeyondLastLine===e.scrollBeyondLastLine&&this.paddingTop===e.paddingTop&&this.paddingBottom===e.paddingBottom&&this.showSlider===e.showSlider&&this.autohide===e.autohide&&this.pixelRatio===e.pixelRatio&&this.typicalHalfwidthCharacterWidth===e.typicalHalfwidthCharacterWidth&&this.lineHeight===e.lineHeight&&this.minimapLeft===e.minimapLeft&&this.minimapWidth===e.minimapWidth&&this.minimapHeight===e.minimapHeight&&this.canvasInnerWidth===e.canvasInnerWidth&&this.canvasInnerHeight===e.canvasInnerHeight&&this.canvasOuterWidth===e.canvasOuterWidth&&this.canvasOuterHeight===e.canvasOuterHeight&&this.isSampling===e.isSampling&&this.editorHeight===e.editorHeight&&this.fontScale===e.fontScale&&this.minimapLineHeight===e.minimapLineHeight&&this.minimapCharWidth===e.minimapCharWidth&&this.defaultBackgroundColor&&this.defaultBackgroundColor.equals(e.defaultBackgroundColor)&&this.backgroundColor&&this.backgroundColor.equals(e.backgroundColor)&&this.foregroundAlpha===e.foregroundAlpha}}class Hv{constructor(e,t,i,n,o,r,a,l,d){this.scrollTop=e,this.scrollHeight=t,this.sliderNeeded=i,this._computedSliderRatio=n,this.sliderTop=o,this.sliderHeight=r,this.topPaddingLineCount=a,this.startLineNumber=l,this.endLineNumber=d}getDesiredScrollTopFromDelta(e){return Math.round(this.scrollTop+e/this._computedSliderRatio)}getDesiredScrollTopFromTouchLocation(e){return Math.round((e-this.sliderHeight/2)/this._computedSliderRatio)}intersectWithViewport(e){const t=Math.max(this.startLineNumber,e.startLineNumber),i=Math.min(this.endLineNumber,e.endLineNumber);return t>i?null:[t,i]}getYForLineNumber(e,t){return+(e-this.startLineNumber+this.topPaddingLineCount)*t}static create(e,t,i,n,o,r,a,l,d,c,u){const h=e.pixelRatio,g=e.minimapLineHeight,f=Math.floor(e.canvasInnerHeight/g),m=e.lineHeight;if(e.minimapHeightIsEditorHeight){let x=l*e.lineHeight+e.paddingTop+e.paddingBottom;e.scrollBeyondLastLine&&(x+=Math.max(0,o-e.lineHeight-e.paddingBottom));const L=Math.max(1,Math.floor(o*o/x)),k=Math.max(0,e.minimapHeight-L),I=k/(c-o),P=d*I,$=k>0,A=Math.floor(e.canvasInnerHeight/e.minimapLineHeight),z=Math.floor(e.paddingTop/e.lineHeight);return new Hv(d,c,$,I,P,L,z,1,Math.min(a,A))}let _;if(r&&i!==a){const x=i-t+1;_=Math.floor(x*g/h)}else{const x=o/m;_=Math.floor(x*g/h)}const v=Math.floor(e.paddingTop/m);let b=Math.floor(e.paddingBottom/m);if(e.scrollBeyondLastLine){const x=o/m;b=Math.max(b,x-1)}let C;if(b>0){const x=o/m;C=(v+a+b-x-1)*g/h}else C=Math.max(0,(v+a)*g/h-_);C=Math.min(e.minimapHeight-_,C);const w=C/(c-o),S=d*w;if(f>=v+a+b){const x=C>0;return new Hv(d,c,x,w,S,_,v,1,a)}else{let x;t>1?x=t+v:x=Math.max(1,d/m);let L,k=Math.max(1,Math.floor(x-S*h/g));k<v?(L=v-k+1,k=1):(L=0,k=Math.max(1,k-v)),u&&u.scrollHeight===c&&(u.scrollTop>d&&(k=Math.min(k,u.startLineNumber),L=Math.max(L,u.topPaddingLineCount)),u.scrollTop<d&&(k=Math.max(k,u.startLineNumber),L=Math.min(L,u.topPaddingLineCount)));const I=Math.min(a,k-L+f-1),P=(d-n)/m;let $;return d>=e.paddingTop?$=(t-k+L+P)*g/h:$=d/e.paddingTop*(L+P)*g/h,new Hv(d,c,!0,w,$,_,L,k,I)}}}class ty{constructor(e){this.dy=e}onContentChanged(){this.dy=-1}onTokensChanged(){this.dy=-1}}ty.INVALID=new ty(-1);class K3{constructor(e,t,i){this.renderedLayout=e,this._imageData=t,this._renderedLines=new PH(()=>ty.INVALID),this._renderedLines._set(e.startLineNumber,i)}linesEquals(e){if(!this.scrollEquals(e))return!1;const i=this._renderedLines._get().lines;for(let n=0,o=i.length;n<o;n++)if(i[n].dy===-1)return!1;return!0}scrollEquals(e){return this.renderedLayout.startLineNumber===e.startLineNumber&&this.renderedLayout.endLineNumber===e.endLineNumber}_get(){const e=this._renderedLines._get();return{imageData:this._imageData,rendLineNumberStart:e.rendLineNumberStart,lines:e.lines}}onLinesChanged(e,t){return this._renderedLines.onLinesChanged(e,t)}onLinesDeleted(e,t){this._renderedLines.onLinesDeleted(e,t)}onLinesInserted(e,t){this._renderedLines.onLinesInserted(e,t)}onTokensChanged(e){return this._renderedLines.onTokensChanged(e)}}class NP{constructor(e,t,i,n){this._backgroundFillData=NP._createBackgroundFillData(t,i,n),this._buffers=[e.createImageData(t,i),e.createImageData(t,i)],this._lastUsedBuffer=0}getBuffer(){this._lastUsedBuffer=1-this._lastUsedBuffer;const e=this._buffers[this._lastUsedBuffer];return e.data.set(this._backgroundFillData),e}static _createBackgroundFillData(e,t,i){const n=i.r,o=i.g,r=i.b,a=i.a,l=new Uint8ClampedArray(e*t*4);let d=0;for(let c=0;c<t;c++)for(let u=0;u<e;u++)l[d]=n,l[d+1]=o,l[d+2]=r,l[d+3]=a,d+=4;return l}}class Z0{static compute(e,t,i){if(e.renderMinimap===0||!e.isSampling)return[null,[]];const{minimapLineCount:n}=Np.computeContainedMinimapLineCount({viewLineCount:t,scrollBeyondLastLine:e.scrollBeyondLastLine,paddingTop:e.paddingTop,paddingBottom:e.paddingBottom,height:e.editorHeight,lineHeight:e.lineHeight,pixelRatio:e.pixelRatio}),o=t/n,r=o/2;if(!i||i.minimapLines.length===0){const _=[];if(_[0]=1,n>1){for(let v=0,b=n-1;v<b;v++)_[v]=Math.round(v*o+r);_[n-1]=t}return[new Z0(o,_),[]]}const a=i.minimapLines,l=a.length,d=[];let c=0,u=0,h=1;const g=10;let f=[],m=null;for(let _=0;_<n;_++){const v=Math.max(h,Math.round(_*o)),b=Math.max(v,Math.round((_+1)*o));for(;c<l&&a[c]<v;){if(f.length<g){const w=c+1+u;m&&m.type==="deleted"&&m._oldIndex===c-1?m.deleteToLineNumber++:(m={type:"deleted",_oldIndex:c,deleteFromLineNumber:w,deleteToLineNumber:w},f.push(m)),u--}c++}let C;if(c<l&&a[c]<=b)C=a[c],c++;else if(_===0?C=1:_+1===n?C=t:C=Math.round(_*o+r),f.length<g){const w=c+1+u;m&&m.type==="inserted"&&m._i===_-1?m.insertToLineNumber++:(m={type:"inserted",_i:_,insertFromLineNumber:w,insertToLineNumber:w},f.push(m)),u++}d[_]=C,h=C}if(f.length<g)for(;c<l;){const _=c+1+u;m&&m.type==="deleted"&&m._oldIndex===c-1?m.deleteToLineNumber++:(m={type:"deleted",_oldIndex:c,deleteFromLineNumber:_,deleteToLineNumber:_},f.push(m)),u--,c++}else f=[{type:"flush"}];return[new Z0(o,d),f]}constructor(e,t){this.samplingRatio=e,this.minimapLines=t}modelLineToMinimapLine(e){return Math.min(this.minimapLines.length,Math.max(1,Math.round(e/this.samplingRatio)))}modelLineRangeToMinimapLineRange(e,t){let i=this.modelLineToMinimapLine(e)-1;for(;i>0&&this.minimapLines[i-1]>=e;)i--;let n=this.modelLineToMinimapLine(t)-1;for(;n+1<this.minimapLines.length&&this.minimapLines[n+1]<=t;)n++;if(i===n){const o=this.minimapLines[i];if(o<e||o>t)return null}return[i+1,n+1]}decorationLineRangeToMinimapLineRange(e,t){let i=this.modelLineToMinimapLine(e),n=this.modelLineToMinimapLine(t);return e!==t&&n===i&&(n===this.minimapLines.length?i>1&&i--:n++),[i,n]}onLinesDeleted(e){const t=e.toLineNumber-e.fromLineNumber+1;let i=this.minimapLines.length,n=0;for(let o=this.minimapLines.length-1;o>=0&&!(this.minimapLines[o]<e.fromLineNumber);o--)this.minimapLines[o]<=e.toLineNumber?(this.minimapLines[o]=Math.max(1,e.fromLineNumber-1),i=Math.min(i,o),n=Math.max(n,o)):this.minimapLines[o]-=t;return[i,n]}onLinesInserted(e){const t=e.toLineNumber-e.fromLineNumber+1;for(let i=this.minimapLines.length-1;i>=0&&!(this.minimapLines[i]<e.fromLineNumber);i--)this.minimapLines[i]+=t}}class Wae extends Eo{constructor(e){super(e),this.tokensColorTracker=mC.getInstance(),this._selections=[],this._minimapSelections=null,this.options=new G0(this._context.configuration,this._context.theme,this.tokensColorTracker);const[t]=Z0.compute(this.options,this._context.viewModel.getLineCount(),null);this._samplingState=t,this._shouldCheckSampling=!1,this._actual=new iy(e.theme,this)}dispose(){this._actual.dispose(),super.dispose()}getDomNode(){return this._actual.getDomNode()}_onOptionsMaybeChanged(){const e=new G0(this._context.configuration,this._context.theme,this.tokensColorTracker);return this.options.equals(e)?!1:(this.options=e,this._recreateLineSampling(),this._actual.onDidChangeOptions(),!0)}onConfigurationChanged(e){return this._onOptionsMaybeChanged()}onCursorStateChanged(e){return this._selections=e.selections,this._minimapSelections=null,this._actual.onSelectionChanged()}onDecorationsChanged(e){return e.affectsMinimap?this._actual.onDecorationsChanged():!1}onFlushed(e){return this._samplingState&&(this._shouldCheckSampling=!0),this._actual.onFlushed()}onLinesChanged(e){if(this._samplingState){const t=this._samplingState.modelLineRangeToMinimapLineRange(e.fromLineNumber,e.fromLineNumber+e.count-1);return t?this._actual.onLinesChanged(t[0],t[1]-t[0]+1):!1}else return this._actual.onLinesChanged(e.fromLineNumber,e.count)}onLinesDeleted(e){if(this._samplingState){const[t,i]=this._samplingState.onLinesDeleted(e);return t<=i&&this._actual.onLinesChanged(t+1,i-t+1),this._shouldCheckSampling=!0,!0}else return this._actual.onLinesDeleted(e.fromLineNumber,e.toLineNumber)}onLinesInserted(e){return this._samplingState?(this._samplingState.onLinesInserted(e),this._shouldCheckSampling=!0,!0):this._actual.onLinesInserted(e.fromLineNumber,e.toLineNumber)}onScrollChanged(e){return this._actual.onScrollChanged()}onThemeChanged(e){return this._actual.onThemeChanged(),this._onOptionsMaybeChanged(),!0}onTokensChanged(e){if(this._samplingState){const t=[];for(const i of e.ranges){const n=this._samplingState.modelLineRangeToMinimapLineRange(i.fromLineNumber,i.toLineNumber);n&&t.push({fromLineNumber:n[0],toLineNumber:n[1]})}return t.length?this._actual.onTokensChanged(t):!1}else return this._actual.onTokensChanged(e.ranges)}onTokensColorsChanged(e){return this._onOptionsMaybeChanged(),this._actual.onTokensColorsChanged()}onZonesChanged(e){return this._actual.onZonesChanged()}prepareRender(e){this._shouldCheckSampling&&(this._shouldCheckSampling=!1,this._recreateLineSampling())}render(e){let t=e.visibleRange.startLineNumber,i=e.visibleRange.endLineNumber;this._samplingState&&(t=this._samplingState.modelLineToMinimapLine(t),i=this._samplingState.modelLineToMinimapLine(i));const n={viewportContainsWhitespaceGaps:e.viewportData.whitespaceViewportData.length>0,scrollWidth:e.scrollWidth,scrollHeight:e.scrollHeight,viewportStartLineNumber:t,viewportEndLineNumber:i,viewportStartLineNumberVerticalOffset:e.getVerticalOffsetForLineNumber(t),scrollTop:e.scrollTop,scrollLeft:e.scrollLeft,viewportWidth:e.viewportWidth,viewportHeight:e.viewportHeight};this._actual.render(n)}_recreateLineSampling(){this._minimapSelections=null;const e=!!this._samplingState,[t,i]=Z0.compute(this.options,this._context.viewModel.getLineCount(),this._samplingState);if(this._samplingState=t,e&&this._samplingState)for(const n of i)switch(n.type){case"deleted":this._actual.onLinesDeleted(n.deleteFromLineNumber,n.deleteToLineNumber);break;case"inserted":this._actual.onLinesInserted(n.insertFromLineNumber,n.insertToLineNumber);break;case"flush":this._actual.onFlushed();break}}getLineCount(){return this._samplingState?this._samplingState.minimapLines.length:this._context.viewModel.getLineCount()}getRealLineCount(){return this._context.viewModel.getLineCount()}getLineContent(e){return this._samplingState?this._context.viewModel.getLineContent(this._samplingState.minimapLines[e-1]):this._context.viewModel.getLineContent(e)}getLineMaxColumn(e){return this._samplingState?this._context.viewModel.getLineMaxColumn(this._samplingState.minimapLines[e-1]):this._context.viewModel.getLineMaxColumn(e)}getMinimapLinesRenderingData(e,t,i){if(this._samplingState){const n=[];for(let o=0,r=t-e+1;o<r;o++)i[o]?n[o]=this._context.viewModel.getViewLineData(this._samplingState.minimapLines[e+o-1]):n[o]=null;return n}return this._context.viewModel.getMinimapLinesRenderingData(e,t,i).data}getSelections(){if(this._minimapSelections===null)if(this._samplingState){this._minimapSelections=[];for(const e of this._selections){const[t,i]=this._samplingState.decorationLineRangeToMinimapLineRange(e.startLineNumber,e.endLineNumber);this._minimapSelections.push(new De(t,e.startColumn,i,e.endColumn))}}else this._minimapSelections=this._selections;return this._minimapSelections}getMinimapDecorationsInViewport(e,t){let i;if(this._samplingState){const o=this._samplingState.minimapLines[e-1],r=this._samplingState.minimapLines[t-1];i=new D(o,1,r,this._context.viewModel.getLineMaxColumn(r))}else i=new D(e,1,t,this._context.viewModel.getLineMaxColumn(t));const n=this._context.viewModel.getMinimapDecorationsInRange(i);if(this._samplingState){const o=[];for(const r of n){if(!r.options.minimap)continue;const a=r.range,l=this._samplingState.modelLineToMinimapLine(a.startLineNumber),d=this._samplingState.modelLineToMinimapLine(a.endLineNumber);o.push(new eH(new D(l,a.startColumn,d,a.endColumn),r.options))}return o}return n}getOptions(){return this._context.viewModel.model.getOptions()}revealLineNumber(e){this._samplingState&&(e=this._samplingState.minimapLines[e-1]),this._context.viewModel.revealRange("mouse",!1,new D(e,1,e,1),1,0)}setScrollTop(e){this._context.viewModel.viewLayout.setScrollPosition({scrollTop:e},1)}}class iy extends j{constructor(e,t){super(),this._renderDecorations=!1,this._gestureInProgress=!1,this._theme=e,this._model=t,this._lastRenderData=null,this._buffers=null,this._selectionColor=this._theme.getColor(k3),this._domNode=Mt(document.createElement("div")),Zl.write(this._domNode,8),this._domNode.setClassName(this._getMinimapDomNodeClassName()),this._domNode.setPosition("absolute"),this._domNode.setAttribute("role","presentation"),this._domNode.setAttribute("aria-hidden","true"),this._shadow=Mt(document.createElement("div")),this._shadow.setClassName("minimap-shadow-hidden"),this._domNode.appendChild(this._shadow),this._canvas=Mt(document.createElement("canvas")),this._canvas.setPosition("absolute"),this._canvas.setLeft(0),this._domNode.appendChild(this._canvas),this._decorationsCanvas=Mt(document.createElement("canvas")),this._decorationsCanvas.setPosition("absolute"),this._decorationsCanvas.setClassName("minimap-decorations-layer"),this._decorationsCanvas.setLeft(0),this._domNode.appendChild(this._decorationsCanvas),this._slider=Mt(document.createElement("div")),this._slider.setPosition("absolute"),this._slider.setClassName("minimap-slider"),this._slider.setLayerHinting(!0),this._slider.setContain("strict"),this._domNode.appendChild(this._slider),this._sliderHorizontal=Mt(document.createElement("div")),this._sliderHorizontal.setPosition("absolute"),this._sliderHorizontal.setClassName("minimap-slider-horizontal"),this._slider.appendChild(this._sliderHorizontal),this._applyLayout(),this._pointerDownListener=Pi(this._domNode.domNode,he.POINTER_DOWN,i=>{if(i.preventDefault(),this._model.options.renderMinimap===0||!this._lastRenderData)return;if(this._model.options.size!=="proportional"){if(i.button===0&&this._lastRenderData){const d=ln(this._slider.domNode),c=d.top+d.height/2;this._startSliderDragging(i,c,this._lastRenderData.renderedLayout)}return}const o=this._model.options.minimapLineHeight,r=this._model.options.canvasInnerHeight/this._model.options.canvasOuterHeight*i.offsetY;let l=Math.floor(r/o)+this._lastRenderData.renderedLayout.startLineNumber-this._lastRenderData.renderedLayout.topPaddingLineCount;l=Math.min(l,this._model.getLineCount()),this._model.revealLineNumber(l)}),this._sliderPointerMoveMonitor=new r_,this._sliderPointerDownListener=Pi(this._slider.domNode,he.POINTER_DOWN,i=>{i.preventDefault(),i.stopPropagation(),i.button===0&&this._lastRenderData&&this._startSliderDragging(i,i.pageY,this._lastRenderData.renderedLayout)}),this._gestureDisposable=Xt.addTarget(this._domNode.domNode),this._sliderTouchStartListener=Y(this._domNode.domNode,Qt.Start,i=>{i.preventDefault(),i.stopPropagation(),this._lastRenderData&&(this._slider.toggleClassName("active",!0),this._gestureInProgress=!0,this.scrollDueToTouchEvent(i))},{passive:!1}),this._sliderTouchMoveListener=Y(this._domNode.domNode,Qt.Change,i=>{i.preventDefault(),i.stopPropagation(),this._lastRenderData&&this._gestureInProgress&&this.scrollDueToTouchEvent(i)},{passive:!1}),this._sliderTouchEndListener=Pi(this._domNode.domNode,Qt.End,i=>{i.preventDefault(),i.stopPropagation(),this._gestureInProgress=!1,this._slider.toggleClassName("active",!1)})}_startSliderDragging(e,t,i){if(!e.target||!(e.target instanceof Element))return;const n=e.pageX;this._slider.toggleClassName("active",!0);const o=(r,a)=>{const l=ln(this._domNode.domNode),d=Math.min(Math.abs(a-n),Math.abs(a-l.left),Math.abs(a-l.left-l.width));if(es&&d>Fae){this._model.setScrollTop(i.scrollTop);return}const c=r-t;this._model.setScrollTop(i.getDesiredScrollTopFromDelta(c))};e.pageY!==t&&o(e.pageY,n),this._sliderPointerMoveMonitor.startMonitoring(e.target,e.pointerId,e.buttons,r=>o(r.pageY,r.pageX),()=>{this._slider.toggleClassName("active",!1)})}scrollDueToTouchEvent(e){const t=this._domNode.domNode.getBoundingClientRect().top,i=this._lastRenderData.renderedLayout.getDesiredScrollTopFromTouchLocation(e.pageY-t);this._model.setScrollTop(i)}dispose(){this._pointerDownListener.dispose(),this._sliderPointerMoveMonitor.dispose(),this._sliderPointerDownListener.dispose(),this._gestureDisposable.dispose(),this._sliderTouchStartListener.dispose(),this._sliderTouchMoveListener.dispose(),this._sliderTouchEndListener.dispose(),super.dispose()}_getMinimapDomNodeClassName(){const e=["minimap"];return this._model.options.showSlider==="always"?e.push("slider-always"):e.push("slider-mouseover"),this._model.options.autohide&&e.push("autohide"),e.join(" ")}getDomNode(){return this._domNode}_applyLayout(){this._domNode.setLeft(this._model.options.minimapLeft),this._domNode.setWidth(this._model.options.minimapWidth),this._domNode.setHeight(this._model.options.minimapHeight),this._shadow.setHeight(this._model.options.minimapHeight),this._canvas.setWidth(this._model.options.canvasOuterWidth),this._canvas.setHeight(this._model.options.canvasOuterHeight),this._canvas.domNode.width=this._model.options.canvasInnerWidth,this._canvas.domNode.height=this._model.options.canvasInnerHeight,this._decorationsCanvas.setWidth(this._model.options.canvasOuterWidth),this._decorationsCanvas.setHeight(this._model.options.canvasOuterHeight),this._decorationsCanvas.domNode.width=this._model.options.canvasInnerWidth,this._decorationsCanvas.domNode.height=this._model.options.canvasInnerHeight,this._slider.setWidth(this._model.options.minimapWidth)}_getBuffer(){return this._buffers||this._model.options.canvasInnerWidth>0&&this._model.options.canvasInnerHeight>0&&(this._buffers=new NP(this._canvas.domNode.getContext("2d"),this._model.options.canvasInnerWidth,this._model.options.canvasInnerHeight,this._model.options.backgroundColor)),this._buffers?this._buffers.getBuffer():null}onDidChangeOptions(){this._lastRenderData=null,this._buffers=null,this._applyLayout(),this._domNode.setClassName(this._getMinimapDomNodeClassName())}onSelectionChanged(){return this._renderDecorations=!0,!0}onDecorationsChanged(){return this._renderDecorations=!0,!0}onFlushed(){return this._lastRenderData=null,!0}onLinesChanged(e,t){return this._lastRenderData?this._lastRenderData.onLinesChanged(e,t):!1}onLinesDeleted(e,t){var i;return(i=this._lastRenderData)===null||i===void 0||i.onLinesDeleted(e,t),!0}onLinesInserted(e,t){var i;return(i=this._lastRenderData)===null||i===void 0||i.onLinesInserted(e,t),!0}onScrollChanged(){return this._renderDecorations=!0,!0}onThemeChanged(){return this._selectionColor=this._theme.getColor(k3),this._renderDecorations=!0,!0}onTokensChanged(e){return this._lastRenderData?this._lastRenderData.onTokensChanged(e):!1}onTokensColorsChanged(){return this._lastRenderData=null,this._buffers=null,!0}onZonesChanged(){return this._lastRenderData=null,!0}render(e){if(this._model.options.renderMinimap===0){this._shadow.setClassName("minimap-shadow-hidden"),this._sliderHorizontal.setWidth(0),this._sliderHorizontal.setHeight(0);return}e.scrollLeft+e.viewportWidth>=e.scrollWidth?this._shadow.setClassName("minimap-shadow-hidden"):this._shadow.setClassName("minimap-shadow-visible");const i=Hv.create(this._model.options,e.viewportStartLineNumber,e.viewportEndLineNumber,e.viewportStartLineNumberVerticalOffset,e.viewportHeight,e.viewportContainsWhitespaceGaps,this._model.getLineCount(),this._model.getRealLineCount(),e.scrollTop,e.scrollHeight,this._lastRenderData?this._lastRenderData.renderedLayout:null);this._slider.setDisplay(i.sliderNeeded?"block":"none"),this._slider.setTop(i.sliderTop),this._slider.setHeight(i.sliderHeight),this._sliderHorizontal.setLeft(0),this._sliderHorizontal.setWidth(this._model.options.minimapWidth),this._sliderHorizontal.setTop(0),this._sliderHorizontal.setHeight(i.sliderHeight),this.renderDecorations(i),this._lastRenderData=this.renderLines(i)}renderDecorations(e){if(this._renderDecorations){this._renderDecorations=!1;const t=this._model.getSelections();t.sort(D.compareRangesUsingStarts);const i=this._model.getMinimapDecorationsInViewport(e.startLineNumber,e.endLineNumber);i.sort((h,g)=>(h.options.zIndex||0)-(g.options.zIndex||0));const{canvasInnerWidth:n,canvasInnerHeight:o}=this._model.options,r=this._model.options.minimapLineHeight,a=this._model.options.minimapCharWidth,l=this._model.getOptions().tabSize,d=this._decorationsCanvas.domNode.getContext("2d");d.clearRect(0,0,n,o);const c=new q3(e.startLineNumber,e.endLineNumber,!1);this._renderSelectionLineHighlights(d,t,c,e,r),this._renderDecorationsLineHighlights(d,i,c,e,r);const u=new q3(e.startLineNumber,e.endLineNumber,null);this._renderSelectionsHighlights(d,t,u,e,r,l,a,n),this._renderDecorationsHighlights(d,i,u,e,r,l,a,n)}}_renderSelectionLineHighlights(e,t,i,n,o){if(!this._selectionColor||this._selectionColor.isTransparent())return;e.fillStyle=this._selectionColor.transparent(.5).toString();let r=0,a=0;for(const l of t){const d=n.intersectWithViewport(l);if(!d)continue;const[c,u]=d;for(let f=c;f<=u;f++)i.set(f,!0);const h=n.getYForLineNumber(c,o),g=n.getYForLineNumber(u,o);a>=h||(a>r&&e.fillRect(Cc,r,e.canvas.width,a-r),r=h),a=g}a>r&&e.fillRect(Cc,r,e.canvas.width,a-r)}_renderDecorationsLineHighlights(e,t,i,n,o){const r=new Map;for(let a=t.length-1;a>=0;a--){const l=t[a],d=l.options.minimap;if(!d||d.position!==bo.Inline)continue;const c=n.intersectWithViewport(l.range);if(!c)continue;const[u,h]=c,g=d.getColor(this._theme.value);if(!g||g.isTransparent())continue;let f=r.get(g.toString());f||(f=g.transparent(.5).toString(),r.set(g.toString(),f)),e.fillStyle=f;for(let m=u;m<=h;m++){if(i.has(m))continue;i.set(m,!0);const _=n.getYForLineNumber(u,o);e.fillRect(Cc,_,e.canvas.width,o)}}}_renderSelectionsHighlights(e,t,i,n,o,r,a,l){if(!(!this._selectionColor||this._selectionColor.isTransparent()))for(const d of t){const c=n.intersectWithViewport(d);if(!c)continue;const[u,h]=c;for(let g=u;g<=h;g++)this.renderDecorationOnLine(e,i,d,this._selectionColor,n,g,o,o,r,a,l)}}_renderDecorationsHighlights(e,t,i,n,o,r,a,l){for(const d of t){const c=d.options.minimap;if(!c)continue;const u=n.intersectWithViewport(d.range);if(!u)continue;const[h,g]=u,f=c.getColor(this._theme.value);if(!(!f||f.isTransparent()))for(let m=h;m<=g;m++)switch(c.position){case bo.Inline:this.renderDecorationOnLine(e,i,d.range,f,n,m,o,o,r,a,l);continue;case bo.Gutter:{const _=n.getYForLineNumber(m,o);this.renderDecoration(e,f,2,_,Bae,o);continue}}}}renderDecorationOnLine(e,t,i,n,o,r,a,l,d,c,u){const h=o.getYForLineNumber(r,l);if(h+a<0||h>this._model.options.canvasInnerHeight)return;const{startLineNumber:g,endLineNumber:f}=i,m=g===r?i.startColumn:1,_=f===r?i.endColumn:this._model.getLineMaxColumn(r),v=this.getXOffsetForPosition(t,r,m,d,c,u),b=this.getXOffsetForPosition(t,r,_,d,c,u);this.renderDecoration(e,n,v,h,b-v,a)}getXOffsetForPosition(e,t,i,n,o,r){if(i===1)return Cc;if((i-1)*o>=r)return r;let l=e.get(t);if(!l){const d=this._model.getLineContent(t);l=[Cc];let c=Cc;for(let u=1;u<d.length+1;u++){const h=d.charCodeAt(u-1),g=h===9?n*o:ku(h)?2*o:o,f=c+g;if(f>=r){l[u]=r;break}l[u]=f,c=f}e.set(t,l)}return i-1<l.length?l[i-1]:r}renderDecoration(e,t,i,n,o,r){e.fillStyle=t&&t.toString()||"",e.fillRect(i,n,o,r)}renderLines(e){const t=e.startLineNumber,i=e.endLineNumber,n=this._model.options.minimapLineHeight;if(this._lastRenderData&&this._lastRenderData.linesEquals(e)){const Q=this._lastRenderData._get();return new K3(e,Q.imageData,Q.lines)}const o=this._getBuffer();if(!o)return null;const[r,a,l]=iy._renderUntouchedLines(o,e.topPaddingLineCount,t,i,n,this._lastRenderData),d=this._model.getMinimapLinesRenderingData(t,i,l),c=this._model.getOptions().tabSize,u=this._model.options.defaultBackgroundColor,h=this._model.options.backgroundColor,g=this._model.options.foregroundAlpha,f=this._model.tokensColorTracker,m=f.backgroundIsLight(),_=this._model.options.renderMinimap,v=this._model.options.charRenderer(),b=this._model.options.fontScale,C=this._model.options.minimapCharWidth,S=(_===1?2:3)*b,x=n>S?Math.floor((n-S)/2):0,L=h.a/255,k=new vr(Math.round((h.r-u.r)*L+u.r),Math.round((h.g-u.g)*L+u.g),Math.round((h.b-u.b)*L+u.b),255);let I=e.topPaddingLineCount*n;const P=[];for(let Q=0,ne=i-t+1;Q<ne;Q++)l[Q]&&iy._renderLine(o,k,h.a,m,_,C,f,g,v,I,x,c,d[Q],b,n),P[Q]=new ty(I),I+=n;const $=r===-1?0:r,z=(a===-1?o.height:a)-$;return this._canvas.domNode.getContext("2d").putImageData(o,0,0,0,$,o.width,z),new K3(e,o,P)}static _renderUntouchedLines(e,t,i,n,o,r){const a=[];if(!r){for(let I=0,P=n-i+1;I<P;I++)a[I]=!0;return[-1,-1,a]}const l=r._get(),d=l.imageData.data,c=l.rendLineNumberStart,u=l.lines,h=u.length,g=e.width,f=e.data,m=(n-i+1)*o*g*4;let _=-1,v=-1,b=-1,C=-1,w=-1,S=-1,x=t*o;for(let I=i;I<=n;I++){const P=I-i,$=I-c,A=$>=0&&$<h?u[$].dy:-1;if(A===-1){a[P]=!0,x+=o;continue}const z=A*g*4,K=(A+o)*g*4,Q=x*g*4,ne=(x+o)*g*4;C===z&&S===Q?(C=K,S=ne):(b!==-1&&(f.set(d.subarray(b,C),w),_===-1&&b===0&&b===w&&(_=C),v===-1&&C===m&&b===w&&(v=b)),b=z,C=K,w=Q,S=ne),a[P]=!1,x+=o}b!==-1&&(f.set(d.subarray(b,C),w),_===-1&&b===0&&b===w&&(_=C),v===-1&&C===m&&b===w&&(v=b));const L=_===-1?-1:_/(g*4),k=v===-1?-1:v/(g*4);return[L,k,a]}static _renderLine(e,t,i,n,o,r,a,l,d,c,u,h,g,f,m){const _=g.content,v=g.tokens,b=e.width-r,C=m===1;let w=Cc,S=0,x=0;for(let L=0,k=v.getCount();L<k;L++){const I=v.getEndOffset(L),P=v.getForeground(L),$=a.getColor(P);for(;S<I;S++){if(w>b)return;const A=_.charCodeAt(S);if(A===9){const z=h-(S+x)%h;x+=z-1,w+=z*r}else if(A===32)w+=r;else{const z=ku(A)?2:1;for(let K=0;K<z;K++)if(o===2?d.blockRenderChar(e,w,c+u,$,l,t,i,C):d.renderChar(e,w,c+u,A,$,l,t,i,f,n,C),w+=r,w>b)return}}}}}class q3{constructor(e,t,i){this._startLineNumber=e,this._endLineNumber=t,this._defaultValue=i,this._values=[];for(let n=0,o=this._endLineNumber-this._startLineNumber+1;n<o;n++)this._values[n]=i}has(e){return this.get(e)!==this._defaultValue}set(e,t){e<this._startLineNumber||e>this._endLineNumber||(this._values[e-this._startLineNumber]=t)}get(e){return e<this._startLineNumber||e>this._endLineNumber?this._defaultValue:this._values[e-this._startLineNumber]}}class Vae extends Eo{constructor(e){super(e);const i=this._context.configuration.options.get(143);this._widgets={},this._verticalScrollbarWidth=i.verticalScrollbarWidth,this._minimapWidth=i.minimap.minimapWidth,this._horizontalScrollbarHeight=i.horizontalScrollbarHeight,this._editorHeight=i.height,this._editorWidth=i.width,this._domNode=Mt(document.createElement("div")),Zl.write(this._domNode,4),this._domNode.setClassName("overlayWidgets")}dispose(){super.dispose(),this._widgets={}}getDomNode(){return this._domNode}onConfigurationChanged(e){const i=this._context.configuration.options.get(143);return this._verticalScrollbarWidth=i.verticalScrollbarWidth,this._minimapWidth=i.minimap.minimapWidth,this._horizontalScrollbarHeight=i.horizontalScrollbarHeight,this._editorHeight=i.height,this._editorWidth=i.width,!0}addWidget(e){const t=Mt(e.getDomNode());this._widgets[e.getId()]={widget:e,preference:null,domNode:t},t.setPosition("absolute"),t.setAttribute("widgetId",e.getId()),this._domNode.appendChild(t),this.setShouldRender(),this._updateMaxMinWidth()}setWidgetPosition(e,t){const i=this._widgets[e.getId()];return i.preference===t?(this._updateMaxMinWidth(),!1):(i.preference=t,this.setShouldRender(),this._updateMaxMinWidth(),!0)}removeWidget(e){const t=e.getId();if(this._widgets.hasOwnProperty(t)){const n=this._widgets[t].domNode.domNode;delete this._widgets[t],n.parentNode.removeChild(n),this.setShouldRender(),this._updateMaxMinWidth()}}_updateMaxMinWidth(){var e,t;let i=0;const n=Object.keys(this._widgets);for(let o=0,r=n.length;o<r;o++){const a=n[o],d=(t=(e=this._widgets[a].widget).getMinContentWidthInPx)===null||t===void 0?void 0:t.call(e);typeof d<"u"&&(i=Math.max(i,d))}this._context.viewLayout.setOverlayWidgetsMinWidth(i)}_renderWidget(e){const t=e.domNode;if(e.preference===null){t.setTop("");return}if(e.preference===0)t.setTop(0),t.setRight(2*this._verticalScrollbarWidth+this._minimapWidth);else if(e.preference===1){const i=t.domNode.clientHeight;t.setTop(this._editorHeight-i-2*this._horizontalScrollbarHeight),t.setRight(2*this._verticalScrollbarWidth+this._minimapWidth)}else e.preference===2&&(t.setTop(0),t.domNode.style.right="50%")}prepareRender(e){}render(e){this._domNode.setWidth(this._editorWidth);const t=Object.keys(this._widgets);for(let i=0,n=t.length;i<n;i++){const o=t[i];this._renderWidget(this._widgets[o])}}}class Hae{constructor(e,t){const i=e.options;this.lineHeight=i.get(66),this.pixelRatio=i.get(141),this.overviewRulerLanes=i.get(82),this.renderBorder=i.get(81);const n=t.getColor(kre);this.borderColor=n?n.toString():null,this.hideCursor=i.get(59);const o=t.getColor(LH);this.cursorColor=o?o.transparent(.7).toString():null,this.themeType=t.type;const r=i.get(72),a=r.enabled,l=r.side,d=t.getColor(Ire),c=xi.getDefaultBackground();d?this.backgroundColor=d:a&&l==="right"?this.backgroundColor=c:this.backgroundColor=null;const h=i.get(143).overviewRuler;this.top=h.top,this.right=h.right,this.domWidth=h.width,this.domHeight=h.height,this.overviewRulerLanes===0?(this.canvasWidth=0,this.canvasHeight=0):(this.canvasWidth=this.domWidth*this.pixelRatio|0,this.canvasHeight=this.domHeight*this.pixelRatio|0);const[g,f]=this._initLanes(1,this.canvasWidth,this.overviewRulerLanes);this.x=g,this.w=f}_initLanes(e,t,i){const n=t-e;if(i>=3){const o=Math.floor(n/3),r=Math.floor(n/3),a=n-o-r,l=e,d=l+o,c=l+o+a;return[[0,l,d,l,c,l,d,l],[0,o,a,o+a,r,o+a+r,a+r,o+a+r]]}else if(i===2){const o=Math.floor(n/2),r=n-o,a=e,l=a+o;return[[0,a,a,a,l,a,a,a],[0,o,o,o,r,o+r,o+r,o+r]]}else{const o=e,r=n;return[[0,o,o,o,o,o,o,o],[0,r,r,r,r,r,r,r]]}}equals(e){return this.lineHeight===e.lineHeight&&this.pixelRatio===e.pixelRatio&&this.overviewRulerLanes===e.overviewRulerLanes&&this.renderBorder===e.renderBorder&&this.borderColor===e.borderColor&&this.hideCursor===e.hideCursor&&this.cursorColor===e.cursorColor&&this.themeType===e.themeType&&G.equals(this.backgroundColor,e.backgroundColor)&&this.top===e.top&&this.right===e.right&&this.domWidth===e.domWidth&&this.domHeight===e.domHeight&&this.canvasWidth===e.canvasWidth&&this.canvasHeight===e.canvasHeight}}class zae extends Eo{constructor(e){super(e),this._actualShouldRender=0,this._renderedDecorations=[],this._renderedCursorPositions=[],this._domNode=Mt(document.createElement("canvas")),this._domNode.setClassName("decorationsOverviewRuler"),this._domNode.setPosition("absolute"),this._domNode.setLayerHinting(!0),this._domNode.setContain("strict"),this._domNode.setAttribute("aria-hidden","true"),this._updateSettings(!1),this._tokensColorTrackerListener=xi.onDidChange(t=>{t.changedColorMap&&this._updateSettings(!0)}),this._cursorPositions=[]}dispose(){super.dispose(),this._tokensColorTrackerListener.dispose()}_updateSettings(e){const t=new Hae(this._context.configuration,this._context.theme);return this._settings&&this._settings.equals(t)?!1:(this._settings=t,this._domNode.setTop(this._settings.top),this._domNode.setRight(this._settings.right),this._domNode.setWidth(this._settings.domWidth),this._domNode.setHeight(this._settings.domHeight),this._domNode.domNode.width=this._settings.canvasWidth,this._domNode.domNode.height=this._settings.canvasHeight,e&&this._render(),!0)}_markRenderingIsNeeded(){return this._actualShouldRender=2,!0}_markRenderingIsMaybeNeeded(){return this._actualShouldRender=1,!0}onConfigurationChanged(e){return this._updateSettings(!1)?this._markRenderingIsNeeded():!1}onCursorStateChanged(e){this._cursorPositions=[];for(let t=0,i=e.selections.length;t<i;t++)this._cursorPositions[t]=e.selections[t].getPosition();return this._cursorPositions.sort(H.compare),this._markRenderingIsMaybeNeeded()}onDecorationsChanged(e){return e.affectsOverviewRuler?this._markRenderingIsMaybeNeeded():!1}onFlushed(e){return this._markRenderingIsNeeded()}onScrollChanged(e){return e.scrollHeightChanged?this._markRenderingIsNeeded():!1}onZonesChanged(e){return this._markRenderingIsNeeded()}onThemeChanged(e){return this._updateSettings(!1)?this._markRenderingIsNeeded():!1}getDomNode(){return this._domNode.domNode}prepareRender(e){}render(e){this._render(),this._actualShouldRender=0}_render(){const e=this._settings.backgroundColor;if(this._settings.overviewRulerLanes===0){this._domNode.setBackgroundColor(e?G.Format.CSS.formatHexA(e):""),this._domNode.setDisplay("none");return}const t=this._context.viewModel.getAllOverviewRulerDecorations(this._context.theme);if(t.sort(F0.compareByRenderingProps),this._actualShouldRender===1&&!F0.equalsArr(this._renderedDecorations,t)&&(this._actualShouldRender=2),this._actualShouldRender===1&&!Ai(this._renderedCursorPositions,this._cursorPositions,(f,m)=>f.lineNumber===m.lineNumber)&&(this._actualShouldRender=2),this._actualShouldRender===1)return;this._renderedDecorations=t,this._renderedCursorPositions=this._cursorPositions,this._domNode.setDisplay("block");const i=this._settings.canvasWidth,n=this._settings.canvasHeight,o=this._settings.lineHeight,r=this._context.viewLayout,a=this._context.viewLayout.getScrollHeight(),l=n/a,d=6*this._settings.pixelRatio|0,c=d/2|0,u=this._domNode.domNode.getContext("2d");e?e.isOpaque()?(u.fillStyle=G.Format.CSS.formatHexA(e),u.fillRect(0,0,i,n)):(u.clearRect(0,0,i,n),u.fillStyle=G.Format.CSS.formatHexA(e),u.fillRect(0,0,i,n)):u.clearRect(0,0,i,n);const h=this._settings.x,g=this._settings.w;for(const f of t){const m=f.color,_=f.data;u.fillStyle=m;let v=0,b=0,C=0;for(let w=0,S=_.length/3;w<S;w++){const x=_[3*w],L=_[3*w+1],k=_[3*w+2];let I=r.getVerticalOffsetForLineNumber(L)*l|0,P=(r.getVerticalOffsetForLineNumber(k)+o)*l|0;if(P-I<d){let A=(I+P)/2|0;A<c?A=c:A+c>n&&(A=n-c),I=A-c,P=A+c}I>C+1||x!==v?(w!==0&&u.fillRect(h[v],b,g[v],C-b),v=x,b=I,C=P):P>C&&(C=P)}u.fillRect(h[v],b,g[v],C-b)}if(!this._settings.hideCursor&&this._settings.cursorColor){const f=2*this._settings.pixelRatio|0,m=f/2|0,_=this._settings.x[7],v=this._settings.w[7];u.fillStyle=this._settings.cursorColor;let b=-100,C=-100;for(let w=0,S=this._cursorPositions.length;w<S;w++){const x=this._cursorPositions[w];let L=r.getVerticalOffsetForLineNumber(x.lineNumber)*l|0;L<m?L=m:L+m>n&&(L=n-m);const k=L-m,I=k+f;k>C+1?(w!==0&&u.fillRect(_,b,v,C-b),b=k,C=I):I>C&&(C=I)}u.fillRect(_,b,v,C-b)}this._settings.renderBorder&&this._settings.borderColor&&this._settings.overviewRulerLanes>0&&(u.beginPath(),u.lineWidth=1,u.strokeStyle=this._settings.borderColor,u.moveTo(0,0),u.lineTo(0,n),u.stroke(),u.moveTo(0,0),u.lineTo(i,0),u.stroke())}}class G3{constructor(e,t,i){this._colorZoneBrand=void 0,this.from=e|0,this.to=t|0,this.colorId=i|0}static compare(e,t){return e.colorId===t.colorId?e.from===t.from?e.to-t.to:e.from-t.from:e.colorId-t.colorId}}class zH{constructor(e,t,i,n){this._overviewRulerZoneBrand=void 0,this.startLineNumber=e,this.endLineNumber=t,this.heightInLines=i,this.color=n,this._colorZone=null}static compare(e,t){return e.color===t.color?e.startLineNumber===t.startLineNumber?e.heightInLines===t.heightInLines?e.endLineNumber-t.endLineNumber:e.heightInLines-t.heightInLines:e.startLineNumber-t.startLineNumber:e.color<t.color?-1:1}setColorZone(e){this._colorZone=e}getColorZones(){return this._colorZone}}class Uae{constructor(e){this._getVerticalOffsetForLine=e,this._zones=[],this._colorZonesInvalid=!1,this._lineHeight=0,this._domWidth=0,this._domHeight=0,this._outerHeight=0,this._pixelRatio=1,this._lastAssignedId=0,this._color2Id=Object.create(null),this._id2Color=[]}getId2Color(){return this._id2Color}setZones(e){this._zones=e,this._zones.sort(zH.compare)}setLineHeight(e){return this._lineHeight===e?!1:(this._lineHeight=e,this._colorZonesInvalid=!0,!0)}setPixelRatio(e){this._pixelRatio=e,this._colorZonesInvalid=!0}getDOMWidth(){return this._domWidth}getCanvasWidth(){return this._domWidth*this._pixelRatio}setDOMWidth(e){return this._domWidth===e?!1:(this._domWidth=e,this._colorZonesInvalid=!0,!0)}getDOMHeight(){return this._domHeight}getCanvasHeight(){return this._domHeight*this._pixelRatio}setDOMHeight(e){return this._domHeight===e?!1:(this._domHeight=e,this._colorZonesInvalid=!0,!0)}getOuterHeight(){return this._outerHeight}setOuterHeight(e){return this._outerHeight===e?!1:(this._outerHeight=e,this._colorZonesInvalid=!0,!0)}resolveColorZones(){const e=this._colorZonesInvalid,t=Math.floor(this._lineHeight),i=Math.floor(this.getCanvasHeight()),n=Math.floor(this._outerHeight),o=i/n,r=Math.floor(4*this._pixelRatio/2),a=[];for(let l=0,d=this._zones.length;l<d;l++){const c=this._zones[l];if(!e){const w=c.getColorZones();if(w){a.push(w);continue}}const u=this._getVerticalOffsetForLine(c.startLineNumber),h=c.heightInLines===0?this._getVerticalOffsetForLine(c.endLineNumber)+t:u+c.heightInLines*t,g=Math.floor(o*u),f=Math.floor(o*h);let m=Math.floor((g+f)/2),_=f-m;_<r&&(_=r),m-_<0&&(m=_),m+_>i&&(m=i-_);const v=c.color;let b=this._color2Id[v];b||(b=++this._lastAssignedId,this._color2Id[v]=b,this._id2Color[b]=v);const C=new G3(m-_,m+_,b);c.setColorZone(C),a.push(C)}return this._colorZonesInvalid=!1,a.sort(G3.compare),a}}class $ae extends uC{constructor(e,t){super(),this._context=e;const i=this._context.configuration.options;this._domNode=Mt(document.createElement("canvas")),this._domNode.setClassName(t),this._domNode.setPosition("absolute"),this._domNode.setLayerHinting(!0),this._domNode.setContain("strict"),this._zoneManager=new Uae(n=>this._context.viewLayout.getVerticalOffsetForLineNumber(n)),this._zoneManager.setDOMWidth(0),this._zoneManager.setDOMHeight(0),this._zoneManager.setOuterHeight(this._context.viewLayout.getScrollHeight()),this._zoneManager.setLineHeight(i.get(66)),this._zoneManager.setPixelRatio(i.get(141)),this._context.addEventHandler(this)}dispose(){this._context.removeEventHandler(this),super.dispose()}onConfigurationChanged(e){const t=this._context.configuration.options;return e.hasChanged(66)&&(this._zoneManager.setLineHeight(t.get(66)),this._render()),e.hasChanged(141)&&(this._zoneManager.setPixelRatio(t.get(141)),this._domNode.setWidth(this._zoneManager.getDOMWidth()),this._domNode.setHeight(this._zoneManager.getDOMHeight()),this._domNode.domNode.width=this._zoneManager.getCanvasWidth(),this._domNode.domNode.height=this._zoneManager.getCanvasHeight(),this._render()),!0}onFlushed(e){return this._render(),!0}onScrollChanged(e){return e.scrollHeightChanged&&(this._zoneManager.setOuterHeight(e.scrollHeight),this._render()),!0}onZonesChanged(e){return this._render(),!0}getDomNode(){return this._domNode.domNode}setLayout(e){this._domNode.setTop(e.top),this._domNode.setRight(e.right);let t=!1;t=this._zoneManager.setDOMWidth(e.width)||t,t=this._zoneManager.setDOMHeight(e.height)||t,t&&(this._domNode.setWidth(this._zoneManager.getDOMWidth()),this._domNode.setHeight(this._zoneManager.getDOMHeight()),this._domNode.domNode.width=this._zoneManager.getCanvasWidth(),this._domNode.domNode.height=this._zoneManager.getCanvasHeight(),this._render())}setZones(e){this._zoneManager.setZones(e),this._render()}_render(){if(this._zoneManager.getOuterHeight()===0)return!1;const e=this._zoneManager.getCanvasWidth(),t=this._zoneManager.getCanvasHeight(),i=this._zoneManager.resolveColorZones(),n=this._zoneManager.getId2Color(),o=this._domNode.domNode.getContext("2d");return o.clearRect(0,0,e,t),i.length>0&&this._renderOneLane(o,i,n,e),!0}_renderOneLane(e,t,i,n){let o=0,r=0,a=0;for(const l of t){const d=l.colorId,c=l.from,u=l.to;d!==o?(e.fillRect(0,r,n,a-r),o=d,e.fillStyle=i[o],r=c,a=u):a>=c?a=Math.max(a,u):(e.fillRect(0,r,n,a-r),r=c,a=u)}e.fillRect(0,r,n,a-r)}}class jae extends Eo{constructor(e){super(e),this.domNode=Mt(document.createElement("div")),this.domNode.setAttribute("role","presentation"),this.domNode.setAttribute("aria-hidden","true"),this.domNode.setClassName("view-rulers"),this._renderedRulers=[];const t=this._context.configuration.options;this._rulers=t.get(101),this._typicalHalfwidthCharacterWidth=t.get(50).typicalHalfwidthCharacterWidth}dispose(){super.dispose()}onConfigurationChanged(e){const t=this._context.configuration.options;return this._rulers=t.get(101),this._typicalHalfwidthCharacterWidth=t.get(50).typicalHalfwidthCharacterWidth,!0}onScrollChanged(e){return e.scrollHeightChanged}prepareRender(e){}_ensureRulersCount(){const e=this._renderedRulers.length,t=this._rulers.length;if(e===t)return;if(e<t){const{tabSize:n}=this._context.viewModel.model.getOptions(),o=n;let r=t-e;for(;r>0;){const a=Mt(document.createElement("div"));a.setClassName("view-ruler"),a.setWidth(o),this.domNode.appendChild(a),this._renderedRulers.push(a),r--}return}let i=e-t;for(;i>0;){const n=this._renderedRulers.pop();this.domNode.removeChild(n),i--}}render(e){this._ensureRulersCount();for(let t=0,i=this._rulers.length;t<i;t++){const n=this._renderedRulers[t],o=this._rulers[t];n.setBoxShadow(o.color?`1px 0 0 0 ${o.color} inset`:""),n.setHeight(Math.min(e.scrollHeight,1e6)),n.setLeft(o.column*this._typicalHalfwidthCharacterWidth)}}}class Kae extends Eo{constructor(e){super(e),this._scrollTop=0,this._width=0,this._updateWidth(),this._shouldShow=!1;const i=this._context.configuration.options.get(102);this._useShadows=i.useShadows,this._domNode=Mt(document.createElement("div")),this._domNode.setAttribute("role","presentation"),this._domNode.setAttribute("aria-hidden","true")}dispose(){super.dispose()}_updateShouldShow(){const e=this._useShadows&&this._scrollTop>0;return this._shouldShow!==e?(this._shouldShow=e,!0):!1}getDomNode(){return this._domNode}_updateWidth(){const t=this._context.configuration.options.get(143);t.minimap.renderMinimap===0||t.minimap.minimapWidth>0&&t.minimap.minimapLeft===0?this._width=t.width:this._width=t.width-t.verticalScrollbarWidth}onConfigurationChanged(e){const i=this._context.configuration.options.get(102);return this._useShadows=i.useShadows,this._updateWidth(),this._updateShouldShow(),!0}onScrollChanged(e){return this._scrollTop=e.scrollTop,this._updateShouldShow()}prepareRender(e){}render(e){this._domNode.setWidth(this._width),this._domNode.setClassName(this._shouldShow?"scroll-decoration":"")}}class qae{constructor(e){this.left=e.left,this.width=e.width,this.startStyle=null,this.endStyle=null}}class Gae{constructor(e,t){this.lineNumber=e,this.ranges=t}}function Zae(s){return new qae(s)}function Yae(s){return new Gae(s.lineNumber,s.ranges.map(Zae))}class Fi extends df{constructor(e){super(),this._previousFrameVisibleRangesWithStyle=[],this._context=e;const t=this._context.configuration.options;this._lineHeight=t.get(66),this._roundedSelection=t.get(100),this._typicalHalfwidthCharacterWidth=t.get(50).typicalHalfwidthCharacterWidth,this._selections=[],this._renderResult=null,this._context.addEventHandler(this)}dispose(){this._context.removeEventHandler(this),this._renderResult=null,super.dispose()}onConfigurationChanged(e){const t=this._context.configuration.options;return this._lineHeight=t.get(66),this._roundedSelection=t.get(100),this._typicalHalfwidthCharacterWidth=t.get(50).typicalHalfwidthCharacterWidth,!0}onCursorStateChanged(e){return this._selections=e.selections.slice(0),!0}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return e.scrollTopChanged}onZonesChanged(e){return!0}_visibleRangesHaveGaps(e){for(let t=0,i=e.length;t<i;t++)if(e[t].ranges.length>1)return!0;return!1}_enrichVisibleRangesWithStyle(e,t,i){const n=this._typicalHalfwidthCharacterWidth/4;let o=null,r=null;if(i&&i.length>0&&t.length>0){const a=t[0].lineNumber;if(a===e.startLineNumber)for(let d=0;!o&&d<i.length;d++)i[d].lineNumber===a&&(o=i[d].ranges[0]);const l=t[t.length-1].lineNumber;if(l===e.endLineNumber)for(let d=i.length-1;!r&&d>=0;d--)i[d].lineNumber===l&&(r=i[d].ranges[0]);o&&!o.startStyle&&(o=null),r&&!r.startStyle&&(r=null)}for(let a=0,l=t.length;a<l;a++){const d=t[a].ranges[0],c=d.left,u=d.left+d.width,h={top:0,bottom:0},g={top:0,bottom:0};if(a>0){const f=t[a-1].ranges[0].left,m=t[a-1].ranges[0].left+t[a-1].ranges[0].width;w1(c-f)<n?h.top=2:c>f&&(h.top=1),w1(u-m)<n?g.top=2:f<u&&u<m&&(g.top=1)}else o&&(h.top=o.startStyle.top,g.top=o.endStyle.top);if(a+1<l){const f=t[a+1].ranges[0].left,m=t[a+1].ranges[0].left+t[a+1].ranges[0].width;w1(c-f)<n?h.bottom=2:f<c&&c<m&&(h.bottom=1),w1(u-m)<n?g.bottom=2:u<m&&(g.bottom=1)}else r&&(h.bottom=r.startStyle.bottom,g.bottom=r.endStyle.bottom);d.startStyle=h,d.endStyle=g}}_getVisibleRangesWithStyle(e,t,i){const o=(t.linesVisibleRangesForRange(e,!0)||[]).map(Yae);return!this._visibleRangesHaveGaps(o)&&this._roundedSelection&&this._enrichVisibleRangesWithStyle(t.visibleRange,o,i),o}_createSelectionPiece(e,t,i,n,o){return'<div class="cslr '+i+'" style="top:'+e.toString()+"px;left:"+n.toString()+"px;width:"+o.toString()+"px;height:"+t+'px;"></div>'}_actualRenderOneSelection(e,t,i,n){if(n.length===0)return;const o=!!n[0].ranges[0].startStyle,r=this._lineHeight.toString(),a=(this._lineHeight-1).toString(),l=n[0].lineNumber,d=n[n.length-1].lineNumber;for(let c=0,u=n.length;c<u;c++){const h=n[c],g=h.lineNumber,f=g-t,m=i&&(g===d||g===l)?a:r,_=i&&g===l?1:0;let v="",b="";for(let C=0,w=h.ranges.length;C<w;C++){const S=h.ranges[C];if(o){const L=S.startStyle,k=S.endStyle;if(L.top===1||L.bottom===1){v+=this._createSelectionPiece(_,m,Fi.SELECTION_CLASS_NAME,S.left-Fi.ROUNDED_PIECE_WIDTH,Fi.ROUNDED_PIECE_WIDTH);let I=Fi.EDITOR_BACKGROUND_CLASS_NAME;L.top===1&&(I+=" "+Fi.SELECTION_TOP_RIGHT),L.bottom===1&&(I+=" "+Fi.SELECTION_BOTTOM_RIGHT),v+=this._createSelectionPiece(_,m,I,S.left-Fi.ROUNDED_PIECE_WIDTH,Fi.ROUNDED_PIECE_WIDTH)}if(k.top===1||k.bottom===1){v+=this._createSelectionPiece(_,m,Fi.SELECTION_CLASS_NAME,S.left+S.width,Fi.ROUNDED_PIECE_WIDTH);let I=Fi.EDITOR_BACKGROUND_CLASS_NAME;k.top===1&&(I+=" "+Fi.SELECTION_TOP_LEFT),k.bottom===1&&(I+=" "+Fi.SELECTION_BOTTOM_LEFT),v+=this._createSelectionPiece(_,m,I,S.left+S.width,Fi.ROUNDED_PIECE_WIDTH)}}let x=Fi.SELECTION_CLASS_NAME;if(o){const L=S.startStyle,k=S.endStyle;L.top===0&&(x+=" "+Fi.SELECTION_TOP_LEFT),L.bottom===0&&(x+=" "+Fi.SELECTION_BOTTOM_LEFT),k.top===0&&(x+=" "+Fi.SELECTION_TOP_RIGHT),k.bottom===0&&(x+=" "+Fi.SELECTION_BOTTOM_RIGHT)}b+=this._createSelectionPiece(_,m,x,S.left,S.width)}e[f][0]+=v,e[f][1]+=b}}prepareRender(e){const t=[],i=e.visibleRange.startLineNumber,n=e.visibleRange.endLineNumber;for(let r=i;r<=n;r++){const a=r-i;t[a]=["",""]}const o=[];for(let r=0,a=this._selections.length;r<a;r++){const l=this._selections[r];if(l.isEmpty()){o[r]=null;continue}const d=this._getVisibleRangesWithStyle(l,e,this._previousFrameVisibleRangesWithStyle[r]);o[r]=d,this._actualRenderOneSelection(t,i,this._selections.length>1,d)}this._previousFrameVisibleRangesWithStyle=o,this._renderResult=t.map(([r,a])=>r+a)}render(e,t){if(!this._renderResult)return"";const i=t-e;return i<0||i>=this._renderResult.length?"":this._renderResult[i]}}Fi.SELECTION_CLASS_NAME="selected-text";Fi.SELECTION_TOP_LEFT="top-left-radius";Fi.SELECTION_BOTTOM_LEFT="bottom-left-radius";Fi.SELECTION_TOP_RIGHT="top-right-radius";Fi.SELECTION_BOTTOM_RIGHT="bottom-right-radius";Fi.EDITOR_BACKGROUND_CLASS_NAME="monaco-editor-background";Fi.ROUNDED_PIECE_WIDTH=10;ia((s,e)=>{const t=s.getColor(Dse);t&&!t.isTransparent()&&e.addRule(`.monaco-editor .view-line span.inline-selected-text { color: ${t}; }`)});function w1(s){return s<0?-s:s}class Z3{constructor(e,t,i,n,o,r,a){this.top=e,this.left=t,this.paddingLeft=i,this.width=n,this.height=o,this.textContent=r,this.textContentClassName=a}}class Y3{constructor(e){this._context=e;const t=this._context.configuration.options,i=t.get(50);this._cursorStyle=t.get(28),this._lineHeight=t.get(66),this._typicalHalfwidthCharacterWidth=i.typicalHalfwidthCharacterWidth,this._lineCursorWidth=Math.min(t.get(31),this._typicalHalfwidthCharacterWidth),this._isVisible=!0,this._domNode=Mt(document.createElement("div")),this._domNode.setClassName(`cursor ${Vp}`),this._domNode.setHeight(this._lineHeight),this._domNode.setTop(0),this._domNode.setLeft(0),Xn(this._domNode,i),this._domNode.setDisplay("none"),this._position=new H(1,1),this._lastRenderedContent="",this._renderData=null}getDomNode(){return this._domNode}getPosition(){return this._position}show(){this._isVisible||(this._domNode.setVisibility("inherit"),this._isVisible=!0)}hide(){this._isVisible&&(this._domNode.setVisibility("hidden"),this._isVisible=!1)}onConfigurationChanged(e){const t=this._context.configuration.options,i=t.get(50);return this._cursorStyle=t.get(28),this._lineHeight=t.get(66),this._typicalHalfwidthCharacterWidth=i.typicalHalfwidthCharacterWidth,this._lineCursorWidth=Math.min(t.get(31),this._typicalHalfwidthCharacterWidth),Xn(this._domNode,i),!0}onCursorPositionChanged(e,t){return t?this._domNode.domNode.style.transitionProperty="none":this._domNode.domNode.style.transitionProperty="",this._position=e,!0}_getGraphemeAwarePosition(){const{lineNumber:e,column:t}=this._position,i=this._context.viewModel.getLineContent(e),[n,o]=rJ(i,t-1);return[new H(e,n+1),i.substring(n,o)]}_prepareRender(e){let t="",i="";const[n,o]=this._getGraphemeAwarePosition();if(this._cursorStyle===Fn.Line||this._cursorStyle===Fn.LineThin){const h=e.visibleRangeForPosition(n);if(!h||h.outsideRenderedLine)return null;const g=Xe(this._domNode.domNode);let f;this._cursorStyle===Fn.Line?(f=D5(g,this._lineCursorWidth>0?this._lineCursorWidth:2),f>2&&(t=o,i=this._getTokenClassName(n))):f=D5(g,1);let m=h.left,_=0;f>=2&&m>=1&&(_=1,m-=_);const v=e.getVerticalOffsetForLineNumber(n.lineNumber)-e.bigNumbersDelta;return new Z3(v,m,_,f,this._lineHeight,t,i)}const r=e.linesVisibleRangesForRange(new D(n.lineNumber,n.column,n.lineNumber,n.column+o.length),!1);if(!r||r.length===0)return null;const a=r[0];if(a.outsideRenderedLine||a.ranges.length===0)return null;const l=a.ranges[0],d=o==="	"?this._typicalHalfwidthCharacterWidth:l.width<1?this._typicalHalfwidthCharacterWidth:l.width;this._cursorStyle===Fn.Block&&(t=o,i=this._getTokenClassName(n));let c=e.getVerticalOffsetForLineNumber(n.lineNumber)-e.bigNumbersDelta,u=this._lineHeight;return(this._cursorStyle===Fn.Underline||this._cursorStyle===Fn.UnderlineThin)&&(c+=this._lineHeight-2,u=2),new Z3(c,l.left,0,d,u,t,i)}_getTokenClassName(e){const t=this._context.viewModel.getViewLineData(e.lineNumber),i=t.tokens.findTokenIndexAtOffset(e.column-1);return t.tokens.getClassName(i)}prepareRender(e){this._renderData=this._prepareRender(e)}render(e){return this._renderData?(this._lastRenderedContent!==this._renderData.textContent&&(this._lastRenderedContent=this._renderData.textContent,this._domNode.domNode.textContent=this._lastRenderedContent),this._domNode.setClassName(`cursor ${Vp} ${this._renderData.textContentClassName}`),this._domNode.setDisplay("block"),this._domNode.setTop(this._renderData.top),this._domNode.setLeft(this._renderData.left),this._domNode.setPaddingLeft(this._renderData.paddingLeft),this._domNode.setWidth(this._renderData.width),this._domNode.setLineHeight(this._renderData.height),this._domNode.setHeight(this._renderData.height),{domNode:this._domNode.domNode,position:this._position,contentLeft:this._renderData.left,height:this._renderData.height,width:2}):(this._domNode.setDisplay("none"),null)}}class Y0 extends Eo{constructor(e){super(e);const t=this._context.configuration.options;this._readOnly=t.get(90),this._cursorBlinking=t.get(26),this._cursorStyle=t.get(28),this._cursorSmoothCaretAnimation=t.get(27),this._selectionIsEmpty=!0,this._isComposingInput=!1,this._isVisible=!1,this._primaryCursor=new Y3(this._context),this._secondaryCursors=[],this._renderData=[],this._domNode=Mt(document.createElement("div")),this._domNode.setAttribute("role","presentation"),this._domNode.setAttribute("aria-hidden","true"),this._updateDomClassName(),this._domNode.appendChild(this._primaryCursor.getDomNode()),this._startCursorBlinkAnimation=new ea,this._cursorFlatBlinkInterval=new eP,this._blinkingEnabled=!1,this._editorHasFocus=!1,this._updateBlinking()}dispose(){super.dispose(),this._startCursorBlinkAnimation.dispose(),this._cursorFlatBlinkInterval.dispose()}getDomNode(){return this._domNode}onCompositionStart(e){return this._isComposingInput=!0,this._updateBlinking(),!0}onCompositionEnd(e){return this._isComposingInput=!1,this._updateBlinking(),!0}onConfigurationChanged(e){const t=this._context.configuration.options;this._readOnly=t.get(90),this._cursorBlinking=t.get(26),this._cursorStyle=t.get(28),this._cursorSmoothCaretAnimation=t.get(27),this._updateBlinking(),this._updateDomClassName(),this._primaryCursor.onConfigurationChanged(e);for(let i=0,n=this._secondaryCursors.length;i<n;i++)this._secondaryCursors[i].onConfigurationChanged(e);return!0}_onCursorPositionChanged(e,t,i){const n=this._secondaryCursors.length!==t.length||this._cursorSmoothCaretAnimation==="explicit"&&i!==3;if(this._primaryCursor.onCursorPositionChanged(e,n),this._updateBlinking(),this._secondaryCursors.length<t.length){const o=t.length-this._secondaryCursors.length;for(let r=0;r<o;r++){const a=new Y3(this._context);this._domNode.domNode.insertBefore(a.getDomNode().domNode,this._primaryCursor.getDomNode().domNode.nextSibling),this._secondaryCursors.push(a)}}else if(this._secondaryCursors.length>t.length){const o=this._secondaryCursors.length-t.length;for(let r=0;r<o;r++)this._domNode.removeChild(this._secondaryCursors[0].getDomNode()),this._secondaryCursors.splice(0,1)}for(let o=0;o<t.length;o++)this._secondaryCursors[o].onCursorPositionChanged(t[o],n)}onCursorStateChanged(e){const t=[];for(let n=0,o=e.selections.length;n<o;n++)t[n]=e.selections[n].getPosition();this._onCursorPositionChanged(t[0],t.slice(1),e.reason);const i=e.selections[0].isEmpty();return this._selectionIsEmpty!==i&&(this._selectionIsEmpty=i,this._updateDomClassName()),!0}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onFocusChanged(e){return this._editorHasFocus=e.isFocused,this._updateBlinking(),!1}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return!0}onTokensChanged(e){const t=i=>{for(let n=0,o=e.ranges.length;n<o;n++)if(e.ranges[n].fromLineNumber<=i.lineNumber&&i.lineNumber<=e.ranges[n].toLineNumber)return!0;return!1};if(t(this._primaryCursor.getPosition()))return!0;for(const i of this._secondaryCursors)if(t(i.getPosition()))return!0;return!1}onZonesChanged(e){return!0}_getCursorBlinking(){return this._isComposingInput||!this._editorHasFocus?0:this._readOnly?5:this._cursorBlinking}_updateBlinking(){this._startCursorBlinkAnimation.cancel(),this._cursorFlatBlinkInterval.cancel();const e=this._getCursorBlinking(),t=e===0,i=e===5;t?this._hide():this._show(),this._blinkingEnabled=!1,this._updateDomClassName(),!t&&!i&&(e===1?this._cursorFlatBlinkInterval.cancelAndSet(()=>{this._isVisible?this._hide():this._show()},Y0.BLINK_INTERVAL,Xe(this._domNode.domNode)):this._startCursorBlinkAnimation.setIfNotSet(()=>{this._blinkingEnabled=!0,this._updateDomClassName()},Y0.BLINK_INTERVAL))}_updateDomClassName(){this._domNode.setClassName(this._getClassName())}_getClassName(){let e="cursors-layer";switch(this._selectionIsEmpty||(e+=" has-selection"),this._cursorStyle){case Fn.Line:e+=" cursor-line-style";break;case Fn.Block:e+=" cursor-block-style";break;case Fn.Underline:e+=" cursor-underline-style";break;case Fn.LineThin:e+=" cursor-line-thin-style";break;case Fn.BlockOutline:e+=" cursor-block-outline-style";break;case Fn.UnderlineThin:e+=" cursor-underline-thin-style";break;default:e+=" cursor-line-style"}if(this._blinkingEnabled)switch(this._getCursorBlinking()){case 1:e+=" cursor-blink";break;case 2:e+=" cursor-smooth";break;case 3:e+=" cursor-phase";break;case 4:e+=" cursor-expand";break;case 5:e+=" cursor-solid";break;default:e+=" cursor-solid"}else e+=" cursor-solid";return(this._cursorSmoothCaretAnimation==="on"||this._cursorSmoothCaretAnimation==="explicit")&&(e+=" cursor-smooth-caret-animation"),e}_show(){this._primaryCursor.show();for(let e=0,t=this._secondaryCursors.length;e<t;e++)this._secondaryCursors[e].show();this._isVisible=!0}_hide(){this._primaryCursor.hide();for(let e=0,t=this._secondaryCursors.length;e<t;e++)this._secondaryCursors[e].hide();this._isVisible=!1}prepareRender(e){this._primaryCursor.prepareRender(e);for(let t=0,i=this._secondaryCursors.length;t<i;t++)this._secondaryCursors[t].prepareRender(e)}render(e){const t=[];let i=0;const n=this._primaryCursor.render(e);n&&(t[i++]=n);for(let o=0,r=this._secondaryCursors.length;o<r;o++){const a=this._secondaryCursors[o].render(e);a&&(t[i++]=a)}this._renderData=t}getLastRenderData(){return this._renderData}}Y0.BLINK_INTERVAL=500;ia((s,e)=>{const t=s.getColor(LH);if(t){let i=s.getColor(fre);i||(i=t.opposite()),e.addRule(`.monaco-editor .cursors-layer .cursor { background-color: ${t}; border-color: ${t}; color: ${i}; }`),Oa(s.type)&&e.addRule(`.monaco-editor .cursors-layer.has-selection .cursor { border-left: 1px solid ${i}; border-right: 1px solid ${i}; }`)}});const cI=()=>{throw new Error("Invalid change accessor")};class Xae extends Eo{constructor(e){super(e);const t=this._context.configuration.options,i=t.get(143);this._lineHeight=t.get(66),this._contentWidth=i.contentWidth,this._contentLeft=i.contentLeft,this.domNode=Mt(document.createElement("div")),this.domNode.setClassName("view-zones"),this.domNode.setPosition("absolute"),this.domNode.setAttribute("role","presentation"),this.domNode.setAttribute("aria-hidden","true"),this.marginDomNode=Mt(document.createElement("div")),this.marginDomNode.setClassName("margin-view-zones"),this.marginDomNode.setPosition("absolute"),this.marginDomNode.setAttribute("role","presentation"),this.marginDomNode.setAttribute("aria-hidden","true"),this._zones={}}dispose(){super.dispose(),this._zones={}}_recomputeWhitespacesProps(){const e=this._context.viewLayout.getWhitespaces(),t=new Map;for(const n of e)t.set(n.id,n);let i=!1;return this._context.viewModel.changeWhitespace(n=>{const o=Object.keys(this._zones);for(let r=0,a=o.length;r<a;r++){const l=o[r],d=this._zones[l],c=this._computeWhitespaceProps(d.delegate);d.isInHiddenArea=c.isInHiddenArea;const u=t.get(l);u&&(u.afterLineNumber!==c.afterViewLineNumber||u.height!==c.heightInPx)&&(n.changeOneWhitespace(l,c.afterViewLineNumber,c.heightInPx),this._safeCallOnComputedHeight(d.delegate,c.heightInPx),i=!0)}}),i}onConfigurationChanged(e){const t=this._context.configuration.options,i=t.get(143);return this._lineHeight=t.get(66),this._contentWidth=i.contentWidth,this._contentLeft=i.contentLeft,e.hasChanged(66)&&this._recomputeWhitespacesProps(),!0}onLineMappingChanged(e){return this._recomputeWhitespacesProps()}onLinesDeleted(e){return!0}onScrollChanged(e){return e.scrollTopChanged||e.scrollWidthChanged}onZonesChanged(e){return!0}onLinesInserted(e){return!0}_getZoneOrdinal(e){var t,i;return(i=(t=e.ordinal)!==null&&t!==void 0?t:e.afterColumn)!==null&&i!==void 0?i:1e4}_computeWhitespaceProps(e){if(e.afterLineNumber===0)return{isInHiddenArea:!1,afterViewLineNumber:0,heightInPx:this._heightInPixels(e),minWidthInPx:this._minWidthInPixels(e)};let t;if(typeof e.afterColumn<"u")t=this._context.viewModel.model.validatePosition({lineNumber:e.afterLineNumber,column:e.afterColumn});else{const r=this._context.viewModel.model.validatePosition({lineNumber:e.afterLineNumber,column:1}).lineNumber;t=new H(r,this._context.viewModel.model.getLineMaxColumn(r))}let i;t.column===this._context.viewModel.model.getLineMaxColumn(t.lineNumber)?i=this._context.viewModel.model.validatePosition({lineNumber:t.lineNumber+1,column:1}):i=this._context.viewModel.model.validatePosition({lineNumber:t.lineNumber,column:t.column+1});const n=this._context.viewModel.coordinatesConverter.convertModelPositionToViewPosition(t,e.afterColumnAffinity,!0),o=e.showInHiddenAreas||this._context.viewModel.coordinatesConverter.modelPositionIsVisible(i);return{isInHiddenArea:!o,afterViewLineNumber:n.lineNumber,heightInPx:o?this._heightInPixels(e):0,minWidthInPx:this._minWidthInPixels(e)}}changeViewZones(e){let t=!1;return this._context.viewModel.changeWhitespace(i=>{const n={addZone:o=>(t=!0,this._addZone(i,o)),removeZone:o=>{o&&(t=this._removeZone(i,o)||t)},layoutZone:o=>{o&&(t=this._layoutZone(i,o)||t)}};Qae(e,n),n.addZone=cI,n.removeZone=cI,n.layoutZone=cI}),t}_addZone(e,t){const i=this._computeWhitespaceProps(t),o={whitespaceId:e.insertWhitespace(i.afterViewLineNumber,this._getZoneOrdinal(t),i.heightInPx,i.minWidthInPx),delegate:t,isInHiddenArea:i.isInHiddenArea,isVisible:!1,domNode:Mt(t.domNode),marginDomNode:t.marginDomNode?Mt(t.marginDomNode):null};return this._safeCallOnComputedHeight(o.delegate,i.heightInPx),o.domNode.setPosition("absolute"),o.domNode.domNode.style.width="100%",o.domNode.setDisplay("none"),o.domNode.setAttribute("monaco-view-zone",o.whitespaceId),this.domNode.appendChild(o.domNode),o.marginDomNode&&(o.marginDomNode.setPosition("absolute"),o.marginDomNode.domNode.style.width="100%",o.marginDomNode.setDisplay("none"),o.marginDomNode.setAttribute("monaco-view-zone",o.whitespaceId),this.marginDomNode.appendChild(o.marginDomNode)),this._zones[o.whitespaceId]=o,this.setShouldRender(),o.whitespaceId}_removeZone(e,t){if(this._zones.hasOwnProperty(t)){const i=this._zones[t];return delete this._zones[t],e.removeWhitespace(i.whitespaceId),i.domNode.removeAttribute("monaco-visible-view-zone"),i.domNode.removeAttribute("monaco-view-zone"),i.domNode.domNode.parentNode.removeChild(i.domNode.domNode),i.marginDomNode&&(i.marginDomNode.removeAttribute("monaco-visible-view-zone"),i.marginDomNode.removeAttribute("monaco-view-zone"),i.marginDomNode.domNode.parentNode.removeChild(i.marginDomNode.domNode)),this.setShouldRender(),!0}return!1}_layoutZone(e,t){if(this._zones.hasOwnProperty(t)){const i=this._zones[t],n=this._computeWhitespaceProps(i.delegate);return i.isInHiddenArea=n.isInHiddenArea,e.changeOneWhitespace(i.whitespaceId,n.afterViewLineNumber,n.heightInPx),this._safeCallOnComputedHeight(i.delegate,n.heightInPx),this.setShouldRender(),!0}return!1}shouldSuppressMouseDownOnViewZone(e){return this._zones.hasOwnProperty(e)?!!this._zones[e].delegate.suppressMouseDown:!1}_heightInPixels(e){return typeof e.heightInPx=="number"?e.heightInPx:typeof e.heightInLines=="number"?this._lineHeight*e.heightInLines:this._lineHeight}_minWidthInPixels(e){return typeof e.minWidthInPx=="number"?e.minWidthInPx:0}_safeCallOnComputedHeight(e,t){if(typeof e.onComputedHeight=="function")try{e.onComputedHeight(t)}catch(i){et(i)}}_safeCallOnDomNodeTop(e,t){if(typeof e.onDomNodeTop=="function")try{e.onDomNodeTop(t)}catch(i){et(i)}}prepareRender(e){}render(e){const t=e.viewportData.whitespaceViewportData,i={};let n=!1;for(const r of t)this._zones[r.id].isInHiddenArea||(i[r.id]=r,n=!0);const o=Object.keys(this._zones);for(let r=0,a=o.length;r<a;r++){const l=o[r],d=this._zones[l];let c=0,u=0,h="none";i.hasOwnProperty(l)?(c=i[l].verticalOffset-e.bigNumbersDelta,u=i[l].height,h="block",d.isVisible||(d.domNode.setAttribute("monaco-visible-view-zone","true"),d.isVisible=!0),this._safeCallOnDomNodeTop(d.delegate,e.getScrolledTopFromAbsoluteTop(i[l].verticalOffset))):(d.isVisible&&(d.domNode.removeAttribute("monaco-visible-view-zone"),d.isVisible=!1),this._safeCallOnDomNodeTop(d.delegate,e.getScrolledTopFromAbsoluteTop(-1e6))),d.domNode.setTop(c),d.domNode.setHeight(u),d.domNode.setDisplay(h),d.marginDomNode&&(d.marginDomNode.setTop(c),d.marginDomNode.setHeight(u),d.marginDomNode.setDisplay(h))}n&&(this.domNode.setWidth(Math.max(e.scrollWidth,this._contentWidth)),this.marginDomNode.setWidth(this._contentLeft))}}function Qae(s,e){try{return s(e)}catch(t){et(t)}}class Jae{get type(){return this._theme.type}get value(){return this._theme}constructor(e){this._theme=e}update(e){this._theme=e}getColor(e){return this._theme.getColor(e)}}class ele{constructor(e,t,i){this.configuration=e,this.theme=new Jae(t),this.viewModel=i,this.viewLayout=i.viewLayout}addEventHandler(e){this.viewModel.addViewEventHandler(e)}removeEventHandler(e){this.viewModel.removeViewEventHandler(e)}}class tle{constructor(e,t,i,n){this.selections=e,this.startLineNumber=t.startLineNumber|0,this.endLineNumber=t.endLineNumber|0,this.relativeVerticalOffset=t.relativeVerticalOffset,this.bigNumbersDelta=t.bigNumbersDelta|0,this.whitespaceViewportData=i,this._model=n,this.visibleRange=new D(t.startLineNumber,this._model.getLineMinColumn(t.startLineNumber),t.endLineNumber,this._model.getLineMaxColumn(t.endLineNumber))}getViewLineRenderingData(e){return this._model.getViewportViewLineRenderingData(this.visibleRange,e)}getDecorationsInViewport(){return this._model.getDecorationsInViewport(this.visibleRange)}}class ile extends Eo{constructor(e){super(e),this.blocks=[],this.contentWidth=-1,this.contentLeft=0,this.domNode=Mt(document.createElement("div")),this.domNode.setAttribute("role","presentation"),this.domNode.setAttribute("aria-hidden","true"),this.domNode.setClassName("blockDecorations-container"),this.update()}update(){let e=!1;const i=this._context.configuration.options.get(143),n=i.contentWidth-i.verticalScrollbarWidth;this.contentWidth!==n&&(this.contentWidth=n,e=!0);const o=i.contentLeft;return this.contentLeft!==o&&(this.contentLeft=o,e=!0),e}dispose(){super.dispose()}onConfigurationChanged(e){return this.update()}onScrollChanged(e){return e.scrollTopChanged||e.scrollLeftChanged}onDecorationsChanged(e){return!0}onZonesChanged(e){return!0}prepareRender(e){}render(e){var t;let i=0;const n=e.getDecorationsInViewport();for(const o of n){if(!o.options.blockClassName)continue;let r=this.blocks[i];r||(r=this.blocks[i]=Mt(document.createElement("div")),this.domNode.appendChild(r));let a,l;o.options.blockIsAfterEnd?(a=e.getVerticalOffsetAfterLineNumber(o.range.endLineNumber,!1),l=e.getVerticalOffsetAfterLineNumber(o.range.endLineNumber,!0)):(a=e.getVerticalOffsetForLineNumber(o.range.startLineNumber,!0),l=o.range.isEmpty()&&!o.options.blockDoesNotCollapse?e.getVerticalOffsetForLineNumber(o.range.startLineNumber,!1):e.getVerticalOffsetAfterLineNumber(o.range.endLineNumber,!0));const[d,c,u,h]=(t=o.options.blockPadding)!==null&&t!==void 0?t:[0,0,0,0];r.setClassName("blockDecorations-block "+o.options.blockClassName),r.setLeft(this.contentLeft-h),r.setWidth(this.contentWidth+h+c),r.setTop(a-e.scrollTop-d),r.setHeight(l-a+d+u),i++}for(let o=i;o<this.blocks.length;o++)this.blocks[o].domNode.remove();this.blocks.length=i}}class nle extends df{constructor(e){super(),this._context=e,this._options=new X3(this._context.configuration),this._selection=[],this._renderResult=null,this._context.addEventHandler(this)}dispose(){this._context.removeEventHandler(this),this._renderResult=null,super.dispose()}onConfigurationChanged(e){const t=new X3(this._context.configuration);return this._options.equals(t)?e.hasChanged(143):(this._options=t,!0)}onCursorStateChanged(e){return this._selection=e.selections,this._options.renderWhitespace==="selection"}onDecorationsChanged(e){return!0}onFlushed(e){return!0}onLinesChanged(e){return!0}onLinesDeleted(e){return!0}onLinesInserted(e){return!0}onScrollChanged(e){return e.scrollTopChanged}onZonesChanged(e){return!0}prepareRender(e){if(this._options.renderWhitespace==="none"){this._renderResult=null;return}const t=e.visibleRange.startLineNumber,n=e.visibleRange.endLineNumber-t+1,o=new Array(n);for(let a=0;a<n;a++)o[a]=!0;const r=this._context.viewModel.getMinimapLinesRenderingData(e.viewportData.startLineNumber,e.viewportData.endLineNumber,o);this._renderResult=[];for(let a=e.viewportData.startLineNumber;a<=e.viewportData.endLineNumber;a++){const l=a-e.viewportData.startLineNumber,d=r.data[l];let c=null;if(this._options.renderWhitespace==="selection"){const u=this._selection;for(const h of u){if(h.endLineNumber<a||h.startLineNumber>a)continue;const g=h.startLineNumber===a?h.startColumn:d.minColumn,f=h.endLineNumber===a?h.endColumn:d.maxColumn;g<f&&(c||(c=[]),c.push(new XV(g-1,f-1)))}}this._renderResult[l]=this._applyRenderWhitespace(e,a,c,d)}}_applyRenderWhitespace(e,t,i,n){if(this._options.renderWhitespace==="selection"&&!i||this._options.renderWhitespace==="trailing"&&n.continuesWithWrappedLine)return"";const o=this._context.theme.getColor(Vd),r=this._options.renderWithSVG,a=n.content,l=this._options.stopRenderingLineAfter===-1?a.length:Math.min(this._options.stopRenderingLineAfter,a.length),d=n.continuesWithWrappedLine,c=n.minColumn-1,u=this._options.renderWhitespace==="boundary",h=this._options.renderWhitespace==="trailing",g=this._options.lineHeight,f=this._options.middotWidth,m=this._options.wsmiddotWidth,_=this._options.spaceWidth,v=Math.abs(m-_),b=Math.abs(f-_),C=v<b?11825:183,w=this._options.canUseHalfwidthRightwardsArrow;let S="",x=!1,L=ws(a),k;L===-1?(x=!0,L=l,k=l):k=Pa(a);let I=0,P=i&&i[I],$=0;for(let A=c;A<l;A++){const z=a.charCodeAt(A);if(P&&A>=P.endOffset&&(I++,P=i&&i[I]),z!==9&&z!==32||h&&!x&&A<=k)continue;if(u&&A>=L&&A<=k&&z===32){const Q=A-1>=0?a.charCodeAt(A-1):0,ne=A+1<l?a.charCodeAt(A+1):0;if(Q!==32&&ne!==32)continue}if(u&&d&&A===l-1){const Q=A-1>=0?a.charCodeAt(A-1):0;if(z===32&&Q!==32&&Q!==9)continue}if(i&&(!P||P.startOffset>A||P.endOffset<=A))continue;const K=e.visibleRangeForPosition(new H(t,A+1));K&&(r?($=Math.max($,K.left),z===9?S+=this._renderArrow(g,_,K.left):S+=`<circle cx="${(K.left+_/2).toFixed(2)}" cy="${(g/2).toFixed(2)}" r="${(_/7).toFixed(2)}" />`):z===9?S+=`<div class="mwh" style="left:${K.left}px;height:${g}px;">${w?"￫":"→"}</div>`:S+=`<div class="mwh" style="left:${K.left}px;height:${g}px;">${String.fromCharCode(C)}</div>`)}return r?($=Math.round($+_),`<svg style="position:absolute;width:${$}px;height:${g}px" viewBox="0 0 ${$} ${g}" xmlns="http://www.w3.org/2000/svg" fill="${o}">`+S+"</svg>"):S}_renderArrow(e,t,i){const n=t/7,o=t,r=e/2,a=i,l={x:0,y:n/2},d={x:100/125*o,y:l.y},c={x:d.x-.2*d.x,y:d.y+.2*d.x},u={x:c.x+.1*d.x,y:c.y+.1*d.x},h={x:u.x+.35*d.x,y:u.y-.35*d.x},g={x:h.x,y:-h.y},f={x:u.x,y:-u.y},m={x:c.x,y:-c.y},_={x:d.x,y:-d.y},v={x:l.x,y:-l.y};return`<path d="M ${[l,d,c,u,h,g,f,m,_,v].map(w=>`${(a+w.x).toFixed(2)} ${(r+w.y).toFixed(2)}`).join(" L ")}" />`}render(e,t){if(!this._renderResult)return"";const i=t-e;return i<0||i>=this._renderResult.length?"":this._renderResult[i]}}class X3{constructor(e){const t=e.options,i=t.get(50),n=t.get(38);n==="off"?(this.renderWhitespace="none",this.renderWithSVG=!1):n==="svg"?(this.renderWhitespace=t.get(98),this.renderWithSVG=!0):(this.renderWhitespace=t.get(98),this.renderWithSVG=!1),this.spaceWidth=i.spaceWidth,this.middotWidth=i.middotWidth,this.wsmiddotWidth=i.wsmiddotWidth,this.canUseHalfwidthRightwardsArrow=i.canUseHalfwidthRightwardsArrow,this.lineHeight=t.get(66),this.stopRenderingLineAfter=t.get(116)}equals(e){return this.renderWhitespace===e.renderWhitespace&&this.renderWithSVG===e.renderWithSVG&&this.spaceWidth===e.spaceWidth&&this.middotWidth===e.middotWidth&&this.wsmiddotWidth===e.wsmiddotWidth&&this.canUseHalfwidthRightwardsArrow===e.canUseHalfwidthRightwardsArrow&&this.lineHeight===e.lineHeight&&this.stopRenderingLineAfter===e.stopRenderingLineAfter}}var sle=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},ole=function(s,e){return function(t,i){e(t,i,s)}};let LT=class extends uC{constructor(e,t,i,n,o,r,a){super(),this._instantiationService=a,this._shouldRecomputeGlyphMarginLanes=!1,this._selections=[new De(1,1,1,1)],this._renderAnimationFrame=null;const l=new hae(t,n,o,e);this._context=new ele(t,i,n),this._context.addEventHandler(this),this._viewParts=[],this._textAreaHandler=this._instantiationService.createInstance(wT,this._context,l,this._createTextAreaHandlerHelper()),this._viewParts.push(this._textAreaHandler),this._linesContent=Mt(document.createElement("div")),this._linesContent.setClassName("lines-content monaco-editor-background"),this._linesContent.setPosition("absolute"),this.domNode=Mt(document.createElement("div")),this.domNode.setClassName(this._getEditorClassName()),this.domNode.setAttribute("role","code"),this._overflowGuardContainer=Mt(document.createElement("div")),Zl.write(this._overflowGuardContainer,3),this._overflowGuardContainer.setClassName("overflow-guard"),this._scrollbar=new wae(this._context,this._linesContent,this.domNode,this._overflowGuardContainer),this._viewParts.push(this._scrollbar),this._viewLines=new Nx(this._context,this._linesContent),this._viewZones=new Xae(this._context),this._viewParts.push(this._viewZones);const d=new zae(this._context);this._viewParts.push(d);const c=new Kae(this._context);this._viewParts.push(c);const u=new fae(this._context);this._viewParts.push(u),u.addDynamicOverlay(new vae(this._context)),u.addDynamicOverlay(new Fi(this._context)),u.addDynamicOverlay(new yae(this._context)),u.addDynamicOverlay(new Cae(this._context)),u.addDynamicOverlay(new nle(this._context));const h=new pae(this._context);this._viewParts.push(h),h.addDynamicOverlay(new bae(this._context)),h.addDynamicOverlay(new Aae(this._context)),h.addDynamicOverlay(new Rae(this._context)),h.addDynamicOverlay(new pC(this._context)),this._glyphMarginWidgets=new Eae(this._context),this._viewParts.push(this._glyphMarginWidgets);const g=new Mg(this._context);g.getDomNode().appendChild(this._viewZones.marginDomNode),g.getDomNode().appendChild(h.getDomNode()),g.getDomNode().appendChild(this._glyphMarginWidgets.domNode),this._viewParts.push(g),this._contentWidgets=new mae(this._context,this.domNode),this._viewParts.push(this._contentWidgets),this._viewCursors=new Y0(this._context),this._viewParts.push(this._viewCursors),this._overlayWidgets=new Vae(this._context),this._viewParts.push(this._overlayWidgets);const f=new jae(this._context);this._viewParts.push(f);const m=new ile(this._context);this._viewParts.push(m);const _=new Wae(this._context);if(this._viewParts.push(_),d){const v=this._scrollbar.getOverviewRulerLayoutInfo();v.parent.insertBefore(d.getDomNode(),v.insertBefore)}this._linesContent.appendChild(u.getDomNode()),this._linesContent.appendChild(f.domNode),this._linesContent.appendChild(this._viewZones.domNode),this._linesContent.appendChild(this._viewLines.getDomNode()),this._linesContent.appendChild(this._contentWidgets.domNode),this._linesContent.appendChild(this._viewCursors.getDomNode()),this._overflowGuardContainer.appendChild(g.getDomNode()),this._overflowGuardContainer.appendChild(this._scrollbar.getDomNode()),this._overflowGuardContainer.appendChild(c.getDomNode()),this._overflowGuardContainer.appendChild(this._textAreaHandler.textArea),this._overflowGuardContainer.appendChild(this._textAreaHandler.textAreaCover),this._overflowGuardContainer.appendChild(this._overlayWidgets.getDomNode()),this._overflowGuardContainer.appendChild(_.getDomNode()),this._overflowGuardContainer.appendChild(m.domNode),this.domNode.appendChild(this._overflowGuardContainer),r?r.appendChild(this._contentWidgets.overflowingContentWidgetsDomNode.domNode):this.domNode.appendChild(this._contentWidgets.overflowingContentWidgetsDomNode),this._applyLayout(),this._pointerHandler=this._register(new ure(this._context,l,this._createPointerHandlerHelper()))}_computeGlyphMarginLaneCount(){const e=this._context.viewModel.model;let t=[];t=t.concat(e.getAllMarginDecorations().map(o=>{var r,a;const l=(a=(r=o.options.glyphMargin)===null||r===void 0?void 0:r.position)!==null&&a!==void 0?a:fg.Left;return{range:o.range,lane:l}})),t=t.concat(this._glyphMarginWidgets.getWidgets().map(o=>({range:e.validateRange(o.preference.range),lane:o.preference.lane}))),t.sort((o,r)=>D.compareRangesUsingStarts(o.range,r.range));let i=null,n=null;for(const o of t)if(o.lane===fg.Left&&(!i||D.compareRangesUsingEnds(i,o.range)<0)&&(i=o.range),o.lane===fg.Right&&(!n||D.compareRangesUsingEnds(n,o.range)<0)&&(n=o.range),i&&n){if(i.endLineNumber<n.startLineNumber){i=null;continue}if(n.endLineNumber<i.startLineNumber){n=null;continue}return 2}return 1}_createPointerHandlerHelper(){return{viewDomNode:this.domNode.domNode,linesContentDomNode:this._linesContent.domNode,viewLinesDomNode:this._viewLines.getDomNode().domNode,focusTextArea:()=>{this.focus()},dispatchTextAreaEvent:e=>{this._textAreaHandler.textArea.domNode.dispatchEvent(e)},getLastRenderData:()=>{const e=this._viewCursors.getLastRenderData()||[],t=this._textAreaHandler.getLastRenderData();return new zoe(e,t)},renderNow:()=>{this.render(!0,!1)},shouldSuppressMouseDownOnViewZone:e=>this._viewZones.shouldSuppressMouseDownOnViewZone(e),shouldSuppressMouseDownOnWidget:e=>this._contentWidgets.shouldSuppressMouseDownOnWidget(e),getPositionFromDOMInfo:(e,t)=>(this._flushAccumulatedAndRenderNow(),this._viewLines.getPositionFromDOMInfo(e,t)),visibleRangeForPosition:(e,t)=>(this._flushAccumulatedAndRenderNow(),this._viewLines.visibleRangeForPosition(new H(e,t))),getLineWidth:e=>(this._flushAccumulatedAndRenderNow(),this._viewLines.getLineWidth(e))}}_createTextAreaHandlerHelper(){return{visibleRangeForPosition:e=>(this._flushAccumulatedAndRenderNow(),this._viewLines.visibleRangeForPosition(e))}}_applyLayout(){const t=this._context.configuration.options.get(143);this.domNode.setWidth(t.width),this.domNode.setHeight(t.height),this._overflowGuardContainer.setWidth(t.width),this._overflowGuardContainer.setHeight(t.height),this._linesContent.setWidth(1e6),this._linesContent.setHeight(1e6)}_getEditorClassName(){const e=this._textAreaHandler.isFocused()?" focused":"";return this._context.configuration.options.get(140)+" "+CT(this._context.theme.type)+e}handleEvents(e){super.handleEvents(e),this._scheduleRender()}onConfigurationChanged(e){return this.domNode.setClassName(this._getEditorClassName()),this._applyLayout(),!1}onCursorStateChanged(e){return this._selections=e.selections,!1}onDecorationsChanged(e){return e.affectsGlyphMargin&&(this._shouldRecomputeGlyphMarginLanes=!0),!1}onFocusChanged(e){return this.domNode.setClassName(this._getEditorClassName()),!1}onThemeChanged(e){return this._context.theme.update(e.theme),this.domNode.setClassName(this._getEditorClassName()),!1}dispose(){this._renderAnimationFrame!==null&&(this._renderAnimationFrame.dispose(),this._renderAnimationFrame=null),this._contentWidgets.overflowingContentWidgetsDomNode.domNode.remove(),this._context.removeEventHandler(this),this._viewLines.dispose();for(const e of this._viewParts)e.dispose();super.dispose()}_scheduleRender(){if(this._store.isDisposed)throw new pi;if(this._renderAnimationFrame===null){const e=this._createCoordinatedRendering();this._renderAnimationFrame=xT.INSTANCE.scheduleCoordinatedRendering({window:Xe(this.domNode.domNode),prepareRenderText:()=>{if(this._store.isDisposed)throw new pi;try{return e.prepareRenderText()}finally{this._renderAnimationFrame=null}},renderText:()=>{if(this._store.isDisposed)throw new pi;return e.renderText()},prepareRender:(t,i)=>{if(this._store.isDisposed)throw new pi;return e.prepareRender(t,i)},render:(t,i)=>{if(this._store.isDisposed)throw new pi;return e.render(t,i)}})}}_flushAccumulatedAndRenderNow(){const e=this._createCoordinatedRendering();Kc(()=>e.prepareRenderText());const t=Kc(()=>e.renderText());if(t){const[i,n]=t;Kc(()=>e.prepareRender(i,n)),Kc(()=>e.render(i,n))}}_getViewPartsToRender(){const e=[];let t=0;for(const i of this._viewParts)i.shouldRender()&&(e[t++]=i);return e}_createCoordinatedRendering(){return{prepareRenderText:()=>{this._shouldRecomputeGlyphMarginLanes&&(this._shouldRecomputeGlyphMarginLanes=!1,this._context.configuration.setGlyphMarginDecorationLaneCount(this._computeGlyphMarginLaneCount())),jc.onRenderStart()},renderText:()=>{if(!this.domNode.domNode.isConnected)return null;let e=this._getViewPartsToRender();if(!this._viewLines.shouldRender()&&e.length===0)return null;const t=this._context.viewLayout.getLinesViewportData();this._context.viewModel.setViewport(t.startLineNumber,t.endLineNumber,t.centeredLineNumber);const i=new tle(this._selections,t,this._context.viewLayout.getWhitespaceViewportData(),this._context.viewModel);return this._contentWidgets.shouldRender()&&this._contentWidgets.onBeforeRender(i),this._viewLines.shouldRender()&&(this._viewLines.renderText(i),this._viewLines.onDidRender(),e=this._getViewPartsToRender()),[e,new Poe(this._context.viewLayout,i,this._viewLines)]},prepareRender:(e,t)=>{for(const i of e)i.prepareRender(t)},render:(e,t)=>{for(const i of e)i.render(t),i.onDidRender()}}}delegateVerticalScrollbarPointerDown(e){this._scrollbar.delegateVerticalScrollbarPointerDown(e)}delegateScrollFromMouseWheelEvent(e){this._scrollbar.delegateScrollFromMouseWheelEvent(e)}restoreState(e){this._context.viewModel.viewLayout.setScrollPosition({scrollTop:e.scrollTop,scrollLeft:e.scrollLeft},1),this._context.viewModel.visibleLinesStabilized()}getOffsetForColumn(e,t){const i=this._context.viewModel.model.validatePosition({lineNumber:e,column:t}),n=this._context.viewModel.coordinatesConverter.convertModelPositionToViewPosition(i);this._flushAccumulatedAndRenderNow();const o=this._viewLines.visibleRangeForPosition(new H(n.lineNumber,n.column));return o?o.left:-1}getTargetAtClientPoint(e,t){const i=this._pointerHandler.getTargetAtClientPoint(e,t);return i?Ix.convertViewToModelMouseTarget(i,this._context.viewModel.coordinatesConverter):null}createOverviewRuler(e){return new $ae(this._context,e)}change(e){this._viewZones.changeViewZones(e),this._scheduleRender()}render(e,t){if(t){this._viewLines.forceShouldRender();for(const i of this._viewParts)i.forceShouldRender()}e?this._flushAccumulatedAndRenderNow():this._scheduleRender()}writeScreenReaderContent(e){this._textAreaHandler.writeScreenReaderContent(e)}focus(){this._textAreaHandler.focusTextArea()}isFocused(){return this._textAreaHandler.isFocused()}setAriaOptions(e){this._textAreaHandler.setAriaOptions(e)}addContentWidget(e){this._contentWidgets.addWidget(e.widget),this.layoutContentWidget(e),this._scheduleRender()}layoutContentWidget(e){var t,i,n,o,r,a,l,d;this._contentWidgets.setWidgetPosition(e.widget,(i=(t=e.position)===null||t===void 0?void 0:t.position)!==null&&i!==void 0?i:null,(o=(n=e.position)===null||n===void 0?void 0:n.secondaryPosition)!==null&&o!==void 0?o:null,(a=(r=e.position)===null||r===void 0?void 0:r.preference)!==null&&a!==void 0?a:null,(d=(l=e.position)===null||l===void 0?void 0:l.positionAffinity)!==null&&d!==void 0?d:null),this._scheduleRender()}removeContentWidget(e){this._contentWidgets.removeWidget(e.widget),this._scheduleRender()}addOverlayWidget(e){this._overlayWidgets.addWidget(e.widget),this.layoutOverlayWidget(e),this._scheduleRender()}layoutOverlayWidget(e){const t=e.position?e.position.preference:null;this._overlayWidgets.setWidgetPosition(e.widget,t)&&this._scheduleRender()}removeOverlayWidget(e){this._overlayWidgets.removeWidget(e.widget),this._scheduleRender()}addGlyphMarginWidget(e){this._glyphMarginWidgets.addWidget(e.widget),this._shouldRecomputeGlyphMarginLanes=!0,this._scheduleRender()}layoutGlyphMarginWidget(e){const t=e.position;this._glyphMarginWidgets.setWidgetPosition(e.widget,t)&&(this._shouldRecomputeGlyphMarginLanes=!0,this._scheduleRender())}removeGlyphMarginWidget(e){this._glyphMarginWidgets.removeWidget(e.widget),this._shouldRecomputeGlyphMarginLanes=!0,this._scheduleRender()}};LT=sle([ole(6,We)],LT);function Kc(s){try{return s()}catch(e){return et(e),null}}class xT{constructor(){this._coordinatedRenderings=[],this._animationFrameRunners=new Map}scheduleCoordinatedRendering(e){return this._coordinatedRenderings.push(e),this._scheduleRender(e.window),{dispose:()=>{const t=this._coordinatedRenderings.indexOf(e);if(t!==-1&&(this._coordinatedRenderings.splice(t,1),this._coordinatedRenderings.length===0)){for(const[i,n]of this._animationFrameRunners)n.dispose();this._animationFrameRunners.clear()}}}}_scheduleRender(e){if(!this._animationFrameRunners.has(e)){const t=()=>{this._animationFrameRunners.delete(e),this._onRenderScheduled()};this._animationFrameRunners.set(e,OS(e,t,100))}}_onRenderScheduled(){const e=this._coordinatedRenderings.slice(0);this._coordinatedRenderings=[];for(const i of e)Kc(()=>i.prepareRenderText());const t=[];for(let i=0,n=e.length;i<n;i++){const o=e[i];t[i]=Kc(()=>o.renderText())}for(let i=0,n=e.length;i<n;i++){const o=e[i],r=t[i];if(!r)continue;const[a,l]=r;Kc(()=>o.prepareRender(a,l))}for(let i=0,n=e.length;i<n;i++){const o=e[i],r=t[i];if(!r)continue;const[a,l]=r;Kc(()=>o.render(a,l))}}}xT.INSTANCE=new xT;class UH{constructor(e,t,i,n,o,r,a){this.id=e,this.label=t,this.alias=i,this.metadata=n,this._precondition=o,this._run=r,this._contextKeyService=a}isSupported(){return this._contextKeyService.contextMatchesRules(this._precondition)}run(e){return this.isSupported()?this._run(e):Promise.resolve(void 0)}}function Ou(s){let e=0,t=0,i=0,n=0;for(let o=0,r=s.length;o<r;o++){const a=s.charCodeAt(o);a===13?(e===0&&(t=o),e++,o+1<r&&s.charCodeAt(o+1)===10?(n|=2,o++):n|=3,i=o+1):a===10&&(n|=1,e===0&&(t=o),e++,i=o+1)}return e===0&&(t=s.length),[e,t,s.length-i,n]}class Q3{constructor(e,t,i,n){this.range=e,this.nestingLevel=t,this.nestingLevelOfEqualBracketType=i,this.isInvalid=n}}class rle{constructor(e,t,i,n,o,r){this.range=e,this.openingBracketRange=t,this.closingBracketRange=i,this.nestingLevel=n,this.nestingLevelOfEqualBracketType=o,this.bracketPairNode=r}get openingBracketInfo(){return this.bracketPairNode.openingBracket.bracketInfo}}class ale extends rle{constructor(e,t,i,n,o,r,a){super(e,t,i,n,o,r),this.minVisibleColumnIndentation=a}}class X0{constructor(e,t){this.lineCount=e,this.columnCount=t}toString(){return`${this.lineCount},${this.columnCount}`}}X0.zero=new X0(0,0);function lle(s,e,t,i){return s!==t?Gi(t-s,i):Gi(0,i-e)}const As=0;function ny(s){return s===0}const Xo=2**26;function Gi(s,e){return s*Xo+e}function wr(s){const e=s,t=Math.floor(e/Xo),i=e-t*Xo;return new X0(t,i)}function dle(s){return Math.floor(s/Xo)}function ki(s,e){let t=s+e;return e>=Xo&&(t=t-s%Xo),t}function cle(s,e){return s.reduce((t,i)=>ki(t,e(i)),As)}function $H(s,e){return s===e}function Q0(s,e){const t=s,i=e;if(i-t<=0)return As;const o=Math.floor(t/Xo),r=Math.floor(i/Xo),a=i-r*Xo;if(o===r){const l=t-o*Xo;return Gi(0,a-l)}else return Gi(r-o,a)}function Up(s,e){return s<e}function $p(s,e){return s<=e}function fv(s,e){return s>=e}function mp(s){return Gi(s.lineNumber-1,s.column-1)}function _g(s,e){const t=s,i=Math.floor(t/Xo),n=t-i*Xo,o=e,r=Math.floor(o/Xo),a=o-r*Xo;return new D(i+1,n+1,r+1,a+1)}function ule(s){const e=Kl(s);return Gi(e.length-1,e[e.length-1].length)}class Hd{static fromModelContentChanges(e){return e.map(i=>{const n=D.lift(i.range);return new Hd(mp(n.getStartPosition()),mp(n.getEndPosition()),ule(i.text))}).reverse()}constructor(e,t,i){this.startOffset=e,this.endOffset=t,this.newLength=i}toString(){return`[${wr(this.startOffset)}...${wr(this.endOffset)}) -> ${wr(this.newLength)}`}}class hle{constructor(e){this.nextEditIdx=0,this.deltaOldToNewLineCount=0,this.deltaOldToNewColumnCount=0,this.deltaLineIdxInOld=-1,this.edits=e.map(t=>TP.from(t))}getOffsetBeforeChange(e){return this.adjustNextEdit(e),this.translateCurToOld(e)}getDistanceToNextChange(e){this.adjustNextEdit(e);const t=this.edits[this.nextEditIdx],i=t?this.translateOldToCur(t.offsetObj):null;return i===null?null:Q0(e,i)}translateOldToCur(e){return e.lineCount===this.deltaLineIdxInOld?Gi(e.lineCount+this.deltaOldToNewLineCount,e.columnCount+this.deltaOldToNewColumnCount):Gi(e.lineCount+this.deltaOldToNewLineCount,e.columnCount)}translateCurToOld(e){const t=wr(e);return t.lineCount-this.deltaOldToNewLineCount===this.deltaLineIdxInOld?Gi(t.lineCount-this.deltaOldToNewLineCount,t.columnCount-this.deltaOldToNewColumnCount):Gi(t.lineCount-this.deltaOldToNewLineCount,t.columnCount)}adjustNextEdit(e){for(;this.nextEditIdx<this.edits.length;){const t=this.edits[this.nextEditIdx],i=this.translateOldToCur(t.endOffsetAfterObj);if($p(i,e)){this.nextEditIdx++;const n=wr(i),o=wr(this.translateOldToCur(t.endOffsetBeforeObj)),r=n.lineCount-o.lineCount;this.deltaOldToNewLineCount+=r;const a=this.deltaLineIdxInOld===t.endOffsetBeforeObj.lineCount?this.deltaOldToNewColumnCount:0,l=n.columnCount-o.columnCount;this.deltaOldToNewColumnCount=a+l,this.deltaLineIdxInOld=t.endOffsetBeforeObj.lineCount}else break}}}class TP{static from(e){return new TP(e.startOffset,e.endOffset,e.newLength)}constructor(e,t,i){this.endOffsetBeforeObj=wr(t),this.endOffsetAfterObj=wr(ki(e,i)),this.offsetObj=wr(e)}}const zw=[];class rn{static create(e,t){if(e<=128&&t.length===0){let i=rn.cache[e];return i||(i=new rn(e,t),rn.cache[e]=i),i}return new rn(e,t)}static getEmpty(){return this.empty}constructor(e,t){this.items=e,this.additionalItems=t}add(e,t){const i=t.getKey(e);let n=i>>5;if(n===0){const r=1<<i|this.items;return r===this.items?this:rn.create(r,this.additionalItems)}n--;const o=this.additionalItems.slice(0);for(;o.length<n;)o.push(0);return o[n]|=1<<(i&31),rn.create(this.items,o)}merge(e){const t=this.items|e.items;if(this.additionalItems===zw&&e.additionalItems===zw)return t===this.items?this:t===e.items?e:rn.create(t,zw);const i=[];for(let n=0;n<Math.max(this.additionalItems.length,e.additionalItems.length);n++){const o=this.additionalItems[n]||0,r=e.additionalItems[n]||0;i.push(o|r)}return rn.create(t,i)}intersects(e){if(this.items&e.items)return!0;for(let t=0;t<Math.min(this.additionalItems.length,e.additionalItems.length);t++)if(this.additionalItems[t]&e.additionalItems[t])return!0;return!1}}rn.cache=new Array(129);rn.empty=rn.create(0,zw);const J3={getKey(s){return s}};class jH{constructor(){this.items=new Map}getKey(e){let t=this.items.get(e);return t===void 0&&(t=this.items.size,this.items.set(e,t)),t}}class MP{get length(){return this._length}constructor(e){this._length=e}}class J0 extends MP{static create(e,t,i){let n=e.length;return t&&(n=ki(n,t.length)),i&&(n=ki(n,i.length)),new J0(n,e,t,i,t?t.missingOpeningBracketIds:rn.getEmpty())}get kind(){return 2}get listHeight(){return 0}get childrenLength(){return 3}getChild(e){switch(e){case 0:return this.openingBracket;case 1:return this.child;case 2:return this.closingBracket}throw new Error("Invalid child index")}get children(){const e=[];return e.push(this.openingBracket),this.child&&e.push(this.child),this.closingBracket&&e.push(this.closingBracket),e}constructor(e,t,i,n,o){super(e),this.openingBracket=t,this.child=i,this.closingBracket=n,this.missingOpeningBracketIds=o}canBeReused(e){return!(this.closingBracket===null||e.intersects(this.missingOpeningBracketIds))}deepClone(){return new J0(this.length,this.openingBracket.deepClone(),this.child&&this.child.deepClone(),this.closingBracket&&this.closingBracket.deepClone(),this.missingOpeningBracketIds)}computeMinIndentation(e,t){return this.child?this.child.computeMinIndentation(ki(e,this.openingBracket.length),t):Number.MAX_SAFE_INTEGER}}class Yl extends MP{static create23(e,t,i,n=!1){let o=e.length,r=e.missingOpeningBracketIds;if(e.listHeight!==t.listHeight)throw new Error("Invalid list heights");if(o=ki(o,t.length),r=r.merge(t.missingOpeningBracketIds),i){if(e.listHeight!==i.listHeight)throw new Error("Invalid list heights");o=ki(o,i.length),r=r.merge(i.missingOpeningBracketIds)}return n?new gle(o,e.listHeight+1,e,t,i,r):new eb(o,e.listHeight+1,e,t,i,r)}static getEmpty(){return new fle(As,0,[],rn.getEmpty())}get kind(){return 4}get missingOpeningBracketIds(){return this._missingOpeningBracketIds}constructor(e,t,i){super(e),this.listHeight=t,this._missingOpeningBracketIds=i,this.cachedMinIndentation=-1}throwIfImmutable(){}makeLastElementMutable(){this.throwIfImmutable();const e=this.childrenLength;if(e===0)return;const t=this.getChild(e-1),i=t.kind===4?t.toMutable():t;return t!==i&&this.setChild(e-1,i),i}makeFirstElementMutable(){if(this.throwIfImmutable(),this.childrenLength===0)return;const t=this.getChild(0),i=t.kind===4?t.toMutable():t;return t!==i&&this.setChild(0,i),i}canBeReused(e){if(e.intersects(this.missingOpeningBracketIds)||this.childrenLength===0)return!1;let t=this;for(;t.kind===4;){const i=t.childrenLength;if(i===0)throw new pi;t=t.getChild(i-1)}return t.canBeReused(e)}handleChildrenChanged(){this.throwIfImmutable();const e=this.childrenLength;let t=this.getChild(0).length,i=this.getChild(0).missingOpeningBracketIds;for(let n=1;n<e;n++){const o=this.getChild(n);t=ki(t,o.length),i=i.merge(o.missingOpeningBracketIds)}this._length=t,this._missingOpeningBracketIds=i,this.cachedMinIndentation=-1}computeMinIndentation(e,t){if(this.cachedMinIndentation!==-1)return this.cachedMinIndentation;let i=Number.MAX_SAFE_INTEGER,n=e;for(let o=0;o<this.childrenLength;o++){const r=this.getChild(o);r&&(i=Math.min(i,r.computeMinIndentation(n,t)),n=ki(n,r.length))}return this.cachedMinIndentation=i,i}}class eb extends Yl{get childrenLength(){return this._item3!==null?3:2}getChild(e){switch(e){case 0:return this._item1;case 1:return this._item2;case 2:return this._item3}throw new Error("Invalid child index")}setChild(e,t){switch(e){case 0:this._item1=t;return;case 1:this._item2=t;return;case 2:this._item3=t;return}throw new Error("Invalid child index")}get children(){return this._item3?[this._item1,this._item2,this._item3]:[this._item1,this._item2]}get item1(){return this._item1}get item2(){return this._item2}get item3(){return this._item3}constructor(e,t,i,n,o,r){super(e,t,r),this._item1=i,this._item2=n,this._item3=o}deepClone(){return new eb(this.length,this.listHeight,this._item1.deepClone(),this._item2.deepClone(),this._item3?this._item3.deepClone():null,this.missingOpeningBracketIds)}appendChildOfSameHeight(e){if(this._item3)throw new Error("Cannot append to a full (2,3) tree node");this.throwIfImmutable(),this._item3=e,this.handleChildrenChanged()}unappendChild(){if(!this._item3)throw new Error("Cannot remove from a non-full (2,3) tree node");this.throwIfImmutable();const e=this._item3;return this._item3=null,this.handleChildrenChanged(),e}prependChildOfSameHeight(e){if(this._item3)throw new Error("Cannot prepend to a full (2,3) tree node");this.throwIfImmutable(),this._item3=this._item2,this._item2=this._item1,this._item1=e,this.handleChildrenChanged()}unprependChild(){if(!this._item3)throw new Error("Cannot remove from a non-full (2,3) tree node");this.throwIfImmutable();const e=this._item1;return this._item1=this._item2,this._item2=this._item3,this._item3=null,this.handleChildrenChanged(),e}toMutable(){return this}}class gle extends eb{toMutable(){return new eb(this.length,this.listHeight,this.item1,this.item2,this.item3,this.missingOpeningBracketIds)}throwIfImmutable(){throw new Error("this instance is immutable")}}class sy extends Yl{get childrenLength(){return this._children.length}getChild(e){return this._children[e]}setChild(e,t){this._children[e]=t}get children(){return this._children}constructor(e,t,i,n){super(e,t,n),this._children=i}deepClone(){const e=new Array(this._children.length);for(let t=0;t<this._children.length;t++)e[t]=this._children[t].deepClone();return new sy(this.length,this.listHeight,e,this.missingOpeningBracketIds)}appendChildOfSameHeight(e){this.throwIfImmutable(),this._children.push(e),this.handleChildrenChanged()}unappendChild(){this.throwIfImmutable();const e=this._children.pop();return this.handleChildrenChanged(),e}prependChildOfSameHeight(e){this.throwIfImmutable(),this._children.unshift(e),this.handleChildrenChanged()}unprependChild(){this.throwIfImmutable();const e=this._children.shift();return this.handleChildrenChanged(),e}toMutable(){return this}}class fle extends sy{toMutable(){return new sy(this.length,this.listHeight,[...this.children],this.missingOpeningBracketIds)}throwIfImmutable(){throw new Error("this instance is immutable")}}const ple=[];class RP extends MP{get listHeight(){return 0}get childrenLength(){return 0}getChild(e){return null}get children(){return ple}deepClone(){return this}}class qh extends RP{get kind(){return 0}get missingOpeningBracketIds(){return rn.getEmpty()}canBeReused(e){return!0}computeMinIndentation(e,t){const i=wr(e),n=(i.columnCount===0?i.lineCount:i.lineCount+1)+1,o=dle(ki(e,this.length))+1;let r=Number.MAX_SAFE_INTEGER;for(let a=n;a<=o;a++){const l=t.getLineFirstNonWhitespaceColumn(a),d=t.getLineContent(a);if(l===0)continue;const c=hn.visibleColumnFromColumn(d,l,t.getOptions().tabSize);r=Math.min(r,c)}return r}}class oy extends RP{static create(e,t,i){return new oy(e,t,i)}get kind(){return 1}get missingOpeningBracketIds(){return rn.getEmpty()}constructor(e,t,i){super(e),this.bracketInfo=t,this.bracketIds=i}get text(){return this.bracketInfo.bracketText}get languageId(){return this.bracketInfo.languageId}canBeReused(e){return!1}computeMinIndentation(e,t){return Number.MAX_SAFE_INTEGER}}class mle extends RP{get kind(){return 3}constructor(e,t){super(t),this.missingOpeningBracketIds=e}canBeReused(e){return!e.intersects(this.missingOpeningBracketIds)}computeMinIndentation(e,t){return Number.MAX_SAFE_INTEGER}}let Fc=class{constructor(e,t,i,n,o){this.length=e,this.kind=t,this.bracketId=i,this.bracketIds=n,this.astNode=o}};class KH{constructor(e,t){this.textModel=e,this.bracketTokens=t,this.reader=new _le(this.textModel,this.bracketTokens),this._offset=As,this.didPeek=!1,this.peeked=null,this.textBufferLineCount=e.getLineCount(),this.textBufferLastLineLength=e.getLineLength(this.textBufferLineCount)}get offset(){return this._offset}get length(){return Gi(this.textBufferLineCount-1,this.textBufferLastLineLength)}skip(e){this.didPeek=!1,this._offset=ki(this._offset,e);const t=wr(this._offset);this.reader.setPosition(t.lineCount,t.columnCount)}read(){let e;return this.peeked?(this.didPeek=!1,e=this.peeked):e=this.reader.read(),e&&(this._offset=ki(this._offset,e.length)),e}peek(){return this.didPeek||(this.peeked=this.reader.read(),this.didPeek=!0),this.peeked}}class _le{constructor(e,t){this.textModel=e,this.bracketTokens=t,this.lineIdx=0,this.line=null,this.lineCharOffset=0,this.lineTokens=null,this.lineTokenOffset=0,this.peekedToken=null,this.textBufferLineCount=e.getLineCount(),this.textBufferLastLineLength=e.getLineLength(this.textBufferLineCount)}setPosition(e,t){e===this.lineIdx?(this.lineCharOffset=t,this.line!==null&&(this.lineTokenOffset=this.lineCharOffset===0?0:this.lineTokens.findTokenIndexAtOffset(this.lineCharOffset))):(this.lineIdx=e,this.lineCharOffset=t,this.line=null),this.peekedToken=null}read(){if(this.peekedToken){const o=this.peekedToken;return this.peekedToken=null,this.lineCharOffset+=o.length,o}if(this.lineIdx>this.textBufferLineCount-1||this.lineIdx===this.textBufferLineCount-1&&this.lineCharOffset>=this.textBufferLastLineLength)return null;this.line===null&&(this.lineTokens=this.textModel.tokenization.getLineTokens(this.lineIdx+1),this.line=this.lineTokens.getLineContent(),this.lineTokenOffset=this.lineCharOffset===0?0:this.lineTokens.findTokenIndexAtOffset(this.lineCharOffset));const e=this.lineIdx,t=this.lineCharOffset;let i=0;for(;;){const o=this.lineTokens,r=o.getCount();let a=null;if(this.lineTokenOffset<r){const l=o.getMetadata(this.lineTokenOffset);for(;this.lineTokenOffset+1<r&&l===o.getMetadata(this.lineTokenOffset+1);)this.lineTokenOffset++;const d=Zn.getTokenType(l)===0,c=Zn.containsBalancedBrackets(l),u=o.getEndOffset(this.lineTokenOffset);if(c&&d&&this.lineCharOffset<u){const h=o.getLanguageId(this.lineTokenOffset),g=this.line.substring(this.lineCharOffset,u),f=this.bracketTokens.getSingleLanguageBracketTokens(h),m=f.regExpGlobal;if(m){m.lastIndex=0;const _=m.exec(g);_&&(a=f.getToken(_[0]),a&&(this.lineCharOffset+=_.index))}}if(i+=u-this.lineCharOffset,a)if(e!==this.lineIdx||t!==this.lineCharOffset){this.peekedToken=a;break}else return this.lineCharOffset+=a.length,a;else this.lineTokenOffset++,this.lineCharOffset=u}else if(this.lineIdx===this.textBufferLineCount-1||(this.lineIdx++,this.lineTokens=this.textModel.tokenization.getLineTokens(this.lineIdx+1),this.lineTokenOffset=0,this.line=this.lineTokens.getLineContent(),this.lineCharOffset=0,i+=33,i>1e3))break;if(i>1500)break}const n=lle(e,t,this.lineIdx,this.lineCharOffset);return new Fc(n,0,-1,rn.getEmpty(),new qh(n))}}class vle{constructor(e,t){this.text=e,this._offset=As,this.idx=0;const i=t.getRegExpStr(),n=i?new RegExp(i+`|
`,"gi"):null,o=[];let r,a=0,l=0,d=0,c=0;const u=[];for(let f=0;f<60;f++)u.push(new Fc(Gi(0,f),0,-1,rn.getEmpty(),new qh(Gi(0,f))));const h=[];for(let f=0;f<60;f++)h.push(new Fc(Gi(1,f),0,-1,rn.getEmpty(),new qh(Gi(1,f))));if(n)for(n.lastIndex=0;(r=n.exec(e))!==null;){const f=r.index,m=r[0];if(m===`
`)a++,l=f+1;else{if(d!==f){let _;if(c===a){const v=f-d;if(v<u.length)_=u[v];else{const b=Gi(0,v);_=new Fc(b,0,-1,rn.getEmpty(),new qh(b))}}else{const v=a-c,b=f-l;if(v===1&&b<h.length)_=h[b];else{const C=Gi(v,b);_=new Fc(C,0,-1,rn.getEmpty(),new qh(C))}}o.push(_)}o.push(t.getToken(m)),d=f+m.length,c=a}}const g=e.length;if(d!==g){const f=c===a?Gi(0,g-d):Gi(a-c,g-l);o.push(new Fc(f,0,-1,rn.getEmpty(),new qh(f)))}this.length=Gi(a,g-l),this.tokens=o}get offset(){return this._offset}read(){return this.tokens[this.idx++]||null}peek(){return this.tokens[this.idx]||null}skip(e){throw new pQ}}class AP{static createFromLanguage(e,t){function i(o){return t.getKey(`${o.languageId}:::${o.bracketText}`)}const n=new Map;for(const o of e.bracketsNew.openingBrackets){const r=Gi(0,o.bracketText.length),a=i(o),l=rn.getEmpty().add(a,J3);n.set(o.bracketText,new Fc(r,1,a,l,oy.create(r,o,l)))}for(const o of e.bracketsNew.closingBrackets){const r=Gi(0,o.bracketText.length);let a=rn.getEmpty();const l=o.getOpeningBrackets();for(const d of l)a=a.add(i(d),J3);n.set(o.bracketText,new Fc(r,2,i(l[0]),a,oy.create(r,o,a)))}return new AP(n)}constructor(e){this.map=e,this.hasRegExp=!1,this._regExpGlobal=null}getRegExpStr(){if(this.isEmpty)return null;{const e=[...this.map.keys()];return e.sort(),e.reverse(),e.map(t=>ble(t)).join("|")}}get regExpGlobal(){if(!this.hasRegExp){const e=this.getRegExpStr();this._regExpGlobal=e?new RegExp(e,"gi"):null,this.hasRegExp=!0}return this._regExpGlobal}getToken(e){return this.map.get(e.toLowerCase())}findClosingTokenText(e){for(const[t,i]of this.map)if(i.kind===2&&i.bracketIds.intersects(e))return t}get isEmpty(){return this.map.size===0}}function ble(s){let e=ir(s);return/^[\w ]+/.test(s)&&(e=`\\b${e}`),/[\w ]+$/.test(s)&&(e=`${e}\\b`),e}class qH{constructor(e,t){this.denseKeyProvider=e,this.getLanguageConfiguration=t,this.languageIdToBracketTokens=new Map}didLanguageChange(e){return this.languageIdToBracketTokens.has(e)}getSingleLanguageBracketTokens(e){let t=this.languageIdToBracketTokens.get(e);return t||(t=AP.createFromLanguage(this.getLanguageConfiguration(e),this.denseKeyProvider),this.languageIdToBracketTokens.set(e,t)),t}}function Cle(s){if(s.length===0)return null;if(s.length===1)return s[0];let e=0;function t(){if(e>=s.length)return null;const r=e,a=s[r].listHeight;for(e++;e<s.length&&s[e].listHeight===a;)e++;return e-r>=2?GH(r===0&&e===s.length?s:s.slice(r,e),!1):s[r]}let i=t(),n=t();if(!n)return i;for(let r=t();r;r=t())e7(i,n)<=e7(n,r)?(i=uI(i,n),n=r):n=uI(n,r);return uI(i,n)}function GH(s,e=!1){if(s.length===0)return null;if(s.length===1)return s[0];let t=s.length;for(;t>3;){const i=t>>1;for(let n=0;n<i;n++){const o=n<<1;s[n]=Yl.create23(s[o],s[o+1],o+3===t?s[o+2]:null,e)}t=i}return Yl.create23(s[0],s[1],t>=3?s[2]:null,e)}function e7(s,e){return Math.abs(s.listHeight-e.listHeight)}function uI(s,e){return s.listHeight===e.listHeight?Yl.create23(s,e,null,!1):s.listHeight>e.listHeight?wle(s,e):Sle(e,s)}function wle(s,e){s=s.toMutable();let t=s;const i=[];let n;for(;;){if(e.listHeight===t.listHeight){n=e;break}if(t.kind!==4)throw new Error("unexpected");i.push(t),t=t.makeLastElementMutable()}for(let o=i.length-1;o>=0;o--){const r=i[o];n?r.childrenLength>=3?n=Yl.create23(r.unappendChild(),n,null,!1):(r.appendChildOfSameHeight(n),n=void 0):r.handleChildrenChanged()}return n?Yl.create23(s,n,null,!1):s}function Sle(s,e){s=s.toMutable();let t=s;const i=[];for(;e.listHeight!==t.listHeight;){if(t.kind!==4)throw new Error("unexpected");i.push(t),t=t.makeFirstElementMutable()}let n=e;for(let o=i.length-1;o>=0;o--){const r=i[o];n?r.childrenLength>=3?n=Yl.create23(n,r.unprependChild(),null,!1):(r.prependChildOfSameHeight(n),n=void 0):r.handleChildrenChanged()}return n?Yl.create23(n,s,null,!1):s}class yle{constructor(e){this.lastOffset=As,this.nextNodes=[e],this.offsets=[As],this.idxs=[]}readLongestNodeAt(e,t){if(Up(e,this.lastOffset))throw new Error("Invalid offset");for(this.lastOffset=e;;){const i=B_(this.nextNodes);if(!i)return;const n=B_(this.offsets);if(Up(e,n))return;if(Up(n,e))if(ki(n,i.length)<=e)this.nextNodeAfterCurrent();else{const o=hI(i);o!==-1?(this.nextNodes.push(i.getChild(o)),this.offsets.push(n),this.idxs.push(o)):this.nextNodeAfterCurrent()}else{if(t(i))return this.nextNodeAfterCurrent(),i;{const o=hI(i);if(o===-1){this.nextNodeAfterCurrent();return}else this.nextNodes.push(i.getChild(o)),this.offsets.push(n),this.idxs.push(o)}}}}nextNodeAfterCurrent(){for(;;){const e=B_(this.offsets),t=B_(this.nextNodes);if(this.nextNodes.pop(),this.offsets.pop(),this.idxs.length===0)break;const i=B_(this.nextNodes),n=hI(i,this.idxs[this.idxs.length-1]);if(n!==-1){this.nextNodes.push(i.getChild(n)),this.offsets.push(ki(e,t.length)),this.idxs[this.idxs.length-1]=n;break}else this.idxs.pop()}}}function hI(s,e=-1){for(;;){if(e++,e>=s.childrenLength)return-1;if(s.getChild(e))return e}}function B_(s){return s.length>0?s[s.length-1]:void 0}function DT(s,e,t,i){return new Lle(s,e,t,i).parseDocument()}class Lle{constructor(e,t,i,n){if(this.tokenizer=e,this.createImmutableLists=n,this._itemsConstructed=0,this._itemsFromCache=0,i&&n)throw new Error("Not supported");this.oldNodeReader=i?new yle(i):void 0,this.positionMapper=new hle(t)}parseDocument(){this._itemsConstructed=0,this._itemsFromCache=0;let e=this.parseList(rn.getEmpty(),0);return e||(e=Yl.getEmpty()),e}parseList(e,t){const i=[];for(;;){let o=this.tryReadChildFromCache(e);if(!o){const r=this.tokenizer.peek();if(!r||r.kind===2&&r.bracketIds.intersects(e))break;o=this.parseChild(e,t+1)}o.kind===4&&o.childrenLength===0||i.push(o)}return this.oldNodeReader?Cle(i):GH(i,this.createImmutableLists)}tryReadChildFromCache(e){if(this.oldNodeReader){const t=this.positionMapper.getDistanceToNextChange(this.tokenizer.offset);if(t===null||!ny(t)){const i=this.oldNodeReader.readLongestNodeAt(this.positionMapper.getOffsetBeforeChange(this.tokenizer.offset),n=>t!==null&&!Up(n.length,t)?!1:n.canBeReused(e));if(i)return this._itemsFromCache++,this.tokenizer.skip(i.length),i}}}parseChild(e,t){this._itemsConstructed++;const i=this.tokenizer.read();switch(i.kind){case 2:return new mle(i.bracketIds,i.length);case 0:return i.astNode;case 1:{if(t>300)return new qh(i.length);const n=e.merge(i.bracketIds),o=this.parseList(n,t+1),r=this.tokenizer.peek();return r&&r.kind===2&&(r.bracketId===i.bracketId||r.bracketIds.intersects(i.bracketIds))?(this.tokenizer.read(),J0.create(i.astNode,o,r.astNode)):J0.create(i.astNode,o,null)}default:throw new Error("unexpected")}}}function ry(s,e){if(s.length===0)return e;if(e.length===0)return s;const t=new Qd(t7(s)),i=t7(e);i.push({modified:!1,lengthBefore:void 0,lengthAfter:void 0});let n=t.dequeue();function o(d){if(d===void 0){const u=t.takeWhile(h=>!0)||[];return n&&u.unshift(n),u}const c=[];for(;n&&!ny(d);){const[u,h]=n.splitAt(d);c.push(u),d=Q0(u.lengthAfter,d),n=h??t.dequeue()}return ny(d)||c.push(new qc(!1,d,d)),c}const r=[];function a(d,c,u){if(r.length>0&&$H(r[r.length-1].endOffset,d)){const h=r[r.length-1];r[r.length-1]=new Hd(h.startOffset,c,ki(h.newLength,u))}else r.push({startOffset:d,endOffset:c,newLength:u})}let l=As;for(const d of i){const c=o(d.lengthBefore);if(d.modified){const u=cle(c,g=>g.lengthBefore),h=ki(l,u);a(l,h,d.lengthAfter),l=h}else for(const u of c){const h=l;l=ki(l,u.lengthBefore),u.modified&&a(h,l,u.lengthAfter)}}return r}class qc{constructor(e,t,i){this.modified=e,this.lengthBefore=t,this.lengthAfter=i}splitAt(e){const t=Q0(e,this.lengthAfter);return $H(t,As)?[this,void 0]:this.modified?[new qc(this.modified,this.lengthBefore,e),new qc(this.modified,As,t)]:[new qc(this.modified,e,e),new qc(this.modified,t,t)]}toString(){return`${this.modified?"M":"U"}:${wr(this.lengthBefore)} -> ${wr(this.lengthAfter)}`}}function t7(s){const e=[];let t=As;for(const i of s){const n=Q0(t,i.startOffset);ny(n)||e.push(new qc(!1,n,n));const o=Q0(i.startOffset,i.endOffset);e.push(new qc(!0,o,i.newLength)),t=i.endOffset}return e}class xle extends j{didLanguageChange(e){return this.brackets.didLanguageChange(e)}constructor(e,t){if(super(),this.textModel=e,this.getLanguageConfiguration=t,this.didChangeEmitter=new W,this.denseKeyProvider=new jH,this.brackets=new qH(this.denseKeyProvider,this.getLanguageConfiguration),this.onDidChange=this.didChangeEmitter.event,this.queuedTextEditsForInitialAstWithoutTokens=[],this.queuedTextEdits=[],e.tokenization.hasTokens)e.tokenization.backgroundTokenizationState===2?(this.initialAstWithoutTokens=void 0,this.astWithTokens=this.parseDocumentFromTextBuffer([],void 0,!1)):(this.initialAstWithoutTokens=this.parseDocumentFromTextBuffer([],void 0,!0),this.astWithTokens=this.initialAstWithoutTokens);else{const i=this.brackets.getSingleLanguageBracketTokens(this.textModel.getLanguageId()),n=new vle(this.textModel.getValue(),i);this.initialAstWithoutTokens=DT(n,[],void 0,!0),this.astWithTokens=this.initialAstWithoutTokens}}handleDidChangeBackgroundTokenizationState(){if(this.textModel.tokenization.backgroundTokenizationState===2){const e=this.initialAstWithoutTokens===void 0;this.initialAstWithoutTokens=void 0,e||this.didChangeEmitter.fire()}}handleDidChangeTokens({ranges:e}){const t=e.map(i=>new Hd(Gi(i.fromLineNumber-1,0),Gi(i.toLineNumber,0),Gi(i.toLineNumber-i.fromLineNumber+1,0)));this.handleEdits(t,!0),this.initialAstWithoutTokens||this.didChangeEmitter.fire()}handleContentChanged(e){const t=Hd.fromModelContentChanges(e.changes);this.handleEdits(t,!1)}handleEdits(e,t){const i=ry(this.queuedTextEdits,e);this.queuedTextEdits=i,this.initialAstWithoutTokens&&!t&&(this.queuedTextEditsForInitialAstWithoutTokens=ry(this.queuedTextEditsForInitialAstWithoutTokens,e))}flushQueue(){this.queuedTextEdits.length>0&&(this.astWithTokens=this.parseDocumentFromTextBuffer(this.queuedTextEdits,this.astWithTokens,!1),this.queuedTextEdits=[]),this.queuedTextEditsForInitialAstWithoutTokens.length>0&&(this.initialAstWithoutTokens&&(this.initialAstWithoutTokens=this.parseDocumentFromTextBuffer(this.queuedTextEditsForInitialAstWithoutTokens,this.initialAstWithoutTokens,!1)),this.queuedTextEditsForInitialAstWithoutTokens=[])}parseDocumentFromTextBuffer(e,t,i){const n=t,o=new KH(this.textModel,this.brackets);return DT(o,e,n,i)}getBracketsInRange(e,t){this.flushQueue();const i=Gi(e.startLineNumber-1,e.startColumn-1),n=Gi(e.endLineNumber-1,e.endColumn-1);return new Fl(o=>{const r=this.initialAstWithoutTokens||this.astWithTokens;kT(r,As,r.length,i,n,o,0,0,new Map,t)})}getBracketPairsInRange(e,t){this.flushQueue();const i=mp(e.getStartPosition()),n=mp(e.getEndPosition());return new Fl(o=>{const r=this.initialAstWithoutTokens||this.astWithTokens,a=new Dle(o,t,this.textModel);IT(r,As,r.length,i,n,a,0,new Map)})}getFirstBracketAfter(e){this.flushQueue();const t=this.initialAstWithoutTokens||this.astWithTokens;return YH(t,As,t.length,mp(e))}getFirstBracketBefore(e){this.flushQueue();const t=this.initialAstWithoutTokens||this.astWithTokens;return ZH(t,As,t.length,mp(e))}}function ZH(s,e,t,i){if(s.kind===4||s.kind===2){const n=[];for(const o of s.children)t=ki(e,o.length),n.push({nodeOffsetStart:e,nodeOffsetEnd:t}),e=t;for(let o=n.length-1;o>=0;o--){const{nodeOffsetStart:r,nodeOffsetEnd:a}=n[o];if(Up(r,i)){const l=ZH(s.children[o],r,a,i);if(l)return l}}return null}else{if(s.kind===3)return null;if(s.kind===1){const n=_g(e,t);return{bracketInfo:s.bracketInfo,range:n}}}return null}function YH(s,e,t,i){if(s.kind===4||s.kind===2){for(const n of s.children){if(t=ki(e,n.length),Up(i,t)){const o=YH(n,e,t,i);if(o)return o}e=t}return null}else{if(s.kind===3)return null;if(s.kind===1){const n=_g(e,t);return{bracketInfo:s.bracketInfo,range:n}}}return null}function kT(s,e,t,i,n,o,r,a,l,d,c=!1){if(r>200)return!0;e:for(;;)switch(s.kind){case 4:{const u=s.childrenLength;for(let h=0;h<u;h++){const g=s.getChild(h);if(g){if(t=ki(e,g.length),$p(e,n)&&fv(t,i)){if(fv(t,n)){s=g;continue e}if(!kT(g,e,t,i,n,o,r,0,l,d))return!1}e=t}}return!0}case 2:{const u=!d||!s.closingBracket||s.closingBracket.bracketInfo.closesColorized(s.openingBracket.bracketInfo);let h=0;if(l){let f=l.get(s.openingBracket.text);f===void 0&&(f=0),h=f,u&&(f++,l.set(s.openingBracket.text,f))}const g=s.childrenLength;for(let f=0;f<g;f++){const m=s.getChild(f);if(m){if(t=ki(e,m.length),$p(e,n)&&fv(t,i)){if(fv(t,n)&&m.kind!==1){s=m,u?(r++,a=h+1):a=h;continue e}if((u||m.kind!==1||!s.closingBracket)&&!kT(m,e,t,i,n,o,u?r+1:r,u?h+1:h,l,d,!s.closingBracket))return!1}e=t}}return l==null||l.set(s.openingBracket.text,h),!0}case 3:{const u=_g(e,t);return o(new Q3(u,r-1,0,!0))}case 1:{const u=_g(e,t);return o(new Q3(u,r-1,a-1,c))}case 0:return!0}}class Dle{constructor(e,t,i){this.push=e,this.includeMinIndentation=t,this.textModel=i}}function IT(s,e,t,i,n,o,r,a){var l;if(r>200)return!0;let d=!0;if(s.kind===2){let c=0;if(a){let g=a.get(s.openingBracket.text);g===void 0&&(g=0),c=g,g++,a.set(s.openingBracket.text,g)}const u=ki(e,s.openingBracket.length);let h=-1;if(o.includeMinIndentation&&(h=s.computeMinIndentation(e,o.textModel)),d=o.push(new ale(_g(e,t),_g(e,u),s.closingBracket?_g(ki(u,((l=s.child)===null||l===void 0?void 0:l.length)||As),t):void 0,r,c,s,h)),e=u,d&&s.child){const g=s.child;if(t=ki(e,g.length),$p(e,n)&&fv(t,i)&&(d=IT(g,e,t,i,n,o,r+1,a),!d))return!1}a==null||a.set(s.openingBracket.text,c)}else{let c=e;for(const u of s.children){const h=c;if(c=ki(c,u.length),$p(h,n)&&$p(i,c)&&(d=IT(u,h,c,i,n,o,r,a),!d))return!1}}return d}class kle extends j{get canBuildAST(){return this.textModel.getValueLength()<=5e6}constructor(e,t){super(),this.textModel=e,this.languageConfigurationService=t,this.bracketPairsTree=this._register(new En),this.onDidChangeEmitter=new W,this.onDidChange=this.onDidChangeEmitter.event,this.bracketsRequested=!1,this._register(this.languageConfigurationService.onDidChange(i=>{var n;(!i.languageId||!((n=this.bracketPairsTree.value)===null||n===void 0)&&n.object.didLanguageChange(i.languageId))&&(this.bracketPairsTree.clear(),this.updateBracketPairsTree())}))}handleDidChangeOptions(e){this.bracketPairsTree.clear(),this.updateBracketPairsTree()}handleDidChangeLanguage(e){this.bracketPairsTree.clear(),this.updateBracketPairsTree()}handleDidChangeContent(e){var t;(t=this.bracketPairsTree.value)===null||t===void 0||t.object.handleContentChanged(e)}handleDidChangeBackgroundTokenizationState(){var e;(e=this.bracketPairsTree.value)===null||e===void 0||e.object.handleDidChangeBackgroundTokenizationState()}handleDidChangeTokens(e){var t;(t=this.bracketPairsTree.value)===null||t===void 0||t.object.handleDidChangeTokens(e)}updateBracketPairsTree(){if(this.bracketsRequested&&this.canBuildAST){if(!this.bracketPairsTree.value){const e=new ie;this.bracketPairsTree.value=Ile(e.add(new xle(this.textModel,t=>this.languageConfigurationService.getLanguageConfiguration(t))),e),e.add(this.bracketPairsTree.value.object.onDidChange(t=>this.onDidChangeEmitter.fire(t))),this.onDidChangeEmitter.fire()}}else this.bracketPairsTree.value&&(this.bracketPairsTree.clear(),this.onDidChangeEmitter.fire())}getBracketPairsInRange(e){var t;return this.bracketsRequested=!0,this.updateBracketPairsTree(),((t=this.bracketPairsTree.value)===null||t===void 0?void 0:t.object.getBracketPairsInRange(e,!1))||Fl.empty}getBracketPairsInRangeWithMinIndentation(e){var t;return this.bracketsRequested=!0,this.updateBracketPairsTree(),((t=this.bracketPairsTree.value)===null||t===void 0?void 0:t.object.getBracketPairsInRange(e,!0))||Fl.empty}getBracketsInRange(e,t=!1){var i;return this.bracketsRequested=!0,this.updateBracketPairsTree(),((i=this.bracketPairsTree.value)===null||i===void 0?void 0:i.object.getBracketsInRange(e,t))||Fl.empty}findMatchingBracketUp(e,t,i){const n=this.textModel.validatePosition(t),o=this.textModel.getLanguageIdAtPosition(n.lineNumber,n.column);if(this.canBuildAST){const r=this.languageConfigurationService.getLanguageConfiguration(o).bracketsNew.getClosingBracketInfo(e);if(!r)return null;const a=this.getBracketPairsInRange(D.fromPositions(t,t)).findLast(l=>r.closes(l.openingBracketInfo));return a?a.openingBracketRange:null}else{const r=e.toLowerCase(),a=this.languageConfigurationService.getLanguageConfiguration(o).brackets;if(!a)return null;const l=a.textIsBracket[r];return l?S1(this._findMatchingBracketUp(l,n,gI(i))):null}}matchBracket(e,t){if(this.canBuildAST){const i=this.getBracketPairsInRange(D.fromPositions(e,e)).filter(n=>n.closingBracketRange!==void 0&&(n.openingBracketRange.containsPosition(e)||n.closingBracketRange.containsPosition(e))).findLastMaxBy(br(n=>n.openingBracketRange.containsPosition(e)?n.openingBracketRange:n.closingBracketRange,D.compareRangesUsingStarts));return i?[i.openingBracketRange,i.closingBracketRange]:null}else{const i=gI(t);return this._matchBracket(this.textModel.validatePosition(e),i)}}_establishBracketSearchOffsets(e,t,i,n){const o=t.getCount(),r=t.getLanguageId(n);let a=Math.max(0,e.column-1-i.maxBracketLength);for(let d=n-1;d>=0;d--){const c=t.getEndOffset(d);if(c<=a)break;if(ol(t.getStandardTokenType(d))||t.getLanguageId(d)!==r){a=c;break}}let l=Math.min(t.getLineContent().length,e.column-1+i.maxBracketLength);for(let d=n+1;d<o;d++){const c=t.getStartOffset(d);if(c>=l)break;if(ol(t.getStandardTokenType(d))||t.getLanguageId(d)!==r){l=c;break}}return{searchStartOffset:a,searchEndOffset:l}}_matchBracket(e,t){const i=e.lineNumber,n=this.textModel.tokenization.getLineTokens(i),o=this.textModel.getLineContent(i),r=n.findTokenIndexAtOffset(e.column-1);if(r<0)return null;const a=this.languageConfigurationService.getLanguageConfiguration(n.getLanguageId(r)).brackets;if(a&&!ol(n.getStandardTokenType(r))){let{searchStartOffset:l,searchEndOffset:d}=this._establishBracketSearchOffsets(e,n,a,r),c=null;for(;;){const u=Or.findNextBracketInRange(a.forwardRegex,i,o,l,d);if(!u)break;if(u.startColumn<=e.column&&e.column<=u.endColumn){const h=o.substring(u.startColumn-1,u.endColumn-1).toLowerCase(),g=this._matchFoundBracket(u,a.textIsBracket[h],a.textIsOpenBracket[h],t);if(g){if(g instanceof Ld)return null;c=g}}l=u.endColumn-1}if(c)return c}if(r>0&&n.getStartOffset(r)===e.column-1){const l=r-1,d=this.languageConfigurationService.getLanguageConfiguration(n.getLanguageId(l)).brackets;if(d&&!ol(n.getStandardTokenType(l))){const{searchStartOffset:c,searchEndOffset:u}=this._establishBracketSearchOffsets(e,n,d,l),h=Or.findPrevBracketInRange(d.reversedRegex,i,o,c,u);if(h&&h.startColumn<=e.column&&e.column<=h.endColumn){const g=o.substring(h.startColumn-1,h.endColumn-1).toLowerCase(),f=this._matchFoundBracket(h,d.textIsBracket[g],d.textIsOpenBracket[g],t);if(f)return f instanceof Ld?null:f}}}return null}_matchFoundBracket(e,t,i,n){if(!t)return null;const o=i?this._findMatchingBracketDown(t,e.getEndPosition(),n):this._findMatchingBracketUp(t,e.getStartPosition(),n);return o?o instanceof Ld?o:[e,o]:null}_findMatchingBracketUp(e,t,i){const n=e.languageId,o=e.reversedRegex;let r=-1,a=0;const l=(d,c,u,h)=>{for(;;){if(i&&++a%100===0&&!i())return Ld.INSTANCE;const g=Or.findPrevBracketInRange(o,d,c,u,h);if(!g)break;const f=c.substring(g.startColumn-1,g.endColumn-1).toLowerCase();if(e.isOpen(f)?r++:e.isClose(f)&&r--,r===0)return g;h=g.startColumn-1}return null};for(let d=t.lineNumber;d>=1;d--){const c=this.textModel.tokenization.getLineTokens(d),u=c.getCount(),h=this.textModel.getLineContent(d);let g=u-1,f=h.length,m=h.length;d===t.lineNumber&&(g=c.findTokenIndexAtOffset(t.column-1),f=t.column-1,m=t.column-1);let _=!0;for(;g>=0;g--){const v=c.getLanguageId(g)===n&&!ol(c.getStandardTokenType(g));if(v)_?f=c.getStartOffset(g):(f=c.getStartOffset(g),m=c.getEndOffset(g));else if(_&&f!==m){const b=l(d,h,f,m);if(b)return b}_=v}if(_&&f!==m){const v=l(d,h,f,m);if(v)return v}}return null}_findMatchingBracketDown(e,t,i){const n=e.languageId,o=e.forwardRegex;let r=1,a=0;const l=(c,u,h,g)=>{for(;;){if(i&&++a%100===0&&!i())return Ld.INSTANCE;const f=Or.findNextBracketInRange(o,c,u,h,g);if(!f)break;const m=u.substring(f.startColumn-1,f.endColumn-1).toLowerCase();if(e.isOpen(m)?r++:e.isClose(m)&&r--,r===0)return f;h=f.endColumn-1}return null},d=this.textModel.getLineCount();for(let c=t.lineNumber;c<=d;c++){const u=this.textModel.tokenization.getLineTokens(c),h=u.getCount(),g=this.textModel.getLineContent(c);let f=0,m=0,_=0;c===t.lineNumber&&(f=u.findTokenIndexAtOffset(t.column-1),m=t.column-1,_=t.column-1);let v=!0;for(;f<h;f++){const b=u.getLanguageId(f)===n&&!ol(u.getStandardTokenType(f));if(b)v||(m=u.getStartOffset(f)),_=u.getEndOffset(f);else if(v&&m!==_){const C=l(c,g,m,_);if(C)return C}v=b}if(v&&m!==_){const b=l(c,g,m,_);if(b)return b}}return null}findPrevBracket(e){var t;const i=this.textModel.validatePosition(e);if(this.canBuildAST)return this.bracketsRequested=!0,this.updateBracketPairsTree(),((t=this.bracketPairsTree.value)===null||t===void 0?void 0:t.object.getFirstBracketBefore(i))||null;let n=null,o=null,r=null;for(let a=i.lineNumber;a>=1;a--){const l=this.textModel.tokenization.getLineTokens(a),d=l.getCount(),c=this.textModel.getLineContent(a);let u=d-1,h=c.length,g=c.length;if(a===i.lineNumber){u=l.findTokenIndexAtOffset(i.column-1),h=i.column-1,g=i.column-1;const m=l.getLanguageId(u);n!==m&&(n=m,o=this.languageConfigurationService.getLanguageConfiguration(n).brackets,r=this.languageConfigurationService.getLanguageConfiguration(n).bracketsNew)}let f=!0;for(;u>=0;u--){const m=l.getLanguageId(u);if(n!==m){if(o&&r&&f&&h!==g){const v=Or.findPrevBracketInRange(o.reversedRegex,a,c,h,g);if(v)return this._toFoundBracket(r,v);f=!1}n=m,o=this.languageConfigurationService.getLanguageConfiguration(n).brackets,r=this.languageConfigurationService.getLanguageConfiguration(n).bracketsNew}const _=!!o&&!ol(l.getStandardTokenType(u));if(_)f?h=l.getStartOffset(u):(h=l.getStartOffset(u),g=l.getEndOffset(u));else if(r&&o&&f&&h!==g){const v=Or.findPrevBracketInRange(o.reversedRegex,a,c,h,g);if(v)return this._toFoundBracket(r,v)}f=_}if(r&&o&&f&&h!==g){const m=Or.findPrevBracketInRange(o.reversedRegex,a,c,h,g);if(m)return this._toFoundBracket(r,m)}}return null}findNextBracket(e){var t;const i=this.textModel.validatePosition(e);if(this.canBuildAST)return this.bracketsRequested=!0,this.updateBracketPairsTree(),((t=this.bracketPairsTree.value)===null||t===void 0?void 0:t.object.getFirstBracketAfter(i))||null;const n=this.textModel.getLineCount();let o=null,r=null,a=null;for(let l=i.lineNumber;l<=n;l++){const d=this.textModel.tokenization.getLineTokens(l),c=d.getCount(),u=this.textModel.getLineContent(l);let h=0,g=0,f=0;if(l===i.lineNumber){h=d.findTokenIndexAtOffset(i.column-1),g=i.column-1,f=i.column-1;const _=d.getLanguageId(h);o!==_&&(o=_,r=this.languageConfigurationService.getLanguageConfiguration(o).brackets,a=this.languageConfigurationService.getLanguageConfiguration(o).bracketsNew)}let m=!0;for(;h<c;h++){const _=d.getLanguageId(h);if(o!==_){if(a&&r&&m&&g!==f){const b=Or.findNextBracketInRange(r.forwardRegex,l,u,g,f);if(b)return this._toFoundBracket(a,b);m=!1}o=_,r=this.languageConfigurationService.getLanguageConfiguration(o).brackets,a=this.languageConfigurationService.getLanguageConfiguration(o).bracketsNew}const v=!!r&&!ol(d.getStandardTokenType(h));if(v)m||(g=d.getStartOffset(h)),f=d.getEndOffset(h);else if(a&&r&&m&&g!==f){const b=Or.findNextBracketInRange(r.forwardRegex,l,u,g,f);if(b)return this._toFoundBracket(a,b)}m=v}if(a&&r&&m&&g!==f){const _=Or.findNextBracketInRange(r.forwardRegex,l,u,g,f);if(_)return this._toFoundBracket(a,_)}}return null}findEnclosingBrackets(e,t){const i=this.textModel.validatePosition(e);if(this.canBuildAST){const g=D.fromPositions(i),f=this.getBracketPairsInRange(D.fromPositions(i,i)).findLast(m=>m.closingBracketRange!==void 0&&m.range.strictContainsRange(g));return f?[f.openingBracketRange,f.closingBracketRange]:null}const n=gI(t),o=this.textModel.getLineCount(),r=new Map;let a=[];const l=(g,f)=>{if(!r.has(g)){const m=[];for(let _=0,v=f?f.brackets.length:0;_<v;_++)m[_]=0;r.set(g,m)}a=r.get(g)};let d=0;const c=(g,f,m,_,v)=>{for(;;){if(n&&++d%100===0&&!n())return Ld.INSTANCE;const b=Or.findNextBracketInRange(g.forwardRegex,f,m,_,v);if(!b)break;const C=m.substring(b.startColumn-1,b.endColumn-1).toLowerCase(),w=g.textIsBracket[C];if(w&&(w.isOpen(C)?a[w.index]++:w.isClose(C)&&a[w.index]--,a[w.index]===-1))return this._matchFoundBracket(b,w,!1,n);_=b.endColumn-1}return null};let u=null,h=null;for(let g=i.lineNumber;g<=o;g++){const f=this.textModel.tokenization.getLineTokens(g),m=f.getCount(),_=this.textModel.getLineContent(g);let v=0,b=0,C=0;if(g===i.lineNumber){v=f.findTokenIndexAtOffset(i.column-1),b=i.column-1,C=i.column-1;const S=f.getLanguageId(v);u!==S&&(u=S,h=this.languageConfigurationService.getLanguageConfiguration(u).brackets,l(u,h))}let w=!0;for(;v<m;v++){const S=f.getLanguageId(v);if(u!==S){if(h&&w&&b!==C){const L=c(h,g,_,b,C);if(L)return S1(L);w=!1}u=S,h=this.languageConfigurationService.getLanguageConfiguration(u).brackets,l(u,h)}const x=!!h&&!ol(f.getStandardTokenType(v));if(x)w||(b=f.getStartOffset(v)),C=f.getEndOffset(v);else if(h&&w&&b!==C){const L=c(h,g,_,b,C);if(L)return S1(L)}w=x}if(h&&w&&b!==C){const S=c(h,g,_,b,C);if(S)return S1(S)}}return null}_toFoundBracket(e,t){if(!t)return null;let i=this.textModel.getValueInRange(t);i=i.toLowerCase();const n=e.getBracketInfo(i);return n?{range:t,bracketInfo:n}:null}}function Ile(s,e){return{object:s,dispose:()=>e==null?void 0:e.dispose()}}function gI(s){if(typeof s>"u")return()=>!0;{const e=Date.now();return()=>Date.now()-e<=s}}class Ld{constructor(){this._searchCanceledBrand=void 0}}Ld.INSTANCE=new Ld;function S1(s){return s instanceof Ld?null:s}class Ele extends j{constructor(e){super(),this.textModel=e,this.colorProvider=new XH,this.onDidChangeEmitter=new W,this.onDidChange=this.onDidChangeEmitter.event,this.colorizationOptions=e.getOptions().bracketPairColorizationOptions,this._register(e.bracketPairs.onDidChange(t=>{this.onDidChangeEmitter.fire()}))}handleDidChangeOptions(e){this.colorizationOptions=this.textModel.getOptions().bracketPairColorizationOptions}getDecorationsInRange(e,t,i,n){return n?[]:t===void 0?[]:this.colorizationOptions.enabled?this.textModel.bracketPairs.getBracketsInRange(e,!0).map(r=>({id:`bracket${r.range.toString()}-${r.nestingLevel}`,options:{description:"BracketPairColorization",inlineClassName:this.colorProvider.getInlineClassName(r,this.colorizationOptions.independentColorPoolPerBracketType)},ownerId:0,range:r.range})).toArray():[]}getAllDecorations(e,t){return e===void 0?[]:this.colorizationOptions.enabled?this.getDecorationsInRange(new D(1,1,this.textModel.getLineCount(),1),e,t):[]}}class XH{constructor(){this.unexpectedClosingBracketClassName="unexpected-closing-bracket"}getInlineClassName(e,t){return e.isInvalid?this.unexpectedClosingBracketClassName:this.getInlineClassNameOfLevel(t?e.nestingLevelOfEqualBracketType:e.nestingLevel)}getInlineClassNameOfLevel(e){return`bracket-highlighting-${e%30}`}}ia((s,e)=>{const t=[DH,kH,IH,EH,NH,TH],i=new XH;e.addRule(`.monaco-editor .${i.unexpectedClosingBracketClassName} { color: ${s.getColor(Rre)}; }`);const n=t.map(o=>s.getColor(o)).filter(o=>!!o).filter(o=>!o.isTransparent());for(let o=0;o<30;o++){const r=n[o%n.length];e.addRule(`.monaco-editor .${i.getInlineClassNameOfLevel(o)} { color: ${r}; }`)}});function y1(s){return s.replace(/\n/g,"\\n").replace(/\r/g,"\\r")}class qn{get oldLength(){return this.oldText.length}get oldEnd(){return this.oldPosition+this.oldText.length}get newLength(){return this.newText.length}get newEnd(){return this.newPosition+this.newText.length}constructor(e,t,i,n){this.oldPosition=e,this.oldText=t,this.newPosition=i,this.newText=n}toString(){return this.oldText.length===0?`(insert@${this.oldPosition} "${y1(this.newText)}")`:this.newText.length===0?`(delete@${this.oldPosition} "${y1(this.oldText)}")`:`(replace@${this.oldPosition} "${y1(this.oldText)}" with "${y1(this.newText)}")`}static _writeStringSize(e){return 4+2*e.length}static _writeString(e,t,i){const n=t.length;pa(e,n,i),i+=4;for(let o=0;o<n;o++)yte(e,t.charCodeAt(o),i),i+=2;return i}static _readString(e,t){const i=fa(e,t);return t+=4,xte(e,t,i)}writeSize(){return 8+qn._writeStringSize(this.oldText)+qn._writeStringSize(this.newText)}write(e,t){return pa(e,this.oldPosition,t),t+=4,pa(e,this.newPosition,t),t+=4,t=qn._writeString(e,this.oldText,t),t=qn._writeString(e,this.newText,t),t}static read(e,t,i){const n=fa(e,t);t+=4;const o=fa(e,t);t+=4;const r=qn._readString(e,t);t+=qn._writeStringSize(r);const a=qn._readString(e,t);return t+=qn._writeStringSize(a),i.push(new qn(n,r,o,a)),t}}function Nle(s,e){return s===null||s.length===0?e:new ll(s,e).compress()}class ll{constructor(e,t){this._prevEdits=e,this._currEdits=t,this._result=[],this._resultLen=0,this._prevLen=this._prevEdits.length,this._prevDeltaOffset=0,this._currLen=this._currEdits.length,this._currDeltaOffset=0}compress(){let e=0,t=0,i=this._getPrev(e),n=this._getCurr(t);for(;e<this._prevLen||t<this._currLen;){if(i===null){this._acceptCurr(n),n=this._getCurr(++t);continue}if(n===null){this._acceptPrev(i),i=this._getPrev(++e);continue}if(n.oldEnd<=i.newPosition){this._acceptCurr(n),n=this._getCurr(++t);continue}if(i.newEnd<=n.oldPosition){this._acceptPrev(i),i=this._getPrev(++e);continue}if(n.oldPosition<i.newPosition){const[d,c]=ll._splitCurr(n,i.newPosition-n.oldPosition);this._acceptCurr(d),n=c;continue}if(i.newPosition<n.oldPosition){const[d,c]=ll._splitPrev(i,n.oldPosition-i.newPosition);this._acceptPrev(d),i=c;continue}let a,l;if(n.oldEnd===i.newEnd)a=i,l=n,i=this._getPrev(++e),n=this._getCurr(++t);else if(n.oldEnd<i.newEnd){const[d,c]=ll._splitPrev(i,n.oldLength);a=d,l=n,i=c,n=this._getCurr(++t)}else{const[d,c]=ll._splitCurr(n,i.newLength);a=i,l=d,i=this._getPrev(++e),n=c}this._result[this._resultLen++]=new qn(a.oldPosition,a.oldText,l.newPosition,l.newText),this._prevDeltaOffset+=a.newLength-a.oldLength,this._currDeltaOffset+=l.newLength-l.oldLength}const o=ll._merge(this._result);return ll._removeNoOps(o)}_acceptCurr(e){this._result[this._resultLen++]=ll._rebaseCurr(this._prevDeltaOffset,e),this._currDeltaOffset+=e.newLength-e.oldLength}_getCurr(e){return e<this._currLen?this._currEdits[e]:null}_acceptPrev(e){this._result[this._resultLen++]=ll._rebasePrev(this._currDeltaOffset,e),this._prevDeltaOffset+=e.newLength-e.oldLength}_getPrev(e){return e<this._prevLen?this._prevEdits[e]:null}static _rebaseCurr(e,t){return new qn(t.oldPosition-e,t.oldText,t.newPosition,t.newText)}static _rebasePrev(e,t){return new qn(t.oldPosition,t.oldText,t.newPosition+e,t.newText)}static _splitPrev(e,t){const i=e.newText.substr(0,t),n=e.newText.substr(t);return[new qn(e.oldPosition,e.oldText,e.newPosition,i),new qn(e.oldEnd,"",e.newPosition+t,n)]}static _splitCurr(e,t){const i=e.oldText.substr(0,t),n=e.oldText.substr(t);return[new qn(e.oldPosition,i,e.newPosition,e.newText),new qn(e.oldPosition+t,n,e.newEnd,"")]}static _merge(e){if(e.length===0)return e;const t=[];let i=0,n=e[0];for(let o=1;o<e.length;o++){const r=e[o];n.oldEnd===r.oldPosition?n=new qn(n.oldPosition,n.oldText+r.oldText,n.newPosition,n.newText+r.newText):(t[i++]=n,n=r)}return t[i++]=n,t}static _removeNoOps(e){if(e.length===0)return e;const t=[];let i=0;for(let n=0;n<e.length;n++){const o=e[n];o.oldText!==o.newText&&(t[i++]=o)}return t}}function mc(s){return s===47||s===92}function QH(s){return s.replace(/[\\/]/g,an.sep)}function Tle(s){return s.indexOf("/")===-1&&(s=QH(s)),/^[a-zA-Z]:(\/|$)/.test(s)&&(s="/"+s),s}function i7(s,e=an.sep){if(!s)return"";const t=s.length,i=s.charCodeAt(0);if(mc(i)){if(mc(s.charCodeAt(1))&&!mc(s.charCodeAt(2))){let o=3;const r=o;for(;o<t&&!mc(s.charCodeAt(o));o++);if(r!==o&&!mc(s.charCodeAt(o+1))){for(o+=1;o<t;o++)if(mc(s.charCodeAt(o)))return s.slice(0,o+1).replace(/[\\/]/g,e)}}return e}else if(JH(i)&&s.charCodeAt(1)===58)return mc(s.charCodeAt(2))?s.slice(0,2)+e:s.slice(0,2);let n=s.indexOf("://");if(n!==-1){for(n+=3;n<t;n++)if(mc(s.charCodeAt(n)))return s.slice(0,n+1)}return""}function ET(s,e,t,i=Aa){if(s===e)return!0;if(!s||!e||e.length>s.length)return!1;if(t){if(!FA(s,e))return!1;if(e.length===s.length)return!0;let o=e.length;return e.charAt(e.length-1)===i&&o--,s.charAt(o)===i}return e.charAt(e.length-1)!==i&&(e+=i),s.indexOf(e)===0}function JH(s){return s>=65&&s<=90||s>=97&&s<=122}function Mle(s,e=es){return e?JH(s.charCodeAt(0))&&s.charCodeAt(1)===58:!1}function rl(s){return ES(s,!0)}class Rle{constructor(e){this._ignorePathCasing=e}compare(e,t,i=!1){return e===t?0:x0(this.getComparisonKey(e,i),this.getComparisonKey(t,i))}isEqual(e,t,i=!1){return e===t?!0:!e||!t?!1:this.getComparisonKey(e,i)===this.getComparisonKey(t,i)}getComparisonKey(e,t=!1){return e.with({path:this._ignorePathCasing(e)?e.path.toLowerCase():void 0,fragment:t?null:void 0}).toString()}isEqualOrParent(e,t,i=!1){if(e.scheme===t.scheme){if(e.scheme===it.file)return ET(rl(e),rl(t),this._ignorePathCasing(e))&&e.query===t.query&&(i||e.fragment===t.fragment);if(s7(e.authority,t.authority))return ET(e.path,t.path,this._ignorePathCasing(e),"/")&&e.query===t.query&&(i||e.fragment===t.fragment)}return!1}joinPath(e,...t){return Pe.joinPath(e,...t)}basenameOrAuthority(e){return kr(e)||e.authority}basename(e){return an.basename(e.path)}extname(e){return an.extname(e.path)}dirname(e){if(e.path.length===0)return e;let t;return e.scheme===it.file?t=Pe.file(RW(rl(e))).path:(t=an.dirname(e.path),e.authority&&t.length&&t.charCodeAt(0)!==47&&(console.error(`dirname("${e.toString})) resulted in a relative path`),t="/")),e.with({path:t})}normalizePath(e){if(!e.path.length)return e;let t;return e.scheme===it.file?t=Pe.file(MW(rl(e))).path:t=an.normalize(e.path),e.with({path:t})}relativePath(e,t){if(e.scheme!==t.scheme||!s7(e.authority,t.authority))return;if(e.scheme===it.file){const o=OQ(rl(e),rl(t));return es?QH(o):o}let i=e.path||"/";const n=t.path||"/";if(this._ignorePathCasing(e)){let o=0;for(const r=Math.min(i.length,n.length);o<r&&!(i.charCodeAt(o)!==n.charCodeAt(o)&&i.charAt(o).toLowerCase()!==n.charAt(o).toLowerCase());o++);i=n.substr(0,o)+i.substr(o)}return an.relative(i,n)}resolvePath(e,t){if(e.scheme===it.file){const i=Pe.file(PQ(rl(e),t));return e.with({authority:i.authority,path:i.path})}return t=Tle(t),e.with({path:an.resolve(e.path,t)})}isAbsolutePath(e){return!!e.path&&e.path[0]==="/"}isEqualAuthority(e,t){return e===t||e!==void 0&&t!==void 0&&np(e,t)}hasTrailingPathSeparator(e,t=Aa){if(e.scheme===it.file){const i=rl(e);return i.length>i7(i).length&&i[i.length-1]===t}else{const i=e.path;return i.length>1&&i.charCodeAt(i.length-1)===47&&!/^[a-zA-Z]:(\/$|\\$)/.test(e.fsPath)}}removeTrailingPathSeparator(e,t=Aa){return o7(e,t)?e.with({path:e.path.substr(0,e.path.length-1)}):e}addTrailingPathSeparator(e,t=Aa){let i=!1;if(e.scheme===it.file){const n=rl(e);i=n!==void 0&&n.length===i7(n).length&&n[n.length-1]===t}else{t="/";const n=e.path;i=n.length===1&&n.charCodeAt(n.length-1)===47}return!i&&!o7(e,t)?e.with({path:e.path+"/"}):e}}const li=new Rle(()=>!1),PP=li.isEqual.bind(li);li.isEqualOrParent.bind(li);li.getComparisonKey.bind(li);const Ale=li.basenameOrAuthority.bind(li),kr=li.basename.bind(li),Ple=li.extname.bind(li),Tx=li.dirname.bind(li),Ole=li.joinPath.bind(li),Fle=li.normalizePath.bind(li),Ble=li.relativePath.bind(li),n7=li.resolvePath.bind(li);li.isAbsolutePath.bind(li);const s7=li.isEqualAuthority.bind(li),o7=li.hasTrailingPathSeparator.bind(li);li.removeTrailingPathSeparator.bind(li);li.addTrailingPathSeparator.bind(li);var Fu;(function(s){s.META_DATA_LABEL="label",s.META_DATA_DESCRIPTION="description",s.META_DATA_SIZE="size",s.META_DATA_MIME="mime";function e(t){const i=new Map;t.path.substring(t.path.indexOf(";")+1,t.path.lastIndexOf(";")).split(";").forEach(r=>{const[a,l]=r.split(":");a&&l&&i.set(a,l)});const o=t.path.substring(0,t.path.indexOf(";"));return o&&i.set(s.META_DATA_MIME,o),i}s.parseMetaData=e})(Fu||(Fu={}));function Tf(s){return s.toString()}class yn{static create(e,t){const i=e.getAlternativeVersionId(),n=NT(e);return new yn(i,i,n,n,t,t,[])}constructor(e,t,i,n,o,r,a){this.beforeVersionId=e,this.afterVersionId=t,this.beforeEOL=i,this.afterEOL=n,this.beforeCursorState=o,this.afterCursorState=r,this.changes=a}append(e,t,i,n,o){t.length>0&&(this.changes=Nle(this.changes,t)),this.afterEOL=i,this.afterVersionId=n,this.afterCursorState=o}static _writeSelectionsSize(e){return 4+4*4*(e?e.length:0)}static _writeSelections(e,t,i){if(pa(e,t?t.length:0,i),i+=4,t)for(const n of t)pa(e,n.selectionStartLineNumber,i),i+=4,pa(e,n.selectionStartColumn,i),i+=4,pa(e,n.positionLineNumber,i),i+=4,pa(e,n.positionColumn,i),i+=4;return i}static _readSelections(e,t,i){const n=fa(e,t);t+=4;for(let o=0;o<n;o++){const r=fa(e,t);t+=4;const a=fa(e,t);t+=4;const l=fa(e,t);t+=4;const d=fa(e,t);t+=4,i.push(new De(r,a,l,d))}return t}serialize(){let e=10+yn._writeSelectionsSize(this.beforeCursorState)+yn._writeSelectionsSize(this.afterCursorState)+4;for(const n of this.changes)e+=n.writeSize();const t=new Uint8Array(e);let i=0;pa(t,this.beforeVersionId,i),i+=4,pa(t,this.afterVersionId,i),i+=4,A5(t,this.beforeEOL,i),i+=1,A5(t,this.afterEOL,i),i+=1,i=yn._writeSelections(t,this.beforeCursorState,i),i=yn._writeSelections(t,this.afterCursorState,i),pa(t,this.changes.length,i),i+=4;for(const n of this.changes)i=n.write(t,i);return t.buffer}static deserialize(e){const t=new Uint8Array(e);let i=0;const n=fa(t,i);i+=4;const o=fa(t,i);i+=4;const r=R5(t,i);i+=1;const a=R5(t,i);i+=1;const l=[];i=yn._readSelections(t,i,l);const d=[];i=yn._readSelections(t,i,d);const c=fa(t,i);i+=4;const u=[];for(let h=0;h<c;h++)i=qn.read(t,i,u);return new yn(n,o,r,a,l,d,u)}}class ez{get type(){return 0}get resource(){return Pe.isUri(this.model)?this.model:this.model.uri}constructor(e,t,i,n){this.label=e,this.code=t,this.model=i,this._data=yn.create(i,n)}toString(){return(this._data instanceof yn?this._data:yn.deserialize(this._data)).changes.map(t=>t.toString()).join(", ")}matchesResource(e){return(Pe.isUri(this.model)?this.model:this.model.uri).toString()===e.toString()}setModel(e){this.model=e}canAppend(e){return this.model===e&&this._data instanceof yn}append(e,t,i,n,o){this._data instanceof yn&&this._data.append(e,t,i,n,o)}close(){this._data instanceof yn&&(this._data=this._data.serialize())}open(){this._data instanceof yn||(this._data=yn.deserialize(this._data))}undo(){if(Pe.isUri(this.model))throw new Error("Invalid SingleModelEditStackElement");this._data instanceof yn&&(this._data=this._data.serialize());const e=yn.deserialize(this._data);this.model._applyUndo(e.changes,e.beforeEOL,e.beforeVersionId,e.beforeCursorState)}redo(){if(Pe.isUri(this.model))throw new Error("Invalid SingleModelEditStackElement");this._data instanceof yn&&(this._data=this._data.serialize());const e=yn.deserialize(this._data);this.model._applyRedo(e.changes,e.afterEOL,e.afterVersionId,e.afterCursorState)}heapSize(){return this._data instanceof yn&&(this._data=this._data.serialize()),this._data.byteLength+168}}class Wle{get resources(){return this._editStackElementsArr.map(e=>e.resource)}constructor(e,t,i){this.label=e,this.code=t,this.type=1,this._isOpen=!0,this._editStackElementsArr=i.slice(0),this._editStackElementsMap=new Map;for(const n of this._editStackElementsArr){const o=Tf(n.resource);this._editStackElementsMap.set(o,n)}this._delegate=null}prepareUndoRedo(){if(this._delegate)return this._delegate.prepareUndoRedo(this)}matchesResource(e){const t=Tf(e);return this._editStackElementsMap.has(t)}setModel(e){const t=Tf(Pe.isUri(e)?e:e.uri);this._editStackElementsMap.has(t)&&this._editStackElementsMap.get(t).setModel(e)}canAppend(e){if(!this._isOpen)return!1;const t=Tf(e.uri);return this._editStackElementsMap.has(t)?this._editStackElementsMap.get(t).canAppend(e):!1}append(e,t,i,n,o){const r=Tf(e.uri);this._editStackElementsMap.get(r).append(e,t,i,n,o)}close(){this._isOpen=!1}open(){}undo(){this._isOpen=!1;for(const e of this._editStackElementsArr)e.undo()}redo(){for(const e of this._editStackElementsArr)e.redo()}heapSize(e){const t=Tf(e);return this._editStackElementsMap.has(t)?this._editStackElementsMap.get(t).heapSize():0}split(){return this._editStackElementsArr}toString(){const e=[];for(const t of this._editStackElementsArr)e.push(`${kr(t.resource)}: ${t}`);return`{${e.join(", ")}}`}}function NT(s){return s.getEOL()===`
`?0:1}function xd(s){return s?s instanceof ez||s instanceof Wle:!1}class OP{constructor(e,t){this._model=e,this._undoRedoService=t}pushStackElement(){const e=this._undoRedoService.getLastElement(this._model.uri);xd(e)&&e.close()}popStackElement(){const e=this._undoRedoService.getLastElement(this._model.uri);xd(e)&&e.open()}clear(){this._undoRedoService.removeElements(this._model.uri)}_getOrCreateEditStackElement(e,t){const i=this._undoRedoService.getLastElement(this._model.uri);if(xd(i)&&i.canAppend(this._model))return i;const n=new ez(p("edit","Typing"),"undoredo.textBufferEdit",this._model,e);return this._undoRedoService.pushElement(n,t),n}pushEOL(e){const t=this._getOrCreateEditStackElement(null,void 0);this._model.setEOL(e),t.append(this._model,[],NT(this._model),this._model.getAlternativeVersionId(),null)}pushEditOperation(e,t,i,n){const o=this._getOrCreateEditStackElement(e,n),r=this._model.applyEdits(t,!0),a=OP._computeCursorState(i,r),l=r.map((d,c)=>({index:c,textChange:d.textChange}));return l.sort((d,c)=>d.textChange.oldPosition===c.textChange.oldPosition?d.index-c.index:d.textChange.oldPosition-c.textChange.oldPosition),o.append(this._model,l.map(d=>d.textChange),NT(this._model),this._model.getAlternativeVersionId(),a),a}static _computeCursorState(e,t){try{return e?e(t):null}catch(i){return et(i),null}}}class Vle{constructor(){this.spacesDiff=0,this.looksLikeAlignment=!1}}function Hle(s,e,t,i,n){n.spacesDiff=0,n.looksLikeAlignment=!1;let o;for(o=0;o<e&&o<i;o++){const h=s.charCodeAt(o),g=t.charCodeAt(o);if(h!==g)break}let r=0,a=0;for(let h=o;h<e;h++)s.charCodeAt(h)===32?r++:a++;let l=0,d=0;for(let h=o;h<i;h++)t.charCodeAt(h)===32?l++:d++;if(r>0&&a>0||l>0&&d>0)return;const c=Math.abs(a-d),u=Math.abs(r-l);if(c===0){n.spacesDiff=u,u>0&&0<=l-1&&l-1<s.length&&l<t.length&&t.charCodeAt(l)!==32&&s.charCodeAt(l-1)===32&&s.charCodeAt(s.length-1)===44&&(n.looksLikeAlignment=!0);return}if(u%c===0){n.spacesDiff=u/c;return}}function r7(s,e,t){const i=Math.min(s.getLineCount(),1e4);let n=0,o=0,r="",a=0;const l=[2,4,6,8,3,5,7],d=8,c=[0,0,0,0,0,0,0,0,0],u=new Vle;for(let f=1;f<=i;f++){const m=s.getLineLength(f),_=s.getLineContent(f),v=m<=65536;let b=!1,C=0,w=0,S=0;for(let L=0,k=m;L<k;L++){const I=v?_.charCodeAt(L):s.getLineCharCode(f,L);if(I===9)S++;else if(I===32)w++;else{b=!0,C=L;break}}if(!b||(S>0?n++:w>1&&o++,Hle(r,a,_,C,u),u.looksLikeAlignment&&!(t&&e===u.spacesDiff)))continue;const x=u.spacesDiff;x<=d&&c[x]++,r=_,a=C}let h=t;n!==o&&(h=n<o);let g=e;if(h){let f=h?0:.1*i;l.forEach(m=>{const _=c[m];_>f&&(f=_,g=m)}),g===4&&c[4]>0&&c[2]>0&&c[2]>=c[4]/2&&(g=2)}return{insertSpaces:h,tabSize:g}}function $s(s){return(s.metadata&1)>>>0}function si(s,e){s.metadata=s.metadata&254|e<<0}function Jn(s){return(s.metadata&2)>>>1===1}function ti(s,e){s.metadata=s.metadata&253|(e?1:0)<<1}function tz(s){return(s.metadata&4)>>>2===1}function a7(s,e){s.metadata=s.metadata&251|(e?1:0)<<2}function iz(s){return(s.metadata&64)>>>6===1}function l7(s,e){s.metadata=s.metadata&191|(e?1:0)<<6}function zle(s){return(s.metadata&24)>>>3}function d7(s,e){s.metadata=s.metadata&231|e<<3}function Ule(s){return(s.metadata&32)>>>5===1}function c7(s,e){s.metadata=s.metadata&223|(e?1:0)<<5}class nz{constructor(e,t,i){this.metadata=0,this.parent=this,this.left=this,this.right=this,si(this,1),this.start=t,this.end=i,this.delta=0,this.maxEnd=i,this.id=e,this.ownerId=0,this.options=null,a7(this,!1),l7(this,!1),d7(this,1),c7(this,!1),this.cachedVersionId=0,this.cachedAbsoluteStart=t,this.cachedAbsoluteEnd=i,this.range=null,ti(this,!1)}reset(e,t,i,n){this.start=t,this.end=i,this.maxEnd=i,this.cachedVersionId=e,this.cachedAbsoluteStart=t,this.cachedAbsoluteEnd=i,this.range=n}setOptions(e){this.options=e;const t=this.options.className;a7(this,t==="squiggly-error"||t==="squiggly-warning"||t==="squiggly-info"),l7(this,this.options.glyphMarginClassName!==null),d7(this,this.options.stickiness),c7(this,this.options.collapseOnReplaceEdit)}setCachedOffsets(e,t,i){this.cachedVersionId!==i&&(this.range=null),this.cachedVersionId=i,this.cachedAbsoluteStart=e,this.cachedAbsoluteEnd=t}detach(){this.parent=null,this.left=null,this.right=null}}const lt=new nz(null,0,0);lt.parent=lt;lt.left=lt;lt.right=lt;si(lt,0);class fI{constructor(){this.root=lt,this.requestNormalizeDelta=!1}intervalSearch(e,t,i,n,o,r){return this.root===lt?[]:Xle(this,e,t,i,n,o,r)}search(e,t,i,n){return this.root===lt?[]:Yle(this,e,t,i,n)}collectNodesFromOwner(e){return Gle(this,e)}collectNodesPostOrder(){return Zle(this)}insert(e){u7(this,e),this._normalizeDeltaIfNecessary()}delete(e){h7(this,e),this._normalizeDeltaIfNecessary()}resolveNode(e,t){const i=e;let n=0;for(;e!==this.root;)e===e.parent.right&&(n+=e.parent.delta),e=e.parent;const o=i.start+n,r=i.end+n;i.setCachedOffsets(o,r,t)}acceptReplace(e,t,i,n){const o=Kle(this,e,e+t);for(let r=0,a=o.length;r<a;r++){const l=o[r];h7(this,l)}this._normalizeDeltaIfNecessary(),qle(this,e,e+t,i),this._normalizeDeltaIfNecessary();for(let r=0,a=o.length;r<a;r++){const l=o[r];l.start=l.cachedAbsoluteStart,l.end=l.cachedAbsoluteEnd,jle(l,e,e+t,i,n),l.maxEnd=l.end,u7(this,l)}this._normalizeDeltaIfNecessary()}_normalizeDeltaIfNecessary(){this.requestNormalizeDelta&&(this.requestNormalizeDelta=!1,$le(this))}}function $le(s){let e=s.root,t=0;for(;e!==lt;){if(e.left!==lt&&!Jn(e.left)){e=e.left;continue}if(e.right!==lt&&!Jn(e.right)){t+=e.delta,e=e.right;continue}e.start=t+e.start,e.end=t+e.end,e.delta=0,Bu(e),ti(e,!0),ti(e.left,!1),ti(e.right,!1),e===e.parent.right&&(t-=e.parent.delta),e=e.parent}ti(s.root,!1)}function Mf(s,e,t,i){return s<t?!0:s>t||i===1?!1:i===2?!0:e}function jle(s,e,t,i,n){const o=zle(s),r=o===0||o===2,a=o===1||o===2,l=t-e,d=i,c=Math.min(l,d),u=s.start;let h=!1;const g=s.end;let f=!1;e<=u&&g<=t&&Ule(s)&&(s.start=e,h=!0,s.end=e,f=!0);{const _=n?1:l>0?2:0;!h&&Mf(u,r,e,_)&&(h=!0),!f&&Mf(g,a,e,_)&&(f=!0)}if(c>0&&!n){const _=l>d?2:0;!h&&Mf(u,r,e+c,_)&&(h=!0),!f&&Mf(g,a,e+c,_)&&(f=!0)}{const _=n?1:0;!h&&Mf(u,r,t,_)&&(s.start=e+d,h=!0),!f&&Mf(g,a,t,_)&&(s.end=e+d,f=!0)}const m=d-l;h||(s.start=Math.max(0,u+m)),f||(s.end=Math.max(0,g+m)),s.start>s.end&&(s.end=s.start)}function Kle(s,e,t){let i=s.root,n=0,o=0,r=0,a=0;const l=[];let d=0;for(;i!==lt;){if(Jn(i)){ti(i.left,!1),ti(i.right,!1),i===i.parent.right&&(n-=i.parent.delta),i=i.parent;continue}if(!Jn(i.left)){if(o=n+i.maxEnd,o<e){ti(i,!0);continue}if(i.left!==lt){i=i.left;continue}}if(r=n+i.start,r>t){ti(i,!0);continue}if(a=n+i.end,a>=e&&(i.setCachedOffsets(r,a,0),l[d++]=i),ti(i,!0),i.right!==lt&&!Jn(i.right)){n+=i.delta,i=i.right;continue}}return ti(s.root,!1),l}function qle(s,e,t,i){let n=s.root,o=0,r=0,a=0;const l=i-(t-e);for(;n!==lt;){if(Jn(n)){ti(n.left,!1),ti(n.right,!1),n===n.parent.right&&(o-=n.parent.delta),Bu(n),n=n.parent;continue}if(!Jn(n.left)){if(r=o+n.maxEnd,r<e){ti(n,!0);continue}if(n.left!==lt){n=n.left;continue}}if(a=o+n.start,a>t){n.start+=l,n.end+=l,n.delta+=l,(n.delta<-1073741824||n.delta>1073741824)&&(s.requestNormalizeDelta=!0),ti(n,!0);continue}if(ti(n,!0),n.right!==lt&&!Jn(n.right)){o+=n.delta,n=n.right;continue}}ti(s.root,!1)}function Gle(s,e){let t=s.root;const i=[];let n=0;for(;t!==lt;){if(Jn(t)){ti(t.left,!1),ti(t.right,!1),t=t.parent;continue}if(t.left!==lt&&!Jn(t.left)){t=t.left;continue}if(t.ownerId===e&&(i[n++]=t),ti(t,!0),t.right!==lt&&!Jn(t.right)){t=t.right;continue}}return ti(s.root,!1),i}function Zle(s){let e=s.root;const t=[];let i=0;for(;e!==lt;){if(Jn(e)){ti(e.left,!1),ti(e.right,!1),e=e.parent;continue}if(e.left!==lt&&!Jn(e.left)){e=e.left;continue}if(e.right!==lt&&!Jn(e.right)){e=e.right;continue}t[i++]=e,ti(e,!0)}return ti(s.root,!1),t}function Yle(s,e,t,i,n){let o=s.root,r=0,a=0,l=0;const d=[];let c=0;for(;o!==lt;){if(Jn(o)){ti(o.left,!1),ti(o.right,!1),o===o.parent.right&&(r-=o.parent.delta),o=o.parent;continue}if(o.left!==lt&&!Jn(o.left)){o=o.left;continue}a=r+o.start,l=r+o.end,o.setCachedOffsets(a,l,i);let u=!0;if(e&&o.ownerId&&o.ownerId!==e&&(u=!1),t&&tz(o)&&(u=!1),n&&!iz(o)&&(u=!1),u&&(d[c++]=o),ti(o,!0),o.right!==lt&&!Jn(o.right)){r+=o.delta,o=o.right;continue}}return ti(s.root,!1),d}function Xle(s,e,t,i,n,o,r){let a=s.root,l=0,d=0,c=0,u=0;const h=[];let g=0;for(;a!==lt;){if(Jn(a)){ti(a.left,!1),ti(a.right,!1),a===a.parent.right&&(l-=a.parent.delta),a=a.parent;continue}if(!Jn(a.left)){if(d=l+a.maxEnd,d<e){ti(a,!0);continue}if(a.left!==lt){a=a.left;continue}}if(c=l+a.start,c>t){ti(a,!0);continue}if(u=l+a.end,u>=e){a.setCachedOffsets(c,u,o);let f=!0;i&&a.ownerId&&a.ownerId!==i&&(f=!1),n&&tz(a)&&(f=!1),r&&!iz(a)&&(f=!1),f&&(h[g++]=a)}if(ti(a,!0),a.right!==lt&&!Jn(a.right)){l+=a.delta,a=a.right;continue}}return ti(s.root,!1),h}function u7(s,e){if(s.root===lt)return e.parent=lt,e.left=lt,e.right=lt,si(e,0),s.root=e,s.root;Qle(s,e),Lc(e.parent);let t=e;for(;t!==s.root&&$s(t.parent)===1;)if(t.parent===t.parent.parent.left){const i=t.parent.parent.right;$s(i)===1?(si(t.parent,0),si(i,0),si(t.parent.parent,1),t=t.parent.parent):(t===t.parent.right&&(t=t.parent,zv(s,t)),si(t.parent,0),si(t.parent.parent,1),Uv(s,t.parent.parent))}else{const i=t.parent.parent.left;$s(i)===1?(si(t.parent,0),si(i,0),si(t.parent.parent,1),t=t.parent.parent):(t===t.parent.left&&(t=t.parent,Uv(s,t)),si(t.parent,0),si(t.parent.parent,1),zv(s,t.parent.parent))}return si(s.root,0),e}function Qle(s,e){let t=0,i=s.root;const n=e.start,o=e.end;for(;;)if(ede(n,o,i.start+t,i.end+t)<0)if(i.left===lt){e.start-=t,e.end-=t,e.maxEnd-=t,i.left=e;break}else i=i.left;else if(i.right===lt){e.start-=t+i.delta,e.end-=t+i.delta,e.maxEnd-=t+i.delta,i.right=e;break}else t+=i.delta,i=i.right;e.parent=i,e.left=lt,e.right=lt,si(e,1)}function h7(s,e){let t,i;if(e.left===lt?(t=e.right,i=e,t.delta+=e.delta,(t.delta<-1073741824||t.delta>1073741824)&&(s.requestNormalizeDelta=!0),t.start+=e.delta,t.end+=e.delta):e.right===lt?(t=e.left,i=e):(i=Jle(e.right),t=i.right,t.start+=i.delta,t.end+=i.delta,t.delta+=i.delta,(t.delta<-1073741824||t.delta>1073741824)&&(s.requestNormalizeDelta=!0),i.start+=e.delta,i.end+=e.delta,i.delta=e.delta,(i.delta<-1073741824||i.delta>1073741824)&&(s.requestNormalizeDelta=!0)),i===s.root){s.root=t,si(t,0),e.detach(),pI(),Bu(t),s.root.parent=lt;return}const n=$s(i)===1;if(i===i.parent.left?i.parent.left=t:i.parent.right=t,i===e?t.parent=i.parent:(i.parent===e?t.parent=i:t.parent=i.parent,i.left=e.left,i.right=e.right,i.parent=e.parent,si(i,$s(e)),e===s.root?s.root=i:e===e.parent.left?e.parent.left=i:e.parent.right=i,i.left!==lt&&(i.left.parent=i),i.right!==lt&&(i.right.parent=i)),e.detach(),n){Lc(t.parent),i!==e&&(Lc(i),Lc(i.parent)),pI();return}Lc(t),Lc(t.parent),i!==e&&(Lc(i),Lc(i.parent));let o;for(;t!==s.root&&$s(t)===0;)t===t.parent.left?(o=t.parent.right,$s(o)===1&&(si(o,0),si(t.parent,1),zv(s,t.parent),o=t.parent.right),$s(o.left)===0&&$s(o.right)===0?(si(o,1),t=t.parent):($s(o.right)===0&&(si(o.left,0),si(o,1),Uv(s,o),o=t.parent.right),si(o,$s(t.parent)),si(t.parent,0),si(o.right,0),zv(s,t.parent),t=s.root)):(o=t.parent.left,$s(o)===1&&(si(o,0),si(t.parent,1),Uv(s,t.parent),o=t.parent.left),$s(o.left)===0&&$s(o.right)===0?(si(o,1),t=t.parent):($s(o.left)===0&&(si(o.right,0),si(o,1),zv(s,o),o=t.parent.left),si(o,$s(t.parent)),si(t.parent,0),si(o.left,0),Uv(s,t.parent),t=s.root));si(t,0),pI()}function Jle(s){for(;s.left!==lt;)s=s.left;return s}function pI(){lt.parent=lt,lt.delta=0,lt.start=0,lt.end=0}function zv(s,e){const t=e.right;t.delta+=e.delta,(t.delta<-1073741824||t.delta>1073741824)&&(s.requestNormalizeDelta=!0),t.start+=e.delta,t.end+=e.delta,e.right=t.left,t.left!==lt&&(t.left.parent=e),t.parent=e.parent,e.parent===lt?s.root=t:e===e.parent.left?e.parent.left=t:e.parent.right=t,t.left=e,e.parent=t,Bu(e),Bu(t)}function Uv(s,e){const t=e.left;e.delta-=t.delta,(e.delta<-1073741824||e.delta>1073741824)&&(s.requestNormalizeDelta=!0),e.start-=t.delta,e.end-=t.delta,e.left=t.right,t.right!==lt&&(t.right.parent=e),t.parent=e.parent,e.parent===lt?s.root=t:e===e.parent.right?e.parent.right=t:e.parent.left=t,t.right=e,e.parent=t,Bu(e),Bu(t)}function sz(s){let e=s.end;if(s.left!==lt){const t=s.left.maxEnd;t>e&&(e=t)}if(s.right!==lt){const t=s.right.maxEnd+s.delta;t>e&&(e=t)}return e}function Bu(s){s.maxEnd=sz(s)}function Lc(s){for(;s!==lt;){const e=sz(s);if(s.maxEnd===e)return;s.maxEnd=e,s=s.parent}}function ede(s,e,t,i){return s===t?e-i:s-t}class TT{constructor(e,t){this.piece=e,this.color=t,this.size_left=0,this.lf_left=0,this.parent=this,this.left=this,this.right=this}next(){if(this.right!==Je)return FP(this.right);let e=this;for(;e.parent!==Je&&e.parent.left!==e;)e=e.parent;return e.parent===Je?Je:e.parent}prev(){if(this.left!==Je)return oz(this.left);let e=this;for(;e.parent!==Je&&e.parent.right!==e;)e=e.parent;return e.parent===Je?Je:e.parent}detach(){this.parent=null,this.left=null,this.right=null}}const Je=new TT(null,0);Je.parent=Je;Je.left=Je;Je.right=Je;Je.color=0;function FP(s){for(;s.left!==Je;)s=s.left;return s}function oz(s){for(;s.right!==Je;)s=s.right;return s}function BP(s){return s===Je?0:s.size_left+s.piece.length+BP(s.right)}function WP(s){return s===Je?0:s.lf_left+s.piece.lineFeedCnt+WP(s.right)}function mI(){Je.parent=Je}function $v(s,e){const t=e.right;t.size_left+=e.size_left+(e.piece?e.piece.length:0),t.lf_left+=e.lf_left+(e.piece?e.piece.lineFeedCnt:0),e.right=t.left,t.left!==Je&&(t.left.parent=e),t.parent=e.parent,e.parent===Je?s.root=t:e.parent.left===e?e.parent.left=t:e.parent.right=t,t.left=e,e.parent=t}function jv(s,e){const t=e.left;e.left=t.right,t.right!==Je&&(t.right.parent=e),t.parent=e.parent,e.size_left-=t.size_left+(t.piece?t.piece.length:0),e.lf_left-=t.lf_left+(t.piece?t.piece.lineFeedCnt:0),e.parent===Je?s.root=t:e===e.parent.right?e.parent.right=t:e.parent.left=t,t.right=e,e.parent=t}function L1(s,e){let t,i;if(e.left===Je?(i=e,t=i.right):e.right===Je?(i=e,t=i.left):(i=FP(e.right),t=i.right),i===s.root){s.root=t,t.color=0,e.detach(),mI(),s.root.parent=Je;return}const n=i.color===1;if(i===i.parent.left?i.parent.left=t:i.parent.right=t,i===e?(t.parent=i.parent,pv(s,t)):(i.parent===e?t.parent=i:t.parent=i.parent,pv(s,t),i.left=e.left,i.right=e.right,i.parent=e.parent,i.color=e.color,e===s.root?s.root=i:e===e.parent.left?e.parent.left=i:e.parent.right=i,i.left!==Je&&(i.left.parent=i),i.right!==Je&&(i.right.parent=i),i.size_left=e.size_left,i.lf_left=e.lf_left,pv(s,i)),e.detach(),t.parent.left===t){const r=BP(t),a=WP(t);if(r!==t.parent.size_left||a!==t.parent.lf_left){const l=r-t.parent.size_left,d=a-t.parent.lf_left;t.parent.size_left=r,t.parent.lf_left=a,vd(s,t.parent,l,d)}}if(pv(s,t.parent),n){mI();return}let o;for(;t!==s.root&&t.color===0;)t===t.parent.left?(o=t.parent.right,o.color===1&&(o.color=0,t.parent.color=1,$v(s,t.parent),o=t.parent.right),o.left.color===0&&o.right.color===0?(o.color=1,t=t.parent):(o.right.color===0&&(o.left.color=0,o.color=1,jv(s,o),o=t.parent.right),o.color=t.parent.color,t.parent.color=0,o.right.color=0,$v(s,t.parent),t=s.root)):(o=t.parent.left,o.color===1&&(o.color=0,t.parent.color=1,jv(s,t.parent),o=t.parent.left),o.left.color===0&&o.right.color===0?(o.color=1,t=t.parent):(o.left.color===0&&(o.right.color=0,o.color=1,$v(s,o),o=t.parent.left),o.color=t.parent.color,t.parent.color=0,o.left.color=0,jv(s,t.parent),t=s.root));t.color=0,mI()}function g7(s,e){for(pv(s,e);e!==s.root&&e.parent.color===1;)if(e.parent===e.parent.parent.left){const t=e.parent.parent.right;t.color===1?(e.parent.color=0,t.color=0,e.parent.parent.color=1,e=e.parent.parent):(e===e.parent.right&&(e=e.parent,$v(s,e)),e.parent.color=0,e.parent.parent.color=1,jv(s,e.parent.parent))}else{const t=e.parent.parent.left;t.color===1?(e.parent.color=0,t.color=0,e.parent.parent.color=1,e=e.parent.parent):(e===e.parent.left&&(e=e.parent,jv(s,e)),e.parent.color=0,e.parent.parent.color=1,$v(s,e.parent.parent))}s.root.color=0}function vd(s,e,t,i){for(;e!==s.root&&e!==Je;)e.parent.left===e&&(e.parent.size_left+=t,e.parent.lf_left+=i),e=e.parent}function pv(s,e){let t=0,i=0;if(e!==s.root){for(;e!==s.root&&e===e.parent.right;)e=e.parent;if(e!==s.root)for(e=e.parent,t=BP(e.left)-e.size_left,i=WP(e.left)-e.lf_left,e.size_left+=t,e.lf_left+=i;e!==s.root&&(t!==0||i!==0);)e.parent.left===e&&(e.parent.size_left+=t,e.parent.lf_left+=i),e=e.parent}}const cd=65535;function rz(s){let e;return s[s.length-1]<65536?e=new Uint16Array(s.length):e=new Uint32Array(s.length),e.set(s,0),e}class tde{constructor(e,t,i,n,o){this.lineStarts=e,this.cr=t,this.lf=i,this.crlf=n,this.isBasicASCII=o}}function bd(s,e=!0){const t=[0];let i=1;for(let n=0,o=s.length;n<o;n++){const r=s.charCodeAt(n);r===13?n+1<o&&s.charCodeAt(n+1)===10?(t[i++]=n+2,n++):t[i++]=n+1:r===10&&(t[i++]=n+1)}return e?rz(t):t}function ide(s,e){s.length=0,s[0]=0;let t=1,i=0,n=0,o=0,r=!0;for(let l=0,d=e.length;l<d;l++){const c=e.charCodeAt(l);c===13?l+1<d&&e.charCodeAt(l+1)===10?(o++,s[t++]=l+2,l++):(i++,s[t++]=l+1):c===10?(n++,s[t++]=l+1):r&&c!==9&&(c<32||c>126)&&(r=!1)}const a=new tde(rz(s),i,n,o,r);return s.length=0,a}class oo{constructor(e,t,i,n,o){this.bufferIndex=e,this.start=t,this.end=i,this.lineFeedCnt=n,this.length=o}}class Gh{constructor(e,t){this.buffer=e,this.lineStarts=t}}class nde{constructor(e,t){this._pieces=[],this._tree=e,this._BOM=t,this._index=0,e.root!==Je&&e.iterate(e.root,i=>(i!==Je&&this._pieces.push(i.piece),!0))}read(){return this._pieces.length===0?this._index===0?(this._index++,this._BOM):null:this._index>this._pieces.length-1?null:this._index===0?this._BOM+this._tree.getPieceContent(this._pieces[this._index++]):this._tree.getPieceContent(this._pieces[this._index++])}}class sde{constructor(e){this._limit=e,this._cache=[]}get(e){for(let t=this._cache.length-1;t>=0;t--){const i=this._cache[t];if(i.nodeStartOffset<=e&&i.nodeStartOffset+i.node.piece.length>=e)return i}return null}get2(e){for(let t=this._cache.length-1;t>=0;t--){const i=this._cache[t];if(i.nodeStartLineNumber&&i.nodeStartLineNumber<e&&i.nodeStartLineNumber+i.node.piece.lineFeedCnt>=e)return i}return null}set(e){this._cache.length>=this._limit&&this._cache.shift(),this._cache.push(e)}validate(e){let t=!1;const i=this._cache;for(let n=0;n<i.length;n++){const o=i[n];if(o.node.parent===null||o.nodeStartOffset>=e){i[n]=null,t=!0;continue}}if(t){const n=[];for(const o of i)o!==null&&n.push(o);this._cache=n}}}class ode{constructor(e,t,i){this.create(e,t,i)}create(e,t,i){this._buffers=[new Gh("",[0])],this._lastChangeBufferPos={line:0,column:0},this.root=Je,this._lineCnt=1,this._length=0,this._EOL=t,this._EOLLength=t.length,this._EOLNormalized=i;let n=null;for(let o=0,r=e.length;o<r;o++)if(e[o].buffer.length>0){e[o].lineStarts||(e[o].lineStarts=bd(e[o].buffer));const a=new oo(o+1,{line:0,column:0},{line:e[o].lineStarts.length-1,column:e[o].buffer.length-e[o].lineStarts[e[o].lineStarts.length-1]},e[o].lineStarts.length-1,e[o].buffer.length);this._buffers.push(e[o]),n=this.rbInsertRight(n,a)}this._searchCache=new sde(1),this._lastVisitedLine={lineNumber:0,value:""},this.computeBufferMetadata()}normalizeEOL(e){const t=cd,i=t-Math.floor(t/3),n=i*2;let o="",r=0;const a=[];if(this.iterate(this.root,l=>{const d=this.getNodeContent(l),c=d.length;if(r<=i||r+c<n)return o+=d,r+=c,!0;const u=o.replace(/\r\n|\r|\n/g,e);return a.push(new Gh(u,bd(u))),o=d,r=c,!0}),r>0){const l=o.replace(/\r\n|\r|\n/g,e);a.push(new Gh(l,bd(l)))}this.create(a,e,!0)}getEOL(){return this._EOL}setEOL(e){this._EOL=e,this._EOLLength=this._EOL.length,this.normalizeEOL(e)}createSnapshot(e){return new nde(this,e)}getOffsetAt(e,t){let i=0,n=this.root;for(;n!==Je;)if(n.left!==Je&&n.lf_left+1>=e)n=n.left;else if(n.lf_left+n.piece.lineFeedCnt+1>=e){i+=n.size_left;const o=this.getAccumulatedValue(n,e-n.lf_left-2);return i+=o+t-1}else e-=n.lf_left+n.piece.lineFeedCnt,i+=n.size_left+n.piece.length,n=n.right;return i}getPositionAt(e){e=Math.floor(e),e=Math.max(0,e);let t=this.root,i=0;const n=e;for(;t!==Je;)if(t.size_left!==0&&t.size_left>=e)t=t.left;else if(t.size_left+t.piece.length>=e){const o=this.getIndexOf(t,e-t.size_left);if(i+=t.lf_left+o.index,o.index===0){const r=this.getOffsetAt(i+1,1),a=n-r;return new H(i+1,a+1)}return new H(i+1,o.remainder+1)}else if(e-=t.size_left+t.piece.length,i+=t.lf_left+t.piece.lineFeedCnt,t.right===Je){const o=this.getOffsetAt(i+1,1),r=n-e-o;return new H(i+1,r+1)}else t=t.right;return new H(1,1)}getValueInRange(e,t){if(e.startLineNumber===e.endLineNumber&&e.startColumn===e.endColumn)return"";const i=this.nodeAt2(e.startLineNumber,e.startColumn),n=this.nodeAt2(e.endLineNumber,e.endColumn),o=this.getValueInRange2(i,n);return t?t!==this._EOL||!this._EOLNormalized?o.replace(/\r\n|\r|\n/g,t):t===this.getEOL()&&this._EOLNormalized?o:o.replace(/\r\n|\r|\n/g,t):o}getValueInRange2(e,t){if(e.node===t.node){const a=e.node,l=this._buffers[a.piece.bufferIndex].buffer,d=this.offsetInBuffer(a.piece.bufferIndex,a.piece.start);return l.substring(d+e.remainder,d+t.remainder)}let i=e.node;const n=this._buffers[i.piece.bufferIndex].buffer,o=this.offsetInBuffer(i.piece.bufferIndex,i.piece.start);let r=n.substring(o+e.remainder,o+i.piece.length);for(i=i.next();i!==Je;){const a=this._buffers[i.piece.bufferIndex].buffer,l=this.offsetInBuffer(i.piece.bufferIndex,i.piece.start);if(i===t.node){r+=a.substring(l,l+t.remainder);break}else r+=a.substr(l,i.piece.length);i=i.next()}return r}getLinesContent(){const e=[];let t=0,i="",n=!1;return this.iterate(this.root,o=>{if(o===Je)return!0;const r=o.piece;let a=r.length;if(a===0)return!0;const l=this._buffers[r.bufferIndex].buffer,d=this._buffers[r.bufferIndex].lineStarts,c=r.start.line,u=r.end.line;let h=d[c]+r.start.column;if(n&&(l.charCodeAt(h)===10&&(h++,a--),e[t++]=i,i="",n=!1,a===0))return!0;if(c===u)return!this._EOLNormalized&&l.charCodeAt(h+a-1)===13?(n=!0,i+=l.substr(h,a-1)):i+=l.substr(h,a),!0;i+=this._EOLNormalized?l.substring(h,Math.max(h,d[c+1]-this._EOLLength)):l.substring(h,d[c+1]).replace(/(\r\n|\r|\n)$/,""),e[t++]=i;for(let g=c+1;g<u;g++)i=this._EOLNormalized?l.substring(d[g],d[g+1]-this._EOLLength):l.substring(d[g],d[g+1]).replace(/(\r\n|\r|\n)$/,""),e[t++]=i;return!this._EOLNormalized&&l.charCodeAt(d[u]+r.end.column-1)===13?(n=!0,r.end.column===0?t--:i=l.substr(d[u],r.end.column-1)):i=l.substr(d[u],r.end.column),!0}),n&&(e[t++]=i,i=""),e[t++]=i,e}getLength(){return this._length}getLineCount(){return this._lineCnt}getLineContent(e){return this._lastVisitedLine.lineNumber===e?this._lastVisitedLine.value:(this._lastVisitedLine.lineNumber=e,e===this._lineCnt?this._lastVisitedLine.value=this.getLineRawContent(e):this._EOLNormalized?this._lastVisitedLine.value=this.getLineRawContent(e,this._EOLLength):this._lastVisitedLine.value=this.getLineRawContent(e).replace(/(\r\n|\r|\n)$/,""),this._lastVisitedLine.value)}_getCharCode(e){if(e.remainder===e.node.piece.length){const t=e.node.next();if(!t)return 0;const i=this._buffers[t.piece.bufferIndex],n=this.offsetInBuffer(t.piece.bufferIndex,t.piece.start);return i.buffer.charCodeAt(n)}else{const t=this._buffers[e.node.piece.bufferIndex],n=this.offsetInBuffer(e.node.piece.bufferIndex,e.node.piece.start)+e.remainder;return t.buffer.charCodeAt(n)}}getLineCharCode(e,t){const i=this.nodeAt2(e,t+1);return this._getCharCode(i)}getLineLength(e){if(e===this.getLineCount()){const t=this.getOffsetAt(e,1);return this.getLength()-t}return this.getOffsetAt(e+1,1)-this.getOffsetAt(e,1)-this._EOLLength}findMatchesInNode(e,t,i,n,o,r,a,l,d,c,u){const h=this._buffers[e.piece.bufferIndex],g=this.offsetInBuffer(e.piece.bufferIndex,e.piece.start),f=this.offsetInBuffer(e.piece.bufferIndex,o),m=this.offsetInBuffer(e.piece.bufferIndex,r);let _;const v={line:0,column:0};let b,C;t._wordSeparators?(b=h.buffer.substring(f,m),C=w=>w+f,t.reset(0)):(b=h.buffer,C=w=>w,t.reset(f));do if(_=t.next(b),_){if(C(_.index)>=m)return c;this.positionInBuffer(e,C(_.index)-g,v);const w=this.getLineFeedCnt(e.piece.bufferIndex,o,v),S=v.line===o.line?v.column-o.column+n:v.column+1,x=S+_[0].length;if(u[c++]=zh(new D(i+w,S,i+w,x),_,l),C(_.index)+_[0].length>=m||c>=d)return c}while(_);return c}findMatchesLineByLine(e,t,i,n){const o=[];let r=0;const a=new rp(t.wordSeparators,t.regex);let l=this.nodeAt2(e.startLineNumber,e.startColumn);if(l===null)return[];const d=this.nodeAt2(e.endLineNumber,e.endColumn);if(d===null)return[];let c=this.positionInBuffer(l.node,l.remainder);const u=this.positionInBuffer(d.node,d.remainder);if(l.node===d.node)return this.findMatchesInNode(l.node,a,e.startLineNumber,e.startColumn,c,u,t,i,n,r,o),o;let h=e.startLineNumber,g=l.node;for(;g!==d.node;){const m=this.getLineFeedCnt(g.piece.bufferIndex,c,g.piece.end);if(m>=1){const v=this._buffers[g.piece.bufferIndex].lineStarts,b=this.offsetInBuffer(g.piece.bufferIndex,g.piece.start),C=v[c.line+m],w=h===e.startLineNumber?e.startColumn:1;if(r=this.findMatchesInNode(g,a,h,w,c,this.positionInBuffer(g,C-b),t,i,n,r,o),r>=n)return o;h+=m}const _=h===e.startLineNumber?e.startColumn-1:0;if(h===e.endLineNumber){const v=this.getLineContent(h).substring(_,e.endColumn-1);return r=this._findMatchesInLine(t,a,v,e.endLineNumber,_,r,o,i,n),o}if(r=this._findMatchesInLine(t,a,this.getLineContent(h).substr(_),h,_,r,o,i,n),r>=n)return o;h++,l=this.nodeAt2(h,1),g=l.node,c=this.positionInBuffer(l.node,l.remainder)}if(h===e.endLineNumber){const m=h===e.startLineNumber?e.startColumn-1:0,_=this.getLineContent(h).substring(m,e.endColumn-1);return r=this._findMatchesInLine(t,a,_,e.endLineNumber,m,r,o,i,n),o}const f=h===e.startLineNumber?e.startColumn:1;return r=this.findMatchesInNode(d.node,a,h,f,c,u,t,i,n,r,o),o}_findMatchesInLine(e,t,i,n,o,r,a,l,d){const c=e.wordSeparators;if(!l&&e.simpleSearch){const h=e.simpleSearch,g=h.length,f=i.length;let m=-g;for(;(m=i.indexOf(h,m+g))!==-1;)if((!c||sP(c,i,f,m,g))&&(a[r++]=new M0(new D(n,m+1+o,n,m+1+g+o),null),r>=d))return r;return r}let u;t.reset(0);do if(u=t.next(i),u&&(a[r++]=zh(new D(n,u.index+1+o,n,u.index+1+u[0].length+o),u,l),r>=d))return r;while(u);return r}insert(e,t,i=!1){if(this._EOLNormalized=this._EOLNormalized&&i,this._lastVisitedLine.lineNumber=0,this._lastVisitedLine.value="",this.root!==Je){const{node:n,remainder:o,nodeStartOffset:r}=this.nodeAt(e),a=n.piece,l=a.bufferIndex,d=this.positionInBuffer(n,o);if(n.piece.bufferIndex===0&&a.end.line===this._lastChangeBufferPos.line&&a.end.column===this._lastChangeBufferPos.column&&r+a.length===e&&t.length<cd){this.appendToNode(n,t),this.computeBufferMetadata();return}if(r===e)this.insertContentToNodeLeft(t,n),this._searchCache.validate(e);else if(r+n.piece.length>e){const c=[];let u=new oo(a.bufferIndex,d,a.end,this.getLineFeedCnt(a.bufferIndex,d,a.end),this.offsetInBuffer(l,a.end)-this.offsetInBuffer(l,d));if(this.shouldCheckCRLF()&&this.endWithCR(t)&&this.nodeCharCodeAt(n,o)===10){const m={line:u.start.line+1,column:0};u=new oo(u.bufferIndex,m,u.end,this.getLineFeedCnt(u.bufferIndex,m,u.end),u.length-1),t+=`
`}if(this.shouldCheckCRLF()&&this.startWithLF(t))if(this.nodeCharCodeAt(n,o-1)===13){const m=this.positionInBuffer(n,o-1);this.deleteNodeTail(n,m),t="\r"+t,n.piece.length===0&&c.push(n)}else this.deleteNodeTail(n,d);else this.deleteNodeTail(n,d);const h=this.createNewPieces(t);u.length>0&&this.rbInsertRight(n,u);let g=n;for(let f=0;f<h.length;f++)g=this.rbInsertRight(g,h[f]);this.deleteNodes(c)}else this.insertContentToNodeRight(t,n)}else{const n=this.createNewPieces(t);let o=this.rbInsertLeft(null,n[0]);for(let r=1;r<n.length;r++)o=this.rbInsertRight(o,n[r])}this.computeBufferMetadata()}delete(e,t){if(this._lastVisitedLine.lineNumber=0,this._lastVisitedLine.value="",t<=0||this.root===Je)return;const i=this.nodeAt(e),n=this.nodeAt(e+t),o=i.node,r=n.node;if(o===r){const h=this.positionInBuffer(o,i.remainder),g=this.positionInBuffer(o,n.remainder);if(i.nodeStartOffset===e){if(t===o.piece.length){const f=o.next();L1(this,o),this.validateCRLFWithPrevNode(f),this.computeBufferMetadata();return}this.deleteNodeHead(o,g),this._searchCache.validate(e),this.validateCRLFWithPrevNode(o),this.computeBufferMetadata();return}if(i.nodeStartOffset+o.piece.length===e+t){this.deleteNodeTail(o,h),this.validateCRLFWithNextNode(o),this.computeBufferMetadata();return}this.shrinkNode(o,h,g),this.computeBufferMetadata();return}const a=[],l=this.positionInBuffer(o,i.remainder);this.deleteNodeTail(o,l),this._searchCache.validate(e),o.piece.length===0&&a.push(o);const d=this.positionInBuffer(r,n.remainder);this.deleteNodeHead(r,d),r.piece.length===0&&a.push(r);const c=o.next();for(let h=c;h!==Je&&h!==r;h=h.next())a.push(h);const u=o.piece.length===0?o.prev():o;this.deleteNodes(a),this.validateCRLFWithNextNode(u),this.computeBufferMetadata()}insertContentToNodeLeft(e,t){const i=[];if(this.shouldCheckCRLF()&&this.endWithCR(e)&&this.startWithLF(t)){const r=t.piece,a={line:r.start.line+1,column:0},l=new oo(r.bufferIndex,a,r.end,this.getLineFeedCnt(r.bufferIndex,a,r.end),r.length-1);t.piece=l,e+=`
`,vd(this,t,-1,-1),t.piece.length===0&&i.push(t)}const n=this.createNewPieces(e);let o=this.rbInsertLeft(t,n[n.length-1]);for(let r=n.length-2;r>=0;r--)o=this.rbInsertLeft(o,n[r]);this.validateCRLFWithPrevNode(o),this.deleteNodes(i)}insertContentToNodeRight(e,t){this.adjustCarriageReturnFromNext(e,t)&&(e+=`
`);const i=this.createNewPieces(e),n=this.rbInsertRight(t,i[0]);let o=n;for(let r=1;r<i.length;r++)o=this.rbInsertRight(o,i[r]);this.validateCRLFWithPrevNode(n)}positionInBuffer(e,t,i){const n=e.piece,o=e.piece.bufferIndex,r=this._buffers[o].lineStarts,l=r[n.start.line]+n.start.column+t;let d=n.start.line,c=n.end.line,u=0,h=0,g=0;for(;d<=c&&(u=d+(c-d)/2|0,g=r[u],u!==c);)if(h=r[u+1],l<g)c=u-1;else if(l>=h)d=u+1;else break;return i?(i.line=u,i.column=l-g,null):{line:u,column:l-g}}getLineFeedCnt(e,t,i){if(i.column===0)return i.line-t.line;const n=this._buffers[e].lineStarts;if(i.line===n.length-1)return i.line-t.line;const o=n[i.line+1],r=n[i.line]+i.column;if(o>r+1)return i.line-t.line;const a=r-1;return this._buffers[e].buffer.charCodeAt(a)===13?i.line-t.line+1:i.line-t.line}offsetInBuffer(e,t){return this._buffers[e].lineStarts[t.line]+t.column}deleteNodes(e){for(let t=0;t<e.length;t++)L1(this,e[t])}createNewPieces(e){if(e.length>cd){const c=[];for(;e.length>cd;){const h=e.charCodeAt(cd-1);let g;h===13||h>=55296&&h<=56319?(g=e.substring(0,cd-1),e=e.substring(cd-1)):(g=e.substring(0,cd),e=e.substring(cd));const f=bd(g);c.push(new oo(this._buffers.length,{line:0,column:0},{line:f.length-1,column:g.length-f[f.length-1]},f.length-1,g.length)),this._buffers.push(new Gh(g,f))}const u=bd(e);return c.push(new oo(this._buffers.length,{line:0,column:0},{line:u.length-1,column:e.length-u[u.length-1]},u.length-1,e.length)),this._buffers.push(new Gh(e,u)),c}let t=this._buffers[0].buffer.length;const i=bd(e,!1);let n=this._lastChangeBufferPos;if(this._buffers[0].lineStarts[this._buffers[0].lineStarts.length-1]===t&&t!==0&&this.startWithLF(e)&&this.endWithCR(this._buffers[0].buffer)){this._lastChangeBufferPos={line:this._lastChangeBufferPos.line,column:this._lastChangeBufferPos.column+1},n=this._lastChangeBufferPos;for(let c=0;c<i.length;c++)i[c]+=t+1;this._buffers[0].lineStarts=this._buffers[0].lineStarts.concat(i.slice(1)),this._buffers[0].buffer+="_"+e,t+=1}else{if(t!==0)for(let c=0;c<i.length;c++)i[c]+=t;this._buffers[0].lineStarts=this._buffers[0].lineStarts.concat(i.slice(1)),this._buffers[0].buffer+=e}const o=this._buffers[0].buffer.length,r=this._buffers[0].lineStarts.length-1,a=o-this._buffers[0].lineStarts[r],l={line:r,column:a},d=new oo(0,n,l,this.getLineFeedCnt(0,n,l),o-t);return this._lastChangeBufferPos=l,[d]}getLineRawContent(e,t=0){let i=this.root,n="";const o=this._searchCache.get2(e);if(o){i=o.node;const r=this.getAccumulatedValue(i,e-o.nodeStartLineNumber-1),a=this._buffers[i.piece.bufferIndex].buffer,l=this.offsetInBuffer(i.piece.bufferIndex,i.piece.start);if(o.nodeStartLineNumber+i.piece.lineFeedCnt===e)n=a.substring(l+r,l+i.piece.length);else{const d=this.getAccumulatedValue(i,e-o.nodeStartLineNumber);return a.substring(l+r,l+d-t)}}else{let r=0;const a=e;for(;i!==Je;)if(i.left!==Je&&i.lf_left>=e-1)i=i.left;else if(i.lf_left+i.piece.lineFeedCnt>e-1){const l=this.getAccumulatedValue(i,e-i.lf_left-2),d=this.getAccumulatedValue(i,e-i.lf_left-1),c=this._buffers[i.piece.bufferIndex].buffer,u=this.offsetInBuffer(i.piece.bufferIndex,i.piece.start);return r+=i.size_left,this._searchCache.set({node:i,nodeStartOffset:r,nodeStartLineNumber:a-(e-1-i.lf_left)}),c.substring(u+l,u+d-t)}else if(i.lf_left+i.piece.lineFeedCnt===e-1){const l=this.getAccumulatedValue(i,e-i.lf_left-2),d=this._buffers[i.piece.bufferIndex].buffer,c=this.offsetInBuffer(i.piece.bufferIndex,i.piece.start);n=d.substring(c+l,c+i.piece.length);break}else e-=i.lf_left+i.piece.lineFeedCnt,r+=i.size_left+i.piece.length,i=i.right}for(i=i.next();i!==Je;){const r=this._buffers[i.piece.bufferIndex].buffer;if(i.piece.lineFeedCnt>0){const a=this.getAccumulatedValue(i,0),l=this.offsetInBuffer(i.piece.bufferIndex,i.piece.start);return n+=r.substring(l,l+a-t),n}else{const a=this.offsetInBuffer(i.piece.bufferIndex,i.piece.start);n+=r.substr(a,i.piece.length)}i=i.next()}return n}computeBufferMetadata(){let e=this.root,t=1,i=0;for(;e!==Je;)t+=e.lf_left+e.piece.lineFeedCnt,i+=e.size_left+e.piece.length,e=e.right;this._lineCnt=t,this._length=i,this._searchCache.validate(this._length)}getIndexOf(e,t){const i=e.piece,n=this.positionInBuffer(e,t),o=n.line-i.start.line;if(this.offsetInBuffer(i.bufferIndex,i.end)-this.offsetInBuffer(i.bufferIndex,i.start)===t){const r=this.getLineFeedCnt(e.piece.bufferIndex,i.start,n);if(r!==o)return{index:r,remainder:0}}return{index:o,remainder:n.column}}getAccumulatedValue(e,t){if(t<0)return 0;const i=e.piece,n=this._buffers[i.bufferIndex].lineStarts,o=i.start.line+t+1;return o>i.end.line?n[i.end.line]+i.end.column-n[i.start.line]-i.start.column:n[o]-n[i.start.line]-i.start.column}deleteNodeTail(e,t){const i=e.piece,n=i.lineFeedCnt,o=this.offsetInBuffer(i.bufferIndex,i.end),r=t,a=this.offsetInBuffer(i.bufferIndex,r),l=this.getLineFeedCnt(i.bufferIndex,i.start,r),d=l-n,c=a-o,u=i.length+c;e.piece=new oo(i.bufferIndex,i.start,r,l,u),vd(this,e,c,d)}deleteNodeHead(e,t){const i=e.piece,n=i.lineFeedCnt,o=this.offsetInBuffer(i.bufferIndex,i.start),r=t,a=this.getLineFeedCnt(i.bufferIndex,r,i.end),l=this.offsetInBuffer(i.bufferIndex,r),d=a-n,c=o-l,u=i.length+c;e.piece=new oo(i.bufferIndex,r,i.end,a,u),vd(this,e,c,d)}shrinkNode(e,t,i){const n=e.piece,o=n.start,r=n.end,a=n.length,l=n.lineFeedCnt,d=t,c=this.getLineFeedCnt(n.bufferIndex,n.start,d),u=this.offsetInBuffer(n.bufferIndex,t)-this.offsetInBuffer(n.bufferIndex,o);e.piece=new oo(n.bufferIndex,n.start,d,c,u),vd(this,e,u-a,c-l);const h=new oo(n.bufferIndex,i,r,this.getLineFeedCnt(n.bufferIndex,i,r),this.offsetInBuffer(n.bufferIndex,r)-this.offsetInBuffer(n.bufferIndex,i)),g=this.rbInsertRight(e,h);this.validateCRLFWithPrevNode(g)}appendToNode(e,t){this.adjustCarriageReturnFromNext(t,e)&&(t+=`
`);const i=this.shouldCheckCRLF()&&this.startWithLF(t)&&this.endWithCR(e),n=this._buffers[0].buffer.length;this._buffers[0].buffer+=t;const o=bd(t,!1);for(let g=0;g<o.length;g++)o[g]+=n;if(i){const g=this._buffers[0].lineStarts[this._buffers[0].lineStarts.length-2];this._buffers[0].lineStarts.pop(),this._lastChangeBufferPos={line:this._lastChangeBufferPos.line-1,column:n-g}}this._buffers[0].lineStarts=this._buffers[0].lineStarts.concat(o.slice(1));const r=this._buffers[0].lineStarts.length-1,a=this._buffers[0].buffer.length-this._buffers[0].lineStarts[r],l={line:r,column:a},d=e.piece.length+t.length,c=e.piece.lineFeedCnt,u=this.getLineFeedCnt(0,e.piece.start,l),h=u-c;e.piece=new oo(e.piece.bufferIndex,e.piece.start,l,u,d),this._lastChangeBufferPos=l,vd(this,e,t.length,h)}nodeAt(e){let t=this.root;const i=this._searchCache.get(e);if(i)return{node:i.node,nodeStartOffset:i.nodeStartOffset,remainder:e-i.nodeStartOffset};let n=0;for(;t!==Je;)if(t.size_left>e)t=t.left;else if(t.size_left+t.piece.length>=e){n+=t.size_left;const o={node:t,remainder:e-t.size_left,nodeStartOffset:n};return this._searchCache.set(o),o}else e-=t.size_left+t.piece.length,n+=t.size_left+t.piece.length,t=t.right;return null}nodeAt2(e,t){let i=this.root,n=0;for(;i!==Je;)if(i.left!==Je&&i.lf_left>=e-1)i=i.left;else if(i.lf_left+i.piece.lineFeedCnt>e-1){const o=this.getAccumulatedValue(i,e-i.lf_left-2),r=this.getAccumulatedValue(i,e-i.lf_left-1);return n+=i.size_left,{node:i,remainder:Math.min(o+t-1,r),nodeStartOffset:n}}else if(i.lf_left+i.piece.lineFeedCnt===e-1){const o=this.getAccumulatedValue(i,e-i.lf_left-2);if(o+t-1<=i.piece.length)return{node:i,remainder:o+t-1,nodeStartOffset:n};t-=i.piece.length-o;break}else e-=i.lf_left+i.piece.lineFeedCnt,n+=i.size_left+i.piece.length,i=i.right;for(i=i.next();i!==Je;){if(i.piece.lineFeedCnt>0){const o=this.getAccumulatedValue(i,0),r=this.offsetOfNode(i);return{node:i,remainder:Math.min(t-1,o),nodeStartOffset:r}}else if(i.piece.length>=t-1){const o=this.offsetOfNode(i);return{node:i,remainder:t-1,nodeStartOffset:o}}else t-=i.piece.length;i=i.next()}return null}nodeCharCodeAt(e,t){if(e.piece.lineFeedCnt<1)return-1;const i=this._buffers[e.piece.bufferIndex],n=this.offsetInBuffer(e.piece.bufferIndex,e.piece.start)+t;return i.buffer.charCodeAt(n)}offsetOfNode(e){if(!e)return 0;let t=e.size_left;for(;e!==this.root;)e.parent.right===e&&(t+=e.parent.size_left+e.parent.piece.length),e=e.parent;return t}shouldCheckCRLF(){return!(this._EOLNormalized&&this._EOL===`
`)}startWithLF(e){if(typeof e=="string")return e.charCodeAt(0)===10;if(e===Je||e.piece.lineFeedCnt===0)return!1;const t=e.piece,i=this._buffers[t.bufferIndex].lineStarts,n=t.start.line,o=i[n]+t.start.column;return n===i.length-1||i[n+1]>o+1?!1:this._buffers[t.bufferIndex].buffer.charCodeAt(o)===10}endWithCR(e){return typeof e=="string"?e.charCodeAt(e.length-1)===13:e===Je||e.piece.lineFeedCnt===0?!1:this.nodeCharCodeAt(e,e.piece.length-1)===13}validateCRLFWithPrevNode(e){if(this.shouldCheckCRLF()&&this.startWithLF(e)){const t=e.prev();this.endWithCR(t)&&this.fixCRLF(t,e)}}validateCRLFWithNextNode(e){if(this.shouldCheckCRLF()&&this.endWithCR(e)){const t=e.next();this.startWithLF(t)&&this.fixCRLF(e,t)}}fixCRLF(e,t){const i=[],n=this._buffers[e.piece.bufferIndex].lineStarts;let o;e.piece.end.column===0?o={line:e.piece.end.line-1,column:n[e.piece.end.line]-n[e.piece.end.line-1]-1}:o={line:e.piece.end.line,column:e.piece.end.column-1};const r=e.piece.length-1,a=e.piece.lineFeedCnt-1;e.piece=new oo(e.piece.bufferIndex,e.piece.start,o,a,r),vd(this,e,-1,-1),e.piece.length===0&&i.push(e);const l={line:t.piece.start.line+1,column:0},d=t.piece.length-1,c=this.getLineFeedCnt(t.piece.bufferIndex,l,t.piece.end);t.piece=new oo(t.piece.bufferIndex,l,t.piece.end,c,d),vd(this,t,-1,-1),t.piece.length===0&&i.push(t);const u=this.createNewPieces(`\r
`);this.rbInsertRight(e,u[0]);for(let h=0;h<i.length;h++)L1(this,i[h])}adjustCarriageReturnFromNext(e,t){if(this.shouldCheckCRLF()&&this.endWithCR(e)){const i=t.next();if(this.startWithLF(i)){if(e+=`
`,i.piece.length===1)L1(this,i);else{const n=i.piece,o={line:n.start.line+1,column:0},r=n.length-1,a=this.getLineFeedCnt(n.bufferIndex,o,n.end);i.piece=new oo(n.bufferIndex,o,n.end,a,r),vd(this,i,-1,-1)}return!0}}return!1}iterate(e,t){if(e===Je)return t(Je);const i=this.iterate(e.left,t);return i&&t(e)&&this.iterate(e.right,t)}getNodeContent(e){if(e===Je)return"";const t=this._buffers[e.piece.bufferIndex],i=e.piece,n=this.offsetInBuffer(i.bufferIndex,i.start),o=this.offsetInBuffer(i.bufferIndex,i.end);return t.buffer.substring(n,o)}getPieceContent(e){const t=this._buffers[e.bufferIndex],i=this.offsetInBuffer(e.bufferIndex,e.start),n=this.offsetInBuffer(e.bufferIndex,e.end);return t.buffer.substring(i,n)}rbInsertRight(e,t){const i=new TT(t,1);if(i.left=Je,i.right=Je,i.parent=Je,i.size_left=0,i.lf_left=0,this.root===Je)this.root=i,i.color=0;else if(e.right===Je)e.right=i,i.parent=e;else{const o=FP(e.right);o.left=i,i.parent=o}return g7(this,i),i}rbInsertLeft(e,t){const i=new TT(t,1);if(i.left=Je,i.right=Je,i.parent=Je,i.size_left=0,i.lf_left=0,this.root===Je)this.root=i,i.color=0;else if(e.left===Je)e.left=i,i.parent=e;else{const n=oz(e.left);n.right=i,i.parent=n}return g7(this,i),i}}class jp extends j{constructor(e,t,i,n,o,r,a){super(),this._onDidChangeContent=this._register(new W),this._BOM=t,this._mightContainNonBasicASCII=!r,this._mightContainRTL=n,this._mightContainUnusualLineTerminators=o,this._pieceTree=new ode(e,i,a)}mightContainRTL(){return this._mightContainRTL}mightContainUnusualLineTerminators(){return this._mightContainUnusualLineTerminators}resetMightContainUnusualLineTerminators(){this._mightContainUnusualLineTerminators=!1}mightContainNonBasicASCII(){return this._mightContainNonBasicASCII}getBOM(){return this._BOM}getEOL(){return this._pieceTree.getEOL()}createSnapshot(e){return this._pieceTree.createSnapshot(e?this._BOM:"")}getOffsetAt(e,t){return this._pieceTree.getOffsetAt(e,t)}getPositionAt(e){return this._pieceTree.getPositionAt(e)}getRangeAt(e,t){const i=e+t,n=this.getPositionAt(e),o=this.getPositionAt(i);return new D(n.lineNumber,n.column,o.lineNumber,o.column)}getValueInRange(e,t=0){if(e.isEmpty())return"";const i=this._getEndOfLine(t);return this._pieceTree.getValueInRange(e,i)}getValueLengthInRange(e,t=0){if(e.isEmpty())return 0;if(e.startLineNumber===e.endLineNumber)return e.endColumn-e.startColumn;const i=this.getOffsetAt(e.startLineNumber,e.startColumn),n=this.getOffsetAt(e.endLineNumber,e.endColumn);let o=0;const r=this._getEndOfLine(t),a=this.getEOL();if(r.length!==a.length){const l=r.length-a.length,d=e.endLineNumber-e.startLineNumber;o=l*d}return n-i+o}getCharacterCountInRange(e,t=0){if(this._mightContainNonBasicASCII){let i=0;const n=e.startLineNumber,o=e.endLineNumber;for(let r=n;r<=o;r++){const a=this.getLineContent(r),l=r===n?e.startColumn-1:0,d=r===o?e.endColumn-1:a.length;for(let c=l;c<d;c++)_n(a.charCodeAt(c))?(i=i+1,c=c+1):i=i+1}return i+=this._getEndOfLine(t).length*(o-n),i}return this.getValueLengthInRange(e,t)}getLength(){return this._pieceTree.getLength()}getLineCount(){return this._pieceTree.getLineCount()}getLinesContent(){return this._pieceTree.getLinesContent()}getLineContent(e){return this._pieceTree.getLineContent(e)}getLineCharCode(e,t){return this._pieceTree.getLineCharCode(e,t)}getLineLength(e){return this._pieceTree.getLineLength(e)}getLineFirstNonWhitespaceColumn(e){const t=ws(this.getLineContent(e));return t===-1?0:t+1}getLineLastNonWhitespaceColumn(e){const t=Pa(this.getLineContent(e));return t===-1?0:t+2}_getEndOfLine(e){switch(e){case 1:return`
`;case 2:return`\r
`;case 0:return this.getEOL();default:throw new Error("Unknown EOL preference")}}setEOL(e){this._pieceTree.setEOL(e)}applyEdits(e,t,i){let n=this._mightContainRTL,o=this._mightContainUnusualLineTerminators,r=this._mightContainNonBasicASCII,a=!0,l=[];for(let m=0;m<e.length;m++){const _=e[m];a&&_._isTracked&&(a=!1);const v=_.range;if(_.text){let x=!0;r||(x=!sC(_.text),r=x),!n&&x&&(n=dm(_.text)),!o&&x&&(o=jW(_.text))}let b="",C=0,w=0,S=0;if(_.text){let x;[C,w,S,x]=Ou(_.text);const L=this.getEOL();x===0||x===(L===`\r
`?2:1)?b=_.text:b=_.text.replace(/\r\n|\r|\n/g,L)}l[m]={sortIndex:m,identifier:_.identifier||null,range:v,rangeOffset:this.getOffsetAt(v.startLineNumber,v.startColumn),rangeLength:this.getValueLengthInRange(v),text:b,eolCount:C,firstLineLength:w,lastLineLength:S,forceMoveMarkers:!!_.forceMoveMarkers,isAutoWhitespaceEdit:_.isAutoWhitespaceEdit||!1}}l.sort(jp._sortOpsAscending);let d=!1;for(let m=0,_=l.length-1;m<_;m++){const v=l[m].range.getEndPosition(),b=l[m+1].range.getStartPosition();if(b.isBeforeOrEqual(v)){if(b.isBefore(v))throw new Error("Overlapping ranges are not allowed!");d=!0}}a&&(l=this._reduceOperations(l));const c=i||t?jp._getInverseEditRanges(l):[],u=[];if(t)for(let m=0;m<l.length;m++){const _=l[m],v=c[m];if(_.isAutoWhitespaceEdit&&_.range.isEmpty())for(let b=v.startLineNumber;b<=v.endLineNumber;b++){let C="";b===v.startLineNumber&&(C=this.getLineContent(_.range.startLineNumber),ws(C)!==-1)||u.push({lineNumber:b,oldContent:C})}}let h=null;if(i){let m=0;h=[];for(let _=0;_<l.length;_++){const v=l[_],b=c[_],C=this.getValueInRange(v.range),w=v.rangeOffset+m;m+=v.text.length-C.length,h[_]={sortIndex:v.sortIndex,identifier:v.identifier,range:b,text:C,textChange:new qn(v.rangeOffset,C,w,v.text)}}d||h.sort((_,v)=>_.sortIndex-v.sortIndex)}this._mightContainRTL=n,this._mightContainUnusualLineTerminators=o,this._mightContainNonBasicASCII=r;const g=this._doApplyEdits(l);let f=null;if(t&&u.length>0){u.sort((m,_)=>_.lineNumber-m.lineNumber),f=[];for(let m=0,_=u.length;m<_;m++){const v=u[m].lineNumber;if(m>0&&u[m-1].lineNumber===v)continue;const b=u[m].oldContent,C=this.getLineContent(v);C.length===0||C===b||ws(C)!==-1||f.push(v)}}return this._onDidChangeContent.fire(),new pie(h,g,f)}_reduceOperations(e){return e.length<1e3?e:[this._toSingleEditOperation(e)]}_toSingleEditOperation(e){let t=!1;const i=e[0].range,n=e[e.length-1].range,o=new D(i.startLineNumber,i.startColumn,n.endLineNumber,n.endColumn);let r=i.startLineNumber,a=i.startColumn;const l=[];for(let g=0,f=e.length;g<f;g++){const m=e[g],_=m.range;t=t||m.forceMoveMarkers,l.push(this.getValueInRange(new D(r,a,_.startLineNumber,_.startColumn))),m.text.length>0&&l.push(m.text),r=_.endLineNumber,a=_.endColumn}const d=l.join(""),[c,u,h]=Ou(d);return{sortIndex:0,identifier:e[0].identifier,range:o,rangeOffset:this.getOffsetAt(o.startLineNumber,o.startColumn),rangeLength:this.getValueLengthInRange(o,0),text:d,eolCount:c,firstLineLength:u,lastLineLength:h,forceMoveMarkers:t,isAutoWhitespaceEdit:!1}}_doApplyEdits(e){e.sort(jp._sortOpsDescending);const t=[];for(let i=0;i<e.length;i++){const n=e[i],o=n.range.startLineNumber,r=n.range.startColumn,a=n.range.endLineNumber,l=n.range.endColumn;if(o===a&&r===l&&n.text.length===0)continue;n.text?(this._pieceTree.delete(n.rangeOffset,n.rangeLength),this._pieceTree.insert(n.rangeOffset,n.text,!0)):this._pieceTree.delete(n.rangeOffset,n.rangeLength);const d=new D(o,r,a,l);t.push({range:d,rangeLength:n.rangeLength,text:n.text,rangeOffset:n.rangeOffset,forceMoveMarkers:n.forceMoveMarkers})}return t}findMatchesLineByLine(e,t,i,n){return this._pieceTree.findMatchesLineByLine(e,t,i,n)}static _getInverseEditRanges(e){const t=[];let i=0,n=0,o=null;for(let r=0,a=e.length;r<a;r++){const l=e[r];let d,c;o?o.range.endLineNumber===l.range.startLineNumber?(d=i,c=n+(l.range.startColumn-o.range.endColumn)):(d=i+(l.range.startLineNumber-o.range.endLineNumber),c=l.range.startColumn):(d=l.range.startLineNumber,c=l.range.startColumn);let u;if(l.text.length>0){const h=l.eolCount+1;h===1?u=new D(d,c,d,c+l.firstLineLength):u=new D(d,c,d+h-1,l.lastLineLength+1)}else u=new D(d,c,d,c);i=u.endLineNumber,n=u.endColumn,t.push(u),o=l}return t}static _sortOpsAscending(e,t){const i=D.compareRangesUsingEnds(e.range,t.range);return i===0?e.sortIndex-t.sortIndex:i}static _sortOpsDescending(e,t){const i=D.compareRangesUsingEnds(e.range,t.range);return i===0?t.sortIndex-e.sortIndex:-i}}class rde{constructor(e,t,i,n,o,r,a,l,d){this._chunks=e,this._bom=t,this._cr=i,this._lf=n,this._crlf=o,this._containsRTL=r,this._containsUnusualLineTerminators=a,this._isBasicASCII=l,this._normalizeEOL=d}_getEOL(e){const t=this._cr+this._lf+this._crlf,i=this._cr+this._crlf;return t===0?e===1?`
`:`\r
`:i>t/2?`\r
`:`
`}create(e){const t=this._getEOL(e),i=this._chunks;if(this._normalizeEOL&&(t===`\r
`&&(this._cr>0||this._lf>0)||t===`
`&&(this._cr>0||this._crlf>0)))for(let o=0,r=i.length;o<r;o++){const a=i[o].buffer.replace(/\r\n|\r|\n/g,t),l=bd(a);i[o]=new Gh(a,l)}const n=new jp(i,this._bom,t,this._containsRTL,this._containsUnusualLineTerminators,this._isBasicASCII,this._normalizeEOL);return{textBuffer:n,disposable:n}}}class az{constructor(){this.chunks=[],this.BOM="",this._hasPreviousChar=!1,this._previousChar=0,this._tmpLineStarts=[],this.cr=0,this.lf=0,this.crlf=0,this.containsRTL=!1,this.containsUnusualLineTerminators=!1,this.isBasicASCII=!0}acceptChunk(e){if(e.length===0)return;this.chunks.length===0&&zA(e)&&(this.BOM=dJ,e=e.substr(1));const t=e.charCodeAt(e.length-1);t===13||t>=55296&&t<=56319?(this._acceptChunk1(e.substr(0,e.length-1),!1),this._hasPreviousChar=!0,this._previousChar=t):(this._acceptChunk1(e,!1),this._hasPreviousChar=!1,this._previousChar=t)}_acceptChunk1(e,t){!t&&e.length===0||(this._hasPreviousChar?this._acceptChunk2(String.fromCharCode(this._previousChar)+e):this._acceptChunk2(e))}_acceptChunk2(e){const t=ide(this._tmpLineStarts,e);this.chunks.push(new Gh(e,t.lineStarts)),this.cr+=t.cr,this.lf+=t.lf,this.crlf+=t.crlf,t.isBasicASCII||(this.isBasicASCII=!1,this.containsRTL||(this.containsRTL=dm(e)),this.containsUnusualLineTerminators||(this.containsUnusualLineTerminators=jW(e)))}finish(e=!0){return this._finish(),new rde(this.chunks,this.BOM,this.cr,this.lf,this.crlf,this.containsRTL,this.containsUnusualLineTerminators,this.isBasicASCII,e)}_finish(){if(this.chunks.length===0&&this._acceptChunk1("",!0),this._hasPreviousChar){this._hasPreviousChar=!1;const e=this.chunks[this.chunks.length-1];e.buffer+=String.fromCharCode(this._previousChar);const t=bd(e.buffer);e.lineStarts=t,this._previousChar===13&&this.cr++}}}class ade{constructor(e){this._default=e,this._store=[]}get(e){return e<this._store.length?this._store[e]:this._default}set(e,t){for(;e>=this._store.length;)this._store[this._store.length]=this._default;this._store[e]=t}replace(e,t,i){if(e>=this._store.length)return;if(t===0){this.insert(e,i);return}else if(i===0){this.delete(e,t);return}const n=this._store.slice(0,e),o=this._store.slice(e+t),r=lde(i,this._default);this._store=n.concat(r,o)}delete(e,t){t===0||e>=this._store.length||this._store.splice(e,t)}insert(e,t){if(t===0||e>=this._store.length)return;const i=[];for(let n=0;n<t;n++)i[n]=this._default;this._store=$L(this._store,e,i)}}function lde(s,e){const t=[];for(let i=0;i<s;i++)t[i]=e;return t}class dde{get startLineNumber(){return this._startLineNumber}get endLineNumber(){return this._startLineNumber+this._tokens.length-1}constructor(e,t){this._startLineNumber=e,this._tokens=t}getLineTokens(e){return this._tokens[e-this._startLineNumber]}appendLineTokens(e){this._tokens.push(e)}}class MT{constructor(){this._tokens=[]}add(e,t){if(this._tokens.length>0){const i=this._tokens[this._tokens.length-1];if(i.endLineNumber+1===e){i.appendLineTokens(t);return}}this._tokens.push(new dde(e,[t]))}finalize(){return this._tokens}}class cde{constructor(e,t){this.tokenizationSupport=t,this.initialState=this.tokenizationSupport.getInitialState(),this.store=new RT(e)}getStartState(e){return this.store.getStartState(e,this.initialState)}getFirstInvalidLine(){return this.store.getFirstInvalidLine(this.initialState)}}class ude extends cde{constructor(e,t,i,n){super(e,t),this._textModel=i,this._languageIdCodec=n}updateTokensUntilLine(e,t){const i=this._textModel.getLanguageId();for(;;){const n=this.getFirstInvalidLine();if(!n||n.lineNumber>t)break;const o=this._textModel.getLineContent(n.lineNumber),r=W_(this._languageIdCodec,i,this.tokenizationSupport,o,!0,n.startState);e.add(n.lineNumber,r.tokens),this.store.setEndState(n.lineNumber,r.endState)}}getTokenTypeIfInsertingCharacter(e,t){const i=this.getStartState(e.lineNumber);if(!i)return 0;const n=this._textModel.getLanguageId(),o=this._textModel.getLineContent(e.lineNumber),r=o.substring(0,e.column-1)+t+o.substring(e.column-1),a=W_(this._languageIdCodec,n,this.tokenizationSupport,r,!0,i),l=new vn(a.tokens,r,this._languageIdCodec);if(l.getCount()===0)return 0;const d=l.findTokenIndexAtOffset(e.column-1);return l.getStandardTokenType(d)}tokenizeLineWithEdit(e,t,i){const n=e.lineNumber,o=e.column,r=this.getStartState(n);if(!r)return null;const a=this._textModel.getLineContent(n),l=a.substring(0,o-1)+i+a.substring(o-1+t),d=this._textModel.getLanguageIdAtPosition(n,0),c=W_(this._languageIdCodec,d,this.tokenizationSupport,l,!0,r);return new vn(c.tokens,l,this._languageIdCodec)}isCheapToTokenize(e){const t=this.store.getFirstInvalidEndStateLineNumberOrMax();return e<t||e===t&&this._textModel.getLineLength(e)<2048}tokenizeHeuristically(e,t,i){if(i<=this.store.getFirstInvalidEndStateLineNumberOrMax())return{heuristicTokens:!1};if(t<=this.store.getFirstInvalidEndStateLineNumberOrMax())return this.updateTokensUntilLine(e,i),{heuristicTokens:!1};let n=this.guessStartState(t);const o=this._textModel.getLanguageId();for(let r=t;r<=i;r++){const a=this._textModel.getLineContent(r),l=W_(this._languageIdCodec,o,this.tokenizationSupport,a,!0,n);e.add(r,l.tokens),n=l.endState}return{heuristicTokens:!0}}guessStartState(e){let t=this._textModel.getLineFirstNonWhitespaceColumn(e);const i=[];let n=null;for(let a=e-1;t>1&&a>=1;a--){const l=this._textModel.getLineFirstNonWhitespaceColumn(a);if(l!==0&&l<t&&(i.push(this._textModel.getLineContent(a)),t=l,n=this.getStartState(a),n))break}n||(n=this.tokenizationSupport.getInitialState()),i.reverse();const o=this._textModel.getLanguageId();let r=n;for(const a of i)r=W_(this._languageIdCodec,o,this.tokenizationSupport,a,!1,r).endState;return r}}class RT{constructor(e){this.lineCount=e,this._tokenizationStateStore=new hde,this._invalidEndStatesLineNumbers=new gde,this._invalidEndStatesLineNumbers.addRange(new rt(1,e+1))}getEndState(e){return this._tokenizationStateStore.getEndState(e)}setEndState(e,t){if(!t)throw new pi("Cannot set null/undefined state");this._invalidEndStatesLineNumbers.delete(e);const i=this._tokenizationStateStore.setEndState(e,t);return i&&e<this.lineCount&&this._invalidEndStatesLineNumbers.addRange(new rt(e+1,e+2)),i}acceptChange(e,t){this.lineCount+=t-e.length,this._tokenizationStateStore.acceptChange(e,t),this._invalidEndStatesLineNumbers.addRangeAndResize(new rt(e.startLineNumber,e.endLineNumberExclusive),t)}acceptChanges(e){for(const t of e){const[i]=Ou(t.text);this.acceptChange(new ft(t.range.startLineNumber,t.range.endLineNumber+1),i+1)}}invalidateEndStateRange(e){this._invalidEndStatesLineNumbers.addRange(new rt(e.startLineNumber,e.endLineNumberExclusive))}getFirstInvalidEndStateLineNumber(){return this._invalidEndStatesLineNumbers.min}getFirstInvalidEndStateLineNumberOrMax(){return this.getFirstInvalidEndStateLineNumber()||Number.MAX_SAFE_INTEGER}allStatesValid(){return this._invalidEndStatesLineNumbers.min===null}getStartState(e,t){return e===1?t:this.getEndState(e-1)}getFirstInvalidLine(e){const t=this.getFirstInvalidEndStateLineNumber();if(t===null)return null;const i=this.getStartState(t,e);if(!i)throw new pi("Start state must be defined");return{lineNumber:t,startState:i}}}class hde{constructor(){this._lineEndStates=new ade(null)}getEndState(e){return this._lineEndStates.get(e)}setEndState(e,t){const i=this._lineEndStates.get(e);return i&&i.equals(t)?!1:(this._lineEndStates.set(e,t),!0)}acceptChange(e,t){let i=e.length;t>0&&i>0&&(i--,t--),this._lineEndStates.replace(e.startLineNumber,i,t)}}class gde{constructor(){this._ranges=[]}get min(){return this._ranges.length===0?null:this._ranges[0].start}delete(e){const t=this._ranges.findIndex(i=>i.contains(e));if(t!==-1){const i=this._ranges[t];i.start===e?i.endExclusive===e+1?this._ranges.splice(t,1):this._ranges[t]=new rt(e+1,i.endExclusive):i.endExclusive===e+1?this._ranges[t]=new rt(i.start,e):this._ranges.splice(t,1,new rt(i.start,e),new rt(e+1,i.endExclusive))}}addRange(e){rt.addRange(e,this._ranges)}addRangeAndResize(e,t){let i=0;for(;!(i>=this._ranges.length||e.start<=this._ranges[i].endExclusive);)i++;let n=i;for(;!(n>=this._ranges.length||e.endExclusive<this._ranges[n].start);)n++;const o=t-e.length;for(let r=n;r<this._ranges.length;r++)this._ranges[r]=this._ranges[r].delta(o);if(i===n){const r=new rt(e.start,e.start+t);r.isEmpty||this._ranges.splice(i,0,r)}else{const r=Math.min(e.start,this._ranges[i].start),a=Math.max(e.endExclusive,this._ranges[n-1].endExclusive),l=new rt(r,a+o);l.isEmpty?this._ranges.splice(i,n-i):this._ranges.splice(i,n-i,l)}}toString(){return this._ranges.map(e=>e.toString()).join(" + ")}}function W_(s,e,t,i,n,o){let r=null;if(t)try{r=t.tokenizeEncoded(i,n,o.clone())}catch(a){et(a)}return r||(r=_x(s.encodeLanguageId(e),o)),vn.convertToEndOffset(r.tokens,i.length),r}class fde{constructor(e,t){this._tokenizerWithStateStore=e,this._backgroundTokenStore=t,this._isDisposed=!1,this._isScheduled=!1}dispose(){this._isDisposed=!0}handleChanges(){this._beginBackgroundTokenization()}_beginBackgroundTokenization(){this._isScheduled||!this._tokenizerWithStateStore._textModel.isAttachedToEditor()||!this._hasLinesToTokenize()||(this._isScheduled=!0,oV(e=>{this._isScheduled=!1,this._backgroundTokenizeWithDeadline(e)}))}_backgroundTokenizeWithDeadline(e){const t=Date.now()+e.timeRemaining(),i=()=>{this._isDisposed||!this._tokenizerWithStateStore._textModel.isAttachedToEditor()||!this._hasLinesToTokenize()||(this._backgroundTokenizeForAtLeast1ms(),Date.now()<t?vW(i):this._beginBackgroundTokenization())};i()}_backgroundTokenizeForAtLeast1ms(){const e=this._tokenizerWithStateStore._textModel.getLineCount(),t=new MT,i=cs.create(!1);do if(i.elapsed()>1||this._tokenizeOneInvalidLine(t)>=e)break;while(this._hasLinesToTokenize());this._backgroundTokenStore.setTokens(t.finalize()),this.checkFinished()}_hasLinesToTokenize(){return this._tokenizerWithStateStore?!this._tokenizerWithStateStore.store.allStatesValid():!1}_tokenizeOneInvalidLine(e){var t;const i=(t=this._tokenizerWithStateStore)===null||t===void 0?void 0:t.getFirstInvalidLine();return i?(this._tokenizerWithStateStore.updateTokensUntilLine(e,i.lineNumber),i.lineNumber):this._tokenizerWithStateStore._textModel.getLineCount()+1}checkFinished(){this._isDisposed||this._tokenizerWithStateStore.store.allStatesValid()&&this._backgroundTokenStore.backgroundTokenizationFinished()}requestTokens(e,t){this._tokenizerWithStateStore.store.invalidateEndStateRange(new ft(e,t))}}const Cd=new Uint32Array(0).buffer;class dl{static deleteBeginning(e,t){return e===null||e===Cd?e:dl.delete(e,0,t)}static deleteEnding(e,t){if(e===null||e===Cd)return e;const i=Md(e),n=i[i.length-2];return dl.delete(e,t,n)}static delete(e,t,i){if(e===null||e===Cd||t===i)return e;const n=Md(e),o=n.length>>>1;if(t===0&&n[n.length-2]===i)return Cd;const r=vn.findIndexInTokensArray(n,t),a=r>0?n[r-1<<1]:0,l=n[r<<1];if(i<l){const g=i-t;for(let f=r;f<o;f++)n[f<<1]-=g;return e}let d,c;a!==t?(n[r<<1]=t,d=r+1<<1,c=t):(d=r<<1,c=a);const u=i-t;for(let g=r+1;g<o;g++){const f=n[g<<1]-u;f>c&&(n[d++]=f,n[d++]=n[(g<<1)+1],c=f)}if(d===n.length)return e;const h=new Uint32Array(d);return h.set(n.subarray(0,d),0),h.buffer}static append(e,t){if(t===Cd)return e;if(e===Cd)return t;if(e===null)return e;if(t===null)return null;const i=Md(e),n=Md(t),o=n.length>>>1,r=new Uint32Array(i.length+n.length);r.set(i,0);let a=i.length;const l=i[i.length-2];for(let d=0;d<o;d++)r[a++]=n[d<<1]+l,r[a++]=n[(d<<1)+1];return r.buffer}static insert(e,t,i){if(e===null||e===Cd)return e;const n=Md(e),o=n.length>>>1;let r=vn.findIndexInTokensArray(n,t);r>0&&n[r-1<<1]===t&&r--;for(let a=r;a<o;a++)n[a<<1]+=i;return e}}function Md(s){return s instanceof Uint32Array?s:new Uint32Array(s)}class tb{constructor(e){this._lineTokens=[],this._len=0,this._languageIdCodec=e}flush(){this._lineTokens=[],this._len=0}get hasTokens(){return this._lineTokens.length>0}getTokens(e,t,i){let n=null;if(t<this._len&&(n=this._lineTokens[t]),n!==null&&n!==Cd)return new vn(Md(n),i,this._languageIdCodec);const o=new Uint32Array(2);return o[0]=i.length,o[1]=f7(this._languageIdCodec.encodeLanguageId(e)),new vn(o,i,this._languageIdCodec)}static _massageTokens(e,t,i){const n=i?Md(i):null;if(t===0){let o=!1;if(n&&n.length>1&&(o=Zn.getLanguageId(n[1])!==e),!o)return Cd}if(!n||n.length===0){const o=new Uint32Array(2);return o[0]=t,o[1]=f7(e),o.buffer}return n[n.length-2]=t,n.byteOffset===0&&n.byteLength===n.buffer.byteLength?n.buffer:n}_ensureLine(e){for(;e>=this._len;)this._lineTokens[this._len]=null,this._len++}_deleteLines(e,t){t!==0&&(e+t>this._len&&(t=this._len-e),this._lineTokens.splice(e,t),this._len-=t)}_insertLines(e,t){if(t===0)return;const i=[];for(let n=0;n<t;n++)i[n]=null;this._lineTokens=$L(this._lineTokens,e,i),this._len+=t}setTokens(e,t,i,n,o){const r=tb._massageTokens(this._languageIdCodec.encodeLanguageId(e),i,n);this._ensureLine(t);const a=this._lineTokens[t];return this._lineTokens[t]=r,o?!tb._equals(a,r):!1}static _equals(e,t){if(!e||!t)return!e&&!t;const i=Md(e),n=Md(t);if(i.length!==n.length)return!1;for(let o=0,r=i.length;o<r;o++)if(i[o]!==n[o])return!1;return!0}acceptEdit(e,t,i){this._acceptDeleteRange(e),this._acceptInsertText(new H(e.startLineNumber,e.startColumn),t,i)}_acceptDeleteRange(e){const t=e.startLineNumber-1;if(t>=this._len)return;if(e.startLineNumber===e.endLineNumber){if(e.startColumn===e.endColumn)return;this._lineTokens[t]=dl.delete(this._lineTokens[t],e.startColumn-1,e.endColumn-1);return}this._lineTokens[t]=dl.deleteEnding(this._lineTokens[t],e.startColumn-1);const i=e.endLineNumber-1;let n=null;i<this._len&&(n=dl.deleteBeginning(this._lineTokens[i],e.endColumn-1)),this._lineTokens[t]=dl.append(this._lineTokens[t],n),this._deleteLines(e.startLineNumber,e.endLineNumber-e.startLineNumber)}_acceptInsertText(e,t,i){if(t===0&&i===0)return;const n=e.lineNumber-1;if(!(n>=this._len)){if(t===0){this._lineTokens[n]=dl.insert(this._lineTokens[n],e.column-1,i);return}this._lineTokens[n]=dl.deleteEnding(this._lineTokens[n],e.column-1),this._lineTokens[n]=dl.insert(this._lineTokens[n],e.column-1,i),this._insertLines(e.lineNumber,t)}}setMultilineTokens(e,t){if(e.length===0)return{changes:[]};const i=[];for(let n=0,o=e.length;n<o;n++){const r=e[n];let a=0,l=0,d=!1;for(let c=r.startLineNumber;c<=r.endLineNumber;c++)d?(this.setTokens(t.getLanguageId(),c-1,t.getLineLength(c),r.getLineTokens(c),!1),l=c):this.setTokens(t.getLanguageId(),c-1,t.getLineLength(c),r.getLineTokens(c),!0)&&(d=!0,a=c,l=c);d&&i.push({fromLineNumber:a,toLineNumber:l})}return{changes:i}}}function f7(s){return(s<<0|0|0|32768|2<<24|1024)>>>0}class VP{constructor(e){this._pieces=[],this._isComplete=!1,this._languageIdCodec=e}flush(){this._pieces=[],this._isComplete=!1}isEmpty(){return this._pieces.length===0}set(e,t){this._pieces=e||[],this._isComplete=t}setPartial(e,t){let i=e;if(t.length>0){const o=t[0].getRange(),r=t[t.length-1].getRange();if(!o||!r)return e;i=e.plusRange(o).plusRange(r)}let n=null;for(let o=0,r=this._pieces.length;o<r;o++){const a=this._pieces[o];if(a.endLineNumber<i.startLineNumber)continue;if(a.startLineNumber>i.endLineNumber){n=n||{index:o};break}if(a.removeTokens(i),a.isEmpty()){this._pieces.splice(o,1),o--,r--;continue}if(a.endLineNumber<i.startLineNumber)continue;if(a.startLineNumber>i.endLineNumber){n=n||{index:o};continue}const[l,d]=a.split(i);if(l.isEmpty()){n=n||{index:o};continue}d.isEmpty()||(this._pieces.splice(o,1,l,d),o++,r++,n=n||{index:o})}return n=n||{index:this._pieces.length},t.length>0&&(this._pieces=$L(this._pieces,n.index,t)),i}isComplete(){return this._isComplete}addSparseTokens(e,t){if(t.getLineContent().length===0)return t;const i=this._pieces;if(i.length===0)return t;const n=VP._findFirstPieceWithLine(i,e),o=i[n].getLineTokens(e);if(!o)return t;const r=t.getCount(),a=o.getCount();let l=0;const d=[];let c=0,u=0;const h=(g,f)=>{g!==u&&(u=g,d[c++]=g,d[c++]=f)};for(let g=0;g<a;g++){const f=o.getStartCharacter(g),m=o.getEndCharacter(g),_=o.getMetadata(g),v=((_&1?2048:0)|(_&2?4096:0)|(_&4?8192:0)|(_&8?16384:0)|(_&16?16744448:0)|(_&32?4278190080:0))>>>0,b=~v>>>0;for(;l<r&&t.getEndOffset(l)<=f;)h(t.getEndOffset(l),t.getMetadata(l)),l++;for(l<r&&t.getStartOffset(l)<f&&h(f,t.getMetadata(l));l<r&&t.getEndOffset(l)<m;)h(t.getEndOffset(l),t.getMetadata(l)&b|_&v),l++;if(l<r)h(m,t.getMetadata(l)&b|_&v),t.getEndOffset(l)===m&&l++;else{const C=Math.min(Math.max(0,l-1),r-1);h(m,t.getMetadata(C)&b|_&v)}}for(;l<r;)h(t.getEndOffset(l),t.getMetadata(l)),l++;return new vn(new Uint32Array(d),t.getLineContent(),this._languageIdCodec)}static _findFirstPieceWithLine(e,t){let i=0,n=e.length-1;for(;i<n;){let o=i+Math.floor((n-i)/2);if(e[o].endLineNumber<t)i=o+1;else if(e[o].startLineNumber>t)n=o-1;else{for(;o>i&&e[o-1].startLineNumber<=t&&t<=e[o-1].endLineNumber;)o--;return o}}return i}acceptEdit(e,t,i,n,o){for(const r of this._pieces)r.acceptEdit(e,t,i,n,o)}}class ay extends WH{constructor(e,t,i,n,o,r){super(),this._languageService=e,this._languageConfigurationService=t,this._textModel=i,this._bracketPairsTextModelPart=n,this._languageId=o,this._attachedViews=r,this._semanticTokens=new VP(this._languageService.languageIdCodec),this._onDidChangeLanguage=this._register(new W),this.onDidChangeLanguage=this._onDidChangeLanguage.event,this._onDidChangeLanguageConfiguration=this._register(new W),this.onDidChangeLanguageConfiguration=this._onDidChangeLanguageConfiguration.event,this._onDidChangeTokens=this._register(new W),this.onDidChangeTokens=this._onDidChangeTokens.event,this.grammarTokens=this._register(new pde(this._languageService.languageIdCodec,this._textModel,()=>this._languageId,this._attachedViews)),this._register(this._languageConfigurationService.onDidChange(a=>{a.affects(this._languageId)&&this._onDidChangeLanguageConfiguration.fire({})})),this._register(this.grammarTokens.onDidChangeTokens(a=>{this._emitModelTokensChangedEvent(a)})),this._register(this.grammarTokens.onDidChangeBackgroundTokenizationState(a=>{this._bracketPairsTextModelPart.handleDidChangeBackgroundTokenizationState()}))}handleDidChangeContent(e){if(e.isFlush)this._semanticTokens.flush();else if(!e.isEolChange)for(const t of e.changes){const[i,n,o]=Ou(t.text);this._semanticTokens.acceptEdit(t.range,i,n,o,t.text.length>0?t.text.charCodeAt(0):0)}this.grammarTokens.handleDidChangeContent(e)}handleDidChangeAttached(){this.grammarTokens.handleDidChangeAttached()}getLineTokens(e){this.validateLineNumber(e);const t=this.grammarTokens.getLineTokens(e);return this._semanticTokens.addSparseTokens(e,t)}_emitModelTokensChangedEvent(e){this._textModel._isDisposing()||(this._bracketPairsTextModelPart.handleDidChangeTokens(e),this._onDidChangeTokens.fire(e))}validateLineNumber(e){if(e<1||e>this._textModel.getLineCount())throw new pi("Illegal value for lineNumber")}get hasTokens(){return this.grammarTokens.hasTokens}resetTokenization(){this.grammarTokens.resetTokenization()}get backgroundTokenizationState(){return this.grammarTokens.backgroundTokenizationState}forceTokenization(e){this.validateLineNumber(e),this.grammarTokens.forceTokenization(e)}isCheapToTokenize(e){return this.validateLineNumber(e),this.grammarTokens.isCheapToTokenize(e)}tokenizeIfCheap(e){this.validateLineNumber(e),this.grammarTokens.tokenizeIfCheap(e)}getTokenTypeIfInsertingCharacter(e,t,i){return this.grammarTokens.getTokenTypeIfInsertingCharacter(e,t,i)}tokenizeLineWithEdit(e,t,i){return this.grammarTokens.tokenizeLineWithEdit(e,t,i)}setSemanticTokens(e,t){this._semanticTokens.set(e,t),this._emitModelTokensChangedEvent({semanticTokensApplied:e!==null,ranges:[{fromLineNumber:1,toLineNumber:this._textModel.getLineCount()}]})}hasCompleteSemanticTokens(){return this._semanticTokens.isComplete()}hasSomeSemanticTokens(){return!this._semanticTokens.isEmpty()}setPartialSemanticTokens(e,t){if(this.hasCompleteSemanticTokens())return;const i=this._textModel.validateRange(this._semanticTokens.setPartial(e,t));this._emitModelTokensChangedEvent({semanticTokensApplied:!0,ranges:[{fromLineNumber:i.startLineNumber,toLineNumber:i.endLineNumber}]})}getWordAtPosition(e){this.assertNotDisposed();const t=this._textModel.validatePosition(e),i=this._textModel.getLineContent(t.lineNumber),n=this.getLineTokens(t.lineNumber),o=n.findTokenIndexAtOffset(t.column-1),[r,a]=ay._findLanguageBoundaries(n,o),l=w0(t.column,this.getLanguageConfiguration(n.getLanguageId(o)).getWordDefinition(),i.substring(r,a),r);if(l&&l.startColumn<=e.column&&e.column<=l.endColumn)return l;if(o>0&&r===t.column-1){const[d,c]=ay._findLanguageBoundaries(n,o-1),u=w0(t.column,this.getLanguageConfiguration(n.getLanguageId(o-1)).getWordDefinition(),i.substring(d,c),d);if(u&&u.startColumn<=e.column&&e.column<=u.endColumn)return u}return null}getLanguageConfiguration(e){return this._languageConfigurationService.getLanguageConfiguration(e)}static _findLanguageBoundaries(e,t){const i=e.getLanguageId(t);let n=0;for(let r=t;r>=0&&e.getLanguageId(r)===i;r--)n=e.getStartOffset(r);let o=e.getLineContent().length;for(let r=t,a=e.getCount();r<a&&e.getLanguageId(r)===i;r++)o=e.getEndOffset(r);return[n,o]}getWordUntilPosition(e){const t=this.getWordAtPosition(e);return t?{word:t.word.substr(0,e.column-t.startColumn),startColumn:t.startColumn,endColumn:e.column}:{word:"",startColumn:e.column,endColumn:e.column}}getLanguageId(){return this._languageId}getLanguageIdAtPosition(e,t){const i=this._textModel.validatePosition(new H(e,t)),n=this.getLineTokens(i.lineNumber);return n.getLanguageId(n.findTokenIndexAtOffset(i.column-1))}setLanguageId(e,t="api"){if(this._languageId===e)return;const i={oldLanguage:this._languageId,newLanguage:e,source:t};this._languageId=e,this._bracketPairsTextModelPart.handleDidChangeLanguage(i),this.grammarTokens.resetTokenization(),this._onDidChangeLanguage.fire(i),this._onDidChangeLanguageConfiguration.fire({})}}class pde extends j{get backgroundTokenizationState(){return this._backgroundTokenizationState}constructor(e,t,i,n){super(),this._languageIdCodec=e,this._textModel=t,this.getLanguageId=i,this._tokenizer=null,this._defaultBackgroundTokenizer=null,this._backgroundTokenizer=this._register(new En),this._tokens=new tb(this._languageIdCodec),this._debugBackgroundTokenizer=this._register(new En),this._backgroundTokenizationState=1,this._onDidChangeBackgroundTokenizationState=this._register(new W),this.onDidChangeBackgroundTokenizationState=this._onDidChangeBackgroundTokenizationState.event,this._onDidChangeTokens=this._register(new W),this.onDidChangeTokens=this._onDidChangeTokens.event,this._attachedViewStates=this._register(new NA),this._register(xi.onDidChange(o=>{const r=this.getLanguageId();o.changedLanguages.indexOf(r)!==-1&&this.resetTokenization()})),this.resetTokenization(),this._register(n.onDidChangeVisibleRanges(({view:o,state:r})=>{if(r){let a=this._attachedViewStates.get(o);a||(a=new mde(()=>this.refreshRanges(a.lineRanges)),this._attachedViewStates.set(o,a)),a.handleStateChange(r)}else this._attachedViewStates.deleteAndDispose(o)}))}resetTokenization(e=!0){var t;this._tokens.flush(),(t=this._debugBackgroundTokens)===null||t===void 0||t.flush(),this._debugBackgroundStates&&(this._debugBackgroundStates=new RT(this._textModel.getLineCount())),e&&this._onDidChangeTokens.fire({semanticTokensApplied:!1,ranges:[{fromLineNumber:1,toLineNumber:this._textModel.getLineCount()}]});const i=()=>{if(this._textModel.isTooLargeForTokenization())return[null,null];const r=xi.get(this.getLanguageId());if(!r)return[null,null];let a;try{a=r.getInitialState()}catch(l){return et(l),[null,null]}return[r,a]},[n,o]=i();if(n&&o?this._tokenizer=new ude(this._textModel.getLineCount(),n,this._textModel,this._languageIdCodec):this._tokenizer=null,this._backgroundTokenizer.clear(),this._defaultBackgroundTokenizer=null,this._tokenizer){const r={setTokens:a=>{this.setTokens(a)},backgroundTokenizationFinished:()=>{if(this._backgroundTokenizationState===2)return;const a=2;this._backgroundTokenizationState=a,this._onDidChangeBackgroundTokenizationState.fire()},setEndState:(a,l)=>{var d;if(!this._tokenizer)return;const c=this._tokenizer.store.getFirstInvalidEndStateLineNumber();c!==null&&a>=c&&((d=this._tokenizer)===null||d===void 0||d.store.setEndState(a,l))}};n&&n.createBackgroundTokenizer&&!n.backgroundTokenizerShouldOnlyVerifyTokens&&(this._backgroundTokenizer.value=n.createBackgroundTokenizer(this._textModel,r)),this._backgroundTokenizer.value||(this._backgroundTokenizer.value=this._defaultBackgroundTokenizer=new fde(this._tokenizer,r),this._defaultBackgroundTokenizer.handleChanges()),n!=null&&n.backgroundTokenizerShouldOnlyVerifyTokens&&n.createBackgroundTokenizer?(this._debugBackgroundTokens=new tb(this._languageIdCodec),this._debugBackgroundStates=new RT(this._textModel.getLineCount()),this._debugBackgroundTokenizer.clear(),this._debugBackgroundTokenizer.value=n.createBackgroundTokenizer(this._textModel,{setTokens:a=>{var l;(l=this._debugBackgroundTokens)===null||l===void 0||l.setMultilineTokens(a,this._textModel)},backgroundTokenizationFinished(){},setEndState:(a,l)=>{var d;(d=this._debugBackgroundStates)===null||d===void 0||d.setEndState(a,l)}})):(this._debugBackgroundTokens=void 0,this._debugBackgroundStates=void 0,this._debugBackgroundTokenizer.value=void 0)}this.refreshAllVisibleLineTokens()}handleDidChangeAttached(){var e;(e=this._defaultBackgroundTokenizer)===null||e===void 0||e.handleChanges()}handleDidChangeContent(e){var t,i,n;if(e.isFlush)this.resetTokenization(!1);else if(!e.isEolChange){for(const o of e.changes){const[r,a]=Ou(o.text);this._tokens.acceptEdit(o.range,r,a),(t=this._debugBackgroundTokens)===null||t===void 0||t.acceptEdit(o.range,r,a)}(i=this._debugBackgroundStates)===null||i===void 0||i.acceptChanges(e.changes),this._tokenizer&&this._tokenizer.store.acceptChanges(e.changes),(n=this._defaultBackgroundTokenizer)===null||n===void 0||n.handleChanges()}}setTokens(e){const{changes:t}=this._tokens.setMultilineTokens(e,this._textModel);return t.length>0&&this._onDidChangeTokens.fire({semanticTokensApplied:!1,ranges:t}),{changes:t}}refreshAllVisibleLineTokens(){const e=ft.joinMany([...this._attachedViewStates].map(([t,i])=>i.lineRanges));this.refreshRanges(e)}refreshRanges(e){for(const t of e)this.refreshRange(t.startLineNumber,t.endLineNumberExclusive-1)}refreshRange(e,t){var i,n;if(!this._tokenizer)return;e=Math.max(1,Math.min(this._textModel.getLineCount(),e)),t=Math.min(this._textModel.getLineCount(),t);const o=new MT,{heuristicTokens:r}=this._tokenizer.tokenizeHeuristically(o,e,t),a=this.setTokens(o.finalize());if(r)for(const l of a.changes)(i=this._backgroundTokenizer.value)===null||i===void 0||i.requestTokens(l.fromLineNumber,l.toLineNumber+1);(n=this._defaultBackgroundTokenizer)===null||n===void 0||n.checkFinished()}forceTokenization(e){var t,i;const n=new MT;(t=this._tokenizer)===null||t===void 0||t.updateTokensUntilLine(n,e),this.setTokens(n.finalize()),(i=this._defaultBackgroundTokenizer)===null||i===void 0||i.checkFinished()}isCheapToTokenize(e){return this._tokenizer?this._tokenizer.isCheapToTokenize(e):!0}tokenizeIfCheap(e){this.isCheapToTokenize(e)&&this.forceTokenization(e)}getLineTokens(e){var t;const i=this._textModel.getLineContent(e),n=this._tokens.getTokens(this._textModel.getLanguageId(),e-1,i);if(this._debugBackgroundTokens&&this._debugBackgroundStates&&this._tokenizer&&this._debugBackgroundStates.getFirstInvalidEndStateLineNumberOrMax()>e&&this._tokenizer.store.getFirstInvalidEndStateLineNumberOrMax()>e){const o=this._debugBackgroundTokens.getTokens(this._textModel.getLanguageId(),e-1,i);!n.equals(o)&&(!((t=this._debugBackgroundTokenizer.value)===null||t===void 0)&&t.reportMismatchingTokens)&&this._debugBackgroundTokenizer.value.reportMismatchingTokens(e)}return n}getTokenTypeIfInsertingCharacter(e,t,i){if(!this._tokenizer)return 0;const n=this._textModel.validatePosition(new H(e,t));return this.forceTokenization(n.lineNumber),this._tokenizer.getTokenTypeIfInsertingCharacter(n,i)}tokenizeLineWithEdit(e,t,i){if(!this._tokenizer)return null;const n=this._textModel.validatePosition(e);return this.forceTokenization(n.lineNumber),this._tokenizer.tokenizeLineWithEdit(n,t,i)}get hasTokens(){return this._tokens.hasTokens}}class mde extends j{get lineRanges(){return this._lineRanges}constructor(e){super(),this._refreshTokens=e,this.runner=this._register(new jt(()=>this.update(),50)),this._computedLineRanges=[],this._lineRanges=[]}update(){Ai(this._computedLineRanges,this._lineRanges,(e,t)=>e.equals(t))||(this._computedLineRanges=this._lineRanges,this._refreshTokens())}handleStateChange(e){this._lineRanges=e.visibleLineRanges,e.stabilized?(this.runner.cancel(),this.update()):this.runner.schedule()}}class _de{constructor(){this.changeType=1}}class Ha{static applyInjectedText(e,t){if(!t||t.length===0)return e;let i="",n=0;for(const o of t)i+=e.substring(n,o.column-1),n=o.column-1,i+=o.options.content;return i+=e.substring(n),i}static fromDecorations(e){const t=[];for(const i of e)i.options.before&&i.options.before.content.length>0&&t.push(new Ha(i.ownerId,i.range.startLineNumber,i.range.startColumn,i.options.before,0)),i.options.after&&i.options.after.content.length>0&&t.push(new Ha(i.ownerId,i.range.endLineNumber,i.range.endColumn,i.options.after,1));return t.sort((i,n)=>i.lineNumber===n.lineNumber?i.column===n.column?i.order-n.order:i.column-n.column:i.lineNumber-n.lineNumber),t}constructor(e,t,i,n,o){this.ownerId=e,this.lineNumber=t,this.column=i,this.options=n,this.order=o}}class p7{constructor(e,t,i){this.changeType=2,this.lineNumber=e,this.detail=t,this.injectedText=i}}class vde{constructor(e,t){this.changeType=3,this.fromLineNumber=e,this.toLineNumber=t}}class bde{constructor(e,t,i,n){this.changeType=4,this.injectedTexts=n,this.fromLineNumber=e,this.toLineNumber=t,this.detail=i}}class Cde{constructor(){this.changeType=5}}class Kp{constructor(e,t,i,n){this.changes=e,this.versionId=t,this.isUndoing=i,this.isRedoing=n,this.resultingSelection=null}containsEvent(e){for(let t=0,i=this.changes.length;t<i;t++)if(this.changes[t].changeType===e)return!0;return!1}static merge(e,t){const i=[].concat(e.changes).concat(t.changes),n=t.versionId,o=e.isUndoing||t.isUndoing,r=e.isRedoing||t.isRedoing;return new Kp(i,n,o,r)}}class lz{constructor(e){this.changes=e}}class vg{constructor(e,t){this.rawContentChangedEvent=e,this.contentChangedEvent=t}merge(e){const t=Kp.merge(this.rawContentChangedEvent,e.rawContentChangedEvent),i=vg._mergeChangeEvents(this.contentChangedEvent,e.contentChangedEvent);return new vg(t,i)}static _mergeChangeEvents(e,t){const i=[].concat(e.changes).concat(t.changes),n=t.eol,o=t.versionId,r=e.isUndoing||t.isUndoing,a=e.isRedoing||t.isRedoing,l=e.isFlush||t.isFlush,d=e.isEolChange&&t.isEolChange;return{changes:i,eol:n,isEolChange:d,versionId:o,isUndoing:r,isRedoing:a,isFlush:l}}}const Mx=ut("undoRedoService");class dz{constructor(e,t){this.resource=e,this.elements=t}}class ym{constructor(){this.id=ym._ID++,this.order=1}nextOrder(){return this.id===0?0:this.order++}}ym._ID=0;ym.None=new ym;class Cl{constructor(){this.id=Cl._ID++,this.order=1}nextOrder(){return this.id===0?0:this.order++}}Cl._ID=0;Cl.None=new Cl;var wde=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},_I=function(s,e){return function(t,i){e(t,i,s)}},Rh;function Sde(s){const e=new az;return e.acceptChunk(s),e.finish()}function yde(s){const e=new az;let t;for(;typeof(t=s.read())=="string";)e.acceptChunk(t);return e.finish()}function m7(s,e){let t;return typeof s=="string"?t=Sde(s):gie(s)?t=yde(s):t=s,t.create(e)}let x1=0;const Lde=999,xde=1e4;class Dde{constructor(e){this._source=e,this._eos=!1}read(){if(this._eos)return null;const e=[];let t=0,i=0;do{const n=this._source.read();if(n===null)return this._eos=!0,t===0?null:e.join("");if(n.length>0&&(e[t++]=n,i+=n.length),i>=64*1024)return e.join("")}while(!0)}}const V_=()=>{throw new Error("Invalid change accessor")};let Xl=Rh=class extends j{static resolveOptions(e,t){if(t.detectIndentation){const i=r7(e,t.tabSize,t.insertSpaces);return new Aw({tabSize:i.tabSize,indentSize:"tabSize",insertSpaces:i.insertSpaces,trimAutoWhitespace:t.trimAutoWhitespace,defaultEOL:t.defaultEOL,bracketPairColorizationOptions:t.bracketPairColorizationOptions})}return new Aw(t)}get onDidChangeLanguage(){return this._tokenizationTextModelPart.onDidChangeLanguage}get onDidChangeLanguageConfiguration(){return this._tokenizationTextModelPart.onDidChangeLanguageConfiguration}get onDidChangeTokens(){return this._tokenizationTextModelPart.onDidChangeTokens}onDidChangeContent(e){return this._eventEmitter.slowEvent(t=>e(t.contentChangedEvent))}onDidChangeContentOrInjectedText(e){return Gr(this._eventEmitter.fastEvent(t=>e(t)),this._onDidChangeInjectedText.event(t=>e(t)))}_isDisposing(){return this.__isDisposing}get tokenization(){return this._tokenizationTextModelPart}get bracketPairs(){return this._bracketPairs}get guides(){return this._guidesTextModelPart}constructor(e,t,i,n=null,o,r,a){super(),this._undoRedoService=o,this._languageService=r,this._languageConfigurationService=a,this._onWillDispose=this._register(new W),this.onWillDispose=this._onWillDispose.event,this._onDidChangeDecorations=this._register(new Tde(g=>this.handleBeforeFireDecorationsChangedEvent(g))),this.onDidChangeDecorations=this._onDidChangeDecorations.event,this._onDidChangeOptions=this._register(new W),this.onDidChangeOptions=this._onDidChangeOptions.event,this._onDidChangeAttached=this._register(new W),this.onDidChangeAttached=this._onDidChangeAttached.event,this._onDidChangeInjectedText=this._register(new W),this._eventEmitter=this._register(new Mde),this._languageSelectionListener=this._register(new En),this._deltaDecorationCallCnt=0,this._attachedViews=new Rde,x1++,this.id="$model"+x1,this.isForSimpleWidget=i.isForSimpleWidget,typeof n>"u"||n===null?this._associatedResource=Pe.parse("inmemory://model/"+x1):this._associatedResource=n,this._attachedEditorCount=0;const{textBuffer:l,disposable:d}=m7(e,i.defaultEOL);this._buffer=l,this._bufferDisposable=d,this._options=Rh.resolveOptions(this._buffer,i);const c=typeof t=="string"?t:t.languageId;typeof t!="string"&&(this._languageSelectionListener.value=t.onDidChange(()=>this._setLanguage(t.languageId))),this._bracketPairs=this._register(new kle(this,this._languageConfigurationService)),this._guidesTextModelPart=this._register(new Sae(this,this._languageConfigurationService)),this._decorationProvider=this._register(new Ele(this)),this._tokenizationTextModelPart=new ay(this._languageService,this._languageConfigurationService,this,this._bracketPairs,c,this._attachedViews);const u=this._buffer.getLineCount(),h=this._buffer.getValueLengthInRange(new D(1,1,u,this._buffer.getLineLength(u)+1),0);i.largeFileOptimizations?(this._isTooLargeForTokenization=h>Rh.LARGE_FILE_SIZE_THRESHOLD||u>Rh.LARGE_FILE_LINE_COUNT_THRESHOLD,this._isTooLargeForHeapOperation=h>Rh.LARGE_FILE_HEAP_OPERATION_THRESHOLD):(this._isTooLargeForTokenization=!1,this._isTooLargeForHeapOperation=!1),this._isTooLargeForSyncing=h>Rh._MODEL_SYNC_LIMIT,this._versionId=1,this._alternativeVersionId=1,this._initialUndoRedoSnapshot=null,this._isDisposed=!1,this.__isDisposing=!1,this._instanceId=KW(x1),this._lastDecorationId=0,this._decorations=Object.create(null),this._decorationsTree=new _7,this._commandManager=new OP(this,this._undoRedoService),this._isUndoing=!1,this._isRedoing=!1,this._trimAutoWhitespaceLines=null,this._register(this._decorationProvider.onDidChange(()=>{this._onDidChangeDecorations.beginDeferredEmit(),this._onDidChangeDecorations.fire(),this._onDidChangeDecorations.endDeferredEmit()})),this._languageService.requestRichLanguageFeatures(c)}dispose(){this.__isDisposing=!0,this._onWillDispose.fire(),this._tokenizationTextModelPart.dispose(),this._isDisposed=!0,super.dispose(),this._bufferDisposable.dispose(),this.__isDisposing=!1;const e=new jp([],"",`
`,!1,!1,!0,!0);e.dispose(),this._buffer=e,this._bufferDisposable=j.None}_assertNotDisposed(){if(this._isDisposed)throw new Error("Model is disposed!")}_emitContentChangedEvent(e,t){this.__isDisposing||(this._tokenizationTextModelPart.handleDidChangeContent(t),this._bracketPairs.handleDidChangeContent(t),this._eventEmitter.fire(new vg(e,t)))}setValue(e){if(this._assertNotDisposed(),e==null)throw Cr();const{textBuffer:t,disposable:i}=m7(e,this._options.defaultEOL);this._setValueFromTextBuffer(t,i)}_createContentChanged2(e,t,i,n,o,r,a,l){return{changes:[{range:e,rangeOffset:t,rangeLength:i,text:n}],eol:this._buffer.getEOL(),isEolChange:l,versionId:this.getVersionId(),isUndoing:o,isRedoing:r,isFlush:a}}_setValueFromTextBuffer(e,t){this._assertNotDisposed();const i=this.getFullModelRange(),n=this.getValueLengthInRange(i),o=this.getLineCount(),r=this.getLineMaxColumn(o);this._buffer=e,this._bufferDisposable.dispose(),this._bufferDisposable=t,this._increaseVersionId(),this._decorations=Object.create(null),this._decorationsTree=new _7,this._commandManager.clear(),this._trimAutoWhitespaceLines=null,this._emitContentChangedEvent(new Kp([new _de],this._versionId,!1,!1),this._createContentChanged2(new D(1,1,o,r),0,n,this.getValue(),!1,!1,!0,!1))}setEOL(e){this._assertNotDisposed();const t=e===1?`\r
`:`
`;if(this._buffer.getEOL()===t)return;const i=this.getFullModelRange(),n=this.getValueLengthInRange(i),o=this.getLineCount(),r=this.getLineMaxColumn(o);this._onBeforeEOLChange(),this._buffer.setEOL(t),this._increaseVersionId(),this._onAfterEOLChange(),this._emitContentChangedEvent(new Kp([new Cde],this._versionId,!1,!1),this._createContentChanged2(new D(1,1,o,r),0,n,this.getValue(),!1,!1,!1,!0))}_onBeforeEOLChange(){this._decorationsTree.ensureAllNodesHaveRanges(this)}_onAfterEOLChange(){const e=this.getVersionId(),t=this._decorationsTree.collectNodesPostOrder();for(let i=0,n=t.length;i<n;i++){const o=t[i],r=o.range,a=o.cachedAbsoluteStart-o.start,l=this._buffer.getOffsetAt(r.startLineNumber,r.startColumn),d=this._buffer.getOffsetAt(r.endLineNumber,r.endColumn);o.cachedAbsoluteStart=l,o.cachedAbsoluteEnd=d,o.cachedVersionId=e,o.start=l-a,o.end=d-a,Bu(o)}}onBeforeAttached(){return this._attachedEditorCount++,this._attachedEditorCount===1&&(this._tokenizationTextModelPart.handleDidChangeAttached(),this._onDidChangeAttached.fire(void 0)),this._attachedViews.attachView()}onBeforeDetached(e){this._attachedEditorCount--,this._attachedEditorCount===0&&(this._tokenizationTextModelPart.handleDidChangeAttached(),this._onDidChangeAttached.fire(void 0)),this._attachedViews.detachView(e)}isAttachedToEditor(){return this._attachedEditorCount>0}getAttachedEditorCount(){return this._attachedEditorCount}isTooLargeForSyncing(){return this._isTooLargeForSyncing}isTooLargeForTokenization(){return this._isTooLargeForTokenization}isTooLargeForHeapOperation(){return this._isTooLargeForHeapOperation}isDisposed(){return this._isDisposed}isDominatedByLongLines(){if(this._assertNotDisposed(),this.isTooLargeForTokenization())return!1;let e=0,t=0;const i=this._buffer.getLineCount();for(let n=1;n<=i;n++){const o=this._buffer.getLineLength(n);o>=xde?t+=o:e+=o}return t>e}get uri(){return this._associatedResource}getOptions(){return this._assertNotDisposed(),this._options}getFormattingOptions(){return{tabSize:this._options.indentSize,insertSpaces:this._options.insertSpaces}}updateOptions(e){this._assertNotDisposed();const t=typeof e.tabSize<"u"?e.tabSize:this._options.tabSize,i=typeof e.indentSize<"u"?e.indentSize:this._options.originalIndentSize,n=typeof e.insertSpaces<"u"?e.insertSpaces:this._options.insertSpaces,o=typeof e.trimAutoWhitespace<"u"?e.trimAutoWhitespace:this._options.trimAutoWhitespace,r=typeof e.bracketColorizationOptions<"u"?e.bracketColorizationOptions:this._options.bracketPairColorizationOptions,a=new Aw({tabSize:t,indentSize:i,insertSpaces:n,defaultEOL:this._options.defaultEOL,trimAutoWhitespace:o,bracketPairColorizationOptions:r});if(this._options.equals(a))return;const l=this._options.createChangeEvent(a);this._options=a,this._bracketPairs.handleDidChangeOptions(l),this._decorationProvider.handleDidChangeOptions(l),this._onDidChangeOptions.fire(l)}detectIndentation(e,t){this._assertNotDisposed();const i=r7(this._buffer,t,e);this.updateOptions({insertSpaces:i.insertSpaces,tabSize:i.tabSize,indentSize:i.tabSize})}normalizeIndentation(e){return this._assertNotDisposed(),JS(e,this._options.indentSize,this._options.insertSpaces)}getVersionId(){return this._assertNotDisposed(),this._versionId}mightContainRTL(){return this._buffer.mightContainRTL()}mightContainUnusualLineTerminators(){return this._buffer.mightContainUnusualLineTerminators()}removeUnusualLineTerminators(e=null){const t=this.findMatches($W.source,!1,!0,!1,null,!1,1073741824);this._buffer.resetMightContainUnusualLineTerminators(),this.pushEditOperations(e,t.map(i=>({range:i.range,text:null})),()=>null)}mightContainNonBasicASCII(){return this._buffer.mightContainNonBasicASCII()}getAlternativeVersionId(){return this._assertNotDisposed(),this._alternativeVersionId}getInitialUndoRedoSnapshot(){return this._assertNotDisposed(),this._initialUndoRedoSnapshot}getOffsetAt(e){this._assertNotDisposed();const t=this._validatePosition(e.lineNumber,e.column,0);return this._buffer.getOffsetAt(t.lineNumber,t.column)}getPositionAt(e){this._assertNotDisposed();const t=Math.min(this._buffer.getLength(),Math.max(0,e));return this._buffer.getPositionAt(t)}_increaseVersionId(){this._versionId=this._versionId+1,this._alternativeVersionId=this._versionId}_overwriteVersionId(e){this._versionId=e}_overwriteAlternativeVersionId(e){this._alternativeVersionId=e}_overwriteInitialUndoRedoSnapshot(e){this._initialUndoRedoSnapshot=e}getValue(e,t=!1){if(this._assertNotDisposed(),this.isTooLargeForHeapOperation())throw new pi("Operation would exceed heap memory limits");const i=this.getFullModelRange(),n=this.getValueInRange(i,e);return t?this._buffer.getBOM()+n:n}createSnapshot(e=!1){return new Dde(this._buffer.createSnapshot(e))}getValueLength(e,t=!1){this._assertNotDisposed();const i=this.getFullModelRange(),n=this.getValueLengthInRange(i,e);return t?this._buffer.getBOM().length+n:n}getValueInRange(e,t=0){return this._assertNotDisposed(),this._buffer.getValueInRange(this.validateRange(e),t)}getValueLengthInRange(e,t=0){return this._assertNotDisposed(),this._buffer.getValueLengthInRange(this.validateRange(e),t)}getCharacterCountInRange(e,t=0){return this._assertNotDisposed(),this._buffer.getCharacterCountInRange(this.validateRange(e),t)}getLineCount(){return this._assertNotDisposed(),this._buffer.getLineCount()}getLineContent(e){if(this._assertNotDisposed(),e<1||e>this.getLineCount())throw new pi("Illegal value for lineNumber");return this._buffer.getLineContent(e)}getLineLength(e){if(this._assertNotDisposed(),e<1||e>this.getLineCount())throw new pi("Illegal value for lineNumber");return this._buffer.getLineLength(e)}getLinesContent(){if(this._assertNotDisposed(),this.isTooLargeForHeapOperation())throw new pi("Operation would exceed heap memory limits");return this._buffer.getLinesContent()}getEOL(){return this._assertNotDisposed(),this._buffer.getEOL()}getEndOfLineSequence(){return this._assertNotDisposed(),this._buffer.getEOL()===`
`?0:1}getLineMinColumn(e){return this._assertNotDisposed(),1}getLineMaxColumn(e){if(this._assertNotDisposed(),e<1||e>this.getLineCount())throw new pi("Illegal value for lineNumber");return this._buffer.getLineLength(e)+1}getLineFirstNonWhitespaceColumn(e){if(this._assertNotDisposed(),e<1||e>this.getLineCount())throw new pi("Illegal value for lineNumber");return this._buffer.getLineFirstNonWhitespaceColumn(e)}getLineLastNonWhitespaceColumn(e){if(this._assertNotDisposed(),e<1||e>this.getLineCount())throw new pi("Illegal value for lineNumber");return this._buffer.getLineLastNonWhitespaceColumn(e)}_validateRangeRelaxedNoAllocations(e){const t=this._buffer.getLineCount(),i=e.startLineNumber,n=e.startColumn;let o=Math.floor(typeof i=="number"&&!isNaN(i)?i:1),r=Math.floor(typeof n=="number"&&!isNaN(n)?n:1);if(o<1)o=1,r=1;else if(o>t)o=t,r=this.getLineMaxColumn(o);else if(r<=1)r=1;else{const u=this.getLineMaxColumn(o);r>=u&&(r=u)}const a=e.endLineNumber,l=e.endColumn;let d=Math.floor(typeof a=="number"&&!isNaN(a)?a:1),c=Math.floor(typeof l=="number"&&!isNaN(l)?l:1);if(d<1)d=1,c=1;else if(d>t)d=t,c=this.getLineMaxColumn(d);else if(c<=1)c=1;else{const u=this.getLineMaxColumn(d);c>=u&&(c=u)}return i===o&&n===r&&a===d&&l===c&&e instanceof D&&!(e instanceof De)?e:new D(o,r,d,c)}_isValidPosition(e,t,i){if(typeof e!="number"||typeof t!="number"||isNaN(e)||isNaN(t)||e<1||t<1||(e|0)!==e||(t|0)!==t)return!1;const n=this._buffer.getLineCount();if(e>n)return!1;if(t===1)return!0;const o=this.getLineMaxColumn(e);if(t>o)return!1;if(i===1){const r=this._buffer.getLineCharCode(e,t-2);if(_n(r))return!1}return!0}_validatePosition(e,t,i){const n=Math.floor(typeof e=="number"&&!isNaN(e)?e:1),o=Math.floor(typeof t=="number"&&!isNaN(t)?t:1),r=this._buffer.getLineCount();if(n<1)return new H(1,1);if(n>r)return new H(r,this.getLineMaxColumn(r));if(o<=1)return new H(n,1);const a=this.getLineMaxColumn(n);if(o>=a)return new H(n,a);if(i===1){const l=this._buffer.getLineCharCode(n,o-2);if(_n(l))return new H(n,o-1)}return new H(n,o)}validatePosition(e){return this._assertNotDisposed(),e instanceof H&&this._isValidPosition(e.lineNumber,e.column,1)?e:this._validatePosition(e.lineNumber,e.column,1)}_isValidRange(e,t){const i=e.startLineNumber,n=e.startColumn,o=e.endLineNumber,r=e.endColumn;if(!this._isValidPosition(i,n,0)||!this._isValidPosition(o,r,0))return!1;if(t===1){const a=n>1?this._buffer.getLineCharCode(i,n-2):0,l=r>1&&r<=this._buffer.getLineLength(o)?this._buffer.getLineCharCode(o,r-2):0,d=_n(a),c=_n(l);return!d&&!c}return!0}validateRange(e){if(this._assertNotDisposed(),e instanceof D&&!(e instanceof De)&&this._isValidRange(e,1))return e;const i=this._validatePosition(e.startLineNumber,e.startColumn,0),n=this._validatePosition(e.endLineNumber,e.endColumn,0),o=i.lineNumber,r=i.column,a=n.lineNumber,l=n.column;{const d=r>1?this._buffer.getLineCharCode(o,r-2):0,c=l>1&&l<=this._buffer.getLineLength(a)?this._buffer.getLineCharCode(a,l-2):0,u=_n(d),h=_n(c);return!u&&!h?new D(o,r,a,l):o===a&&r===l?new D(o,r-1,a,l-1):u&&h?new D(o,r-1,a,l+1):u?new D(o,r-1,a,l):new D(o,r,a,l+1)}}modifyPosition(e,t){this._assertNotDisposed();const i=this.getOffsetAt(e)+t;return this.getPositionAt(Math.min(this._buffer.getLength(),Math.max(0,i)))}getFullModelRange(){this._assertNotDisposed();const e=this.getLineCount();return new D(1,1,e,this.getLineMaxColumn(e))}findMatchesLineByLine(e,t,i,n){return this._buffer.findMatchesLineByLine(e,t,i,n)}findMatches(e,t,i,n,o,r,a=Lde){this._assertNotDisposed();let l=null;t!==null&&(Array.isArray(t)||(t=[t]),t.every(u=>D.isIRange(u))&&(l=t.map(u=>this.validateRange(u)))),l===null&&(l=[this.getFullModelRange()]),l=l.sort((u,h)=>u.startLineNumber-h.startLineNumber||u.startColumn-h.startColumn);const d=[];d.push(l.reduce((u,h)=>D.areIntersecting(u,h)?u.plusRange(h):(d.push(u),h)));let c;if(!i&&e.indexOf(`
`)<0){const h=new Mh(e,i,n,o).parseSearchRequest();if(!h)return[];c=g=>this.findMatchesLineByLine(g,h,r,a)}else c=u=>c1.findMatches(this,new Mh(e,i,n,o),u,r,a);return d.map(c).reduce((u,h)=>u.concat(h),[])}findNextMatch(e,t,i,n,o,r){this._assertNotDisposed();const a=this.validatePosition(t);if(!i&&e.indexOf(`
`)<0){const d=new Mh(e,i,n,o).parseSearchRequest();if(!d)return null;const c=this.getLineCount();let u=new D(a.lineNumber,a.column,c,this.getLineMaxColumn(c)),h=this.findMatchesLineByLine(u,d,r,1);return c1.findNextMatch(this,new Mh(e,i,n,o),a,r),h.length>0||(u=new D(1,1,a.lineNumber,this.getLineMaxColumn(a.lineNumber)),h=this.findMatchesLineByLine(u,d,r,1),h.length>0)?h[0]:null}return c1.findNextMatch(this,new Mh(e,i,n,o),a,r)}findPreviousMatch(e,t,i,n,o,r){this._assertNotDisposed();const a=this.validatePosition(t);return c1.findPreviousMatch(this,new Mh(e,i,n,o),a,r)}pushStackElement(){this._commandManager.pushStackElement()}popStackElement(){this._commandManager.popStackElement()}pushEOL(e){if((this.getEOL()===`
`?0:1)!==e)try{this._onDidChangeDecorations.beginDeferredEmit(),this._eventEmitter.beginDeferredEmit(),this._initialUndoRedoSnapshot===null&&(this._initialUndoRedoSnapshot=this._undoRedoService.createSnapshot(this.uri)),this._commandManager.pushEOL(e)}finally{this._eventEmitter.endDeferredEmit(),this._onDidChangeDecorations.endDeferredEmit()}}_validateEditOperation(e){return e instanceof Xk?e:new Xk(e.identifier||null,this.validateRange(e.range),e.text,e.forceMoveMarkers||!1,e.isAutoWhitespaceEdit||!1,e._isTracked||!1)}_validateEditOperations(e){const t=[];for(let i=0,n=e.length;i<n;i++)t[i]=this._validateEditOperation(e[i]);return t}pushEditOperations(e,t,i,n){try{return this._onDidChangeDecorations.beginDeferredEmit(),this._eventEmitter.beginDeferredEmit(),this._pushEditOperations(e,this._validateEditOperations(t),i,n)}finally{this._eventEmitter.endDeferredEmit(),this._onDidChangeDecorations.endDeferredEmit()}}_pushEditOperations(e,t,i,n){if(this._options.trimAutoWhitespace&&this._trimAutoWhitespaceLines){const o=t.map(a=>({range:this.validateRange(a.range),text:a.text}));let r=!0;if(e)for(let a=0,l=e.length;a<l;a++){const d=e[a];let c=!1;for(let u=0,h=o.length;u<h;u++){const g=o[u].range,f=g.startLineNumber>d.endLineNumber,m=d.startLineNumber>g.endLineNumber;if(!f&&!m){c=!0;break}}if(!c){r=!1;break}}if(r)for(let a=0,l=this._trimAutoWhitespaceLines.length;a<l;a++){const d=this._trimAutoWhitespaceLines[a],c=this.getLineMaxColumn(d);let u=!0;for(let h=0,g=o.length;h<g;h++){const f=o[h].range,m=o[h].text;if(!(d<f.startLineNumber||d>f.endLineNumber)&&!(d===f.startLineNumber&&f.startColumn===c&&f.isEmpty()&&m&&m.length>0&&m.charAt(0)===`
`)&&!(d===f.startLineNumber&&f.startColumn===1&&f.isEmpty()&&m&&m.length>0&&m.charAt(m.length-1)===`
`)){u=!1;break}}if(u){const h=new D(d,1,d,c);t.push(new Xk(null,h,null,!1,!1,!1))}}this._trimAutoWhitespaceLines=null}return this._initialUndoRedoSnapshot===null&&(this._initialUndoRedoSnapshot=this._undoRedoService.createSnapshot(this.uri)),this._commandManager.pushEditOperation(e,t,i,n)}_applyUndo(e,t,i,n){const o=e.map(r=>{const a=this.getPositionAt(r.newPosition),l=this.getPositionAt(r.newEnd);return{range:new D(a.lineNumber,a.column,l.lineNumber,l.column),text:r.oldText}});this._applyUndoRedoEdits(o,t,!0,!1,i,n)}_applyRedo(e,t,i,n){const o=e.map(r=>{const a=this.getPositionAt(r.oldPosition),l=this.getPositionAt(r.oldEnd);return{range:new D(a.lineNumber,a.column,l.lineNumber,l.column),text:r.newText}});this._applyUndoRedoEdits(o,t,!1,!0,i,n)}_applyUndoRedoEdits(e,t,i,n,o,r){try{this._onDidChangeDecorations.beginDeferredEmit(),this._eventEmitter.beginDeferredEmit(),this._isUndoing=i,this._isRedoing=n,this.applyEdits(e,!1),this.setEOL(t),this._overwriteAlternativeVersionId(o)}finally{this._isUndoing=!1,this._isRedoing=!1,this._eventEmitter.endDeferredEmit(r),this._onDidChangeDecorations.endDeferredEmit()}}applyEdits(e,t=!1){try{this._onDidChangeDecorations.beginDeferredEmit(),this._eventEmitter.beginDeferredEmit();const i=this._validateEditOperations(e);return this._doApplyEdits(i,t)}finally{this._eventEmitter.endDeferredEmit(),this._onDidChangeDecorations.endDeferredEmit()}}_doApplyEdits(e,t){const i=this._buffer.getLineCount(),n=this._buffer.applyEdits(e,this._options.trimAutoWhitespace,t),o=this._buffer.getLineCount(),r=n.changes;if(this._trimAutoWhitespaceLines=n.trimAutoWhitespaceLineNumbers,r.length!==0){for(let d=0,c=r.length;d<c;d++){const u=r[d];this._decorationsTree.acceptReplace(u.rangeOffset,u.rangeLength,u.text.length,u.forceMoveMarkers)}const a=[];this._increaseVersionId();let l=i;for(let d=0,c=r.length;d<c;d++){const u=r[d],[h]=Ou(u.text);this._onDidChangeDecorations.fire();const g=u.range.startLineNumber,f=u.range.endLineNumber,m=f-g,_=h,v=Math.min(m,_),b=_-m,C=o-l-b+g,w=C,S=C+_,x=this._decorationsTree.getInjectedTextInInterval(this,this.getOffsetAt(new H(w,1)),this.getOffsetAt(new H(S,this.getLineMaxColumn(S))),0),L=Ha.fromDecorations(x),k=new Qd(L);for(let I=v;I>=0;I--){const P=g+I,$=C+I;k.takeFromEndWhile(z=>z.lineNumber>$);const A=k.takeFromEndWhile(z=>z.lineNumber===$);a.push(new p7(P,this.getLineContent($),A))}if(v<m){const I=g+v;a.push(new vde(I+1,f))}if(v<_){const I=new Qd(L),P=g+v,$=_-v,A=o-l-$+P+1,z=[],K=[];for(let Q=0;Q<$;Q++){const ne=A+Q;K[Q]=this.getLineContent(ne),I.takeWhile(fe=>fe.lineNumber<ne),z[Q]=I.takeWhile(fe=>fe.lineNumber===ne)}a.push(new bde(P+1,g+_,K,z))}l+=b}this._emitContentChangedEvent(new Kp(a,this.getVersionId(),this._isUndoing,this._isRedoing),{changes:r,eol:this._buffer.getEOL(),isEolChange:!1,versionId:this.getVersionId(),isUndoing:this._isUndoing,isRedoing:this._isRedoing,isFlush:!1})}return n.reverseEdits===null?void 0:n.reverseEdits}undo(){return this._undoRedoService.undo(this.uri)}canUndo(){return this._undoRedoService.canUndo(this.uri)}redo(){return this._undoRedoService.redo(this.uri)}canRedo(){return this._undoRedoService.canRedo(this.uri)}handleBeforeFireDecorationsChangedEvent(e){if(e===null||e.size===0)return;const i=Array.from(e).map(n=>new p7(n,this.getLineContent(n),this._getInjectedTextInLine(n)));this._onDidChangeInjectedText.fire(new lz(i))}changeDecorations(e,t=0){this._assertNotDisposed();try{return this._onDidChangeDecorations.beginDeferredEmit(),this._changeDecorations(t,e)}finally{this._onDidChangeDecorations.endDeferredEmit()}}_changeDecorations(e,t){const i={addDecoration:(o,r)=>this._deltaDecorationsImpl(e,[],[{range:o,options:r}])[0],changeDecoration:(o,r)=>{this._changeDecorationImpl(o,r)},changeDecorationOptions:(o,r)=>{this._changeDecorationOptionsImpl(o,b7(r))},removeDecoration:o=>{this._deltaDecorationsImpl(e,[o],[])},deltaDecorations:(o,r)=>o.length===0&&r.length===0?[]:this._deltaDecorationsImpl(e,o,r)};let n=null;try{n=t(i)}catch(o){et(o)}return i.addDecoration=V_,i.changeDecoration=V_,i.changeDecorationOptions=V_,i.removeDecoration=V_,i.deltaDecorations=V_,n}deltaDecorations(e,t,i=0){if(this._assertNotDisposed(),e||(e=[]),e.length===0&&t.length===0)return[];try{return this._deltaDecorationCallCnt++,this._deltaDecorationCallCnt>1&&(console.warn("Invoking deltaDecorations recursively could lead to leaking decorations."),et(new Error("Invoking deltaDecorations recursively could lead to leaking decorations."))),this._onDidChangeDecorations.beginDeferredEmit(),this._deltaDecorationsImpl(i,e,t)}finally{this._onDidChangeDecorations.endDeferredEmit(),this._deltaDecorationCallCnt--}}_getTrackedRange(e){return this.getDecorationRange(e)}_setTrackedRange(e,t,i){const n=e?this._decorations[e]:null;if(!n)return t?this._deltaDecorationsImpl(0,[],[{range:t,options:v7[i]}],!0)[0]:null;if(!t)return this._decorationsTree.delete(n),delete this._decorations[n.id],null;const o=this._validateRangeRelaxedNoAllocations(t),r=this._buffer.getOffsetAt(o.startLineNumber,o.startColumn),a=this._buffer.getOffsetAt(o.endLineNumber,o.endColumn);return this._decorationsTree.delete(n),n.reset(this.getVersionId(),r,a,o),n.setOptions(v7[i]),this._decorationsTree.insert(n),n.id}removeAllDecorationsWithOwnerId(e){if(this._isDisposed)return;const t=this._decorationsTree.collectNodesFromOwner(e);for(let i=0,n=t.length;i<n;i++){const o=t[i];this._decorationsTree.delete(o),delete this._decorations[o.id]}}getDecorationOptions(e){const t=this._decorations[e];return t?t.options:null}getDecorationRange(e){const t=this._decorations[e];return t?this._decorationsTree.getNodeRange(this,t):null}getLineDecorations(e,t=0,i=!1){return e<1||e>this.getLineCount()?[]:this.getLinesDecorations(e,e,t,i)}getLinesDecorations(e,t,i=0,n=!1,o=!1){const r=this.getLineCount(),a=Math.min(r,Math.max(1,e)),l=Math.min(r,Math.max(1,t)),d=this.getLineMaxColumn(l),c=new D(a,1,l,d),u=this._getDecorationsInRange(c,i,n,o);return $E(u,this._decorationProvider.getDecorationsInRange(c,i,n)),u}getDecorationsInRange(e,t=0,i=!1,n=!1,o=!1){const r=this.validateRange(e),a=this._getDecorationsInRange(r,t,i,o);return $E(a,this._decorationProvider.getDecorationsInRange(r,t,i,n)),a}getOverviewRulerDecorations(e=0,t=!1){return this._decorationsTree.getAll(this,e,t,!0,!1)}getInjectedTextDecorations(e=0){return this._decorationsTree.getAllInjectedText(this,e)}_getInjectedTextInLine(e){const t=this._buffer.getOffsetAt(e,1),i=t+this._buffer.getLineLength(e),n=this._decorationsTree.getInjectedTextInInterval(this,t,i,0);return Ha.fromDecorations(n).filter(o=>o.lineNumber===e)}getAllDecorations(e=0,t=!1){let i=this._decorationsTree.getAll(this,e,t,!1,!1);return i=i.concat(this._decorationProvider.getAllDecorations(e,t)),i}getAllMarginDecorations(e=0){return this._decorationsTree.getAll(this,e,!1,!1,!0)}_getDecorationsInRange(e,t,i,n){const o=this._buffer.getOffsetAt(e.startLineNumber,e.startColumn),r=this._buffer.getOffsetAt(e.endLineNumber,e.endColumn);return this._decorationsTree.getAllInInterval(this,o,r,t,i,n)}getRangeAt(e,t){return this._buffer.getRangeAt(e,t-e)}_changeDecorationImpl(e,t){const i=this._decorations[e];if(!i)return;if(i.options.after){const a=this.getDecorationRange(e);this._onDidChangeDecorations.recordLineAffectedByInjectedText(a.endLineNumber)}if(i.options.before){const a=this.getDecorationRange(e);this._onDidChangeDecorations.recordLineAffectedByInjectedText(a.startLineNumber)}const n=this._validateRangeRelaxedNoAllocations(t),o=this._buffer.getOffsetAt(n.startLineNumber,n.startColumn),r=this._buffer.getOffsetAt(n.endLineNumber,n.endColumn);this._decorationsTree.delete(i),i.reset(this.getVersionId(),o,r,n),this._decorationsTree.insert(i),this._onDidChangeDecorations.checkAffectedAndFire(i.options),i.options.after&&this._onDidChangeDecorations.recordLineAffectedByInjectedText(n.endLineNumber),i.options.before&&this._onDidChangeDecorations.recordLineAffectedByInjectedText(n.startLineNumber)}_changeDecorationOptionsImpl(e,t){const i=this._decorations[e];if(!i)return;const n=!!(i.options.overviewRuler&&i.options.overviewRuler.color),o=!!(t.overviewRuler&&t.overviewRuler.color);if(this._onDidChangeDecorations.checkAffectedAndFire(i.options),this._onDidChangeDecorations.checkAffectedAndFire(t),i.options.after||t.after){const r=this._decorationsTree.getNodeRange(this,i);this._onDidChangeDecorations.recordLineAffectedByInjectedText(r.endLineNumber)}if(i.options.before||t.before){const r=this._decorationsTree.getNodeRange(this,i);this._onDidChangeDecorations.recordLineAffectedByInjectedText(r.startLineNumber)}n!==o?(this._decorationsTree.delete(i),i.setOptions(t),this._decorationsTree.insert(i)):i.setOptions(t)}_deltaDecorationsImpl(e,t,i,n=!1){const o=this.getVersionId(),r=t.length;let a=0;const l=i.length;let d=0;this._onDidChangeDecorations.beginDeferredEmit();try{const c=new Array(l);for(;a<r||d<l;){let u=null;if(a<r){do u=this._decorations[t[a++]];while(!u&&a<r);if(u){if(u.options.after){const h=this._decorationsTree.getNodeRange(this,u);this._onDidChangeDecorations.recordLineAffectedByInjectedText(h.endLineNumber)}if(u.options.before){const h=this._decorationsTree.getNodeRange(this,u);this._onDidChangeDecorations.recordLineAffectedByInjectedText(h.startLineNumber)}this._decorationsTree.delete(u),n||this._onDidChangeDecorations.checkAffectedAndFire(u.options)}}if(d<l){if(!u){const v=++this._lastDecorationId,b=`${this._instanceId};${v}`;u=new nz(b,0,0),this._decorations[b]=u}const h=i[d],g=this._validateRangeRelaxedNoAllocations(h.range),f=b7(h.options),m=this._buffer.getOffsetAt(g.startLineNumber,g.startColumn),_=this._buffer.getOffsetAt(g.endLineNumber,g.endColumn);u.ownerId=e,u.reset(o,m,_,g),u.setOptions(f),u.options.after&&this._onDidChangeDecorations.recordLineAffectedByInjectedText(g.endLineNumber),u.options.before&&this._onDidChangeDecorations.recordLineAffectedByInjectedText(g.startLineNumber),n||this._onDidChangeDecorations.checkAffectedAndFire(f),this._decorationsTree.insert(u),c[d]=u.id,d++}else u&&delete this._decorations[u.id]}return c}finally{this._onDidChangeDecorations.endDeferredEmit()}}getLanguageId(){return this.tokenization.getLanguageId()}setLanguage(e,t){typeof e=="string"?(this._languageSelectionListener.clear(),this._setLanguage(e,t)):(this._languageSelectionListener.value=e.onDidChange(()=>this._setLanguage(e.languageId,t)),this._setLanguage(e.languageId,t))}_setLanguage(e,t){this.tokenization.setLanguageId(e,t),this._languageService.requestRichLanguageFeatures(e)}getLanguageIdAtPosition(e,t){return this.tokenization.getLanguageIdAtPosition(e,t)}getWordAtPosition(e){return this._tokenizationTextModelPart.getWordAtPosition(e)}getWordUntilPosition(e){return this._tokenizationTextModelPart.getWordUntilPosition(e)}normalizePosition(e,t){return e}getLineIndentColumn(e){return kde(this.getLineContent(e))+1}};Xl._MODEL_SYNC_LIMIT=50*1024*1024;Xl.LARGE_FILE_SIZE_THRESHOLD=20*1024*1024;Xl.LARGE_FILE_LINE_COUNT_THRESHOLD=300*1e3;Xl.LARGE_FILE_HEAP_OPERATION_THRESHOLD=256*1024*1024;Xl.DEFAULT_CREATION_OPTIONS={isForSimpleWidget:!1,tabSize:os.tabSize,indentSize:os.indentSize,insertSpaces:os.insertSpaces,detectIndentation:!1,defaultEOL:1,trimAutoWhitespace:os.trimAutoWhitespace,largeFileOptimizations:os.largeFileOptimizations,bracketPairColorizationOptions:os.bracketPairColorizationOptions};Xl=Rh=wde([_I(4,Mx),_I(5,fi),_I(6,Jt)],Xl);function kde(s){let e=0;for(const t of s)if(t===" "||t==="	")e++;else break;return e}function vI(s){return!!(s.options.overviewRuler&&s.options.overviewRuler.color)}function bI(s){return!!s.options.after||!!s.options.before}class _7{constructor(){this._decorationsTree0=new fI,this._decorationsTree1=new fI,this._injectedTextDecorationsTree=new fI}ensureAllNodesHaveRanges(e){this.getAll(e,0,!1,!1,!1)}_ensureNodesHaveRanges(e,t){for(const i of t)i.range===null&&(i.range=e.getRangeAt(i.cachedAbsoluteStart,i.cachedAbsoluteEnd));return t}getAllInInterval(e,t,i,n,o,r){const a=e.getVersionId(),l=this._intervalSearch(t,i,n,o,a,r);return this._ensureNodesHaveRanges(e,l)}_intervalSearch(e,t,i,n,o,r){const a=this._decorationsTree0.intervalSearch(e,t,i,n,o,r),l=this._decorationsTree1.intervalSearch(e,t,i,n,o,r),d=this._injectedTextDecorationsTree.intervalSearch(e,t,i,n,o,r);return a.concat(l).concat(d)}getInjectedTextInInterval(e,t,i,n){const o=e.getVersionId(),r=this._injectedTextDecorationsTree.intervalSearch(t,i,n,!1,o,!1);return this._ensureNodesHaveRanges(e,r).filter(a=>a.options.showIfCollapsed||!a.range.isEmpty())}getAllInjectedText(e,t){const i=e.getVersionId(),n=this._injectedTextDecorationsTree.search(t,!1,i,!1);return this._ensureNodesHaveRanges(e,n).filter(o=>o.options.showIfCollapsed||!o.range.isEmpty())}getAll(e,t,i,n,o){const r=e.getVersionId(),a=this._search(t,i,n,r,o);return this._ensureNodesHaveRanges(e,a)}_search(e,t,i,n,o){if(i)return this._decorationsTree1.search(e,t,n,o);{const r=this._decorationsTree0.search(e,t,n,o),a=this._decorationsTree1.search(e,t,n,o),l=this._injectedTextDecorationsTree.search(e,t,n,o);return r.concat(a).concat(l)}}collectNodesFromOwner(e){const t=this._decorationsTree0.collectNodesFromOwner(e),i=this._decorationsTree1.collectNodesFromOwner(e),n=this._injectedTextDecorationsTree.collectNodesFromOwner(e);return t.concat(i).concat(n)}collectNodesPostOrder(){const e=this._decorationsTree0.collectNodesPostOrder(),t=this._decorationsTree1.collectNodesPostOrder(),i=this._injectedTextDecorationsTree.collectNodesPostOrder();return e.concat(t).concat(i)}insert(e){bI(e)?this._injectedTextDecorationsTree.insert(e):vI(e)?this._decorationsTree1.insert(e):this._decorationsTree0.insert(e)}delete(e){bI(e)?this._injectedTextDecorationsTree.delete(e):vI(e)?this._decorationsTree1.delete(e):this._decorationsTree0.delete(e)}getNodeRange(e,t){const i=e.getVersionId();return t.cachedVersionId!==i&&this._resolveNode(t,i),t.range===null&&(t.range=e.getRangeAt(t.cachedAbsoluteStart,t.cachedAbsoluteEnd)),t.range}_resolveNode(e,t){bI(e)?this._injectedTextDecorationsTree.resolveNode(e,t):vI(e)?this._decorationsTree1.resolveNode(e,t):this._decorationsTree0.resolveNode(e,t)}acceptReplace(e,t,i,n){this._decorationsTree0.acceptReplace(e,t,i,n),this._decorationsTree1.acceptReplace(e,t,i,n),this._injectedTextDecorationsTree.acceptReplace(e,t,i,n)}}function ud(s){return s.replace(/[^a-z0-9\-_]/gi," ")}class cz{constructor(e){this.color=e.color||"",this.darkColor=e.darkColor||""}}class Ide extends cz{constructor(e){super(e),this._resolvedColor=null,this.position=typeof e.position=="number"?e.position:nr.Center}getColor(e){return this._resolvedColor||(e.type!=="light"&&this.darkColor?this._resolvedColor=this._resolveColor(this.darkColor,e):this._resolvedColor=this._resolveColor(this.color,e)),this._resolvedColor}invalidateCachedColor(){this._resolvedColor=null}_resolveColor(e,t){if(typeof e=="string")return e;const i=e?t.getColor(e.id):null;return i?i.toString():""}}class Ede{constructor(e){var t;this.position=(t=e==null?void 0:e.position)!==null&&t!==void 0?t:fg.Left}}class Nde extends cz{constructor(e){super(e),this.position=e.position}getColor(e){return this._resolvedColor||(e.type!=="light"&&this.darkColor?this._resolvedColor=this._resolveColor(this.darkColor,e):this._resolvedColor=this._resolveColor(this.color,e)),this._resolvedColor}invalidateCachedColor(){this._resolvedColor=void 0}_resolveColor(e,t){return typeof e=="string"?G.fromHex(e):t.getColor(e.id)}}class Wu{static from(e){return e instanceof Wu?e:new Wu(e)}constructor(e){this.content=e.content||"",this.inlineClassName=e.inlineClassName||null,this.inlineClassNameAffectsLetterSpacing=e.inlineClassNameAffectsLetterSpacing||!1,this.attachedData=e.attachedData||null,this.cursorStops=e.cursorStops||null}}class tt{static register(e){return new tt(e)}static createDynamic(e){return new tt(e)}constructor(e){var t,i,n,o,r,a;this.description=e.description,this.blockClassName=e.blockClassName?ud(e.blockClassName):null,this.blockDoesNotCollapse=(t=e.blockDoesNotCollapse)!==null&&t!==void 0?t:null,this.blockIsAfterEnd=(i=e.blockIsAfterEnd)!==null&&i!==void 0?i:null,this.blockPadding=(n=e.blockPadding)!==null&&n!==void 0?n:null,this.stickiness=e.stickiness||0,this.zIndex=e.zIndex||0,this.className=e.className?ud(e.className):null,this.shouldFillLineOnLineBreak=(o=e.shouldFillLineOnLineBreak)!==null&&o!==void 0?o:null,this.hoverMessage=e.hoverMessage||null,this.glyphMarginHoverMessage=e.glyphMarginHoverMessage||null,this.isWholeLine=e.isWholeLine||!1,this.showIfCollapsed=e.showIfCollapsed||!1,this.collapseOnReplaceEdit=e.collapseOnReplaceEdit||!1,this.overviewRuler=e.overviewRuler?new Ide(e.overviewRuler):null,this.minimap=e.minimap?new Nde(e.minimap):null,this.glyphMargin=e.glyphMarginClassName?new Ede(e.glyphMargin):null,this.glyphMarginClassName=e.glyphMarginClassName?ud(e.glyphMarginClassName):null,this.linesDecorationsClassName=e.linesDecorationsClassName?ud(e.linesDecorationsClassName):null,this.firstLineDecorationClassName=e.firstLineDecorationClassName?ud(e.firstLineDecorationClassName):null,this.marginClassName=e.marginClassName?ud(e.marginClassName):null,this.inlineClassName=e.inlineClassName?ud(e.inlineClassName):null,this.inlineClassNameAffectsLetterSpacing=e.inlineClassNameAffectsLetterSpacing||!1,this.beforeContentClassName=e.beforeContentClassName?ud(e.beforeContentClassName):null,this.afterContentClassName=e.afterContentClassName?ud(e.afterContentClassName):null,this.after=e.after?Wu.from(e.after):null,this.before=e.before?Wu.from(e.before):null,this.hideInCommentTokens=(r=e.hideInCommentTokens)!==null&&r!==void 0?r:!1,this.hideInStringTokens=(a=e.hideInStringTokens)!==null&&a!==void 0?a:!1}}tt.EMPTY=tt.register({description:"empty"});const v7=[tt.register({description:"tracked-range-always-grows-when-typing-at-edges",stickiness:0}),tt.register({description:"tracked-range-never-grows-when-typing-at-edges",stickiness:1}),tt.register({description:"tracked-range-grows-only-when-typing-before",stickiness:2}),tt.register({description:"tracked-range-grows-only-when-typing-after",stickiness:3})];function b7(s){return s instanceof tt?s:tt.createDynamic(s)}class Tde extends j{constructor(e){super(),this.handleBeforeFire=e,this._actual=this._register(new W),this.event=this._actual.event,this._affectedInjectedTextLines=null,this._deferredCnt=0,this._shouldFireDeferred=!1,this._affectsMinimap=!1,this._affectsOverviewRuler=!1,this._affectsGlyphMargin=!1}beginDeferredEmit(){this._deferredCnt++}endDeferredEmit(){var e;this._deferredCnt--,this._deferredCnt===0&&(this._shouldFireDeferred&&this.doFire(),(e=this._affectedInjectedTextLines)===null||e===void 0||e.clear(),this._affectedInjectedTextLines=null)}recordLineAffectedByInjectedText(e){this._affectedInjectedTextLines||(this._affectedInjectedTextLines=new Set),this._affectedInjectedTextLines.add(e)}checkAffectedAndFire(e){this._affectsMinimap||(this._affectsMinimap=!!(e.minimap&&e.minimap.position)),this._affectsOverviewRuler||(this._affectsOverviewRuler=!!(e.overviewRuler&&e.overviewRuler.color)),this._affectsGlyphMargin||(this._affectsGlyphMargin=!!e.glyphMarginClassName),this.tryFire()}fire(){this._affectsMinimap=!0,this._affectsOverviewRuler=!0,this._affectsGlyphMargin=!0,this.tryFire()}tryFire(){this._deferredCnt===0?this.doFire():this._shouldFireDeferred=!0}doFire(){this.handleBeforeFire(this._affectedInjectedTextLines);const e={affectsMinimap:this._affectsMinimap,affectsOverviewRuler:this._affectsOverviewRuler,affectsGlyphMargin:this._affectsGlyphMargin};this._shouldFireDeferred=!1,this._affectsMinimap=!1,this._affectsOverviewRuler=!1,this._affectsGlyphMargin=!1,this._actual.fire(e)}}class Mde extends j{constructor(){super(),this._fastEmitter=this._register(new W),this.fastEvent=this._fastEmitter.event,this._slowEmitter=this._register(new W),this.slowEvent=this._slowEmitter.event,this._deferredCnt=0,this._deferredEvent=null}beginDeferredEmit(){this._deferredCnt++}endDeferredEmit(e=null){if(this._deferredCnt--,this._deferredCnt===0&&this._deferredEvent!==null){this._deferredEvent.rawContentChangedEvent.resultingSelection=e;const t=this._deferredEvent;this._deferredEvent=null,this._fastEmitter.fire(t),this._slowEmitter.fire(t)}}fire(e){if(this._deferredCnt>0){this._deferredEvent?this._deferredEvent=this._deferredEvent.merge(e):this._deferredEvent=e;return}this._fastEmitter.fire(e),this._slowEmitter.fire(e)}}class Rde{constructor(){this._onDidChangeVisibleRanges=new W,this.onDidChangeVisibleRanges=this._onDidChangeVisibleRanges.event,this._views=new Set}attachView(){const e=new Ade(t=>{this._onDidChangeVisibleRanges.fire({view:e,state:t})});return this._views.add(e),e}detachView(e){this._views.delete(e),this._onDidChangeVisibleRanges.fire({view:e,state:void 0})}}class Ade{constructor(e){this.handleStateChange=e}setVisibleLines(e,t){const i=e.map(n=>new ft(n.startLineNumber,n.endLineNumber+1));this.handleStateChange({visibleLineRanges:i,stabilized:t})}}class ly{constructor(e){this._selTrackedRange=null,this._trackSelection=!0,this._setState(e,new On(new D(1,1,1,1),0,0,new H(1,1),0),new On(new D(1,1,1,1),0,0,new H(1,1),0))}dispose(e){this._removeTrackedRange(e)}startTrackingSelection(e){this._trackSelection=!0,this._updateTrackedRange(e)}stopTrackingSelection(e){this._trackSelection=!1,this._removeTrackedRange(e)}_updateTrackedRange(e){this._trackSelection&&(this._selTrackedRange=e.model._setTrackedRange(this._selTrackedRange,this.modelState.selection,0))}_removeTrackedRange(e){this._selTrackedRange=e.model._setTrackedRange(this._selTrackedRange,null,0)}asCursorState(){return new yt(this.modelState,this.viewState)}readSelectionFromMarkers(e){const t=e.model._getTrackedRange(this._selTrackedRange);return this.modelState.selection.isEmpty()&&!t.isEmpty()?De.fromRange(t.collapseToEnd(),this.modelState.selection.getDirection()):De.fromRange(t,this.modelState.selection.getDirection())}ensureValidState(e){this._setState(e,this.modelState,this.viewState)}setState(e,t,i){this._setState(e,t,i)}static _validatePositionWithCache(e,t,i,n){return t.equals(i)?n:e.normalizePosition(t,2)}static _validateViewState(e,t){const i=t.position,n=t.selectionStart.getStartPosition(),o=t.selectionStart.getEndPosition(),r=e.normalizePosition(i,2),a=this._validatePositionWithCache(e,n,i,r),l=this._validatePositionWithCache(e,o,n,a);return i.equals(r)&&n.equals(a)&&o.equals(l)?t:new On(D.fromPositions(a,l),t.selectionStartKind,t.selectionStartLeftoverVisibleColumns+n.column-a.column,r,t.leftoverVisibleColumns+i.column-r.column)}_setState(e,t,i){if(i&&(i=ly._validateViewState(e.viewModel,i)),t){const n=e.model.validateRange(t.selectionStart),o=t.selectionStart.equalsRange(n)?t.selectionStartLeftoverVisibleColumns:0,r=e.model.validatePosition(t.position),a=t.position.equals(r)?t.leftoverVisibleColumns:0;t=new On(n,t.selectionStartKind,o,r,a)}else{if(!i)return;const n=e.model.validateRange(e.coordinatesConverter.convertViewRangeToModelRange(i.selectionStart)),o=e.model.validatePosition(e.coordinatesConverter.convertViewPositionToModelPosition(i.position));t=new On(n,i.selectionStartKind,i.selectionStartLeftoverVisibleColumns,o,i.leftoverVisibleColumns)}if(i){const n=e.coordinatesConverter.validateViewRange(i.selectionStart,t.selectionStart),o=e.coordinatesConverter.validateViewPosition(i.position,t.position);i=new On(n,t.selectionStartKind,t.selectionStartLeftoverVisibleColumns,o,t.leftoverVisibleColumns)}else{const n=e.coordinatesConverter.convertModelPositionToViewPosition(new H(t.selectionStart.startLineNumber,t.selectionStart.startColumn)),o=e.coordinatesConverter.convertModelPositionToViewPosition(new H(t.selectionStart.endLineNumber,t.selectionStart.endColumn)),r=new D(n.lineNumber,n.column,o.lineNumber,o.column),a=e.coordinatesConverter.convertModelPositionToViewPosition(t.position);i=new On(r,t.selectionStartKind,t.selectionStartLeftoverVisibleColumns,a,t.leftoverVisibleColumns)}this.modelState=t,this.viewState=i,this._updateTrackedRange(e)}}class C7{constructor(e){this.context=e,this.cursors=[new ly(e)],this.lastAddedCursorIndex=0}dispose(){for(const e of this.cursors)e.dispose(this.context)}startTrackingSelections(){for(const e of this.cursors)e.startTrackingSelection(this.context)}stopTrackingSelections(){for(const e of this.cursors)e.stopTrackingSelection(this.context)}updateContext(e){this.context=e}ensureValidState(){for(const e of this.cursors)e.ensureValidState(this.context)}readSelectionFromMarkers(){return this.cursors.map(e=>e.readSelectionFromMarkers(this.context))}getAll(){return this.cursors.map(e=>e.asCursorState())}getViewPositions(){return this.cursors.map(e=>e.viewState.position)}getTopMostViewPosition(){return xie(this.cursors,br(e=>e.viewState.position,H.compare)).viewState.position}getBottomMostViewPosition(){return Lie(this.cursors,br(e=>e.viewState.position,H.compare)).viewState.position}getSelections(){return this.cursors.map(e=>e.modelState.selection)}getViewSelections(){return this.cursors.map(e=>e.viewState.selection)}setSelections(e){this.setStates(yt.fromModelSelections(e))}getPrimaryCursor(){return this.cursors[0].asCursorState()}setStates(e){e!==null&&(this.cursors[0].setState(this.context,e[0].modelState,e[0].viewState),this._setSecondaryStates(e.slice(1)))}_setSecondaryStates(e){const t=this.cursors.length-1,i=e.length;if(t<i){const n=i-t;for(let o=0;o<n;o++)this._addSecondaryCursor()}else if(t>i){const n=t-i;for(let o=0;o<n;o++)this._removeSecondaryCursor(this.cursors.length-2)}for(let n=0;n<i;n++)this.cursors[n+1].setState(this.context,e[n].modelState,e[n].viewState)}killSecondaryCursors(){this._setSecondaryStates([])}_addSecondaryCursor(){this.cursors.push(new ly(this.context)),this.lastAddedCursorIndex=this.cursors.length-1}getLastAddedCursorIndex(){return this.cursors.length===1||this.lastAddedCursorIndex===0?0:this.lastAddedCursorIndex}_removeSecondaryCursor(e){this.lastAddedCursorIndex>=e+1&&this.lastAddedCursorIndex--,this.cursors[e+1].dispose(this.context),this.cursors.splice(e+1,1)}normalize(){if(this.cursors.length===1)return;const e=this.cursors.slice(0),t=[];for(let i=0,n=e.length;i<n;i++)t.push({index:i,selection:e[i].modelState.selection});t.sort(br(i=>i.selection,D.compareRangesUsingStarts));for(let i=0;i<t.length-1;i++){const n=t[i],o=t[i+1],r=n.selection,a=o.selection;if(!this.context.cursorConfig.multiCursorMergeOverlapping)continue;let l;if(a.isEmpty()||r.isEmpty()?l=a.getStartPosition().isBeforeOrEqual(r.getEndPosition()):l=a.getStartPosition().isBefore(r.getEndPosition()),l){const d=n.index<o.index?i:i+1,c=n.index<o.index?i+1:i,u=t[c].index,h=t[d].index,g=t[c].selection,f=t[d].selection;if(!g.equalsSelection(f)){const m=g.plusRange(f),_=g.selectionStartLineNumber===g.startLineNumber&&g.selectionStartColumn===g.startColumn,v=f.selectionStartLineNumber===f.startLineNumber&&f.selectionStartColumn===f.startColumn;let b;u===this.lastAddedCursorIndex?(b=_,this.lastAddedCursorIndex=h):b=v;let C;b?C=new De(m.startLineNumber,m.startColumn,m.endLineNumber,m.endColumn):C=new De(m.endLineNumber,m.endColumn,m.startLineNumber,m.startColumn),t[d].selection=C;const w=yt.fromModelSelection(C);e[h].setState(this.context,w.modelState,w.viewState)}for(const m of t)m.index>u&&m.index--;e.splice(u,1),t.splice(c,1),this._removeSecondaryCursor(u-1),i--}}}}class w7{constructor(e,t,i,n){this._cursorContextBrand=void 0,this.model=e,this.viewModel=t,this.coordinatesConverter=i,this.cursorConfig=n}}class Pde{constructor(){this.type=0}}class Ode{constructor(){this.type=1}}class Fde{constructor(e){this.type=2,this._source=e}hasChanged(e){return this._source.hasChanged(e)}}class Bde{constructor(e,t,i){this.selections=e,this.modelSelections=t,this.reason=i,this.type=3}}class wh{constructor(e){this.type=4,e?(this.affectsMinimap=e.affectsMinimap,this.affectsOverviewRuler=e.affectsOverviewRuler,this.affectsGlyphMargin=e.affectsGlyphMargin):(this.affectsMinimap=!0,this.affectsOverviewRuler=!0,this.affectsGlyphMargin=!0)}}class D1{constructor(){this.type=5}}class Wde{constructor(e){this.type=6,this.isFocused=e}}class Vde{constructor(){this.type=7}}class k1{constructor(){this.type=8}}class uz{constructor(e,t){this.fromLineNumber=e,this.count=t,this.type=9}}class AT{constructor(e,t){this.type=10,this.fromLineNumber=e,this.toLineNumber=t}}class PT{constructor(e,t){this.type=11,this.fromLineNumber=e,this.toLineNumber=t}}class Uw{constructor(e,t,i,n,o,r,a){this.source=e,this.minimalReveal=t,this.range=i,this.selections=n,this.verticalType=o,this.revealHorizontal=r,this.scrollType=a,this.type=12}}class Hde{constructor(e){this.type=13,this.scrollWidth=e.scrollWidth,this.scrollLeft=e.scrollLeft,this.scrollHeight=e.scrollHeight,this.scrollTop=e.scrollTop,this.scrollWidthChanged=e.scrollWidthChanged,this.scrollLeftChanged=e.scrollLeftChanged,this.scrollHeightChanged=e.scrollHeightChanged,this.scrollTopChanged=e.scrollTopChanged}}class zde{constructor(e){this.theme=e,this.type=14}}class Ude{constructor(e){this.type=15,this.ranges=e}}class $de{constructor(){this.type=16}}let jde=class{constructor(){this.type=17}};class Kde extends j{constructor(){super(),this._onEvent=this._register(new W),this.onEvent=this._onEvent.event,this._eventHandlers=[],this._viewEventQueue=null,this._isConsumingViewEventQueue=!1,this._collector=null,this._collectorCnt=0,this._outgoingEvents=[]}emitOutgoingEvent(e){this._addOutgoingEvent(e),this._emitOutgoingEvents()}_addOutgoingEvent(e){for(let t=0,i=this._outgoingEvents.length;t<i;t++){const n=this._outgoingEvents[t].kind===e.kind?this._outgoingEvents[t].attemptToMerge(e):null;if(n){this._outgoingEvents[t]=n;return}}this._outgoingEvents.push(e)}_emitOutgoingEvents(){for(;this._outgoingEvents.length>0;){if(this._collector||this._isConsumingViewEventQueue)return;const e=this._outgoingEvents.shift();e.isNoOp()||this._onEvent.fire(e)}}addViewEventHandler(e){for(let t=0,i=this._eventHandlers.length;t<i;t++)this._eventHandlers[t]===e&&console.warn("Detected duplicate listener in ViewEventDispatcher",e);this._eventHandlers.push(e)}removeViewEventHandler(e){for(let t=0;t<this._eventHandlers.length;t++)if(this._eventHandlers[t]===e){this._eventHandlers.splice(t,1);break}}beginEmitViewEvents(){return this._collectorCnt++,this._collectorCnt===1&&(this._collector=new qde),this._collector}endEmitViewEvents(){if(this._collectorCnt--,this._collectorCnt===0){const e=this._collector.outgoingEvents,t=this._collector.viewEvents;this._collector=null;for(const i of e)this._addOutgoingEvent(i);t.length>0&&this._emitMany(t)}this._emitOutgoingEvents()}emitSingleViewEvent(e){try{this.beginEmitViewEvents().emitViewEvent(e)}finally{this.endEmitViewEvents()}}_emitMany(e){this._viewEventQueue?this._viewEventQueue=this._viewEventQueue.concat(e):this._viewEventQueue=e,this._isConsumingViewEventQueue||this._consumeViewEventQueue()}_consumeViewEventQueue(){try{this._isConsumingViewEventQueue=!0,this._doConsumeQueue()}finally{this._isConsumingViewEventQueue=!1}}_doConsumeQueue(){for(;this._viewEventQueue;){const e=this._viewEventQueue;this._viewEventQueue=null;const t=this._eventHandlers.slice(0);for(const i of t)i.handleEvents(e)}}}class qde{constructor(){this.viewEvents=[],this.outgoingEvents=[]}emitViewEvent(e){this.viewEvents.push(e)}emitOutgoingEvent(e){this.outgoingEvents.push(e)}}class HP{constructor(e,t,i,n){this.kind=0,this._oldContentWidth=e,this._oldContentHeight=t,this.contentWidth=i,this.contentHeight=n,this.contentWidthChanged=this._oldContentWidth!==this.contentWidth,this.contentHeightChanged=this._oldContentHeight!==this.contentHeight}isNoOp(){return!this.contentWidthChanged&&!this.contentHeightChanged}attemptToMerge(e){return e.kind!==this.kind?null:new HP(this._oldContentWidth,this._oldContentHeight,e.contentWidth,e.contentHeight)}}class zP{constructor(e,t){this.kind=1,this.oldHasFocus=e,this.hasFocus=t}isNoOp(){return this.oldHasFocus===this.hasFocus}attemptToMerge(e){return e.kind!==this.kind?null:new zP(this.oldHasFocus,e.hasFocus)}}class UP{constructor(e,t,i,n,o,r,a,l){this.kind=2,this._oldScrollWidth=e,this._oldScrollLeft=t,this._oldScrollHeight=i,this._oldScrollTop=n,this.scrollWidth=o,this.scrollLeft=r,this.scrollHeight=a,this.scrollTop=l,this.scrollWidthChanged=this._oldScrollWidth!==this.scrollWidth,this.scrollLeftChanged=this._oldScrollLeft!==this.scrollLeft,this.scrollHeightChanged=this._oldScrollHeight!==this.scrollHeight,this.scrollTopChanged=this._oldScrollTop!==this.scrollTop}isNoOp(){return!this.scrollWidthChanged&&!this.scrollLeftChanged&&!this.scrollHeightChanged&&!this.scrollTopChanged}attemptToMerge(e){return e.kind!==this.kind?null:new UP(this._oldScrollWidth,this._oldScrollLeft,this._oldScrollHeight,this._oldScrollTop,e.scrollWidth,e.scrollLeft,e.scrollHeight,e.scrollTop)}}class Gde{constructor(){this.kind=3}isNoOp(){return!1}attemptToMerge(e){return e.kind!==this.kind?null:this}}class Zde{constructor(){this.kind=4}isNoOp(){return!1}attemptToMerge(e){return e.kind!==this.kind?null:this}}class dy{constructor(e,t,i,n,o,r,a){this.kind=6,this.oldSelections=e,this.selections=t,this.oldModelVersionId=i,this.modelVersionId=n,this.source=o,this.reason=r,this.reachedMaxCursorCount=a}static _selectionsAreEqual(e,t){if(!e&&!t)return!0;if(!e||!t)return!1;const i=e.length,n=t.length;if(i!==n)return!1;for(let o=0;o<i;o++)if(!e[o].equalsSelection(t[o]))return!1;return!0}isNoOp(){return dy._selectionsAreEqual(this.oldSelections,this.selections)&&this.oldModelVersionId===this.modelVersionId}attemptToMerge(e){return e.kind!==this.kind?null:new dy(this.oldSelections,e.selections,this.oldModelVersionId,e.modelVersionId,e.source,e.reason,this.reachedMaxCursorCount||e.reachedMaxCursorCount)}}class Yde{constructor(){this.kind=5}isNoOp(){return!1}attemptToMerge(e){return e.kind!==this.kind?null:this}}class Xde{constructor(e){this.event=e,this.kind=7}isNoOp(){return!1}attemptToMerge(e){return null}}class Qde{constructor(e){this.event=e,this.kind=8}isNoOp(){return!1}attemptToMerge(e){return null}}class Jde{constructor(e){this.event=e,this.kind=9}isNoOp(){return!1}attemptToMerge(e){return null}}class ece{constructor(e){this.event=e,this.kind=10}isNoOp(){return!1}attemptToMerge(e){return null}}class tce{constructor(e){this.event=e,this.kind=11}isNoOp(){return!1}attemptToMerge(e){return null}}class ice{constructor(e){this.event=e,this.kind=12}isNoOp(){return!1}attemptToMerge(e){return null}}class nce extends j{constructor(e,t,i,n){super(),this._model=e,this._knownModelVersionId=this._model.getVersionId(),this._viewModel=t,this._coordinatesConverter=i,this.context=new w7(this._model,this._viewModel,this._coordinatesConverter,n),this._cursors=new C7(this.context),this._hasFocus=!1,this._isHandling=!1,this._compositionState=null,this._columnSelectData=null,this._autoClosedActions=[],this._prevEditOperationType=0}dispose(){this._cursors.dispose(),this._autoClosedActions=Bt(this._autoClosedActions),super.dispose()}updateConfiguration(e){this.context=new w7(this._model,this._viewModel,this._coordinatesConverter,e),this._cursors.updateContext(this.context)}onLineMappingChanged(e){this._knownModelVersionId===this._model.getVersionId()&&this.setStates(e,"viewModel",0,this.getCursorStates())}setHasFocus(e){this._hasFocus=e}_validateAutoClosedActions(){if(this._autoClosedActions.length>0){const e=this._cursors.getSelections();for(let t=0;t<this._autoClosedActions.length;t++){const i=this._autoClosedActions[t];i.isValid(e)||(i.dispose(),this._autoClosedActions.splice(t,1),t--)}}}getPrimaryCursorState(){return this._cursors.getPrimaryCursor()}getLastAddedCursorIndex(){return this._cursors.getLastAddedCursorIndex()}getCursorStates(){return this._cursors.getAll()}setStates(e,t,i,n){let o=!1;const r=this.context.cursorConfig.multiCursorLimit;n!==null&&n.length>r&&(n=n.slice(0,r),o=!0);const a=Kv.from(this._model,this);return this._cursors.setStates(n),this._cursors.normalize(),this._columnSelectData=null,this._validateAutoClosedActions(),this._emitStateChangedIfNecessary(e,t,i,a,o)}setCursorColumnSelectData(e){this._columnSelectData=e}revealPrimary(e,t,i,n,o,r){const a=this._cursors.getViewPositions();let l=null,d=null;a.length>1?d=this._cursors.getViewSelections():l=D.fromPositions(a[0],a[0]),e.emitViewEvent(new Uw(t,i,l,d,n,o,r))}saveState(){const e=[],t=this._cursors.getSelections();for(let i=0,n=t.length;i<n;i++){const o=t[i];e.push({inSelectionMode:!o.isEmpty(),selectionStart:{lineNumber:o.selectionStartLineNumber,column:o.selectionStartColumn},position:{lineNumber:o.positionLineNumber,column:o.positionColumn}})}return e}restoreState(e,t){const i=[];for(let n=0,o=t.length;n<o;n++){const r=t[n];let a=1,l=1;r.position&&r.position.lineNumber&&(a=r.position.lineNumber),r.position&&r.position.column&&(l=r.position.column);let d=a,c=l;r.selectionStart&&r.selectionStart.lineNumber&&(d=r.selectionStart.lineNumber),r.selectionStart&&r.selectionStart.column&&(c=r.selectionStart.column),i.push({selectionStartLineNumber:d,selectionStartColumn:c,positionLineNumber:a,positionColumn:l})}this.setStates(e,"restoreState",0,yt.fromModelSelections(i)),this.revealPrimary(e,"restoreState",!1,0,!0,1)}onModelContentChanged(e,t){if(t instanceof lz){if(this._isHandling)return;this._isHandling=!0;try{this.setStates(e,"modelChange",0,this.getCursorStates())}finally{this._isHandling=!1}}else{const i=t.rawContentChangedEvent;if(this._knownModelVersionId=i.versionId,this._isHandling)return;const n=i.containsEvent(1);if(this._prevEditOperationType=0,n)this._cursors.dispose(),this._cursors=new C7(this.context),this._validateAutoClosedActions(),this._emitStateChangedIfNecessary(e,"model",1,null,!1);else if(this._hasFocus&&i.resultingSelection&&i.resultingSelection.length>0){const o=yt.fromModelSelections(i.resultingSelection);this.setStates(e,"modelChange",i.isUndoing?5:i.isRedoing?6:2,o)&&this.revealPrimary(e,"modelChange",!1,0,!0,0)}else{const o=this._cursors.readSelectionFromMarkers();this.setStates(e,"modelChange",2,yt.fromModelSelections(o))}}}getSelection(){return this._cursors.getPrimaryCursor().modelState.selection}getTopMostViewPosition(){return this._cursors.getTopMostViewPosition()}getBottomMostViewPosition(){return this._cursors.getBottomMostViewPosition()}getCursorColumnSelectData(){if(this._columnSelectData)return this._columnSelectData;const e=this._cursors.getPrimaryCursor(),t=e.viewState.selectionStart.getStartPosition(),i=e.viewState.position;return{isReal:!1,fromViewLineNumber:t.lineNumber,fromViewVisualColumn:this.context.cursorConfig.visibleColumnFromColumn(this._viewModel,t),toViewLineNumber:i.lineNumber,toViewVisualColumn:this.context.cursorConfig.visibleColumnFromColumn(this._viewModel,i)}}getSelections(){return this._cursors.getSelections()}setSelections(e,t,i,n){this.setStates(e,t,n,yt.fromModelSelections(i))}getPrevEditOperationType(){return this._prevEditOperationType}setPrevEditOperationType(e){this._prevEditOperationType=e}_pushAutoClosedAction(e,t){const i=[],n=[];for(let a=0,l=e.length;a<l;a++)i.push({range:e[a],options:{description:"auto-closed-character",inlineClassName:"auto-closed-character",stickiness:1}}),n.push({range:t[a],options:{description:"auto-closed-enclosing",stickiness:1}});const o=this._model.deltaDecorations([],i),r=this._model.deltaDecorations([],n);this._autoClosedActions.push(new S7(this._model,o,r))}_executeEditOperation(e){if(!e)return;e.shouldPushStackElementBefore&&this._model.pushStackElement();const t=sce.executeCommands(this._model,this._cursors.getSelections(),e.commands);if(t){this._interpretCommandResult(t);const i=[],n=[];for(let o=0;o<e.commands.length;o++){const r=e.commands[o];r instanceof AH&&r.enclosingRange&&r.closeCharacterRange&&(i.push(r.closeCharacterRange),n.push(r.enclosingRange))}i.length>0&&this._pushAutoClosedAction(i,n),this._prevEditOperationType=e.type}e.shouldPushStackElementAfter&&this._model.pushStackElement()}_interpretCommandResult(e){(!e||e.length===0)&&(e=this._cursors.readSelectionFromMarkers()),this._columnSelectData=null,this._cursors.setSelections(e),this._cursors.normalize()}_emitStateChangedIfNecessary(e,t,i,n,o){const r=Kv.from(this._model,this);if(r.equals(n))return!1;const a=this._cursors.getSelections(),l=this._cursors.getViewSelections();if(e.emitViewEvent(new Bde(l,a,i)),!n||n.cursorState.length!==r.cursorState.length||r.cursorState.some((d,c)=>!d.modelState.equals(n.cursorState[c].modelState))){const d=n?n.cursorState.map(u=>u.modelState.selection):null,c=n?n.modelVersionId:0;e.emitOutgoingEvent(new dy(d,a,c,r.modelVersionId,t||"keyboard",i,o))}return!0}_findAutoClosingPairs(e){if(!e.length)return null;const t=[];for(let i=0,n=e.length;i<n;i++){const o=e[i];if(!o.text||o.text.indexOf(`
`)>=0)return null;const r=o.text.match(/([)\]}>'"`])([^)\]}>'"`]*)$/);if(!r)return null;const a=r[1],l=this.context.cursorConfig.autoClosingPairs.autoClosingPairsCloseSingleChar.get(a);if(!l||l.length!==1)return null;const d=l[0].open,c=o.text.length-r[2].length-1,u=o.text.lastIndexOf(d,c-1);if(u===-1)return null;t.push([u,c])}return t}executeEdits(e,t,i,n){let o=null;t==="snippet"&&(o=this._findAutoClosingPairs(i)),o&&(i[0]._isTracked=!0);const r=[],a=[],l=this._model.pushEditOperations(this.getSelections(),i,d=>{if(o)for(let u=0,h=o.length;u<h;u++){const[g,f]=o[u],m=d[u],_=m.range.startLineNumber,v=m.range.startColumn-1+g,b=m.range.startColumn-1+f;r.push(new D(_,b+1,_,b+2)),a.push(new D(_,v+1,_,b+2))}const c=n(d);return c&&(this._isHandling=!0),c});l&&(this._isHandling=!1,this.setSelections(e,t,l,0)),r.length>0&&this._pushAutoClosedAction(r,a)}_executeEdit(e,t,i,n=0){if(this.context.cursorConfig.readOnly)return;const o=Kv.from(this._model,this);this._cursors.stopTrackingSelections(),this._isHandling=!0;try{this._cursors.ensureValidState(),e()}catch(r){et(r)}this._isHandling=!1,this._cursors.startTrackingSelections(),this._validateAutoClosedActions(),this._emitStateChangedIfNecessary(t,i,n,o,!1)&&this.revealPrimary(t,i,!1,0,!0,0)}getAutoClosedCharacters(){return S7.getAllAutoClosedCharacters(this._autoClosedActions)}startComposition(e){this._compositionState=new qv(this._model,this.getSelections())}endComposition(e,t){const i=this._compositionState?this._compositionState.deduceOutcome(this._model,this.getSelections()):null;this._compositionState=null,this._executeEdit(()=>{t==="keyboard"&&this._executeEditOperation(bi.compositionEndWithInterceptors(this._prevEditOperationType,this.context.cursorConfig,this._model,i,this.getSelections(),this.getAutoClosedCharacters()))},e,t)}type(e,t,i){this._executeEdit(()=>{if(i==="keyboard"){const n=t.length;let o=0;for(;o<n;){const r=VA(t,o),a=t.substr(o,r);this._executeEditOperation(bi.typeWithInterceptors(!!this._compositionState,this._prevEditOperationType,this.context.cursorConfig,this._model,this.getSelections(),this.getAutoClosedCharacters(),a)),o+=r}}else this._executeEditOperation(bi.typeWithoutInterceptors(this._prevEditOperationType,this.context.cursorConfig,this._model,this.getSelections(),t))},e,i)}compositionType(e,t,i,n,o,r){if(t.length===0&&i===0&&n===0){if(o!==0){const a=this.getSelections().map(l=>{const d=l.getPosition();return new De(d.lineNumber,d.column+o,d.lineNumber,d.column+o)});this.setSelections(e,r,a,0)}return}this._executeEdit(()=>{this._executeEditOperation(bi.compositionType(this._prevEditOperationType,this.context.cursorConfig,this._model,this.getSelections(),t,i,n,o))},e,r)}paste(e,t,i,n,o){this._executeEdit(()=>{this._executeEditOperation(bi.paste(this.context.cursorConfig,this._model,this.getSelections(),t,i,n||[]))},e,o,4)}cut(e,t){this._executeEdit(()=>{this._executeEditOperation(Rg.cut(this.context.cursorConfig,this._model,this.getSelections()))},e,t)}executeCommand(e,t,i){this._executeEdit(()=>{this._cursors.killSecondaryCursors(),this._executeEditOperation(new Us(0,[t],{shouldPushStackElementBefore:!1,shouldPushStackElementAfter:!1}))},e,i)}executeCommands(e,t,i){this._executeEdit(()=>{this._executeEditOperation(new Us(0,t,{shouldPushStackElementBefore:!1,shouldPushStackElementAfter:!1}))},e,i)}}class Kv{static from(e,t){return new Kv(e.getVersionId(),t.getCursorStates())}constructor(e,t){this.modelVersionId=e,this.cursorState=t}equals(e){if(!e||this.modelVersionId!==e.modelVersionId||this.cursorState.length!==e.cursorState.length)return!1;for(let t=0,i=this.cursorState.length;t<i;t++)if(!this.cursorState[t].equals(e.cursorState[t]))return!1;return!0}}class S7{static getAllAutoClosedCharacters(e){let t=[];for(const i of e)t=t.concat(i.getAutoClosedCharactersRanges());return t}constructor(e,t,i){this._model=e,this._autoClosedCharactersDecorations=t,this._autoClosedEnclosingDecorations=i}dispose(){this._autoClosedCharactersDecorations=this._model.deltaDecorations(this._autoClosedCharactersDecorations,[]),this._autoClosedEnclosingDecorations=this._model.deltaDecorations(this._autoClosedEnclosingDecorations,[])}getAutoClosedCharactersRanges(){const e=[];for(let t=0;t<this._autoClosedCharactersDecorations.length;t++){const i=this._model.getDecorationRange(this._autoClosedCharactersDecorations[t]);i&&e.push(i)}return e}isValid(e){const t=[];for(let i=0;i<this._autoClosedEnclosingDecorations.length;i++){const n=this._model.getDecorationRange(this._autoClosedEnclosingDecorations[i]);if(n&&(t.push(n),n.startLineNumber!==n.endLineNumber))return!1}t.sort(D.compareRangesUsingStarts),e.sort(D.compareRangesUsingStarts);for(let i=0;i<e.length;i++)if(i>=t.length||!t[i].strictContainsRange(e[i]))return!1;return!0}}class sce{static executeCommands(e,t,i){const n={model:e,selectionsBefore:t,trackedRanges:[],trackedRangesDirection:[]},o=this._innerExecuteCommands(n,i);for(let r=0,a=n.trackedRanges.length;r<a;r++)n.model._setTrackedRange(n.trackedRanges[r],null,0);return o}static _innerExecuteCommands(e,t){if(this._arrayIsEmpty(t))return null;const i=this._getEditOperations(e,t);if(i.operations.length===0)return null;const n=i.operations,o=this._getLoserCursorMap(n);if(o.hasOwnProperty("0"))return console.warn("Ignoring commands"),null;const r=[];for(let d=0,c=n.length;d<c;d++)o.hasOwnProperty(n[d].identifier.major.toString())||r.push(n[d]);i.hadTrackedEditOperation&&r.length>0&&(r[0]._isTracked=!0);let a=e.model.pushEditOperations(e.selectionsBefore,r,d=>{const c=[];for(let g=0;g<e.selectionsBefore.length;g++)c[g]=[];for(const g of d)g.identifier&&c[g.identifier.major].push(g);const u=(g,f)=>g.identifier.minor-f.identifier.minor,h=[];for(let g=0;g<e.selectionsBefore.length;g++)c[g].length>0?(c[g].sort(u),h[g]=t[g].computeCursorState(e.model,{getInverseEditOperations:()=>c[g],getTrackedSelection:f=>{const m=parseInt(f,10),_=e.model._getTrackedRange(e.trackedRanges[m]);return e.trackedRangesDirection[m]===0?new De(_.startLineNumber,_.startColumn,_.endLineNumber,_.endColumn):new De(_.endLineNumber,_.endColumn,_.startLineNumber,_.startColumn)}})):h[g]=e.selectionsBefore[g];return h});a||(a=e.selectionsBefore);const l=[];for(const d in o)o.hasOwnProperty(d)&&l.push(parseInt(d,10));l.sort((d,c)=>c-d);for(const d of l)a.splice(d,1);return a}static _arrayIsEmpty(e){for(let t=0,i=e.length;t<i;t++)if(e[t])return!1;return!0}static _getEditOperations(e,t){let i=[],n=!1;for(let o=0,r=t.length;o<r;o++){const a=t[o];if(a){const l=this._getEditOperationsFromCommand(e,o,a);i=i.concat(l.operations),n=n||l.hadTrackedEditOperation}}return{operations:i,hadTrackedEditOperation:n}}static _getEditOperationsFromCommand(e,t,i){const n=[];let o=0;const r=(u,h,g=!1)=>{D.isEmpty(u)&&h===""||n.push({identifier:{major:t,minor:o++},range:u,text:h,forceMoveMarkers:g,isAutoWhitespaceEdit:i.insertsAutoWhitespace})};let a=!1;const c={addEditOperation:r,addTrackedEditOperation:(u,h,g)=>{a=!0,r(u,h,g)},trackSelection:(u,h)=>{const g=De.liftSelection(u);let f;if(g.isEmpty())if(typeof h=="boolean")h?f=2:f=3;else{const v=e.model.getLineMaxColumn(g.startLineNumber);g.startColumn===v?f=2:f=3}else f=1;const m=e.trackedRanges.length,_=e.model._setTrackedRange(null,g,f);return e.trackedRanges[m]=_,e.trackedRangesDirection[m]=g.getDirection(),m.toString()}};try{i.getEditOperations(e.model,c)}catch(u){return et(u),{operations:[],hadTrackedEditOperation:!1}}return{operations:n,hadTrackedEditOperation:a}}static _getLoserCursorMap(e){e=e.slice(0),e.sort((i,n)=>-D.compareRangesUsingEnds(i.range,n.range));const t={};for(let i=1;i<e.length;i++){const n=e[i-1],o=e[i];if(D.getStartPosition(n.range).isBefore(D.getEndPosition(o.range))){let r;n.identifier.major>o.identifier.major?r=n.identifier.major:r=o.identifier.major,t[r.toString()]=!0;for(let a=0;a<e.length;a++)e[a].identifier.major===r&&(e.splice(a,1),a<i&&i--,a--);i>0&&i--}}return t}}class oce{constructor(e,t,i){this.text=e,this.startSelection=t,this.endSelection=i}}class qv{static _capture(e,t){const i=[];for(const n of t){if(n.startLineNumber!==n.endLineNumber)return null;i.push(new oce(e.getLineContent(n.startLineNumber),n.startColumn-1,n.endColumn-1))}return i}constructor(e,t){this._original=qv._capture(e,t)}deduceOutcome(e,t){if(!this._original)return null;const i=qv._capture(e,t);if(!i||this._original.length!==i.length)return null;const n=[];for(let o=0,r=this._original.length;o<r;o++)n.push(qv._deduceOutcome(this._original[o],i[o]));return n}static _deduceOutcome(e,t){const i=Math.min(e.startSelection,t.startSelection,Dg(e.text,t.text)),n=Math.min(e.text.length-e.endSelection,t.text.length-t.endSelection,RS(e.text,t.text)),o=e.text.substring(i,e.text.length-n),r=t.text.substring(i,t.text.length-n);return new cae(o,e.startSelection-i,e.endSelection-i,r,t.startSelection-i,t.endSelection-i)}}const y7={getInitialState:()=>pm,tokenizeEncoded:(s,e,t)=>_x(0,t)};async function rce(s,e,t){if(!t)return L7(e,s.languageIdCodec,y7);const i=await xi.getOrCreate(t);return L7(e,s.languageIdCodec,i||y7)}function ace(s,e,t,i,n,o,r){let a="<div>",l=i,d=0,c=!0;for(let u=0,h=e.getCount();u<h;u++){const g=e.getEndOffset(u);if(g<=i)continue;let f="";for(;l<g&&l<n;l++){const m=s.charCodeAt(l);switch(m){case 9:{let _=o-(l+d)%o;for(d+=_-1;_>0;)r&&c?(f+="&#160;",c=!1):(f+=" ",c=!0),_--;break}case 60:f+="&lt;",c=!1;break;case 62:f+="&gt;",c=!1;break;case 38:f+="&amp;",c=!1;break;case 0:f+="&#00;",c=!1;break;case 65279:case 8232:case 8233:case 133:f+="�",c=!1;break;case 13:f+="&#8203",c=!1;break;case 32:r&&c?(f+="&#160;",c=!1):(f+=" ",c=!0);break;default:f+=String.fromCharCode(m),c=!1}}if(a+=`<span style="${e.getInlineStyle(u,t)}">${f}</span>`,g>n||l>=n)break}return a+="</div>",a}function L7(s,e,t){let i='<div class="monaco-tokenized-source">';const n=Kl(s);let o=t.getInitialState();for(let r=0,a=n.length;r<a;r++){const l=n[r];r>0&&(i+="<br/>");const d=t.tokenizeEncoded(l,!0,o);vn.convertToEndOffset(d.tokens,l.length);const u=new vn(d.tokens,l,e).inflate();let h=0;for(let g=0,f=u.getCount();g<f;g++){const m=u.getClassName(g),_=u.getEndOffset(g);i+=`<span class="${m}">${MS(l.substring(h,_))}</span>`,h=_}o=d.endState}return i+="</div>",i}class lce{constructor(){this._hasPending=!1,this._inserts=[],this._changes=[],this._removes=[]}insert(e){this._hasPending=!0,this._inserts.push(e)}change(e){this._hasPending=!0,this._changes.push(e)}remove(e){this._hasPending=!0,this._removes.push(e)}mustCommit(){return this._hasPending}commit(e){if(!this._hasPending)return;const t=this._inserts,i=this._changes,n=this._removes;this._hasPending=!1,this._inserts=[],this._changes=[],this._removes=[],e._commitPendingChanges(t,i,n)}}class dce{constructor(e,t,i,n,o){this.id=e,this.afterLineNumber=t,this.ordinal=i,this.height=n,this.minWidth=o,this.prefixSum=0}}let hz=class OT{constructor(e,t,i,n){this._instanceId=KW(++OT.INSTANCE_COUNT),this._pendingChanges=new lce,this._lastWhitespaceId=0,this._arr=[],this._prefixSumValidIndex=-1,this._minWidth=-1,this._lineCount=e,this._lineHeight=t,this._paddingTop=i,this._paddingBottom=n}static findInsertionIndex(e,t,i){let n=0,o=e.length;for(;n<o;){const r=n+o>>>1;t===e[r].afterLineNumber?i<e[r].ordinal?o=r:n=r+1:t<e[r].afterLineNumber?o=r:n=r+1}return n}setLineHeight(e){this._checkPendingChanges(),this._lineHeight=e}setPadding(e,t){this._paddingTop=e,this._paddingBottom=t}onFlushed(e){this._checkPendingChanges(),this._lineCount=e}changeWhitespace(e){let t=!1;try{e({insertWhitespace:(n,o,r,a)=>{t=!0,n=n|0,o=o|0,r=r|0,a=a|0;const l=this._instanceId+ ++this._lastWhitespaceId;return this._pendingChanges.insert(new dce(l,n,o,r,a)),l},changeOneWhitespace:(n,o,r)=>{t=!0,o=o|0,r=r|0,this._pendingChanges.change({id:n,newAfterLineNumber:o,newHeight:r})},removeWhitespace:n=>{t=!0,this._pendingChanges.remove({id:n})}})}finally{this._pendingChanges.commit(this)}return t}_commitPendingChanges(e,t,i){if((e.length>0||i.length>0)&&(this._minWidth=-1),e.length+t.length+i.length<=1){for(const l of e)this._insertWhitespace(l);for(const l of t)this._changeOneWhitespace(l.id,l.newAfterLineNumber,l.newHeight);for(const l of i){const d=this._findWhitespaceIndex(l.id);d!==-1&&this._removeWhitespace(d)}return}const n=new Set;for(const l of i)n.add(l.id);const o=new Map;for(const l of t)o.set(l.id,l);const r=l=>{const d=[];for(const c of l)if(!n.has(c.id)){if(o.has(c.id)){const u=o.get(c.id);c.afterLineNumber=u.newAfterLineNumber,c.height=u.newHeight}d.push(c)}return d},a=r(this._arr).concat(r(e));a.sort((l,d)=>l.afterLineNumber===d.afterLineNumber?l.ordinal-d.ordinal:l.afterLineNumber-d.afterLineNumber),this._arr=a,this._prefixSumValidIndex=-1}_checkPendingChanges(){this._pendingChanges.mustCommit()&&this._pendingChanges.commit(this)}_insertWhitespace(e){const t=OT.findInsertionIndex(this._arr,e.afterLineNumber,e.ordinal);this._arr.splice(t,0,e),this._prefixSumValidIndex=Math.min(this._prefixSumValidIndex,t-1)}_findWhitespaceIndex(e){const t=this._arr;for(let i=0,n=t.length;i<n;i++)if(t[i].id===e)return i;return-1}_changeOneWhitespace(e,t,i){const n=this._findWhitespaceIndex(e);if(n!==-1&&(this._arr[n].height!==i&&(this._arr[n].height=i,this._prefixSumValidIndex=Math.min(this._prefixSumValidIndex,n-1)),this._arr[n].afterLineNumber!==t)){const o=this._arr[n];this._removeWhitespace(n),o.afterLineNumber=t,this._insertWhitespace(o)}}_removeWhitespace(e){this._arr.splice(e,1),this._prefixSumValidIndex=Math.min(this._prefixSumValidIndex,e-1)}onLinesDeleted(e,t){this._checkPendingChanges(),e=e|0,t=t|0,this._lineCount-=t-e+1;for(let i=0,n=this._arr.length;i<n;i++){const o=this._arr[i].afterLineNumber;e<=o&&o<=t?this._arr[i].afterLineNumber=e-1:o>t&&(this._arr[i].afterLineNumber-=t-e+1)}}onLinesInserted(e,t){this._checkPendingChanges(),e=e|0,t=t|0,this._lineCount+=t-e+1;for(let i=0,n=this._arr.length;i<n;i++){const o=this._arr[i].afterLineNumber;e<=o&&(this._arr[i].afterLineNumber+=t-e+1)}}getWhitespacesTotalHeight(){return this._checkPendingChanges(),this._arr.length===0?0:this.getWhitespacesAccumulatedHeight(this._arr.length-1)}getWhitespacesAccumulatedHeight(e){this._checkPendingChanges(),e=e|0;let t=Math.max(0,this._prefixSumValidIndex+1);t===0&&(this._arr[0].prefixSum=this._arr[0].height,t++);for(let i=t;i<=e;i++)this._arr[i].prefixSum=this._arr[i-1].prefixSum+this._arr[i].height;return this._prefixSumValidIndex=Math.max(this._prefixSumValidIndex,e),this._arr[e].prefixSum}getLinesTotalHeight(){this._checkPendingChanges();const e=this._lineHeight*this._lineCount,t=this.getWhitespacesTotalHeight();return e+t+this._paddingTop+this._paddingBottom}getWhitespaceAccumulatedHeightBeforeLineNumber(e){this._checkPendingChanges(),e=e|0;const t=this._findLastWhitespaceBeforeLineNumber(e);return t===-1?0:this.getWhitespacesAccumulatedHeight(t)}_findLastWhitespaceBeforeLineNumber(e){e=e|0;const t=this._arr;let i=0,n=t.length-1;for(;i<=n;){const r=(n-i|0)/2|0,a=i+r|0;if(t[a].afterLineNumber<e){if(a+1>=t.length||t[a+1].afterLineNumber>=e)return a;i=a+1|0}else n=a-1|0}return-1}_findFirstWhitespaceAfterLineNumber(e){e=e|0;const i=this._findLastWhitespaceBeforeLineNumber(e)+1;return i<this._arr.length?i:-1}getFirstWhitespaceIndexAfterLineNumber(e){return this._checkPendingChanges(),e=e|0,this._findFirstWhitespaceAfterLineNumber(e)}getVerticalOffsetForLineNumber(e,t=!1){this._checkPendingChanges(),e=e|0;let i;e>1?i=this._lineHeight*(e-1):i=0;const n=this.getWhitespaceAccumulatedHeightBeforeLineNumber(e-(t?1:0));return i+n+this._paddingTop}getVerticalOffsetAfterLineNumber(e,t=!1){this._checkPendingChanges(),e=e|0;const i=this._lineHeight*e,n=this.getWhitespaceAccumulatedHeightBeforeLineNumber(e+(t?1:0));return i+n+this._paddingTop}getWhitespaceMinWidth(){if(this._checkPendingChanges(),this._minWidth===-1){let e=0;for(let t=0,i=this._arr.length;t<i;t++)e=Math.max(e,this._arr[t].minWidth);this._minWidth=e}return this._minWidth}isAfterLines(e){this._checkPendingChanges();const t=this.getLinesTotalHeight();return e>t}isInTopPadding(e){return this._paddingTop===0?!1:(this._checkPendingChanges(),e<this._paddingTop)}isInBottomPadding(e){if(this._paddingBottom===0)return!1;this._checkPendingChanges();const t=this.getLinesTotalHeight();return e>=t-this._paddingBottom}getLineNumberAtOrAfterVerticalOffset(e){if(this._checkPendingChanges(),e=e|0,e<0)return 1;const t=this._lineCount|0,i=this._lineHeight;let n=1,o=t;for(;n<o;){const r=(n+o)/2|0,a=this.getVerticalOffsetForLineNumber(r)|0;if(e>=a+i)n=r+1;else{if(e>=a)return r;o=r}}return n>t?t:n}getLinesViewportData(e,t){this._checkPendingChanges(),e=e|0,t=t|0;const i=this._lineHeight,n=this.getLineNumberAtOrAfterVerticalOffset(e)|0,o=this.getVerticalOffsetForLineNumber(n)|0;let r=this._lineCount|0,a=this.getFirstWhitespaceIndexAfterLineNumber(n)|0;const l=this.getWhitespacesCount()|0;let d,c;a===-1?(a=l,c=r+1,d=0):(c=this.getAfterLineNumberForWhitespaceIndex(a)|0,d=this.getHeightForWhitespaceIndex(a)|0);let u=o,h=u;const g=5e5;let f=0;o>=g&&(f=Math.floor(o/g)*g,f=Math.floor(f/i)*i,h-=f);const m=[],_=e+(t-e)/2;let v=-1;for(let S=n;S<=r;S++){if(v===-1){const x=u,L=u+i;(x<=_&&_<L||x>_)&&(v=S)}for(u+=i,m[S-n]=h,h+=i;c===S;)h+=d,u+=d,a++,a>=l?c=r+1:(c=this.getAfterLineNumberForWhitespaceIndex(a)|0,d=this.getHeightForWhitespaceIndex(a)|0);if(u>=t){r=S;break}}v===-1&&(v=r);const b=this.getVerticalOffsetForLineNumber(r)|0;let C=n,w=r;return C<w&&o<e&&C++,C<w&&b+i>t&&w--,{bigNumbersDelta:f,startLineNumber:n,endLineNumber:r,relativeVerticalOffset:m,centeredLineNumber:v,completelyVisibleStartLineNumber:C,completelyVisibleEndLineNumber:w}}getVerticalOffsetForWhitespaceIndex(e){this._checkPendingChanges(),e=e|0;const t=this.getAfterLineNumberForWhitespaceIndex(e);let i;t>=1?i=this._lineHeight*t:i=0;let n;return e>0?n=this.getWhitespacesAccumulatedHeight(e-1):n=0,i+n+this._paddingTop}getWhitespaceIndexAtOrAfterVerticallOffset(e){this._checkPendingChanges(),e=e|0;let t=0,i=this.getWhitespacesCount()-1;if(i<0)return-1;const n=this.getVerticalOffsetForWhitespaceIndex(i),o=this.getHeightForWhitespaceIndex(i);if(e>=n+o)return-1;for(;t<i;){const r=Math.floor((t+i)/2),a=this.getVerticalOffsetForWhitespaceIndex(r),l=this.getHeightForWhitespaceIndex(r);if(e>=a+l)t=r+1;else{if(e>=a)return r;i=r}}return t}getWhitespaceAtVerticalOffset(e){this._checkPendingChanges(),e=e|0;const t=this.getWhitespaceIndexAtOrAfterVerticallOffset(e);if(t<0||t>=this.getWhitespacesCount())return null;const i=this.getVerticalOffsetForWhitespaceIndex(t);if(i>e)return null;const n=this.getHeightForWhitespaceIndex(t),o=this.getIdForWhitespaceIndex(t),r=this.getAfterLineNumberForWhitespaceIndex(t);return{id:o,afterLineNumber:r,verticalOffset:i,height:n}}getWhitespaceViewportData(e,t){this._checkPendingChanges(),e=e|0,t=t|0;const i=this.getWhitespaceIndexAtOrAfterVerticallOffset(e),n=this.getWhitespacesCount()-1;if(i<0)return[];const o=[];for(let r=i;r<=n;r++){const a=this.getVerticalOffsetForWhitespaceIndex(r),l=this.getHeightForWhitespaceIndex(r);if(a>=t)break;o.push({id:this.getIdForWhitespaceIndex(r),afterLineNumber:this.getAfterLineNumberForWhitespaceIndex(r),verticalOffset:a,height:l})}return o}getWhitespaces(){return this._checkPendingChanges(),this._arr.slice(0)}getWhitespacesCount(){return this._checkPendingChanges(),this._arr.length}getIdForWhitespaceIndex(e){return this._checkPendingChanges(),e=e|0,this._arr[e].id}getAfterLineNumberForWhitespaceIndex(e){return this._checkPendingChanges(),e=e|0,this._arr[e].afterLineNumber}getHeightForWhitespaceIndex(e){return this._checkPendingChanges(),e=e|0,this._arr[e].height}};hz.INSTANCE_COUNT=0;const cce=125;class mv{constructor(e,t,i,n){e=e|0,t=t|0,i=i|0,n=n|0,e<0&&(e=0),t<0&&(t=0),i<0&&(i=0),n<0&&(n=0),this.width=e,this.contentWidth=t,this.scrollWidth=Math.max(e,t),this.height=i,this.contentHeight=n,this.scrollHeight=Math.max(i,n)}equals(e){return this.width===e.width&&this.contentWidth===e.contentWidth&&this.height===e.height&&this.contentHeight===e.contentHeight}}class uce extends j{constructor(e,t){super(),this._onDidContentSizeChange=this._register(new W),this.onDidContentSizeChange=this._onDidContentSizeChange.event,this._dimensions=new mv(0,0,0,0),this._scrollable=this._register(new a_({forceIntegerValues:!0,smoothScrollDuration:e,scheduleAtNextAnimationFrame:t})),this.onDidScroll=this._scrollable.onScroll}getScrollable(){return this._scrollable}setSmoothScrollDuration(e){this._scrollable.setSmoothScrollDuration(e)}validateScrollPosition(e){return this._scrollable.validateScrollPosition(e)}getScrollDimensions(){return this._dimensions}setScrollDimensions(e){if(this._dimensions.equals(e))return;const t=this._dimensions;this._dimensions=e,this._scrollable.setScrollDimensions({width:e.width,scrollWidth:e.scrollWidth,height:e.height,scrollHeight:e.scrollHeight},!0);const i=t.contentWidth!==e.contentWidth,n=t.contentHeight!==e.contentHeight;(i||n)&&this._onDidContentSizeChange.fire(new HP(t.contentWidth,t.contentHeight,e.contentWidth,e.contentHeight))}getFutureScrollPosition(){return this._scrollable.getFutureScrollPosition()}getCurrentScrollPosition(){return this._scrollable.getCurrentScrollPosition()}setScrollPositionNow(e){this._scrollable.setScrollPositionNow(e)}setScrollPositionSmooth(e){this._scrollable.setScrollPositionSmooth(e)}hasPendingScrollAnimation(){return this._scrollable.hasPendingScrollAnimation()}}class hce extends j{constructor(e,t,i){super(),this._configuration=e;const n=this._configuration.options,o=n.get(143),r=n.get(83);this._linesLayout=new hz(t,n.get(66),r.top,r.bottom),this._maxLineWidth=0,this._overlayWidgetsMinWidth=0,this._scrollable=this._register(new uce(0,i)),this._configureSmoothScrollDuration(),this._scrollable.setScrollDimensions(new mv(o.contentWidth,0,o.height,0)),this.onDidScroll=this._scrollable.onDidScroll,this.onDidContentSizeChange=this._scrollable.onDidContentSizeChange,this._updateHeight()}dispose(){super.dispose()}getScrollable(){return this._scrollable.getScrollable()}onHeightMaybeChanged(){this._updateHeight()}_configureSmoothScrollDuration(){this._scrollable.setSmoothScrollDuration(this._configuration.options.get(113)?cce:0)}onConfigurationChanged(e){const t=this._configuration.options;if(e.hasChanged(66)&&this._linesLayout.setLineHeight(t.get(66)),e.hasChanged(83)){const i=t.get(83);this._linesLayout.setPadding(i.top,i.bottom)}if(e.hasChanged(143)){const i=t.get(143),n=i.contentWidth,o=i.height,r=this._scrollable.getScrollDimensions(),a=r.contentWidth;this._scrollable.setScrollDimensions(new mv(n,r.contentWidth,o,this._getContentHeight(n,o,a)))}else this._updateHeight();e.hasChanged(113)&&this._configureSmoothScrollDuration()}onFlushed(e){this._linesLayout.onFlushed(e)}onLinesDeleted(e,t){this._linesLayout.onLinesDeleted(e,t)}onLinesInserted(e,t){this._linesLayout.onLinesInserted(e,t)}_getHorizontalScrollbarHeight(e,t){const n=this._configuration.options.get(102);return n.horizontal===2||e>=t?0:n.horizontalScrollbarSize}_getContentHeight(e,t,i){const n=this._configuration.options;let o=this._linesLayout.getLinesTotalHeight();return n.get(104)?o+=Math.max(0,t-n.get(66)-n.get(83).bottom):n.get(102).ignoreHorizontalScrollbarInContentHeight||(o+=this._getHorizontalScrollbarHeight(e,i)),o}_updateHeight(){const e=this._scrollable.getScrollDimensions(),t=e.width,i=e.height,n=e.contentWidth;this._scrollable.setScrollDimensions(new mv(t,e.contentWidth,i,this._getContentHeight(t,i,n)))}getCurrentViewport(){const e=this._scrollable.getScrollDimensions(),t=this._scrollable.getCurrentScrollPosition();return new p3(t.scrollTop,t.scrollLeft,e.width,e.height)}getFutureViewport(){const e=this._scrollable.getScrollDimensions(),t=this._scrollable.getFutureScrollPosition();return new p3(t.scrollTop,t.scrollLeft,e.width,e.height)}_computeContentWidth(){const e=this._configuration.options,t=this._maxLineWidth,i=e.get(144),n=e.get(50),o=e.get(143);if(i.isViewportWrapping){const r=e.get(72);return t>o.contentWidth+n.typicalHalfwidthCharacterWidth&&r.enabled&&r.side==="right"?t+o.verticalScrollbarWidth:t}else{const r=e.get(103)*n.typicalHalfwidthCharacterWidth,a=this._linesLayout.getWhitespaceMinWidth();return Math.max(t+r+o.verticalScrollbarWidth,a,this._overlayWidgetsMinWidth)}}setMaxLineWidth(e){this._maxLineWidth=e,this._updateContentWidth()}setOverlayWidgetsMinWidth(e){this._overlayWidgetsMinWidth=e,this._updateContentWidth()}_updateContentWidth(){const e=this._scrollable.getScrollDimensions();this._scrollable.setScrollDimensions(new mv(e.width,this._computeContentWidth(),e.height,e.contentHeight)),this._updateHeight()}saveState(){const e=this._scrollable.getFutureScrollPosition(),t=e.scrollTop,i=this._linesLayout.getLineNumberAtOrAfterVerticalOffset(t),n=this._linesLayout.getWhitespaceAccumulatedHeightBeforeLineNumber(i);return{scrollTop:t,scrollTopWithoutViewZones:t-n,scrollLeft:e.scrollLeft}}changeWhitespace(e){const t=this._linesLayout.changeWhitespace(e);return t&&this.onHeightMaybeChanged(),t}getVerticalOffsetForLineNumber(e,t=!1){return this._linesLayout.getVerticalOffsetForLineNumber(e,t)}getVerticalOffsetAfterLineNumber(e,t=!1){return this._linesLayout.getVerticalOffsetAfterLineNumber(e,t)}isAfterLines(e){return this._linesLayout.isAfterLines(e)}isInTopPadding(e){return this._linesLayout.isInTopPadding(e)}isInBottomPadding(e){return this._linesLayout.isInBottomPadding(e)}getLineNumberAtVerticalOffset(e){return this._linesLayout.getLineNumberAtOrAfterVerticalOffset(e)}getWhitespaceAtVerticalOffset(e){return this._linesLayout.getWhitespaceAtVerticalOffset(e)}getLinesViewportData(){const e=this.getCurrentViewport();return this._linesLayout.getLinesViewportData(e.top,e.top+e.height)}getLinesViewportDataAtScrollTop(e){const t=this._scrollable.getScrollDimensions();return e+t.height>t.scrollHeight&&(e=t.scrollHeight-t.height),e<0&&(e=0),this._linesLayout.getLinesViewportData(e,e+t.height)}getWhitespaceViewportData(){const e=this.getCurrentViewport();return this._linesLayout.getWhitespaceViewportData(e.top,e.top+e.height)}getWhitespaces(){return this._linesLayout.getWhitespaces()}getContentWidth(){return this._scrollable.getScrollDimensions().contentWidth}getScrollWidth(){return this._scrollable.getScrollDimensions().scrollWidth}getContentHeight(){return this._scrollable.getScrollDimensions().contentHeight}getScrollHeight(){return this._scrollable.getScrollDimensions().scrollHeight}getCurrentScrollLeft(){return this._scrollable.getCurrentScrollPosition().scrollLeft}getCurrentScrollTop(){return this._scrollable.getCurrentScrollPosition().scrollTop}validateScrollPosition(e){return this._scrollable.validateScrollPosition(e)}setScrollPosition(e,t){t===1?this._scrollable.setScrollPositionNow(e):this._scrollable.setScrollPositionSmooth(e)}hasPendingScrollAnimation(){return this._scrollable.hasPendingScrollAnimation()}deltaScrollNow(e,t){const i=this._scrollable.getCurrentScrollPosition();this._scrollable.setScrollPositionNow({scrollLeft:i.scrollLeft+e,scrollTop:i.scrollTop+t})}}class gce{constructor(e,t,i,n,o){this.editorId=e,this.model=t,this.configuration=i,this._linesCollection=n,this._coordinatesConverter=o,this._decorationsCache=Object.create(null),this._cachedModelDecorationsResolver=null,this._cachedModelDecorationsResolverViewRange=null}_clearCachedModelDecorationsResolver(){this._cachedModelDecorationsResolver=null,this._cachedModelDecorationsResolverViewRange=null}dispose(){this._decorationsCache=Object.create(null),this._clearCachedModelDecorationsResolver()}reset(){this._decorationsCache=Object.create(null),this._clearCachedModelDecorationsResolver()}onModelDecorationsChanged(){this._decorationsCache=Object.create(null),this._clearCachedModelDecorationsResolver()}onLineMappingChanged(){this._decorationsCache=Object.create(null),this._clearCachedModelDecorationsResolver()}_getOrCreateViewModelDecoration(e){const t=e.id;let i=this._decorationsCache[t];if(!i){const n=e.range,o=e.options;let r;if(o.isWholeLine){const a=this._coordinatesConverter.convertModelPositionToViewPosition(new H(n.startLineNumber,1),0,!1,!0),l=this._coordinatesConverter.convertModelPositionToViewPosition(new H(n.endLineNumber,this.model.getLineMaxColumn(n.endLineNumber)),1);r=new D(a.lineNumber,a.column,l.lineNumber,l.column)}else r=this._coordinatesConverter.convertModelRangeToViewRange(n,1);i=new eH(r,o),this._decorationsCache[t]=i}return i}getMinimapDecorationsInRange(e){return this._getDecorationsInRange(e,!0,!1).decorations}getDecorationsViewportData(e){let t=this._cachedModelDecorationsResolver!==null;return t=t&&e.equalsRange(this._cachedModelDecorationsResolverViewRange),t||(this._cachedModelDecorationsResolver=this._getDecorationsInRange(e,!1,!1),this._cachedModelDecorationsResolverViewRange=e),this._cachedModelDecorationsResolver}getInlineDecorationsOnLine(e,t=!1,i=!1){const n=new D(e,this._linesCollection.getViewLineMinColumn(e),e,this._linesCollection.getViewLineMaxColumn(e));return this._getDecorationsInRange(n,t,i).inlineDecorations[0]}_getDecorationsInRange(e,t,i){const n=this._linesCollection.getDecorationsInRange(e,this.editorId,LS(this.configuration.options),t,i),o=e.startLineNumber,r=e.endLineNumber,a=[];let l=0;const d=[];for(let c=o;c<=r;c++)d[c-o]=[];for(let c=0,u=n.length;c<u;c++){const h=n[c],g=h.options;if(!$P(this.model,h))continue;const f=this._getOrCreateViewModelDecoration(h),m=f.range;if(a[l++]=f,g.inlineClassName){const _=new Pv(m,g.inlineClassName,g.inlineClassNameAffectsLetterSpacing?3:0),v=Math.max(o,m.startLineNumber),b=Math.min(r,m.endLineNumber);for(let C=v;C<=b;C++)d[C-o].push(_)}if(g.beforeContentClassName&&o<=m.startLineNumber&&m.startLineNumber<=r){const _=new Pv(new D(m.startLineNumber,m.startColumn,m.startLineNumber,m.startColumn),g.beforeContentClassName,1);d[m.startLineNumber-o].push(_)}if(g.afterContentClassName&&o<=m.endLineNumber&&m.endLineNumber<=r){const _=new Pv(new D(m.endLineNumber,m.endColumn,m.endLineNumber,m.endColumn),g.afterContentClassName,2);d[m.endLineNumber-o].push(_)}}return{decorations:a,inlineDecorations:d}}}function $P(s,e){return!(e.options.hideInCommentTokens&&jP(s,e)||e.options.hideInStringTokens&&KP(s,e))}function jP(s,e){return gz(s,e.range,t=>t===1)}function KP(s,e){return gz(s,e.range,t=>t===2)}function gz(s,e,t){for(let i=e.startLineNumber;i<=e.endLineNumber;i++){const n=s.tokenization.getLineTokens(i),o=i===e.startLineNumber,r=i===e.endLineNumber;let a=o?n.findTokenIndexAtOffset(e.startColumn-1):0;for(;a<n.getCount()&&!(r&&n.getStartOffset(a)>e.endColumn-1);){if(!t(n.getStandardTokenType(a)))return!1;a++}}return!0}function CI(s,e){return s===null?e?cy.INSTANCE:uy.INSTANCE:new fce(s,e)}class fce{constructor(e,t){this._projectionData=e,this._isVisible=t}isVisible(){return this._isVisible}setVisible(e){return this._isVisible=e,this}getProjectionData(){return this._projectionData}getViewLineCount(){return this._isVisible?this._projectionData.getOutputLineCount():0}getViewLineContent(e,t,i){this._assertVisible();const n=i>0?this._projectionData.breakOffsets[i-1]:0,o=this._projectionData.breakOffsets[i];let r;if(this._projectionData.injectionOffsets!==null){const a=this._projectionData.injectionOffsets.map((d,c)=>new Ha(0,0,d+1,this._projectionData.injectionOptions[c],0));r=Ha.applyInjectedText(e.getLineContent(t),a).substring(n,o)}else r=e.getValueInRange({startLineNumber:t,startColumn:n+1,endLineNumber:t,endColumn:o+1});return i>0&&(r=x7(this._projectionData.wrappedTextIndentLength)+r),r}getViewLineLength(e,t,i){return this._assertVisible(),this._projectionData.getLineLength(i)}getViewLineMinColumn(e,t,i){return this._assertVisible(),this._projectionData.getMinOutputOffset(i)+1}getViewLineMaxColumn(e,t,i){return this._assertVisible(),this._projectionData.getMaxOutputOffset(i)+1}getViewLineData(e,t,i){const n=new Array;return this.getViewLinesData(e,t,i,1,0,[!0],n),n[0]}getViewLinesData(e,t,i,n,o,r,a){this._assertVisible();const l=this._projectionData,d=l.injectionOffsets,c=l.injectionOptions;let u=null;if(d){u=[];let g=0,f=0;for(let m=0;m<l.getOutputLineCount();m++){const _=new Array;u[m]=_;const v=m>0?l.breakOffsets[m-1]:0,b=l.breakOffsets[m];for(;f<d.length;){const C=c[f].content.length,w=d[f]+g,S=w+C;if(w>b)break;if(v<S){const x=c[f];if(x.inlineClassName){const L=m>0?l.wrappedTextIndentLength:0,k=L+Math.max(w-v,0),I=L+Math.min(S-v,b-v);k!==I&&_.push(new Lne(k,I,x.inlineClassName,x.inlineClassNameAffectsLetterSpacing))}}if(S<=b)g+=C,f++;else break}}}let h;d?h=e.tokenization.getLineTokens(t).withInserted(d.map((g,f)=>({offset:g,text:c[f].content,tokenMetadata:vn.defaultTokenMetadata}))):h=e.tokenization.getLineTokens(t);for(let g=i;g<i+n;g++){const f=o+g-i;if(!r[f]){a[f]=null;continue}a[f]=this._getViewLineData(h,u?u[g]:null,g)}}_getViewLineData(e,t,i){this._assertVisible();const n=this._projectionData,o=i>0?n.wrappedTextIndentLength:0,r=i>0?n.breakOffsets[i-1]:0,a=n.breakOffsets[i],l=e.sliceAndInflate(r,a,o);let d=l.getLineContent();i>0&&(d=x7(n.wrappedTextIndentLength)+d);const c=this._projectionData.getMinOutputOffset(i)+1,u=d.length+1,h=i+1<this.getViewLineCount(),g=i===0?0:n.breakOffsetsVisibleColumn[i-1];return new fP(d,h,c,u,g,l,t)}getModelColumnOfViewPosition(e,t){return this._assertVisible(),this._projectionData.translateToInputOffset(e,t-1)+1}getViewPositionOfModelPosition(e,t,i=2){return this._assertVisible(),this._projectionData.translateToOutputPosition(t-1,i).toPosition(e)}getViewLineNumberOfModelPosition(e,t){this._assertVisible();const i=this._projectionData.translateToOutputPosition(t-1);return e+i.outputLineIndex}normalizePosition(e,t,i){const n=t.lineNumber-e;return this._projectionData.normalizeOutputPosition(e,t.column-1,i).toPosition(n)}getInjectedTextAt(e,t){return this._projectionData.getInjectedText(e,t-1)}_assertVisible(){if(!this._isVisible)throw new Error("Not supported")}}class cy{constructor(){}isVisible(){return!0}setVisible(e){return e?this:uy.INSTANCE}getProjectionData(){return null}getViewLineCount(){return 1}getViewLineContent(e,t,i){return e.getLineContent(t)}getViewLineLength(e,t,i){return e.getLineLength(t)}getViewLineMinColumn(e,t,i){return e.getLineMinColumn(t)}getViewLineMaxColumn(e,t,i){return e.getLineMaxColumn(t)}getViewLineData(e,t,i){const n=e.tokenization.getLineTokens(t),o=n.getLineContent();return new fP(o,!1,1,o.length+1,0,n.inflate(),null)}getViewLinesData(e,t,i,n,o,r,a){if(!r[o]){a[o]=null;return}a[o]=this.getViewLineData(e,t,0)}getModelColumnOfViewPosition(e,t){return t}getViewPositionOfModelPosition(e,t){return new H(e,t)}getViewLineNumberOfModelPosition(e,t){return e}normalizePosition(e,t,i){return t}getInjectedTextAt(e,t){return null}}cy.INSTANCE=new cy;class uy{constructor(){}isVisible(){return!1}setVisible(e){return e?cy.INSTANCE:this}getProjectionData(){return null}getViewLineCount(){return 0}getViewLineContent(e,t,i){throw new Error("Not supported")}getViewLineLength(e,t,i){throw new Error("Not supported")}getViewLineMinColumn(e,t,i){throw new Error("Not supported")}getViewLineMaxColumn(e,t,i){throw new Error("Not supported")}getViewLineData(e,t,i){throw new Error("Not supported")}getViewLinesData(e,t,i,n,o,r,a){throw new Error("Not supported")}getModelColumnOfViewPosition(e,t){throw new Error("Not supported")}getViewPositionOfModelPosition(e,t){throw new Error("Not supported")}getViewLineNumberOfModelPosition(e,t){throw new Error("Not supported")}normalizePosition(e,t,i){throw new Error("Not supported")}getInjectedTextAt(e,t){throw new Error("Not supported")}}uy.INSTANCE=new uy;const wI=[""];function x7(s){if(s>=wI.length)for(let e=1;e<=s;e++)wI[e]=pce(e);return wI[s]}function pce(s){return new Array(s+1).join(" ")}class mce{constructor(e,t,i,n,o,r,a,l,d,c){this._editorId=e,this.model=t,this._validModelVersionId=-1,this._domLineBreaksComputerFactory=i,this._monospaceLineBreaksComputerFactory=n,this.fontInfo=o,this.tabSize=r,this.wrappingStrategy=a,this.wrappingColumn=l,this.wrappingIndent=d,this.wordBreak=c,this._constructLines(!0,null)}dispose(){this.hiddenAreasDecorationIds=this.model.deltaDecorations(this.hiddenAreasDecorationIds,[])}createCoordinatesConverter(){return new vce(this)}_constructLines(e,t){this.modelLineProjections=[],e&&(this.hiddenAreasDecorationIds=this.model.deltaDecorations(this.hiddenAreasDecorationIds,[]));const i=this.model.getLinesContent(),n=this.model.getInjectedTextDecorations(this._editorId),o=i.length,r=this.createLineBreaksComputer(),a=new Qd(Ha.fromDecorations(n));for(let m=0;m<o;m++){const _=a.takeWhile(v=>v.lineNumber===m+1);r.addRequest(i[m],_,t?t[m]:null)}const l=r.finalize(),d=[],c=this.hiddenAreasDecorationIds.map(m=>this.model.getDecorationRange(m)).sort(D.compareRangesUsingStarts);let u=1,h=0,g=-1,f=g+1<c.length?h+1:o+2;for(let m=0;m<o;m++){const _=m+1;_===f&&(g++,u=c[g].startLineNumber,h=c[g].endLineNumber,f=g+1<c.length?h+1:o+2);const v=_>=u&&_<=h,b=CI(l[m],!v);d[m]=b.getViewLineCount(),this.modelLineProjections[m]=b}this._validModelVersionId=this.model.getVersionId(),this.projectedModelLineLineCounts=new sie(d)}getHiddenAreas(){return this.hiddenAreasDecorationIds.map(e=>this.model.getDecorationRange(e))}setHiddenAreas(e){const t=e.map(h=>this.model.validateRange(h)),i=_ce(t),n=this.hiddenAreasDecorationIds.map(h=>this.model.getDecorationRange(h)).sort(D.compareRangesUsingStarts);if(i.length===n.length){let h=!1;for(let g=0;g<i.length;g++)if(!i[g].equalsRange(n[g])){h=!0;break}if(!h)return!1}const o=i.map(h=>({range:h,options:tt.EMPTY}));this.hiddenAreasDecorationIds=this.model.deltaDecorations(this.hiddenAreasDecorationIds,o);const r=i;let a=1,l=0,d=-1,c=d+1<r.length?l+1:this.modelLineProjections.length+2,u=!1;for(let h=0;h<this.modelLineProjections.length;h++){const g=h+1;g===c&&(d++,a=r[d].startLineNumber,l=r[d].endLineNumber,c=d+1<r.length?l+1:this.modelLineProjections.length+2);let f=!1;if(g>=a&&g<=l?this.modelLineProjections[h].isVisible()&&(this.modelLineProjections[h]=this.modelLineProjections[h].setVisible(!1),f=!0):(u=!0,this.modelLineProjections[h].isVisible()||(this.modelLineProjections[h]=this.modelLineProjections[h].setVisible(!0),f=!0)),f){const m=this.modelLineProjections[h].getViewLineCount();this.projectedModelLineLineCounts.setValue(h,m)}}return u||this.setHiddenAreas([]),!0}modelPositionIsVisible(e,t){return e<1||e>this.modelLineProjections.length?!1:this.modelLineProjections[e-1].isVisible()}getModelLineViewLineCount(e){return e<1||e>this.modelLineProjections.length?1:this.modelLineProjections[e-1].getViewLineCount()}setTabSize(e){return this.tabSize===e?!1:(this.tabSize=e,this._constructLines(!1,null),!0)}setWrappingSettings(e,t,i,n,o){const r=this.fontInfo.equals(e),a=this.wrappingStrategy===t,l=this.wrappingColumn===i,d=this.wrappingIndent===n,c=this.wordBreak===o;if(r&&a&&l&&d&&c)return!1;const u=r&&a&&!l&&d&&c;this.fontInfo=e,this.wrappingStrategy=t,this.wrappingColumn=i,this.wrappingIndent=n,this.wordBreak=o;let h=null;if(u){h=[];for(let g=0,f=this.modelLineProjections.length;g<f;g++)h[g]=this.modelLineProjections[g].getProjectionData()}return this._constructLines(!1,h),!0}createLineBreaksComputer(){return(this.wrappingStrategy==="advanced"?this._domLineBreaksComputerFactory:this._monospaceLineBreaksComputerFactory).createLineBreaksComputer(this.fontInfo,this.tabSize,this.wrappingColumn,this.wrappingIndent,this.wordBreak)}onModelFlushed(){this._constructLines(!0,null)}onModelLinesDeleted(e,t,i){if(!e||e<=this._validModelVersionId)return null;const n=t===1?1:this.projectedModelLineLineCounts.getPrefixSum(t-1)+1,o=this.projectedModelLineLineCounts.getPrefixSum(i);return this.modelLineProjections.splice(t-1,i-t+1),this.projectedModelLineLineCounts.removeValues(t-1,i-t+1),new AT(n,o)}onModelLinesInserted(e,t,i,n){if(!e||e<=this._validModelVersionId)return null;const o=t>2&&!this.modelLineProjections[t-2].isVisible(),r=t===1?1:this.projectedModelLineLineCounts.getPrefixSum(t-1)+1;let a=0;const l=[],d=[];for(let c=0,u=n.length;c<u;c++){const h=CI(n[c],!o);l.push(h);const g=h.getViewLineCount();a+=g,d[c]=g}return this.modelLineProjections=this.modelLineProjections.slice(0,t-1).concat(l).concat(this.modelLineProjections.slice(t-1)),this.projectedModelLineLineCounts.insertValues(t-1,d),new PT(r,r+a-1)}onModelLineChanged(e,t,i){if(e!==null&&e<=this._validModelVersionId)return[!1,null,null,null];const n=t-1,o=this.modelLineProjections[n].getViewLineCount(),r=this.modelLineProjections[n].isVisible(),a=CI(i,r);this.modelLineProjections[n]=a;const l=this.modelLineProjections[n].getViewLineCount();let d=!1,c=0,u=-1,h=0,g=-1,f=0,m=-1;o>l?(c=this.projectedModelLineLineCounts.getPrefixSum(t-1)+1,u=c+l-1,f=u+1,m=f+(o-l)-1,d=!0):o<l?(c=this.projectedModelLineLineCounts.getPrefixSum(t-1)+1,u=c+o-1,h=u+1,g=h+(l-o)-1,d=!0):(c=this.projectedModelLineLineCounts.getPrefixSum(t-1)+1,u=c+l-1),this.projectedModelLineLineCounts.setValue(n,l);const _=c<=u?new uz(c,u-c+1):null,v=h<=g?new PT(h,g):null,b=f<=m?new AT(f,m):null;return[d,_,v,b]}acceptVersionId(e){this._validModelVersionId=e,this.modelLineProjections.length===1&&!this.modelLineProjections[0].isVisible()&&this.setHiddenAreas([])}getViewLineCount(){return this.projectedModelLineLineCounts.getTotalSum()}_toValidViewLineNumber(e){if(e<1)return 1;const t=this.getViewLineCount();return e>t?t:e|0}getActiveIndentGuide(e,t,i){e=this._toValidViewLineNumber(e),t=this._toValidViewLineNumber(t),i=this._toValidViewLineNumber(i);const n=this.convertViewPositionToModelPosition(e,this.getViewLineMinColumn(e)),o=this.convertViewPositionToModelPosition(t,this.getViewLineMinColumn(t)),r=this.convertViewPositionToModelPosition(i,this.getViewLineMinColumn(i)),a=this.model.guides.getActiveIndentGuide(n.lineNumber,o.lineNumber,r.lineNumber),l=this.convertModelPositionToViewPosition(a.startLineNumber,1),d=this.convertModelPositionToViewPosition(a.endLineNumber,this.model.getLineMaxColumn(a.endLineNumber));return{startLineNumber:l.lineNumber,endLineNumber:d.lineNumber,indent:a.indent}}getViewLineInfo(e){e=this._toValidViewLineNumber(e);const t=this.projectedModelLineLineCounts.getIndexOf(e-1),i=t.index,n=t.remainder;return new D7(i+1,n)}getMinColumnOfViewLine(e){return this.modelLineProjections[e.modelLineNumber-1].getViewLineMinColumn(this.model,e.modelLineNumber,e.modelLineWrappedLineIdx)}getMaxColumnOfViewLine(e){return this.modelLineProjections[e.modelLineNumber-1].getViewLineMaxColumn(this.model,e.modelLineNumber,e.modelLineWrappedLineIdx)}getModelStartPositionOfViewLine(e){const t=this.modelLineProjections[e.modelLineNumber-1],i=t.getViewLineMinColumn(this.model,e.modelLineNumber,e.modelLineWrappedLineIdx),n=t.getModelColumnOfViewPosition(e.modelLineWrappedLineIdx,i);return new H(e.modelLineNumber,n)}getModelEndPositionOfViewLine(e){const t=this.modelLineProjections[e.modelLineNumber-1],i=t.getViewLineMaxColumn(this.model,e.modelLineNumber,e.modelLineWrappedLineIdx),n=t.getModelColumnOfViewPosition(e.modelLineWrappedLineIdx,i);return new H(e.modelLineNumber,n)}getViewLineInfosGroupedByModelRanges(e,t){const i=this.getViewLineInfo(e),n=this.getViewLineInfo(t),o=new Array;let r=this.getModelStartPositionOfViewLine(i),a=new Array;for(let l=i.modelLineNumber;l<=n.modelLineNumber;l++){const d=this.modelLineProjections[l-1];if(d.isVisible()){const c=l===i.modelLineNumber?i.modelLineWrappedLineIdx:0,u=l===n.modelLineNumber?n.modelLineWrappedLineIdx+1:d.getViewLineCount();for(let h=c;h<u;h++)a.push(new D7(l,h))}if(!d.isVisible()&&r){const c=new H(l-1,this.model.getLineMaxColumn(l-1)+1),u=D.fromPositions(r,c);o.push(new k7(u,a)),a=[],r=null}else d.isVisible()&&!r&&(r=new H(l,1))}if(r){const l=D.fromPositions(r,this.getModelEndPositionOfViewLine(n));o.push(new k7(l,a))}return o}getViewLinesBracketGuides(e,t,i,n){const o=i?this.convertViewPositionToModelPosition(i.lineNumber,i.column):null,r=[];for(const a of this.getViewLineInfosGroupedByModelRanges(e,t)){const l=a.modelRange.startLineNumber,d=this.model.guides.getLinesBracketGuides(l,a.modelRange.endLineNumber,o,n);for(const c of a.viewLines){const h=d[c.modelLineNumber-l].map(g=>{if(g.forWrappedLinesAfterColumn!==-1&&this.modelLineProjections[c.modelLineNumber-1].getViewPositionOfModelPosition(0,g.forWrappedLinesAfterColumn).lineNumber>=c.modelLineWrappedLineIdx||g.forWrappedLinesBeforeOrAtColumn!==-1&&this.modelLineProjections[c.modelLineNumber-1].getViewPositionOfModelPosition(0,g.forWrappedLinesBeforeOrAtColumn).lineNumber<c.modelLineWrappedLineIdx)return;if(!g.horizontalLine)return g;let f=-1;if(g.column!==-1){const v=this.modelLineProjections[c.modelLineNumber-1].getViewPositionOfModelPosition(0,g.column);if(v.lineNumber===c.modelLineWrappedLineIdx)f=v.column;else if(v.lineNumber<c.modelLineWrappedLineIdx)f=this.getMinColumnOfViewLine(c);else if(v.lineNumber>c.modelLineWrappedLineIdx)return}const m=this.convertModelPositionToViewPosition(c.modelLineNumber,g.horizontalLine.endColumn),_=this.modelLineProjections[c.modelLineNumber-1].getViewPositionOfModelPosition(0,g.horizontalLine.endColumn);return _.lineNumber===c.modelLineWrappedLineIdx?new ng(g.visibleColumn,f,g.className,new Wv(g.horizontalLine.top,m.column),-1,-1):_.lineNumber<c.modelLineWrappedLineIdx||g.visibleColumn!==-1?void 0:new ng(g.visibleColumn,f,g.className,new Wv(g.horizontalLine.top,this.getMaxColumnOfViewLine(c)),-1,-1)});r.push(h.filter(g=>!!g))}}return r}getViewLinesIndentGuides(e,t){e=this._toValidViewLineNumber(e),t=this._toValidViewLineNumber(t);const i=this.convertViewPositionToModelPosition(e,this.getViewLineMinColumn(e)),n=this.convertViewPositionToModelPosition(t,this.getViewLineMaxColumn(t));let o=[];const r=[],a=[],l=i.lineNumber-1,d=n.lineNumber-1;let c=null;for(let f=l;f<=d;f++){const m=this.modelLineProjections[f];if(m.isVisible()){const _=m.getViewLineNumberOfModelPosition(0,f===l?i.column:1),v=m.getViewLineNumberOfModelPosition(0,this.model.getLineMaxColumn(f+1)),b=v-_+1;let C=0;b>1&&m.getViewLineMinColumn(this.model,f+1,v)===1&&(C=_===0?1:2),r.push(b),a.push(C),c===null&&(c=new H(f+1,0))}else c!==null&&(o=o.concat(this.model.guides.getLinesIndentGuides(c.lineNumber,f)),c=null)}c!==null&&(o=o.concat(this.model.guides.getLinesIndentGuides(c.lineNumber,n.lineNumber)),c=null);const u=t-e+1,h=new Array(u);let g=0;for(let f=0,m=o.length;f<m;f++){let _=o[f];const v=Math.min(u-g,r[f]),b=a[f];let C;b===2?C=0:b===1?C=1:C=v;for(let w=0;w<v;w++)w===C&&(_=0),h[g++]=_}return h}getViewLineContent(e){const t=this.getViewLineInfo(e);return this.modelLineProjections[t.modelLineNumber-1].getViewLineContent(this.model,t.modelLineNumber,t.modelLineWrappedLineIdx)}getViewLineLength(e){const t=this.getViewLineInfo(e);return this.modelLineProjections[t.modelLineNumber-1].getViewLineLength(this.model,t.modelLineNumber,t.modelLineWrappedLineIdx)}getViewLineMinColumn(e){const t=this.getViewLineInfo(e);return this.modelLineProjections[t.modelLineNumber-1].getViewLineMinColumn(this.model,t.modelLineNumber,t.modelLineWrappedLineIdx)}getViewLineMaxColumn(e){const t=this.getViewLineInfo(e);return this.modelLineProjections[t.modelLineNumber-1].getViewLineMaxColumn(this.model,t.modelLineNumber,t.modelLineWrappedLineIdx)}getViewLineData(e){const t=this.getViewLineInfo(e);return this.modelLineProjections[t.modelLineNumber-1].getViewLineData(this.model,t.modelLineNumber,t.modelLineWrappedLineIdx)}getViewLinesData(e,t,i){e=this._toValidViewLineNumber(e),t=this._toValidViewLineNumber(t);const n=this.projectedModelLineLineCounts.getIndexOf(e-1);let o=e;const r=n.index,a=n.remainder,l=[];for(let d=r,c=this.model.getLineCount();d<c;d++){const u=this.modelLineProjections[d];if(!u.isVisible())continue;const h=d===r?a:0;let g=u.getViewLineCount()-h,f=!1;if(o+g>t&&(f=!0,g=t-o+1),u.getViewLinesData(this.model,d+1,h,g,o-e,i,l),o+=g,f)break}return l}validateViewPosition(e,t,i){e=this._toValidViewLineNumber(e);const n=this.projectedModelLineLineCounts.getIndexOf(e-1),o=n.index,r=n.remainder,a=this.modelLineProjections[o],l=a.getViewLineMinColumn(this.model,o+1,r),d=a.getViewLineMaxColumn(this.model,o+1,r);t<l&&(t=l),t>d&&(t=d);const c=a.getModelColumnOfViewPosition(r,t);return this.model.validatePosition(new H(o+1,c)).equals(i)?new H(e,t):this.convertModelPositionToViewPosition(i.lineNumber,i.column)}validateViewRange(e,t){const i=this.validateViewPosition(e.startLineNumber,e.startColumn,t.getStartPosition()),n=this.validateViewPosition(e.endLineNumber,e.endColumn,t.getEndPosition());return new D(i.lineNumber,i.column,n.lineNumber,n.column)}convertViewPositionToModelPosition(e,t){const i=this.getViewLineInfo(e),n=this.modelLineProjections[i.modelLineNumber-1].getModelColumnOfViewPosition(i.modelLineWrappedLineIdx,t);return this.model.validatePosition(new H(i.modelLineNumber,n))}convertViewRangeToModelRange(e){const t=this.convertViewPositionToModelPosition(e.startLineNumber,e.startColumn),i=this.convertViewPositionToModelPosition(e.endLineNumber,e.endColumn);return new D(t.lineNumber,t.column,i.lineNumber,i.column)}convertModelPositionToViewPosition(e,t,i=2,n=!1,o=!1){const r=this.model.validatePosition(new H(e,t)),a=r.lineNumber,l=r.column;let d=a-1,c=!1;if(o)for(;d<this.modelLineProjections.length&&!this.modelLineProjections[d].isVisible();)d++,c=!0;else for(;d>0&&!this.modelLineProjections[d].isVisible();)d--,c=!0;if(d===0&&!this.modelLineProjections[d].isVisible())return new H(n?0:1,1);const u=1+this.projectedModelLineLineCounts.getPrefixSum(d);let h;return c?o?h=this.modelLineProjections[d].getViewPositionOfModelPosition(u,1,i):h=this.modelLineProjections[d].getViewPositionOfModelPosition(u,this.model.getLineMaxColumn(d+1),i):h=this.modelLineProjections[a-1].getViewPositionOfModelPosition(u,l,i),h}convertModelRangeToViewRange(e,t=0){if(e.isEmpty()){const i=this.convertModelPositionToViewPosition(e.startLineNumber,e.startColumn,t);return D.fromPositions(i)}else{const i=this.convertModelPositionToViewPosition(e.startLineNumber,e.startColumn,1),n=this.convertModelPositionToViewPosition(e.endLineNumber,e.endColumn,0);return new D(i.lineNumber,i.column,n.lineNumber,n.column)}}getViewLineNumberOfModelPosition(e,t){let i=e-1;if(this.modelLineProjections[i].isVisible()){const o=1+this.projectedModelLineLineCounts.getPrefixSum(i);return this.modelLineProjections[i].getViewLineNumberOfModelPosition(o,t)}for(;i>0&&!this.modelLineProjections[i].isVisible();)i--;if(i===0&&!this.modelLineProjections[i].isVisible())return 1;const n=1+this.projectedModelLineLineCounts.getPrefixSum(i);return this.modelLineProjections[i].getViewLineNumberOfModelPosition(n,this.model.getLineMaxColumn(i+1))}getDecorationsInRange(e,t,i,n,o){const r=this.convertViewPositionToModelPosition(e.startLineNumber,e.startColumn),a=this.convertViewPositionToModelPosition(e.endLineNumber,e.endColumn);if(a.lineNumber-r.lineNumber<=e.endLineNumber-e.startLineNumber)return this.model.getDecorationsInRange(new D(r.lineNumber,1,a.lineNumber,a.column),t,i,n,o);let l=[];const d=r.lineNumber-1,c=a.lineNumber-1;let u=null;for(let m=d;m<=c;m++)if(this.modelLineProjections[m].isVisible())u===null&&(u=new H(m+1,m===d?r.column:1));else if(u!==null){const v=this.model.getLineMaxColumn(m);l=l.concat(this.model.getDecorationsInRange(new D(u.lineNumber,u.column,m,v),t,i,n)),u=null}u!==null&&(l=l.concat(this.model.getDecorationsInRange(new D(u.lineNumber,u.column,a.lineNumber,a.column),t,i,n)),u=null),l.sort((m,_)=>{const v=D.compareRangesUsingStarts(m.range,_.range);return v===0?m.id<_.id?-1:m.id>_.id?1:0:v});const h=[];let g=0,f=null;for(const m of l){const _=m.id;f!==_&&(f=_,h[g++]=m)}return h}getInjectedTextAt(e){const t=this.getViewLineInfo(e.lineNumber);return this.modelLineProjections[t.modelLineNumber-1].getInjectedTextAt(t.modelLineWrappedLineIdx,e.column)}normalizePosition(e,t){const i=this.getViewLineInfo(e.lineNumber);return this.modelLineProjections[i.modelLineNumber-1].normalizePosition(i.modelLineWrappedLineIdx,e,t)}getLineIndentColumn(e){const t=this.getViewLineInfo(e);return t.modelLineWrappedLineIdx===0?this.model.getLineIndentColumn(t.modelLineNumber):0}}function _ce(s){if(s.length===0)return[];const e=s.slice();e.sort(D.compareRangesUsingStarts);const t=[];let i=e[0].startLineNumber,n=e[0].endLineNumber;for(let o=1,r=e.length;o<r;o++){const a=e[o];a.startLineNumber>n+1?(t.push(new D(i,1,n,1)),i=a.startLineNumber,n=a.endLineNumber):a.endLineNumber>n&&(n=a.endLineNumber)}return t.push(new D(i,1,n,1)),t}class D7{constructor(e,t){this.modelLineNumber=e,this.modelLineWrappedLineIdx=t}}class k7{constructor(e,t){this.modelRange=e,this.viewLines=t}}class vce{constructor(e){this._lines=e}convertViewPositionToModelPosition(e){return this._lines.convertViewPositionToModelPosition(e.lineNumber,e.column)}convertViewRangeToModelRange(e){return this._lines.convertViewRangeToModelRange(e)}validateViewPosition(e,t){return this._lines.validateViewPosition(e.lineNumber,e.column,t)}validateViewRange(e,t){return this._lines.validateViewRange(e,t)}convertModelPositionToViewPosition(e,t,i,n){return this._lines.convertModelPositionToViewPosition(e.lineNumber,e.column,t,i,n)}convertModelRangeToViewRange(e,t){return this._lines.convertModelRangeToViewRange(e,t)}modelPositionIsVisible(e){return this._lines.modelPositionIsVisible(e.lineNumber,e.column)}getModelLineViewLineCount(e){return this._lines.getModelLineViewLineCount(e)}getViewLineNumberOfModelPosition(e,t){return this._lines.getViewLineNumberOfModelPosition(e,t)}}class bce{constructor(e){this.model=e}dispose(){}createCoordinatesConverter(){return new Cce(this)}getHiddenAreas(){return[]}setHiddenAreas(e){return!1}setTabSize(e){return!1}setWrappingSettings(e,t,i,n){return!1}createLineBreaksComputer(){const e=[];return{addRequest:(t,i,n)=>{e.push(null)},finalize:()=>e}}onModelFlushed(){}onModelLinesDeleted(e,t,i){return new AT(t,i)}onModelLinesInserted(e,t,i,n){return new PT(t,i)}onModelLineChanged(e,t,i){return[!1,new uz(t,1),null,null]}acceptVersionId(e){}getViewLineCount(){return this.model.getLineCount()}getActiveIndentGuide(e,t,i){return{startLineNumber:e,endLineNumber:e,indent:0}}getViewLinesBracketGuides(e,t,i){return new Array(t-e+1).fill([])}getViewLinesIndentGuides(e,t){const i=t-e+1,n=new Array(i);for(let o=0;o<i;o++)n[o]=0;return n}getViewLineContent(e){return this.model.getLineContent(e)}getViewLineLength(e){return this.model.getLineLength(e)}getViewLineMinColumn(e){return this.model.getLineMinColumn(e)}getViewLineMaxColumn(e){return this.model.getLineMaxColumn(e)}getViewLineData(e){const t=this.model.tokenization.getLineTokens(e),i=t.getLineContent();return new fP(i,!1,1,i.length+1,0,t.inflate(),null)}getViewLinesData(e,t,i){const n=this.model.getLineCount();e=Math.min(Math.max(1,e),n),t=Math.min(Math.max(1,t),n);const o=[];for(let r=e;r<=t;r++){const a=r-e;o[a]=i[a]?this.getViewLineData(r):null}return o}getDecorationsInRange(e,t,i,n,o){return this.model.getDecorationsInRange(e,t,i,n,o)}normalizePosition(e,t){return this.model.normalizePosition(e,t)}getLineIndentColumn(e){return this.model.getLineIndentColumn(e)}getInjectedTextAt(e){return null}}class Cce{constructor(e){this._lines=e}_validPosition(e){return this._lines.model.validatePosition(e)}_validRange(e){return this._lines.model.validateRange(e)}convertViewPositionToModelPosition(e){return this._validPosition(e)}convertViewRangeToModelRange(e){return this._validRange(e)}validateViewPosition(e,t){return this._validPosition(t)}validateViewRange(e,t){return this._validRange(t)}convertModelPositionToViewPosition(e){return this._validPosition(e)}convertModelRangeToViewRange(e){return this._validRange(e)}modelPositionIsVisible(e){const t=this._lines.model.getLineCount();return!(e.lineNumber<1||e.lineNumber>t)}getModelLineViewLineCount(e){return 1}getViewLineNumberOfModelPosition(e,t){return e}}let wce=class extends j{constructor(e,t,i,n,o,r,a,l,d){if(super(),this.languageConfigurationService=a,this._themeService=l,this._attachedView=d,this.hiddenAreasModel=new yce,this.previousHiddenAreas=[],this._editorId=e,this._configuration=t,this.model=i,this._eventDispatcher=new Kde,this.onEvent=this._eventDispatcher.onEvent,this.cursorConfig=new Ef(this.model.getLanguageId(),this.model.getOptions(),this._configuration,this.languageConfigurationService),this._updateConfigurationViewLineCount=this._register(new jt(()=>this._updateConfigurationViewLineCountNow(),0)),this._hasFocus=!1,this._viewportStart=qP.create(this.model),this.model.isTooLargeForTokenization())this._lines=new bce(this.model);else{const c=this._configuration.options,u=c.get(50),h=c.get(137),g=c.get(144),f=c.get(136),m=c.get(128);this._lines=new mce(this._editorId,this.model,n,o,u,this.model.getOptions().tabSize,h,g.wrappingColumn,f,m)}this.coordinatesConverter=this._lines.createCoordinatesConverter(),this._cursor=this._register(new nce(i,this,this.coordinatesConverter,this.cursorConfig)),this.viewLayout=this._register(new hce(this._configuration,this.getLineCount(),r)),this._register(this.viewLayout.onDidScroll(c=>{c.scrollTopChanged&&this._handleVisibleLinesChanged(),c.scrollTopChanged&&this._viewportStart.invalidate(),this._eventDispatcher.emitSingleViewEvent(new Hde(c)),this._eventDispatcher.emitOutgoingEvent(new UP(c.oldScrollWidth,c.oldScrollLeft,c.oldScrollHeight,c.oldScrollTop,c.scrollWidth,c.scrollLeft,c.scrollHeight,c.scrollTop))})),this._register(this.viewLayout.onDidContentSizeChange(c=>{this._eventDispatcher.emitOutgoingEvent(c)})),this._decorations=new gce(this._editorId,this.model,this._configuration,this._lines,this.coordinatesConverter),this._registerModelEvents(),this._register(this._configuration.onDidChangeFast(c=>{try{const u=this._eventDispatcher.beginEmitViewEvents();this._onConfigurationChanged(u,c)}finally{this._eventDispatcher.endEmitViewEvents()}})),this._register(mC.getInstance().onDidChange(()=>{this._eventDispatcher.emitSingleViewEvent(new $de)})),this._register(this._themeService.onDidColorThemeChange(c=>{this._invalidateDecorationsColorCache(),this._eventDispatcher.emitSingleViewEvent(new zde(c))})),this._updateConfigurationViewLineCountNow()}dispose(){super.dispose(),this._decorations.dispose(),this._lines.dispose(),this._viewportStart.dispose(),this._eventDispatcher.dispose()}createLineBreaksComputer(){return this._lines.createLineBreaksComputer()}addViewEventHandler(e){this._eventDispatcher.addViewEventHandler(e)}removeViewEventHandler(e){this._eventDispatcher.removeViewEventHandler(e)}_updateConfigurationViewLineCountNow(){this._configuration.setViewLineCount(this._lines.getViewLineCount())}getModelVisibleRanges(){const e=this.viewLayout.getLinesViewportData(),t=new D(e.startLineNumber,this.getLineMinColumn(e.startLineNumber),e.endLineNumber,this.getLineMaxColumn(e.endLineNumber));return this._toModelVisibleRanges(t)}visibleLinesStabilized(){const e=this.getModelVisibleRanges();this._attachedView.setVisibleLines(e,!0)}_handleVisibleLinesChanged(){const e=this.getModelVisibleRanges();this._attachedView.setVisibleLines(e,!1)}setHasFocus(e){this._hasFocus=e,this._cursor.setHasFocus(e),this._eventDispatcher.emitSingleViewEvent(new Wde(e)),this._eventDispatcher.emitOutgoingEvent(new zP(!e,e))}onCompositionStart(){this._eventDispatcher.emitSingleViewEvent(new Pde)}onCompositionEnd(){this._eventDispatcher.emitSingleViewEvent(new Ode)}_captureStableViewport(){if(this._viewportStart.isValid&&this.viewLayout.getCurrentScrollTop()>0){const e=new H(this._viewportStart.viewLineNumber,this.getLineMinColumn(this._viewportStart.viewLineNumber)),t=this.coordinatesConverter.convertViewPositionToModelPosition(e);return new E7(t,this._viewportStart.startLineDelta)}return new E7(null,0)}_onConfigurationChanged(e,t){const i=this._captureStableViewport(),n=this._configuration.options,o=n.get(50),r=n.get(137),a=n.get(144),l=n.get(136),d=n.get(128);this._lines.setWrappingSettings(o,r,a.wrappingColumn,l,d)&&(e.emitViewEvent(new D1),e.emitViewEvent(new k1),e.emitViewEvent(new wh(null)),this._cursor.onLineMappingChanged(e),this._decorations.onLineMappingChanged(),this.viewLayout.onFlushed(this.getLineCount()),this._updateConfigurationViewLineCount.schedule()),t.hasChanged(90)&&(this._decorations.reset(),e.emitViewEvent(new wh(null))),t.hasChanged(97)&&(this._decorations.reset(),e.emitViewEvent(new wh(null))),e.emitViewEvent(new Fde(t)),this.viewLayout.onConfigurationChanged(t),i.recoverViewportStart(this.coordinatesConverter,this.viewLayout),Ef.shouldRecreate(t)&&(this.cursorConfig=new Ef(this.model.getLanguageId(),this.model.getOptions(),this._configuration,this.languageConfigurationService),this._cursor.updateConfiguration(this.cursorConfig))}_registerModelEvents(){this._register(this.model.onDidChangeContentOrInjectedText(e=>{try{const i=this._eventDispatcher.beginEmitViewEvents();let n=!1,o=!1;const r=e instanceof vg?e.rawContentChangedEvent.changes:e.changes,a=e instanceof vg?e.rawContentChangedEvent.versionId:null,l=this._lines.createLineBreaksComputer();for(const u of r)switch(u.changeType){case 4:{for(let h=0;h<u.detail.length;h++){const g=u.detail[h];let f=u.injectedTexts[h];f&&(f=f.filter(m=>!m.ownerId||m.ownerId===this._editorId)),l.addRequest(g,f,null)}break}case 2:{let h=null;u.injectedText&&(h=u.injectedText.filter(g=>!g.ownerId||g.ownerId===this._editorId)),l.addRequest(u.detail,h,null);break}}const d=l.finalize(),c=new Qd(d);for(const u of r)switch(u.changeType){case 1:{this._lines.onModelFlushed(),i.emitViewEvent(new D1),this._decorations.reset(),this.viewLayout.onFlushed(this.getLineCount()),n=!0;break}case 3:{const h=this._lines.onModelLinesDeleted(a,u.fromLineNumber,u.toLineNumber);h!==null&&(i.emitViewEvent(h),this.viewLayout.onLinesDeleted(h.fromLineNumber,h.toLineNumber)),n=!0;break}case 4:{const h=c.takeCount(u.detail.length),g=this._lines.onModelLinesInserted(a,u.fromLineNumber,u.toLineNumber,h);g!==null&&(i.emitViewEvent(g),this.viewLayout.onLinesInserted(g.fromLineNumber,g.toLineNumber)),n=!0;break}case 2:{const h=c.dequeue(),[g,f,m,_]=this._lines.onModelLineChanged(a,u.lineNumber,h);o=g,f&&i.emitViewEvent(f),m&&(i.emitViewEvent(m),this.viewLayout.onLinesInserted(m.fromLineNumber,m.toLineNumber)),_&&(i.emitViewEvent(_),this.viewLayout.onLinesDeleted(_.fromLineNumber,_.toLineNumber));break}case 5:break}a!==null&&this._lines.acceptVersionId(a),this.viewLayout.onHeightMaybeChanged(),!n&&o&&(i.emitViewEvent(new k1),i.emitViewEvent(new wh(null)),this._cursor.onLineMappingChanged(i),this._decorations.onLineMappingChanged())}finally{this._eventDispatcher.endEmitViewEvents()}const t=this._viewportStart.isValid;if(this._viewportStart.invalidate(),this._configuration.setModelLineCount(this.model.getLineCount()),this._updateConfigurationViewLineCountNow(),!this._hasFocus&&this.model.getAttachedEditorCount()>=2&&t){const i=this.model._getTrackedRange(this._viewportStart.modelTrackedRange);if(i){const n=this.coordinatesConverter.convertModelPositionToViewPosition(i.getStartPosition()),o=this.viewLayout.getVerticalOffsetForLineNumber(n.lineNumber);this.viewLayout.setScrollPosition({scrollTop:o+this._viewportStart.startLineDelta},1)}}try{const i=this._eventDispatcher.beginEmitViewEvents();e instanceof vg&&i.emitOutgoingEvent(new ece(e.contentChangedEvent)),this._cursor.onModelContentChanged(i,e)}finally{this._eventDispatcher.endEmitViewEvents()}this._handleVisibleLinesChanged()})),this._register(this.model.onDidChangeTokens(e=>{const t=[];for(let i=0,n=e.ranges.length;i<n;i++){const o=e.ranges[i],r=this.coordinatesConverter.convertModelPositionToViewPosition(new H(o.fromLineNumber,1)).lineNumber,a=this.coordinatesConverter.convertModelPositionToViewPosition(new H(o.toLineNumber,this.model.getLineMaxColumn(o.toLineNumber))).lineNumber;t[i]={fromLineNumber:r,toLineNumber:a}}this._eventDispatcher.emitSingleViewEvent(new Ude(t)),this._eventDispatcher.emitOutgoingEvent(new ice(e))})),this._register(this.model.onDidChangeLanguageConfiguration(e=>{this._eventDispatcher.emitSingleViewEvent(new Vde),this.cursorConfig=new Ef(this.model.getLanguageId(),this.model.getOptions(),this._configuration,this.languageConfigurationService),this._cursor.updateConfiguration(this.cursorConfig),this._eventDispatcher.emitOutgoingEvent(new Jde(e))})),this._register(this.model.onDidChangeLanguage(e=>{this.cursorConfig=new Ef(this.model.getLanguageId(),this.model.getOptions(),this._configuration,this.languageConfigurationService),this._cursor.updateConfiguration(this.cursorConfig),this._eventDispatcher.emitOutgoingEvent(new Qde(e))})),this._register(this.model.onDidChangeOptions(e=>{if(this._lines.setTabSize(this.model.getOptions().tabSize)){try{const t=this._eventDispatcher.beginEmitViewEvents();t.emitViewEvent(new D1),t.emitViewEvent(new k1),t.emitViewEvent(new wh(null)),this._cursor.onLineMappingChanged(t),this._decorations.onLineMappingChanged(),this.viewLayout.onFlushed(this.getLineCount())}finally{this._eventDispatcher.endEmitViewEvents()}this._updateConfigurationViewLineCount.schedule()}this.cursorConfig=new Ef(this.model.getLanguageId(),this.model.getOptions(),this._configuration,this.languageConfigurationService),this._cursor.updateConfiguration(this.cursorConfig),this._eventDispatcher.emitOutgoingEvent(new tce(e))})),this._register(this.model.onDidChangeDecorations(e=>{this._decorations.onModelDecorationsChanged(),this._eventDispatcher.emitSingleViewEvent(new wh(e)),this._eventDispatcher.emitOutgoingEvent(new Xde(e))}))}setHiddenAreas(e,t){var i;this.hiddenAreasModel.setHiddenAreas(t,e);const n=this.hiddenAreasModel.getMergedRanges();if(n===this.previousHiddenAreas)return;this.previousHiddenAreas=n;const o=this._captureStableViewport();let r=!1;try{const a=this._eventDispatcher.beginEmitViewEvents();r=this._lines.setHiddenAreas(n),r&&(a.emitViewEvent(new D1),a.emitViewEvent(new k1),a.emitViewEvent(new wh(null)),this._cursor.onLineMappingChanged(a),this._decorations.onLineMappingChanged(),this.viewLayout.onFlushed(this.getLineCount()),this.viewLayout.onHeightMaybeChanged());const l=(i=o.viewportStartModelPosition)===null||i===void 0?void 0:i.lineNumber;l&&n.some(c=>c.startLineNumber<=l&&l<=c.endLineNumber)||o.recoverViewportStart(this.coordinatesConverter,this.viewLayout)}finally{this._eventDispatcher.endEmitViewEvents()}this._updateConfigurationViewLineCount.schedule(),r&&this._eventDispatcher.emitOutgoingEvent(new Zde)}getVisibleRangesPlusViewportAboveBelow(){const e=this._configuration.options.get(143),t=this._configuration.options.get(66),i=Math.max(20,Math.round(e.height/t)),n=this.viewLayout.getLinesViewportData(),o=Math.max(1,n.completelyVisibleStartLineNumber-i),r=Math.min(this.getLineCount(),n.completelyVisibleEndLineNumber+i);return this._toModelVisibleRanges(new D(o,this.getLineMinColumn(o),r,this.getLineMaxColumn(r)))}getVisibleRanges(){const e=this.getCompletelyVisibleViewRange();return this._toModelVisibleRanges(e)}getHiddenAreas(){return this._lines.getHiddenAreas()}_toModelVisibleRanges(e){const t=this.coordinatesConverter.convertViewRangeToModelRange(e),i=this._lines.getHiddenAreas();if(i.length===0)return[t];const n=[];let o=0,r=t.startLineNumber,a=t.startColumn;const l=t.endLineNumber,d=t.endColumn;for(let c=0,u=i.length;c<u;c++){const h=i[c].startLineNumber,g=i[c].endLineNumber;g<r||h>l||(r<h&&(n[o++]=new D(r,a,h-1,this.model.getLineMaxColumn(h-1))),r=g+1,a=1)}return(r<l||r===l&&a<d)&&(n[o++]=new D(r,a,l,d)),n}getCompletelyVisibleViewRange(){const e=this.viewLayout.getLinesViewportData(),t=e.completelyVisibleStartLineNumber,i=e.completelyVisibleEndLineNumber;return new D(t,this.getLineMinColumn(t),i,this.getLineMaxColumn(i))}getCompletelyVisibleViewRangeAtScrollTop(e){const t=this.viewLayout.getLinesViewportDataAtScrollTop(e),i=t.completelyVisibleStartLineNumber,n=t.completelyVisibleEndLineNumber;return new D(i,this.getLineMinColumn(i),n,this.getLineMaxColumn(n))}saveState(){const e=this.viewLayout.saveState(),t=e.scrollTop,i=this.viewLayout.getLineNumberAtVerticalOffset(t),n=this.coordinatesConverter.convertViewPositionToModelPosition(new H(i,this.getLineMinColumn(i))),o=this.viewLayout.getVerticalOffsetForLineNumber(i)-t;return{scrollLeft:e.scrollLeft,firstPosition:n,firstPositionDeltaTop:o}}reduceRestoreState(e){if(typeof e.firstPosition>"u")return this._reduceRestoreStateCompatibility(e);const t=this.model.validatePosition(e.firstPosition),i=this.coordinatesConverter.convertModelPositionToViewPosition(t),n=this.viewLayout.getVerticalOffsetForLineNumber(i.lineNumber)-e.firstPositionDeltaTop;return{scrollLeft:e.scrollLeft,scrollTop:n}}_reduceRestoreStateCompatibility(e){return{scrollLeft:e.scrollLeft,scrollTop:e.scrollTopWithoutViewZones}}getTabSize(){return this.model.getOptions().tabSize}getLineCount(){return this._lines.getViewLineCount()}setViewport(e,t,i){this._viewportStart.update(this,e)}getActiveIndentGuide(e,t,i){return this._lines.getActiveIndentGuide(e,t,i)}getLinesIndentGuides(e,t){return this._lines.getViewLinesIndentGuides(e,t)}getBracketGuidesInRangeByLine(e,t,i,n){return this._lines.getViewLinesBracketGuides(e,t,i,n)}getLineContent(e){return this._lines.getViewLineContent(e)}getLineLength(e){return this._lines.getViewLineLength(e)}getLineMinColumn(e){return this._lines.getViewLineMinColumn(e)}getLineMaxColumn(e){return this._lines.getViewLineMaxColumn(e)}getLineFirstNonWhitespaceColumn(e){const t=ws(this.getLineContent(e));return t===-1?0:t+1}getLineLastNonWhitespaceColumn(e){const t=Pa(this.getLineContent(e));return t===-1?0:t+2}getMinimapDecorationsInRange(e){return this._decorations.getMinimapDecorationsInRange(e)}getDecorationsInViewport(e){return this._decorations.getDecorationsViewportData(e).decorations}getInjectedTextAt(e){return this._lines.getInjectedTextAt(e)}getViewportViewLineRenderingData(e,t){const n=this._decorations.getDecorationsViewportData(e).inlineDecorations[t-e.startLineNumber];return this._getViewLineRenderingData(t,n)}getViewLineRenderingData(e){const t=this._decorations.getInlineDecorationsOnLine(e);return this._getViewLineRenderingData(e,t)}_getViewLineRenderingData(e,t){const i=this.model.mightContainRTL(),n=this.model.mightContainNonBasicASCII(),o=this.getTabSize(),r=this._lines.getViewLineData(e);return r.inlineDecorations&&(t=[...t,...r.inlineDecorations.map(a=>a.toInlineDecoration(e))]),new sr(r.minColumn,r.maxColumn,r.content,r.continuesWithWrappedLine,i,n,r.tokens,t,o,r.startVisibleColumn)}getViewLineData(e){return this._lines.getViewLineData(e)}getMinimapLinesRenderingData(e,t,i){const n=this._lines.getViewLinesData(e,t,i);return new yne(this.getTabSize(),n)}getAllOverviewRulerDecorations(e){const t=this.model.getOverviewRulerDecorations(this._editorId,LS(this._configuration.options)),i=new Sce;for(const n of t){const o=n.options,r=o.overviewRuler;if(!r)continue;const a=r.position;if(a===0)continue;const l=r.getColor(e.value),d=this.coordinatesConverter.getViewLineNumberOfModelPosition(n.range.startLineNumber,n.range.startColumn),c=this.coordinatesConverter.getViewLineNumberOfModelPosition(n.range.endLineNumber,n.range.endColumn);i.accept(l,o.zIndex,d,c,a)}return i.asArray}_invalidateDecorationsColorCache(){const e=this.model.getOverviewRulerDecorations();for(const t of e){const i=t.options.overviewRuler;i==null||i.invalidateCachedColor();const n=t.options.minimap;n==null||n.invalidateCachedColor()}}getValueInRange(e,t){const i=this.coordinatesConverter.convertViewRangeToModelRange(e);return this.model.getValueInRange(i,t)}getValueLengthInRange(e,t){const i=this.coordinatesConverter.convertViewRangeToModelRange(e);return this.model.getValueLengthInRange(i,t)}modifyPosition(e,t){const i=this.coordinatesConverter.convertViewPositionToModelPosition(e);return this.model.modifyPosition(i,t)}deduceModelPositionRelativeToViewPosition(e,t,i){const n=this.coordinatesConverter.convertViewPositionToModelPosition(e);this.model.getEOL().length===2&&(t<0?t-=i:t+=i);const r=this.model.getOffsetAt(n)+t;return this.model.getPositionAt(r)}getPlainTextToCopy(e,t,i){const n=i?`\r
`:this.model.getEOL();e=e.slice(0),e.sort(D.compareRangesUsingStarts);let o=!1,r=!1;for(const l of e)l.isEmpty()?o=!0:r=!0;if(!r){if(!t)return"";const l=e.map(c=>c.startLineNumber);let d="";for(let c=0;c<l.length;c++)c>0&&l[c-1]===l[c]||(d+=this.model.getLineContent(l[c])+n);return d}if(o&&t){const l=[];let d=0;for(const c of e){const u=c.startLineNumber;c.isEmpty()?u!==d&&l.push(this.model.getLineContent(u)):l.push(this.model.getValueInRange(c,i?2:0)),d=u}return l.length===1?l[0]:l}const a=[];for(const l of e)l.isEmpty()||a.push(this.model.getValueInRange(l,i?2:0));return a.length===1?a[0]:a}getRichTextToCopy(e,t){const i=this.model.getLanguageId();if(i===er||e.length!==1)return null;let n=e[0];if(n.isEmpty()){if(!t)return null;const c=n.startLineNumber;n=new D(c,this.model.getLineMinColumn(c),c,this.model.getLineMaxColumn(c))}const o=this._configuration.options.get(50),r=this._getColorMap(),l=/[:;\\\/<>]/.test(o.fontFamily)||o.fontFamily===vo.fontFamily;let d;return l?d=vo.fontFamily:(d=o.fontFamily,d=d.replace(/"/g,"'"),/[,']/.test(d)||/[+ ]/.test(d)&&(d=`'${d}'`),d=`${d}, ${vo.fontFamily}`),{mode:i,html:`<div style="color: ${r[1]};background-color: ${r[2]};font-family: ${d};font-weight: ${o.fontWeight};font-size: ${o.fontSize}px;line-height: ${o.lineHeight}px;white-space: pre;">`+this._getHTMLToCopy(n,r)+"</div>"}}_getHTMLToCopy(e,t){const i=e.startLineNumber,n=e.startColumn,o=e.endLineNumber,r=e.endColumn,a=this.getTabSize();let l="";for(let d=i;d<=o;d++){const c=this.model.tokenization.getLineTokens(d),u=c.getLineContent(),h=d===i?n-1:0,g=d===o?r-1:u.length;u===""?l+="<br>":l+=ace(u,c.inflate(),t,h,g,a,es)}return l}_getColorMap(){const e=xi.getColorMap(),t=["#000000"];if(e)for(let i=1,n=e.length;i<n;i++)t[i]=G.Format.CSS.formatHex(e[i]);return t}getPrimaryCursorState(){return this._cursor.getPrimaryCursorState()}getLastAddedCursorIndex(){return this._cursor.getLastAddedCursorIndex()}getCursorStates(){return this._cursor.getCursorStates()}setCursorStates(e,t,i){return this._withViewEventsCollector(n=>this._cursor.setStates(n,e,t,i))}getCursorColumnSelectData(){return this._cursor.getCursorColumnSelectData()}getCursorAutoClosedCharacters(){return this._cursor.getAutoClosedCharacters()}setCursorColumnSelectData(e){this._cursor.setCursorColumnSelectData(e)}getPrevEditOperationType(){return this._cursor.getPrevEditOperationType()}setPrevEditOperationType(e){this._cursor.setPrevEditOperationType(e)}getSelection(){return this._cursor.getSelection()}getSelections(){return this._cursor.getSelections()}getPosition(){return this._cursor.getPrimaryCursorState().modelState.position}setSelections(e,t,i=0){this._withViewEventsCollector(n=>this._cursor.setSelections(n,e,t,i))}saveCursorState(){return this._cursor.saveState()}restoreCursorState(e){this._withViewEventsCollector(t=>this._cursor.restoreState(t,e))}_executeCursorEdit(e){if(this._cursor.context.cursorConfig.readOnly){this._eventDispatcher.emitOutgoingEvent(new Yde);return}this._withViewEventsCollector(e)}executeEdits(e,t,i){this._executeCursorEdit(n=>this._cursor.executeEdits(n,e,t,i))}startComposition(){this._executeCursorEdit(e=>this._cursor.startComposition(e))}endComposition(e){this._executeCursorEdit(t=>this._cursor.endComposition(t,e))}type(e,t){this._executeCursorEdit(i=>this._cursor.type(i,e,t))}compositionType(e,t,i,n,o){this._executeCursorEdit(r=>this._cursor.compositionType(r,e,t,i,n,o))}paste(e,t,i,n){this._executeCursorEdit(o=>this._cursor.paste(o,e,t,i,n))}cut(e){this._executeCursorEdit(t=>this._cursor.cut(t,e))}executeCommand(e,t){this._executeCursorEdit(i=>this._cursor.executeCommand(i,e,t))}executeCommands(e,t){this._executeCursorEdit(i=>this._cursor.executeCommands(i,e,t))}revealPrimaryCursor(e,t,i=!1){this._withViewEventsCollector(n=>this._cursor.revealPrimary(n,e,i,0,t,0))}revealTopMostCursor(e){const t=this._cursor.getTopMostViewPosition(),i=new D(t.lineNumber,t.column,t.lineNumber,t.column);this._withViewEventsCollector(n=>n.emitViewEvent(new Uw(e,!1,i,null,0,!0,0)))}revealBottomMostCursor(e){const t=this._cursor.getBottomMostViewPosition(),i=new D(t.lineNumber,t.column,t.lineNumber,t.column);this._withViewEventsCollector(n=>n.emitViewEvent(new Uw(e,!1,i,null,0,!0,0)))}revealRange(e,t,i,n,o){this._withViewEventsCollector(r=>r.emitViewEvent(new Uw(e,!1,i,null,n,t,o)))}changeWhitespace(e){this.viewLayout.changeWhitespace(e)&&(this._eventDispatcher.emitSingleViewEvent(new jde),this._eventDispatcher.emitOutgoingEvent(new Gde))}_withViewEventsCollector(e){try{const t=this._eventDispatcher.beginEmitViewEvents();return e(t)}finally{this._eventDispatcher.endEmitViewEvents()}}normalizePosition(e,t){return this._lines.normalizePosition(e,t)}getLineIndentColumn(e){return this._lines.getLineIndentColumn(e)}};class qP{static create(e){const t=e._setTrackedRange(null,new D(1,1,1,1),1);return new qP(e,1,!1,t,0)}get viewLineNumber(){return this._viewLineNumber}get isValid(){return this._isValid}get modelTrackedRange(){return this._modelTrackedRange}get startLineDelta(){return this._startLineDelta}constructor(e,t,i,n,o){this._model=e,this._viewLineNumber=t,this._isValid=i,this._modelTrackedRange=n,this._startLineDelta=o}dispose(){this._model._setTrackedRange(this._modelTrackedRange,null,1)}update(e,t){const i=e.coordinatesConverter.convertViewPositionToModelPosition(new H(t,e.getLineMinColumn(t))),n=e.model._setTrackedRange(this._modelTrackedRange,new D(i.lineNumber,i.column,i.lineNumber,i.column),1),o=e.viewLayout.getVerticalOffsetForLineNumber(t),r=e.viewLayout.getCurrentScrollTop();this._viewLineNumber=t,this._isValid=!0,this._modelTrackedRange=n,this._startLineDelta=r-o}invalidate(){this._isValid=!1}}class Sce{constructor(){this._asMap=Object.create(null),this.asArray=[]}accept(e,t,i,n,o){const r=this._asMap[e];if(r){const a=r.data,l=a[a.length-3],d=a[a.length-1];if(l===o&&d+1>=i){n>d&&(a[a.length-1]=n);return}a.push(o,i,n)}else{const a=new F0(e,t,[o,i,n]);this._asMap[e]=a,this.asArray.push(a)}}}class yce{constructor(){this.hiddenAreas=new Map,this.shouldRecompute=!1,this.ranges=[]}setHiddenAreas(e,t){const i=this.hiddenAreas.get(e);i&&I7(i,t)||(this.hiddenAreas.set(e,t),this.shouldRecompute=!0)}getMergedRanges(){if(!this.shouldRecompute)return this.ranges;this.shouldRecompute=!1;const e=Array.from(this.hiddenAreas.values()).reduce((t,i)=>Lce(t,i),[]);return I7(this.ranges,e)?this.ranges:(this.ranges=e,this.ranges)}}function Lce(s,e){const t=[];let i=0,n=0;for(;i<s.length&&n<e.length;){const o=s[i],r=e[n];if(o.endLineNumber<r.startLineNumber-1)t.push(s[i++]);else if(r.endLineNumber<o.startLineNumber-1)t.push(e[n++]);else{const a=Math.min(o.startLineNumber,r.startLineNumber),l=Math.max(o.endLineNumber,r.endLineNumber);t.push(new D(a,1,l,1)),i++,n++}}for(;i<s.length;)t.push(s[i++]);for(;n<e.length;)t.push(e[n++]);return t}function I7(s,e){if(s.length!==e.length)return!1;for(let t=0;t<s.length;t++)if(!s[t].equalsRange(e[t]))return!1;return!0}class E7{constructor(e,t){this.viewportStartModelPosition=e,this.startLineDelta=t}recoverViewportStart(e,t){if(!this.viewportStartModelPosition)return;const i=e.convertModelPositionToViewPosition(this.viewportStartModelPosition),n=t.getVerticalOffsetForLineNumber(i.lineNumber);t.setScrollPosition({scrollTop:n+this.startLineDelta},1)}}class _C{constructor(...e){this._entries=new Map;for(const[t,i]of e)this.set(t,i)}set(e,t){const i=this._entries.get(e);return this._entries.set(e,t),i}get(e){return this._entries.get(e)}}var ib;(function(s){s[s.Ignore=0]="Ignore",s[s.Info=1]="Info",s[s.Warning=2]="Warning",s[s.Error=3]="Error"})(ib||(ib={}));(function(s){const e="error",t="warning",i="warn",n="info",o="ignore";function r(l){return l?np(e,l)?s.Error:np(t,l)||np(i,l)?s.Warning:np(n,l)?s.Info:s.Ignore:s.Ignore}s.fromValue=r;function a(l){switch(l){case s.Error:return e;case s.Warning:return t;case s.Info:return n;default:return o}}s.toString=a})(ib||(ib={}));const Wi=ib;var Rx=Wi;const Qi=ut("notificationService");class xce{}class Gv{constructor(e,t,i,n,o){this.injectionOffsets=e,this.injectionOptions=t,this.breakOffsets=i,this.breakOffsetsVisibleColumn=n,this.wrappedTextIndentLength=o}getOutputLineCount(){return this.breakOffsets.length}getMinOutputOffset(e){return e>0?this.wrappedTextIndentLength:0}getLineLength(e){const t=e>0?this.breakOffsets[e-1]:0;let n=this.breakOffsets[e]-t;return e>0&&(n+=this.wrappedTextIndentLength),n}getMaxOutputOffset(e){return this.getLineLength(e)}translateToInputOffset(e,t){e>0&&(t=Math.max(0,t-this.wrappedTextIndentLength));let n=e===0?t:this.breakOffsets[e-1]+t;if(this.injectionOffsets!==null)for(let o=0;o<this.injectionOffsets.length&&n>this.injectionOffsets[o];o++)n<this.injectionOffsets[o]+this.injectionOptions[o].content.length?n=this.injectionOffsets[o]:n-=this.injectionOptions[o].content.length;return n}translateToOutputPosition(e,t=2){let i=e;if(this.injectionOffsets!==null)for(let n=0;n<this.injectionOffsets.length&&!(e<this.injectionOffsets[n]||t!==1&&e===this.injectionOffsets[n]);n++)i+=this.injectionOptions[n].content.length;return this.offsetInInputWithInjectionsToOutputPosition(i,t)}offsetInInputWithInjectionsToOutputPosition(e,t=2){let i=0,n=this.breakOffsets.length-1,o=0,r=0;for(;i<=n;){o=i+(n-i)/2|0;const l=this.breakOffsets[o];if(r=o>0?this.breakOffsets[o-1]:0,t===0)if(e<=r)n=o-1;else if(e>l)i=o+1;else break;else if(e<r)n=o-1;else if(e>=l)i=o+1;else break}let a=e-r;return o>0&&(a+=this.wrappedTextIndentLength),new I1(o,a)}normalizeOutputPosition(e,t,i){if(this.injectionOffsets!==null){const n=this.outputPositionToOffsetInInputWithInjections(e,t),o=this.normalizeOffsetInInputWithInjectionsAroundInjections(n,i);if(o!==n)return this.offsetInInputWithInjectionsToOutputPosition(o,i)}if(i===0){if(e>0&&t===this.getMinOutputOffset(e))return new I1(e-1,this.getMaxOutputOffset(e-1))}else if(i===1){const n=this.getOutputLineCount()-1;if(e<n&&t===this.getMaxOutputOffset(e))return new I1(e+1,this.getMinOutputOffset(e+1))}return new I1(e,t)}outputPositionToOffsetInInputWithInjections(e,t){return e>0&&(t=Math.max(0,t-this.wrappedTextIndentLength)),(e>0?this.breakOffsets[e-1]:0)+t}normalizeOffsetInInputWithInjectionsAroundInjections(e,t){const i=this.getInjectedTextAtOffset(e);if(!i)return e;if(t===2){if(e===i.offsetInInputWithInjections+i.length&&N7(this.injectionOptions[i.injectedTextIndex].cursorStops))return i.offsetInInputWithInjections+i.length;{let n=i.offsetInInputWithInjections;if(T7(this.injectionOptions[i.injectedTextIndex].cursorStops))return n;let o=i.injectedTextIndex-1;for(;o>=0&&this.injectionOffsets[o]===this.injectionOffsets[i.injectedTextIndex]&&!(N7(this.injectionOptions[o].cursorStops)||(n-=this.injectionOptions[o].content.length,T7(this.injectionOptions[o].cursorStops)));)o--;return n}}else if(t===1||t===4){let n=i.offsetInInputWithInjections+i.length,o=i.injectedTextIndex;for(;o+1<this.injectionOffsets.length&&this.injectionOffsets[o+1]===this.injectionOffsets[o];)n+=this.injectionOptions[o+1].content.length,o++;return n}else if(t===0||t===3){let n=i.offsetInInputWithInjections,o=i.injectedTextIndex;for(;o-1>=0&&this.injectionOffsets[o-1]===this.injectionOffsets[o];)n-=this.injectionOptions[o-1].content.length,o--;return n}nx()}getInjectedText(e,t){const i=this.outputPositionToOffsetInInputWithInjections(e,t),n=this.getInjectedTextAtOffset(i);return n?{options:this.injectionOptions[n.injectedTextIndex]}:null}getInjectedTextAtOffset(e){const t=this.injectionOffsets,i=this.injectionOptions;if(t!==null){let n=0;for(let o=0;o<t.length;o++){const r=i[o].content.length,a=t[o]+n,l=t[o]+n+r;if(a>e)break;if(e<=l)return{injectedTextIndex:o,offsetInInputWithInjections:a,length:r};n+=r}}}}function N7(s){return s==null?!0:s===Na.Right||s===Na.Both}function T7(s){return s==null?!0:s===Na.Left||s===Na.Both}class I1{constructor(e,t){this.outputLineIndex=e,this.outputOffset=t}toString(){return`${this.outputLineIndex}:${this.outputOffset}`}toPosition(e){return new H(e+this.outputLineIndex,this.outputOffset+1)}}class GP{static create(e){return new GP(e.get(132),e.get(131))}constructor(e,t){this.classifier=new Dce(e,t)}createLineBreaksComputer(e,t,i,n,o){const r=[],a=[],l=[];return{addRequest:(d,c,u)=>{r.push(d),a.push(c),l.push(u)},finalize:()=>{const d=e.typicalFullwidthCharacterWidth/e.typicalHalfwidthCharacterWidth,c=[];for(let u=0,h=r.length;u<h;u++){const g=a[u],f=l[u];f&&!f.injectionOptions&&!g?c[u]=kce(this.classifier,f,r[u],t,i,d,n,o):c[u]=Ice(this.classifier,r[u],g,t,i,d,n,o)}return FT.length=0,BT.length=0,c}}}}class Dce extends o_{constructor(e,t){super(0);for(let i=0;i<e.length;i++)this.set(e.charCodeAt(i),1);for(let i=0;i<t.length;i++)this.set(t.charCodeAt(i),2)}get(e){return e>=0&&e<256?this._asciiMap[e]:e>=12352&&e<=12543||e>=13312&&e<=19903||e>=19968&&e<=40959?3:this._map.get(e)||this._defaultValue}}let FT=[],BT=[];function kce(s,e,t,i,n,o,r,a){if(n===-1)return null;const l=t.length;if(l<=1)return null;const d=a==="keepAll",c=e.breakOffsets,u=e.breakOffsetsVisibleColumn,h=fz(t,i,n,o,r),g=n-h,f=FT,m=BT;let _=0,v=0,b=0,C=n;const w=c.length;let S=0;if(S>=0){let x=Math.abs(u[S]-C);for(;S+1<w;){const L=Math.abs(u[S+1]-C);if(L>=x)break;x=L,S++}}for(;S<w;){let x=S<0?0:c[S],L=S<0?0:u[S];v>x&&(x=v,L=b);let k=0,I=0,P=0,$=0;if(L<=C){let z=L,K=x===0?0:t.charCodeAt(x-1),Q=x===0?0:s.get(K),ne=!0;for(let fe=x;fe<l;fe++){const ve=fe,ye=t.charCodeAt(fe);let Be,Ve;if(_n(ye)?(fe++,Be=0,Ve=2):(Be=s.get(ye),Ve=Zv(ye,z,i,o)),ve>v&&WT(K,Q,ye,Be,d)&&(k=ve,I=z),z+=Ve,z>C){ve>v?(P=ve,$=z-Ve):(P=fe+1,$=z),z-I>g&&(k=0),ne=!1;break}K=ye,Q=Be}if(ne){_>0&&(f[_]=c[c.length-1],m[_]=u[c.length-1],_++);break}}if(k===0){let z=L,K=t.charCodeAt(x),Q=s.get(K),ne=!1;for(let fe=x-1;fe>=v;fe--){const ve=fe+1,ye=t.charCodeAt(fe);if(ye===9){ne=!0;break}let Be,Ve;if(kg(ye)?(fe--,Be=0,Ve=2):(Be=s.get(ye),Ve=ku(ye)?o:1),z<=C){if(P===0&&(P=ve,$=z),z<=C-g)break;if(WT(ye,Be,K,Q,d)){k=ve,I=z;break}}z-=Ve,K=ye,Q=Be}if(k!==0){const fe=g-($-I);if(fe<=i){const ve=t.charCodeAt(P);let ye;_n(ve)?ye=2:ye=Zv(ve,$,i,o),fe-ye<0&&(k=0)}}if(ne){S--;continue}}if(k===0&&(k=P,I=$),k<=v){const z=t.charCodeAt(v);_n(z)?(k=v+2,I=b+2):(k=v+1,I=b+Zv(z,b,i,o))}for(v=k,f[_]=k,b=I,m[_]=I,_++,C=I+g;S<0||S<w&&u[S]<I;)S++;let A=Math.abs(u[S]-C);for(;S+1<w;){const z=Math.abs(u[S+1]-C);if(z>=A)break;A=z,S++}}return _===0?null:(f.length=_,m.length=_,FT=e.breakOffsets,BT=e.breakOffsetsVisibleColumn,e.breakOffsets=f,e.breakOffsetsVisibleColumn=m,e.wrappedTextIndentLength=h,e)}function Ice(s,e,t,i,n,o,r,a){const l=Ha.applyInjectedText(e,t);let d,c;if(t&&t.length>0?(d=t.map(I=>I.options),c=t.map(I=>I.column-1)):(d=null,c=null),n===-1)return d?new Gv(c,d,[l.length],[],0):null;const u=l.length;if(u<=1)return d?new Gv(c,d,[l.length],[],0):null;const h=a==="keepAll",g=fz(l,i,n,o,r),f=n-g,m=[],_=[];let v=0,b=0,C=0,w=n,S=l.charCodeAt(0),x=s.get(S),L=Zv(S,0,i,o),k=1;_n(S)&&(L+=1,S=l.charCodeAt(1),x=s.get(S),k++);for(let I=k;I<u;I++){const P=I,$=l.charCodeAt(I);let A,z;_n($)?(I++,A=0,z=2):(A=s.get($),z=Zv($,L,i,o)),WT(S,x,$,A,h)&&(b=P,C=L),L+=z,L>w&&((b===0||L-C>f)&&(b=P,C=L-z),m[v]=b,_[v]=C,v++,w=C+f,b=0),S=$,x=A}return v===0&&(!t||t.length===0)?null:(m[v]=u,_[v]=L,new Gv(c,d,m,_,g))}function Zv(s,e,t,i){return s===9?t-e%t:ku(s)||s<32?i:1}function M7(s,e){return e-s%e}function WT(s,e,t,i,n){return t!==32&&(e===2&&i!==2||e!==1&&i===1||!n&&e===3&&i!==2||!n&&i===3&&e!==1)}function fz(s,e,t,i,n){let o=0;if(n!==0){const r=ws(s);if(r!==-1){for(let l=0;l<r;l++){const d=s.charCodeAt(l)===9?M7(o,e):1;o+=d}const a=n===3?2:n===2?1:0;for(let l=0;l<a;l++){const d=M7(o,e);o+=d}o+i>t&&(o=0)}}return o}const SI=oc("domLineBreaksComputer",{createHTML:s=>s});class ZP{static create(e){return new ZP(new WeakRef(e))}constructor(e){this.targetWindow=e}createLineBreaksComputer(e,t,i,n,o){const r=[],a=[];return{addRequest:(l,d,c)=>{r.push(l),a.push(d)},finalize:()=>Ece(Vc(this.targetWindow.deref()),r,e,t,i,n,o,a)}}}function Ece(s,e,t,i,n,o,r,a){var l;function d(P){const $=a[P];if($){const A=Ha.applyInjectedText(e[P],$),z=$.map(Q=>Q.options),K=$.map(Q=>Q.column-1);return new Gv(K,z,[A.length],[],0)}else return null}if(n===-1){const P=[];for(let $=0,A=e.length;$<A;$++)P[$]=d($);return P}const c=Math.round(n*t.typicalHalfwidthCharacterWidth),h=Math.round(i*(o===3?2:o===2?1:0)),g=Math.ceil(t.spaceWidth*h),f=document.createElement("div");Xn(f,t);const m=new s_(1e4),_=[],v=[],b=[],C=[],w=[];for(let P=0;P<e.length;P++){const $=Ha.applyInjectedText(e[P],a[P]);let A=0,z=0,K=c;if(o!==0)if(A=ws($),A===-1)A=0;else{for(let ve=0;ve<A;ve++){const ye=$.charCodeAt(ve)===9?i-z%i:1;z+=ye}const fe=Math.ceil(t.spaceWidth*z);fe+t.typicalFullwidthCharacterWidth>c?(A=0,z=0):K=c-fe}const Q=$.substr(A),ne=Nce(Q,z,i,K,m,g);_[P]=A,v[P]=z,b[P]=Q,C[P]=ne[0],w[P]=ne[1]}const S=m.build(),x=(l=SI==null?void 0:SI.createHTML(S))!==null&&l!==void 0?l:S;f.innerHTML=x,f.style.position="absolute",f.style.top="10000",r==="keepAll"?(f.style.wordBreak="keep-all",f.style.overflowWrap="anywhere"):(f.style.wordBreak="inherit",f.style.overflowWrap="break-word"),s.document.body.appendChild(f);const L=document.createRange(),k=Array.prototype.slice.call(f.children,0),I=[];for(let P=0;P<e.length;P++){const $=k[P],A=Tce(L,$,b[P],C[P]);if(A===null){I[P]=d(P);continue}const z=_[P],K=v[P]+h,Q=w[P],ne=[];for(let Be=0,Ve=A.length;Be<Ve;Be++)ne[Be]=Q[A[Be]];if(z!==0)for(let Be=0,Ve=A.length;Be<Ve;Be++)A[Be]+=z;let fe,ve;const ye=a[P];ye?(fe=ye.map(Be=>Be.options),ve=ye.map(Be=>Be.column-1)):(fe=null,ve=null),I[P]=new Gv(ve,fe,A,ne,K)}return s.document.body.removeChild(f),I}function Nce(s,e,t,i,n,o){if(o!==0){const h=String(o);n.appendString('<div style="text-indent: -'),n.appendString(h),n.appendString("px; padding-left: "),n.appendString(h),n.appendString("px; box-sizing: border-box; width:")}else n.appendString('<div style="width:');n.appendString(String(i)),n.appendString('px;">');const r=s.length;let a=e,l=0;const d=[],c=[];let u=0<r?s.charCodeAt(0):0;n.appendString("<span>");for(let h=0;h<r;h++){h!==0&&h%16384===0&&n.appendString("</span><span>"),d[h]=l,c[h]=a;const g=u;u=h+1<r?s.charCodeAt(h+1):0;let f=1,m=1;switch(g){case 9:f=t-a%t,m=f;for(let _=1;_<=f;_++)_<f?n.appendCharCode(160):n.appendASCIICharCode(32);break;case 32:u===32?n.appendCharCode(160):n.appendASCIICharCode(32);break;case 60:n.appendString("&lt;");break;case 62:n.appendString("&gt;");break;case 38:n.appendString("&amp;");break;case 0:n.appendString("&#00;");break;case 65279:case 8232:case 8233:case 133:n.appendCharCode(65533);break;default:ku(g)&&m++,g<32?n.appendCharCode(9216+g):n.appendCharCode(g)}l+=f,a+=m}return n.appendString("</span>"),d[s.length]=l,c[s.length]=a,n.appendString("</div>"),[d,c]}function Tce(s,e,t,i){if(t.length<=1)return null;const n=Array.prototype.slice.call(e.children,0),o=[];try{VT(s,n,i,0,null,t.length-1,null,o)}catch(r){return console.log(r),null}return o.length===0?null:(o.push(t.length),o)}function VT(s,e,t,i,n,o,r,a){if(i===o||(n=n||yI(s,e,t[i],t[i+1]),r=r||yI(s,e,t[o],t[o+1]),Math.abs(n[0].top-r[0].top)<=.1))return;if(i+1===o){a.push(o);return}const l=i+(o-i)/2|0,d=yI(s,e,t[l],t[l+1]);VT(s,e,t,i,n,l,d,a),VT(s,e,t,l,d,o,r,a)}function yI(s,e,t,i){return s.setStart(e[t/16384|0].firstChild,t%16384),s.setEnd(e[i/16384|0].firstChild,i%16384),s.getClientRects()}class Mce extends j{constructor(){super(),this._editor=null,this._instantiationService=null,this._instances=this._register(new NA),this._pending=new Map,this._finishedInstantiation=[],this._finishedInstantiation[0]=!1,this._finishedInstantiation[1]=!1,this._finishedInstantiation[2]=!1,this._finishedInstantiation[3]=!1}initialize(e,t,i){this._editor=e,this._instantiationService=i;for(const n of t){if(this._pending.has(n.id)){et(new Error(`Cannot have two contributions with the same id ${n.id}`));continue}this._pending.set(n.id,n)}this._instantiateSome(0),this._register(ov(Xe(this._editor.getDomNode()),()=>{this._instantiateSome(1)})),this._register(ov(Xe(this._editor.getDomNode()),()=>{this._instantiateSome(2)})),this._register(ov(Xe(this._editor.getDomNode()),()=>{this._instantiateSome(3)},5e3))}saveViewState(){const e={};for(const[t,i]of this._instances)typeof i.saveViewState=="function"&&(e[t]=i.saveViewState());return e}restoreViewState(e){for(const[t,i]of this._instances)typeof i.restoreViewState=="function"&&i.restoreViewState(e[t])}get(e){return this._instantiateById(e),this._instances.get(e)||null}onBeforeInteractionEvent(){this._instantiateSome(2)}onAfterModelAttached(){var e;this._register(ov(Xe((e=this._editor)===null||e===void 0?void 0:e.getDomNode()),()=>{this._instantiateSome(1)},50))}_instantiateSome(e){if(this._finishedInstantiation[e])return;this._finishedInstantiation[e]=!0;const t=this._findPendingContributionsByInstantiation(e);for(const i of t)this._instantiateById(i.id)}_findPendingContributionsByInstantiation(e){const t=[];for(const[,i]of this._pending)i.instantiation===e&&t.push(i);return t}_instantiateById(e){const t=this._pending.get(e);if(t){if(this._pending.delete(e),!this._instantiationService||!this._editor)throw new Error("Cannot instantiate contributions before being initialized!");try{const i=this._instantiationService.createInstance(t.ctor,this._editor);this._instances.set(t.id,i),typeof i.restoreViewState=="function"&&t.instantiation!==0&&console.warn(`Editor contribution '${t.id}' should be eager instantiated because it uses saveViewState / restoreViewState.`)}catch(i){et(i)}}}}var Rce=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},hd=function(s,e){return function(t,i){e(t,i,s)}},Ah;let Ace=0,Pce=class{constructor(e,t,i,n,o,r){this.model=e,this.viewModel=t,this.view=i,this.hasRealView=n,this.listenersToRemove=o,this.attachedView=r}dispose(){Bt(this.listenersToRemove),this.model.onBeforeDetached(this.attachedView),this.hasRealView&&this.view.dispose(),this.viewModel.dispose()}},Lm=Ah=class extends j{get isSimpleWidget(){return this._configuration.isSimpleWidget}constructor(e,t,i,n,o,r,a,l,d,c,u,h){var g;super(),this.languageConfigurationService=u,this._deliveryQueue=SQ(),this._contributions=this._register(new Mce),this._onDidDispose=this._register(new W),this.onDidDispose=this._onDidDispose.event,this._onDidChangeModelContent=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeModelContent=this._onDidChangeModelContent.event,this._onDidChangeModelLanguage=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeModelLanguage=this._onDidChangeModelLanguage.event,this._onDidChangeModelLanguageConfiguration=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeModelLanguageConfiguration=this._onDidChangeModelLanguageConfiguration.event,this._onDidChangeModelOptions=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeModelOptions=this._onDidChangeModelOptions.event,this._onDidChangeModelDecorations=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeModelDecorations=this._onDidChangeModelDecorations.event,this._onDidChangeModelTokens=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeModelTokens=this._onDidChangeModelTokens.event,this._onDidChangeConfiguration=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeConfiguration=this._onDidChangeConfiguration.event,this._onDidChangeModel=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeModel=this._onDidChangeModel.event,this._onDidChangeCursorPosition=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeCursorPosition=this._onDidChangeCursorPosition.event,this._onDidChangeCursorSelection=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeCursorSelection=this._onDidChangeCursorSelection.event,this._onDidAttemptReadOnlyEdit=this._register(new fs(this._contributions,this._deliveryQueue)),this.onDidAttemptReadOnlyEdit=this._onDidAttemptReadOnlyEdit.event,this._onDidLayoutChange=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidLayoutChange=this._onDidLayoutChange.event,this._editorTextFocus=this._register(new R7({deliveryQueue:this._deliveryQueue})),this.onDidFocusEditorText=this._editorTextFocus.onDidChangeToTrue,this.onDidBlurEditorText=this._editorTextFocus.onDidChangeToFalse,this._editorWidgetFocus=this._register(new R7({deliveryQueue:this._deliveryQueue})),this.onDidFocusEditorWidget=this._editorWidgetFocus.onDidChangeToTrue,this.onDidBlurEditorWidget=this._editorWidgetFocus.onDidChangeToFalse,this._onWillType=this._register(new fs(this._contributions,this._deliveryQueue)),this.onWillType=this._onWillType.event,this._onDidType=this._register(new fs(this._contributions,this._deliveryQueue)),this.onDidType=this._onDidType.event,this._onDidCompositionStart=this._register(new fs(this._contributions,this._deliveryQueue)),this.onDidCompositionStart=this._onDidCompositionStart.event,this._onDidCompositionEnd=this._register(new fs(this._contributions,this._deliveryQueue)),this.onDidCompositionEnd=this._onDidCompositionEnd.event,this._onDidPaste=this._register(new fs(this._contributions,this._deliveryQueue)),this.onDidPaste=this._onDidPaste.event,this._onMouseUp=this._register(new fs(this._contributions,this._deliveryQueue)),this.onMouseUp=this._onMouseUp.event,this._onMouseDown=this._register(new fs(this._contributions,this._deliveryQueue)),this.onMouseDown=this._onMouseDown.event,this._onMouseDrag=this._register(new fs(this._contributions,this._deliveryQueue)),this.onMouseDrag=this._onMouseDrag.event,this._onMouseDrop=this._register(new fs(this._contributions,this._deliveryQueue)),this.onMouseDrop=this._onMouseDrop.event,this._onMouseDropCanceled=this._register(new fs(this._contributions,this._deliveryQueue)),this.onMouseDropCanceled=this._onMouseDropCanceled.event,this._onDropIntoEditor=this._register(new fs(this._contributions,this._deliveryQueue)),this.onDropIntoEditor=this._onDropIntoEditor.event,this._onContextMenu=this._register(new fs(this._contributions,this._deliveryQueue)),this.onContextMenu=this._onContextMenu.event,this._onMouseMove=this._register(new fs(this._contributions,this._deliveryQueue)),this.onMouseMove=this._onMouseMove.event,this._onMouseLeave=this._register(new fs(this._contributions,this._deliveryQueue)),this.onMouseLeave=this._onMouseLeave.event,this._onMouseWheel=this._register(new fs(this._contributions,this._deliveryQueue)),this.onMouseWheel=this._onMouseWheel.event,this._onKeyUp=this._register(new fs(this._contributions,this._deliveryQueue)),this.onKeyUp=this._onKeyUp.event,this._onKeyDown=this._register(new fs(this._contributions,this._deliveryQueue)),this.onKeyDown=this._onKeyDown.event,this._onDidContentSizeChange=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidContentSizeChange=this._onDidContentSizeChange.event,this._onDidScrollChange=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidScrollChange=this._onDidScrollChange.event,this._onDidChangeViewZones=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeViewZones=this._onDidChangeViewZones.event,this._onDidChangeHiddenAreas=this._register(new W({deliveryQueue:this._deliveryQueue})),this.onDidChangeHiddenAreas=this._onDidChangeHiddenAreas.event,this._actions=new Map,this._bannerDomNode=null,this._dropIntoEditorDecorations=this.createDecorationsCollection(),o.willCreateCodeEditor();const f={...t};this._domElement=e,this._overflowWidgetsDomNode=f.overflowWidgetsDomNode,delete f.overflowWidgetsDomNode,this._id=++Ace,this._decorationTypeKeysToIds={},this._decorationTypeSubtypes={},this._telemetryData=i.telemetryData,this._configuration=this._register(this._createConfiguration(i.isSimpleWidget||!1,f,c)),this._register(this._configuration.onDidChange(v=>{this._onDidChangeConfiguration.fire(v);const b=this._configuration.options;if(v.hasChanged(143)){const C=b.get(143);this._onDidLayoutChange.fire(C)}})),this._contextKeyService=this._register(a.createScoped(this._domElement)),this._notificationService=d,this._codeEditorService=o,this._commandService=r,this._themeService=l,this._register(new Oce(this,this._contextKeyService)),this._register(new Fce(this,this._contextKeyService,h)),this._instantiationService=n.createChild(new _C([je,this._contextKeyService])),this._modelData=null,this._focusTracker=new Bce(e),this._register(this._focusTracker.onChange(()=>{this._editorWidgetFocus.setValue(this._focusTracker.hasFocus())})),this._contentWidgets={},this._overlayWidgets={},this._glyphMarginWidgets={};let m;Array.isArray(i.contributions)?m=i.contributions:m=Ap.getEditorContributions(),this._contributions.initialize(this,m,this._instantiationService);for(const v of Ap.getEditorActions()){if(this._actions.has(v.id)){et(new Error(`Cannot have two actions with the same id ${v.id}`));continue}const b=new UH(v.id,v.label,v.alias,v.metadata,(g=v.precondition)!==null&&g!==void 0?g:void 0,()=>this._instantiationService.invokeFunction(C=>Promise.resolve(v.runEditorCommand(C,this,null))),this._contextKeyService);this._actions.set(b.id,b)}const _=()=>!this._configuration.options.get(90)&&this._configuration.options.get(36).enabled;this._register(new ste(this._domElement,{onDragOver:v=>{if(!_())return;const b=this.getTargetAtClientPoint(v.clientX,v.clientY);b!=null&&b.position&&this.showDropIndicatorAt(b.position)},onDrop:async v=>{if(!_()||(this.removeDropIndicator(),!v.dataTransfer))return;const b=this.getTargetAtClientPoint(v.clientX,v.clientY);b!=null&&b.position&&this._onDropIntoEditor.fire({position:b.position,event:v})},onDragLeave:()=>{this.removeDropIndicator()},onDragEnd:()=>{this.removeDropIndicator()}})),this._codeEditorService.addCodeEditor(this)}writeScreenReaderContent(e){var t;(t=this._modelData)===null||t===void 0||t.view.writeScreenReaderContent(e)}_createConfiguration(e,t,i){return new hT(e,t,this._domElement,i)}getId(){return this.getEditorType()+":"+this._id}getEditorType(){return aC.ICodeEditor}dispose(){this._codeEditorService.removeCodeEditor(this),this._focusTracker.dispose(),this._actions.clear(),this._contentWidgets={},this._overlayWidgets={},this._removeDecorationTypes(),this._postDetachModelCleanup(this._detachModel()),this._onDidDispose.fire(),super.dispose()}invokeWithinContext(e){return this._instantiationService.invokeFunction(e)}updateOptions(e){this._configuration.updateOptions(e||{})}getOptions(){return this._configuration.options}getOption(e){return this._configuration.options.get(e)}getRawOptions(){return this._configuration.getRawOptions()}getOverflowWidgetsDomNode(){return this._overflowWidgetsDomNode}getConfiguredWordAtPosition(e){return this._modelData?Nt.getWordAtPosition(this._modelData.model,this._configuration.options.get(129),e):null}getValue(e=null){if(!this._modelData)return"";const t=!!(e&&e.preserveBOM);let i=0;return e&&e.lineEnding&&e.lineEnding===`
`?i=1:e&&e.lineEnding&&e.lineEnding===`\r
`&&(i=2),this._modelData.model.getValue(i,t)}setValue(e){this._modelData&&this._modelData.model.setValue(e)}getModel(){return this._modelData?this._modelData.model:null}setModel(e=null){const t=e;if(this._modelData===null&&t===null||this._modelData&&this._modelData.model===t)return;const i=this.hasTextFocus(),n=this._detachModel();this._attachModel(t),i&&this.hasModel()&&this.focus();const o={oldModelUrl:n?n.uri:null,newModelUrl:t?t.uri:null};this._removeDecorationTypes(),this._onDidChangeModel.fire(o),this._postDetachModelCleanup(n),this._contributions.onAfterModelAttached()}_removeDecorationTypes(){if(this._decorationTypeKeysToIds={},this._decorationTypeSubtypes){for(const e in this._decorationTypeSubtypes){const t=this._decorationTypeSubtypes[e];for(const i in t)this._removeDecorationType(e+"-"+i)}this._decorationTypeSubtypes={}}}getVisibleRanges(){return this._modelData?this._modelData.viewModel.getVisibleRanges():[]}getVisibleRangesPlusViewportAboveBelow(){return this._modelData?this._modelData.viewModel.getVisibleRangesPlusViewportAboveBelow():[]}getWhitespaces(){return this._modelData?this._modelData.viewModel.viewLayout.getWhitespaces():[]}static _getVerticalOffsetAfterPosition(e,t,i,n){const o=e.model.validatePosition({lineNumber:t,column:i}),r=e.viewModel.coordinatesConverter.convertModelPositionToViewPosition(o);return e.viewModel.viewLayout.getVerticalOffsetAfterLineNumber(r.lineNumber,n)}getTopForLineNumber(e,t=!1){return this._modelData?Ah._getVerticalOffsetForPosition(this._modelData,e,1,t):-1}getTopForPosition(e,t){return this._modelData?Ah._getVerticalOffsetForPosition(this._modelData,e,t,!1):-1}static _getVerticalOffsetForPosition(e,t,i,n=!1){const o=e.model.validatePosition({lineNumber:t,column:i}),r=e.viewModel.coordinatesConverter.convertModelPositionToViewPosition(o);return e.viewModel.viewLayout.getVerticalOffsetForLineNumber(r.lineNumber,n)}getBottomForLineNumber(e,t=!1){return this._modelData?Ah._getVerticalOffsetAfterPosition(this._modelData,e,1,t):-1}setHiddenAreas(e,t){var i;(i=this._modelData)===null||i===void 0||i.viewModel.setHiddenAreas(e.map(n=>D.lift(n)),t)}getVisibleColumnFromPosition(e){if(!this._modelData)return e.column;const t=this._modelData.model.validatePosition(e),i=this._modelData.model.getOptions().tabSize;return hn.visibleColumnFromColumn(this._modelData.model.getLineContent(t.lineNumber),t.column,i)+1}getPosition(){return this._modelData?this._modelData.viewModel.getPosition():null}setPosition(e,t="api"){if(this._modelData){if(!H.isIPosition(e))throw new Error("Invalid arguments");this._modelData.viewModel.setSelections(t,[{selectionStartLineNumber:e.lineNumber,selectionStartColumn:e.column,positionLineNumber:e.lineNumber,positionColumn:e.column}])}}_sendRevealRange(e,t,i,n){if(!this._modelData)return;if(!D.isIRange(e))throw new Error("Invalid arguments");const o=this._modelData.model.validateRange(e),r=this._modelData.viewModel.coordinatesConverter.convertModelRangeToViewRange(o);this._modelData.viewModel.revealRange("api",i,r,t,n)}revealLine(e,t=0){this._revealLine(e,0,t)}revealLineInCenter(e,t=0){this._revealLine(e,1,t)}revealLineInCenterIfOutsideViewport(e,t=0){this._revealLine(e,2,t)}revealLineNearTop(e,t=0){this._revealLine(e,5,t)}_revealLine(e,t,i){if(typeof e!="number")throw new Error("Invalid arguments");this._sendRevealRange(new D(e,1,e,1),t,!1,i)}revealPosition(e,t=0){this._revealPosition(e,0,!0,t)}revealPositionInCenter(e,t=0){this._revealPosition(e,1,!0,t)}revealPositionInCenterIfOutsideViewport(e,t=0){this._revealPosition(e,2,!0,t)}revealPositionNearTop(e,t=0){this._revealPosition(e,5,!0,t)}_revealPosition(e,t,i,n){if(!H.isIPosition(e))throw new Error("Invalid arguments");this._sendRevealRange(new D(e.lineNumber,e.column,e.lineNumber,e.column),t,i,n)}getSelection(){return this._modelData?this._modelData.viewModel.getSelection():null}getSelections(){return this._modelData?this._modelData.viewModel.getSelections():null}setSelection(e,t="api"){const i=De.isISelection(e),n=D.isIRange(e);if(!i&&!n)throw new Error("Invalid arguments");if(i)this._setSelectionImpl(e,t);else if(n){const o={selectionStartLineNumber:e.startLineNumber,selectionStartColumn:e.startColumn,positionLineNumber:e.endLineNumber,positionColumn:e.endColumn};this._setSelectionImpl(o,t)}}_setSelectionImpl(e,t){if(!this._modelData)return;const i=new De(e.selectionStartLineNumber,e.selectionStartColumn,e.positionLineNumber,e.positionColumn);this._modelData.viewModel.setSelections(t,[i])}revealLines(e,t,i=0){this._revealLines(e,t,0,i)}revealLinesInCenter(e,t,i=0){this._revealLines(e,t,1,i)}revealLinesInCenterIfOutsideViewport(e,t,i=0){this._revealLines(e,t,2,i)}revealLinesNearTop(e,t,i=0){this._revealLines(e,t,5,i)}_revealLines(e,t,i,n){if(typeof e!="number"||typeof t!="number")throw new Error("Invalid arguments");this._sendRevealRange(new D(e,1,t,1),i,!1,n)}revealRange(e,t=0,i=!1,n=!0){this._revealRange(e,i?1:0,n,t)}revealRangeInCenter(e,t=0){this._revealRange(e,1,!0,t)}revealRangeInCenterIfOutsideViewport(e,t=0){this._revealRange(e,2,!0,t)}revealRangeNearTop(e,t=0){this._revealRange(e,5,!0,t)}revealRangeNearTopIfOutsideViewport(e,t=0){this._revealRange(e,6,!0,t)}revealRangeAtTop(e,t=0){this._revealRange(e,3,!0,t)}_revealRange(e,t,i,n){if(!D.isIRange(e))throw new Error("Invalid arguments");this._sendRevealRange(D.lift(e),t,i,n)}setSelections(e,t="api",i=0){if(this._modelData){if(!e||e.length===0)throw new Error("Invalid arguments");for(let n=0,o=e.length;n<o;n++)if(!De.isISelection(e[n]))throw new Error("Invalid arguments");this._modelData.viewModel.setSelections(t,e,i)}}getContentWidth(){return this._modelData?this._modelData.viewModel.viewLayout.getContentWidth():-1}getScrollWidth(){return this._modelData?this._modelData.viewModel.viewLayout.getScrollWidth():-1}getScrollLeft(){return this._modelData?this._modelData.viewModel.viewLayout.getCurrentScrollLeft():-1}getContentHeight(){return this._modelData?this._modelData.viewModel.viewLayout.getContentHeight():-1}getScrollHeight(){return this._modelData?this._modelData.viewModel.viewLayout.getScrollHeight():-1}getScrollTop(){return this._modelData?this._modelData.viewModel.viewLayout.getCurrentScrollTop():-1}setScrollLeft(e,t=1){if(this._modelData){if(typeof e!="number")throw new Error("Invalid arguments");this._modelData.viewModel.viewLayout.setScrollPosition({scrollLeft:e},t)}}setScrollTop(e,t=1){if(this._modelData){if(typeof e!="number")throw new Error("Invalid arguments");this._modelData.viewModel.viewLayout.setScrollPosition({scrollTop:e},t)}}setScrollPosition(e,t=1){this._modelData&&this._modelData.viewModel.viewLayout.setScrollPosition(e,t)}hasPendingScrollAnimation(){return this._modelData?this._modelData.viewModel.viewLayout.hasPendingScrollAnimation():!1}saveViewState(){if(!this._modelData)return null;const e=this._contributions.saveViewState(),t=this._modelData.viewModel.saveCursorState(),i=this._modelData.viewModel.saveState();return{cursorState:t,viewState:i,contributionsState:e}}restoreViewState(e){if(!this._modelData||!this._modelData.hasRealView)return;const t=e;if(t&&t.cursorState&&t.viewState){const i=t.cursorState;Array.isArray(i)?i.length>0&&this._modelData.viewModel.restoreCursorState(i):this._modelData.viewModel.restoreCursorState([i]),this._contributions.restoreViewState(t.contributionsState||{});const n=this._modelData.viewModel.reduceRestoreState(t.viewState);this._modelData.view.restoreState(n)}}handleInitialized(){var e;(e=this._getViewModel())===null||e===void 0||e.visibleLinesStabilized()}getContribution(e){return this._contributions.get(e)}getActions(){return Array.from(this._actions.values())}getSupportedActions(){let e=this.getActions();return e=e.filter(t=>t.isSupported()),e}getAction(e){return this._actions.get(e)||null}trigger(e,t,i){switch(i=i||{},t){case"compositionStart":this._startComposition();return;case"compositionEnd":this._endComposition(e);return;case"type":{const o=i;this._type(e,o.text||"");return}case"replacePreviousChar":{const o=i;this._compositionType(e,o.text||"",o.replaceCharCnt||0,0,0);return}case"compositionType":{const o=i;this._compositionType(e,o.text||"",o.replacePrevCharCnt||0,o.replaceNextCharCnt||0,o.positionDelta||0);return}case"paste":{const o=i;this._paste(e,o.text||"",o.pasteOnNewLine||!1,o.multicursorText||null,o.mode||null);return}case"cut":this._cut(e);return}const n=this.getAction(t);if(n){Promise.resolve(n.run(i)).then(void 0,et);return}this._modelData&&(this._triggerEditorCommand(e,t,i)||this._triggerCommand(t,i))}_triggerCommand(e,t){this._commandService.executeCommand(e,t)}_startComposition(){this._modelData&&(this._modelData.viewModel.startComposition(),this._onDidCompositionStart.fire())}_endComposition(e){this._modelData&&(this._modelData.viewModel.endComposition(e),this._onDidCompositionEnd.fire())}_type(e,t){!this._modelData||t.length===0||(e==="keyboard"&&this._onWillType.fire(t),this._modelData.viewModel.type(t,e),e==="keyboard"&&this._onDidType.fire(t))}_compositionType(e,t,i,n,o){this._modelData&&this._modelData.viewModel.compositionType(t,i,n,o,e)}_paste(e,t,i,n,o){if(!this._modelData||t.length===0)return;const r=this._modelData.viewModel,a=r.getSelection().getStartPosition();r.paste(t,i,n,e);const l=r.getSelection().getStartPosition();e==="keyboard"&&this._onDidPaste.fire({range:new D(a.lineNumber,a.column,l.lineNumber,l.column),languageId:o})}_cut(e){this._modelData&&this._modelData.viewModel.cut(e)}_triggerEditorCommand(e,t,i){const n=Ap.getEditorCommand(t);return n?(i=i||{},i.source=e,this._instantiationService.invokeFunction(o=>{Promise.resolve(n.runEditorCommand(o,this,i)).then(void 0,et)}),!0):!1}_getViewModel(){return this._modelData?this._modelData.viewModel:null}pushUndoStop(){return!this._modelData||this._configuration.options.get(90)?!1:(this._modelData.model.pushStackElement(),!0)}popUndoStop(){return!this._modelData||this._configuration.options.get(90)?!1:(this._modelData.model.popStackElement(),!0)}executeEdits(e,t,i){if(!this._modelData||this._configuration.options.get(90))return!1;let n;return i?Array.isArray(i)?n=()=>i:n=i:n=()=>null,this._modelData.viewModel.executeEdits(e,t,n),!0}executeCommand(e,t){this._modelData&&this._modelData.viewModel.executeCommand(t,e)}executeCommands(e,t){this._modelData&&this._modelData.viewModel.executeCommands(t,e)}createDecorationsCollection(e){return new Wce(this,e)}changeDecorations(e){return this._modelData?this._modelData.model.changeDecorations(e,this._id):null}getLineDecorations(e){return this._modelData?this._modelData.model.getLineDecorations(e,this._id,LS(this._configuration.options)):null}getDecorationsInRange(e){return this._modelData?this._modelData.model.getDecorationsInRange(e,this._id,LS(this._configuration.options)):null}deltaDecorations(e,t){return this._modelData?e.length===0&&t.length===0?e:this._modelData.model.deltaDecorations(e,t,this._id):[]}removeDecorations(e){!this._modelData||e.length===0||this._modelData.model.changeDecorations(t=>{t.deltaDecorations(e,[])})}removeDecorationsByType(e){const t=this._decorationTypeKeysToIds[e];t&&this.deltaDecorations(t,[]),this._decorationTypeKeysToIds.hasOwnProperty(e)&&delete this._decorationTypeKeysToIds[e],this._decorationTypeSubtypes.hasOwnProperty(e)&&delete this._decorationTypeSubtypes[e]}getLayoutInfo(){return this._configuration.options.get(143)}createOverviewRuler(e){return!this._modelData||!this._modelData.hasRealView?null:this._modelData.view.createOverviewRuler(e)}getContainerDomNode(){return this._domElement}getDomNode(){return!this._modelData||!this._modelData.hasRealView?null:this._modelData.view.domNode.domNode}delegateVerticalScrollbarPointerDown(e){!this._modelData||!this._modelData.hasRealView||this._modelData.view.delegateVerticalScrollbarPointerDown(e)}delegateScrollFromMouseWheelEvent(e){!this._modelData||!this._modelData.hasRealView||this._modelData.view.delegateScrollFromMouseWheelEvent(e)}layout(e,t=!1){this._configuration.observeContainer(e),t||this.render()}focus(){!this._modelData||!this._modelData.hasRealView||this._modelData.view.focus()}hasTextFocus(){return!this._modelData||!this._modelData.hasRealView?!1:this._modelData.view.isFocused()}hasWidgetFocus(){return this._focusTracker&&this._focusTracker.hasFocus()}addContentWidget(e){const t={widget:e,position:e.getPosition()};this._contentWidgets.hasOwnProperty(e.getId())&&console.warn("Overwriting a content widget with the same id:"+e.getId()),this._contentWidgets[e.getId()]=t,this._modelData&&this._modelData.hasRealView&&this._modelData.view.addContentWidget(t)}layoutContentWidget(e){const t=e.getId();if(this._contentWidgets.hasOwnProperty(t)){const i=this._contentWidgets[t];i.position=e.getPosition(),this._modelData&&this._modelData.hasRealView&&this._modelData.view.layoutContentWidget(i)}}removeContentWidget(e){const t=e.getId();if(this._contentWidgets.hasOwnProperty(t)){const i=this._contentWidgets[t];delete this._contentWidgets[t],this._modelData&&this._modelData.hasRealView&&this._modelData.view.removeContentWidget(i)}}addOverlayWidget(e){const t={widget:e,position:e.getPosition()};this._overlayWidgets.hasOwnProperty(e.getId())&&console.warn("Overwriting an overlay widget with the same id."),this._overlayWidgets[e.getId()]=t,this._modelData&&this._modelData.hasRealView&&this._modelData.view.addOverlayWidget(t)}layoutOverlayWidget(e){const t=e.getId();if(this._overlayWidgets.hasOwnProperty(t)){const i=this._overlayWidgets[t];i.position=e.getPosition(),this._modelData&&this._modelData.hasRealView&&this._modelData.view.layoutOverlayWidget(i)}}removeOverlayWidget(e){const t=e.getId();if(this._overlayWidgets.hasOwnProperty(t)){const i=this._overlayWidgets[t];delete this._overlayWidgets[t],this._modelData&&this._modelData.hasRealView&&this._modelData.view.removeOverlayWidget(i)}}addGlyphMarginWidget(e){const t={widget:e,position:e.getPosition()};this._glyphMarginWidgets.hasOwnProperty(e.getId())&&console.warn("Overwriting a glyph margin widget with the same id."),this._glyphMarginWidgets[e.getId()]=t,this._modelData&&this._modelData.hasRealView&&this._modelData.view.addGlyphMarginWidget(t)}layoutGlyphMarginWidget(e){const t=e.getId();if(this._glyphMarginWidgets.hasOwnProperty(t)){const i=this._glyphMarginWidgets[t];i.position=e.getPosition(),this._modelData&&this._modelData.hasRealView&&this._modelData.view.layoutGlyphMarginWidget(i)}}removeGlyphMarginWidget(e){const t=e.getId();if(this._glyphMarginWidgets.hasOwnProperty(t)){const i=this._glyphMarginWidgets[t];delete this._glyphMarginWidgets[t],this._modelData&&this._modelData.hasRealView&&this._modelData.view.removeGlyphMarginWidget(i)}}changeViewZones(e){!this._modelData||!this._modelData.hasRealView||this._modelData.view.change(e)}getTargetAtClientPoint(e,t){return!this._modelData||!this._modelData.hasRealView?null:this._modelData.view.getTargetAtClientPoint(e,t)}getScrolledVisiblePosition(e){if(!this._modelData||!this._modelData.hasRealView)return null;const t=this._modelData.model.validatePosition(e),i=this._configuration.options,n=i.get(143),o=Ah._getVerticalOffsetForPosition(this._modelData,t.lineNumber,t.column)-this.getScrollTop(),r=this._modelData.view.getOffsetForColumn(t.lineNumber,t.column)+n.glyphMarginWidth+n.lineNumbersWidth+n.decorationsWidth-this.getScrollLeft();return{top:o,left:r,height:i.get(66)}}getOffsetForColumn(e,t){return!this._modelData||!this._modelData.hasRealView?-1:this._modelData.view.getOffsetForColumn(e,t)}render(e=!1){!this._modelData||!this._modelData.hasRealView||this._modelData.view.render(!0,e)}setAriaOptions(e){!this._modelData||!this._modelData.hasRealView||this._modelData.view.setAriaOptions(e)}applyFontInfo(e){Xn(e,this._configuration.options.get(50))}setBanner(e,t){this._bannerDomNode&&this._domElement.contains(this._bannerDomNode)&&this._domElement.removeChild(this._bannerDomNode),this._bannerDomNode=e,this._configuration.setReservedHeight(e?t:0),this._bannerDomNode&&this._domElement.prepend(this._bannerDomNode)}_attachModel(e){if(!e){this._modelData=null;return}const t=[];this._domElement.setAttribute("data-mode-id",e.getLanguageId()),this._configuration.setIsDominatedByLongLines(e.isDominatedByLongLines()),this._configuration.setModelLineCount(e.getLineCount());const i=e.onBeforeAttached(),n=new wce(this._id,this._configuration,e,ZP.create(Xe(this._domElement)),GP.create(this._configuration.options),a=>yo(Xe(this._domElement),a),this.languageConfigurationService,this._themeService,i);t.push(e.onWillDispose(()=>this.setModel(null))),t.push(n.onEvent(a=>{switch(a.kind){case 0:this._onDidContentSizeChange.fire(a);break;case 1:this._editorTextFocus.setValue(a.hasFocus);break;case 2:this._onDidScrollChange.fire(a);break;case 3:this._onDidChangeViewZones.fire();break;case 4:this._onDidChangeHiddenAreas.fire();break;case 5:this._onDidAttemptReadOnlyEdit.fire();break;case 6:{if(a.reachedMaxCursorCount){const u=this.getOption(79),h=p("cursors.maximum","The number of cursors has been limited to {0}. Consider using [find and replace](https://code.visualstudio.com/docs/editor/codebasics#_find-and-replace) for larger changes or increase the editor multi cursor limit setting.",u);this._notificationService.prompt(Rx.Warning,h,[{label:"Find and Replace",run:()=>{this._commandService.executeCommand("editor.action.startFindReplaceAction")}},{label:p("goToSetting","Increase Multi Cursor Limit"),run:()=>{this._commandService.executeCommand("workbench.action.openSettings2",{query:"editor.multiCursorLimit"})}}])}const l=[];for(let u=0,h=a.selections.length;u<h;u++)l[u]=a.selections[u].getPosition();const d={position:l[0],secondaryPositions:l.slice(1),reason:a.reason,source:a.source};this._onDidChangeCursorPosition.fire(d);const c={selection:a.selections[0],secondarySelections:a.selections.slice(1),modelVersionId:a.modelVersionId,oldSelections:a.oldSelections,oldModelVersionId:a.oldModelVersionId,source:a.source,reason:a.reason};this._onDidChangeCursorSelection.fire(c);break}case 7:this._onDidChangeModelDecorations.fire(a.event);break;case 8:this._domElement.setAttribute("data-mode-id",e.getLanguageId()),this._onDidChangeModelLanguage.fire(a.event);break;case 9:this._onDidChangeModelLanguageConfiguration.fire(a.event);break;case 10:this._onDidChangeModelContent.fire(a.event);break;case 11:this._onDidChangeModelOptions.fire(a.event);break;case 12:this._onDidChangeModelTokens.fire(a.event);break}}));const[o,r]=this._createView(n);if(r){this._domElement.appendChild(o.domNode.domNode);let a=Object.keys(this._contentWidgets);for(let l=0,d=a.length;l<d;l++){const c=a[l];o.addContentWidget(this._contentWidgets[c])}a=Object.keys(this._overlayWidgets);for(let l=0,d=a.length;l<d;l++){const c=a[l];o.addOverlayWidget(this._overlayWidgets[c])}a=Object.keys(this._glyphMarginWidgets);for(let l=0,d=a.length;l<d;l++){const c=a[l];o.addGlyphMarginWidget(this._glyphMarginWidgets[c])}o.render(!1,!0),o.domNode.domNode.setAttribute("data-uri",e.uri.toString())}this._modelData=new Pce(e,n,o,r,t,i)}_createView(e){let t;this.isSimpleWidget?t={paste:(o,r,a,l)=>{this._paste("keyboard",o,r,a,l)},type:o=>{this._type("keyboard",o)},compositionType:(o,r,a,l)=>{this._compositionType("keyboard",o,r,a,l)},startComposition:()=>{this._startComposition()},endComposition:()=>{this._endComposition("keyboard")},cut:()=>{this._cut("keyboard")}}:t={paste:(o,r,a,l)=>{const d={text:o,pasteOnNewLine:r,multicursorText:a,mode:l};this._commandService.executeCommand("paste",d)},type:o=>{const r={text:o};this._commandService.executeCommand("type",r)},compositionType:(o,r,a,l)=>{if(a||l){const d={text:o,replacePrevCharCnt:r,replaceNextCharCnt:a,positionDelta:l};this._commandService.executeCommand("compositionType",d)}else{const d={text:o,replaceCharCnt:r};this._commandService.executeCommand("replacePreviousChar",d)}},startComposition:()=>{this._commandService.executeCommand("compositionStart",{})},endComposition:()=>{this._commandService.executeCommand("compositionEnd",{})},cut:()=>{this._commandService.executeCommand("cut",{})}};const i=new Ix(e.coordinatesConverter);return i.onKeyDown=o=>this._onKeyDown.fire(o),i.onKeyUp=o=>this._onKeyUp.fire(o),i.onContextMenu=o=>this._onContextMenu.fire(o),i.onMouseMove=o=>this._onMouseMove.fire(o),i.onMouseLeave=o=>this._onMouseLeave.fire(o),i.onMouseDown=o=>this._onMouseDown.fire(o),i.onMouseUp=o=>this._onMouseUp.fire(o),i.onMouseDrag=o=>this._onMouseDrag.fire(o),i.onMouseDrop=o=>this._onMouseDrop.fire(o),i.onMouseDropCanceled=o=>this._onMouseDropCanceled.fire(o),i.onMouseWheel=o=>this._onMouseWheel.fire(o),[new LT(t,this._configuration,this._themeService.getColorTheme(),e,i,this._overflowWidgetsDomNode,this._instantiationService),!0]}_postDetachModelCleanup(e){e==null||e.removeAllDecorationsWithOwnerId(this._id)}_detachModel(){if(!this._modelData)return null;const e=this._modelData.model,t=this._modelData.hasRealView?this._modelData.view.domNode.domNode:null;return this._modelData.dispose(),this._modelData=null,this._domElement.removeAttribute("data-mode-id"),t&&this._domElement.contains(t)&&this._domElement.removeChild(t),this._bannerDomNode&&this._domElement.contains(this._bannerDomNode)&&this._domElement.removeChild(this._bannerDomNode),e}_removeDecorationType(e){this._codeEditorService.removeDecorationType(e)}hasModel(){return this._modelData!==null}showDropIndicatorAt(e){const t=[{range:new D(e.lineNumber,e.column,e.lineNumber,e.column),options:Ah.dropIntoEditorDecorationOptions}];this._dropIntoEditorDecorations.set(t),this.revealPosition(e,1)}removeDropIndicator(){this._dropIntoEditorDecorations.clear()}setContextValue(e,t){this._contextKeyService.createKey(e,t)}};Lm.dropIntoEditorDecorationOptions=tt.register({description:"workbench-dnd-target",className:"dnd-target"});Lm=Ah=Rce([hd(3,We),hd(4,It),hd(5,Ei),hd(6,je),hd(7,Cn),hd(8,Qi),hd(9,ad),hd(10,Jt),hd(11,xe)],Lm);class R7 extends j{constructor(e){super(),this._emitterOptions=e,this._onDidChangeToTrue=this._register(new W(this._emitterOptions)),this.onDidChangeToTrue=this._onDidChangeToTrue.event,this._onDidChangeToFalse=this._register(new W(this._emitterOptions)),this.onDidChangeToFalse=this._onDidChangeToFalse.event,this._value=0}setValue(e){const t=e?2:1;this._value!==t&&(this._value=t,this._value===2?this._onDidChangeToTrue.fire():this._value===1&&this._onDidChangeToFalse.fire())}}class fs extends W{constructor(e,t){super({deliveryQueue:t}),this._contributions=e}fire(e){this._contributions.onBeforeInteractionEvent(),super.fire(e)}}class Oce extends j{constructor(e,t){super(),this._editor=e,t.createKey("editorId",e.getId()),this._editorSimpleInput=T.editorSimpleInput.bindTo(t),this._editorFocus=T.focus.bindTo(t),this._textInputFocus=T.textInputFocus.bindTo(t),this._editorTextFocus=T.editorTextFocus.bindTo(t),this._tabMovesFocus=T.tabMovesFocus.bindTo(t),this._editorReadonly=T.readOnly.bindTo(t),this._inDiffEditor=T.inDiffEditor.bindTo(t),this._editorColumnSelection=T.columnSelection.bindTo(t),this._hasMultipleSelections=T.hasMultipleSelections.bindTo(t),this._hasNonEmptySelection=T.hasNonEmptySelection.bindTo(t),this._canUndo=T.canUndo.bindTo(t),this._canRedo=T.canRedo.bindTo(t),this._register(this._editor.onDidChangeConfiguration(()=>this._updateFromConfig())),this._register(this._editor.onDidChangeCursorSelection(()=>this._updateFromSelection())),this._register(this._editor.onDidFocusEditorWidget(()=>this._updateFromFocus())),this._register(this._editor.onDidBlurEditorWidget(()=>this._updateFromFocus())),this._register(this._editor.onDidFocusEditorText(()=>this._updateFromFocus())),this._register(this._editor.onDidBlurEditorText(()=>this._updateFromFocus())),this._register(this._editor.onDidChangeModel(()=>this._updateFromModel())),this._register(this._editor.onDidChangeConfiguration(()=>this._updateFromModel())),this._register(mm.onDidChangeTabFocus(i=>this._tabMovesFocus.set(i))),this._updateFromConfig(),this._updateFromSelection(),this._updateFromFocus(),this._updateFromModel(),this._editorSimpleInput.set(this._editor.isSimpleWidget)}_updateFromConfig(){const e=this._editor.getOptions();this._tabMovesFocus.set(mm.getTabFocusMode()),this._editorReadonly.set(e.get(90)),this._inDiffEditor.set(e.get(61)),this._editorColumnSelection.set(e.get(22))}_updateFromSelection(){const e=this._editor.getSelections();e?(this._hasMultipleSelections.set(e.length>1),this._hasNonEmptySelection.set(e.some(t=>!t.isEmpty()))):(this._hasMultipleSelections.reset(),this._hasNonEmptySelection.reset())}_updateFromFocus(){this._editorFocus.set(this._editor.hasWidgetFocus()&&!this._editor.isSimpleWidget),this._editorTextFocus.set(this._editor.hasTextFocus()&&!this._editor.isSimpleWidget),this._textInputFocus.set(this._editor.hasTextFocus())}_updateFromModel(){const e=this._editor.getModel();this._canUndo.set(!!(e&&e.canUndo())),this._canRedo.set(!!(e&&e.canRedo()))}}class Fce extends j{constructor(e,t,i){super(),this._editor=e,this._contextKeyService=t,this._languageFeaturesService=i,this._langId=T.languageId.bindTo(t),this._hasCompletionItemProvider=T.hasCompletionItemProvider.bindTo(t),this._hasCodeActionsProvider=T.hasCodeActionsProvider.bindTo(t),this._hasCodeLensProvider=T.hasCodeLensProvider.bindTo(t),this._hasDefinitionProvider=T.hasDefinitionProvider.bindTo(t),this._hasDeclarationProvider=T.hasDeclarationProvider.bindTo(t),this._hasImplementationProvider=T.hasImplementationProvider.bindTo(t),this._hasTypeDefinitionProvider=T.hasTypeDefinitionProvider.bindTo(t),this._hasHoverProvider=T.hasHoverProvider.bindTo(t),this._hasDocumentHighlightProvider=T.hasDocumentHighlightProvider.bindTo(t),this._hasDocumentSymbolProvider=T.hasDocumentSymbolProvider.bindTo(t),this._hasReferenceProvider=T.hasReferenceProvider.bindTo(t),this._hasRenameProvider=T.hasRenameProvider.bindTo(t),this._hasSignatureHelpProvider=T.hasSignatureHelpProvider.bindTo(t),this._hasInlayHintsProvider=T.hasInlayHintsProvider.bindTo(t),this._hasDocumentFormattingProvider=T.hasDocumentFormattingProvider.bindTo(t),this._hasDocumentSelectionFormattingProvider=T.hasDocumentSelectionFormattingProvider.bindTo(t),this._hasMultipleDocumentFormattingProvider=T.hasMultipleDocumentFormattingProvider.bindTo(t),this._hasMultipleDocumentSelectionFormattingProvider=T.hasMultipleDocumentSelectionFormattingProvider.bindTo(t),this._isInWalkThrough=T.isInWalkThroughSnippet.bindTo(t);const n=()=>this._update();this._register(e.onDidChangeModel(n)),this._register(e.onDidChangeModelLanguage(n)),this._register(i.completionProvider.onDidChange(n)),this._register(i.codeActionProvider.onDidChange(n)),this._register(i.codeLensProvider.onDidChange(n)),this._register(i.definitionProvider.onDidChange(n)),this._register(i.declarationProvider.onDidChange(n)),this._register(i.implementationProvider.onDidChange(n)),this._register(i.typeDefinitionProvider.onDidChange(n)),this._register(i.hoverProvider.onDidChange(n)),this._register(i.documentHighlightProvider.onDidChange(n)),this._register(i.documentSymbolProvider.onDidChange(n)),this._register(i.referenceProvider.onDidChange(n)),this._register(i.renameProvider.onDidChange(n)),this._register(i.documentFormattingEditProvider.onDidChange(n)),this._register(i.documentRangeFormattingEditProvider.onDidChange(n)),this._register(i.signatureHelpProvider.onDidChange(n)),this._register(i.inlayHintsProvider.onDidChange(n)),n()}dispose(){super.dispose()}reset(){this._contextKeyService.bufferChangeEvents(()=>{this._langId.reset(),this._hasCompletionItemProvider.reset(),this._hasCodeActionsProvider.reset(),this._hasCodeLensProvider.reset(),this._hasDefinitionProvider.reset(),this._hasDeclarationProvider.reset(),this._hasImplementationProvider.reset(),this._hasTypeDefinitionProvider.reset(),this._hasHoverProvider.reset(),this._hasDocumentHighlightProvider.reset(),this._hasDocumentSymbolProvider.reset(),this._hasReferenceProvider.reset(),this._hasRenameProvider.reset(),this._hasDocumentFormattingProvider.reset(),this._hasDocumentSelectionFormattingProvider.reset(),this._hasSignatureHelpProvider.reset(),this._isInWalkThrough.reset()})}_update(){const e=this._editor.getModel();if(!e){this.reset();return}this._contextKeyService.bufferChangeEvents(()=>{this._langId.set(e.getLanguageId()),this._hasCompletionItemProvider.set(this._languageFeaturesService.completionProvider.has(e)),this._hasCodeActionsProvider.set(this._languageFeaturesService.codeActionProvider.has(e)),this._hasCodeLensProvider.set(this._languageFeaturesService.codeLensProvider.has(e)),this._hasDefinitionProvider.set(this._languageFeaturesService.definitionProvider.has(e)),this._hasDeclarationProvider.set(this._languageFeaturesService.declarationProvider.has(e)),this._hasImplementationProvider.set(this._languageFeaturesService.implementationProvider.has(e)),this._hasTypeDefinitionProvider.set(this._languageFeaturesService.typeDefinitionProvider.has(e)),this._hasHoverProvider.set(this._languageFeaturesService.hoverProvider.has(e)),this._hasDocumentHighlightProvider.set(this._languageFeaturesService.documentHighlightProvider.has(e)),this._hasDocumentSymbolProvider.set(this._languageFeaturesService.documentSymbolProvider.has(e)),this._hasReferenceProvider.set(this._languageFeaturesService.referenceProvider.has(e)),this._hasRenameProvider.set(this._languageFeaturesService.renameProvider.has(e)),this._hasSignatureHelpProvider.set(this._languageFeaturesService.signatureHelpProvider.has(e)),this._hasInlayHintsProvider.set(this._languageFeaturesService.inlayHintsProvider.has(e)),this._hasDocumentFormattingProvider.set(this._languageFeaturesService.documentFormattingEditProvider.has(e)||this._languageFeaturesService.documentRangeFormattingEditProvider.has(e)),this._hasDocumentSelectionFormattingProvider.set(this._languageFeaturesService.documentRangeFormattingEditProvider.has(e)),this._hasMultipleDocumentFormattingProvider.set(this._languageFeaturesService.documentFormattingEditProvider.all(e).length+this._languageFeaturesService.documentRangeFormattingEditProvider.all(e).length>1),this._hasMultipleDocumentSelectionFormattingProvider.set(this._languageFeaturesService.documentRangeFormattingEditProvider.all(e).length>1),this._isInWalkThrough.set(e.uri.scheme===it.walkThroughSnippet)})}}class Bce extends j{constructor(e){super(),this._onChange=this._register(new W),this.onChange=this._onChange.event,this._hasFocus=!1,this._domFocusTracker=this._register(ql(e)),this._register(this._domFocusTracker.onDidFocus(()=>{this._hasFocus=!0,this._onChange.fire(void 0)})),this._register(this._domFocusTracker.onDidBlur(()=>{this._hasFocus=!1,this._onChange.fire(void 0)}))}hasFocus(){return this._hasFocus}}class Wce{get length(){return this._decorationIds.length}constructor(e,t){this._editor=e,this._decorationIds=[],this._isChangingDecorations=!1,Array.isArray(t)&&t.length>0&&this.set(t)}onDidChange(e,t,i){return this._editor.onDidChangeModelDecorations(n=>{this._isChangingDecorations||e.call(t,n)},i)}getRange(e){return!this._editor.hasModel()||e>=this._decorationIds.length?null:this._editor.getModel().getDecorationRange(this._decorationIds[e])}getRanges(){if(!this._editor.hasModel())return[];const e=this._editor.getModel(),t=[];for(const i of this._decorationIds){const n=e.getDecorationRange(i);n&&t.push(n)}return t}has(e){return this._decorationIds.includes(e.id)}clear(){this._decorationIds.length!==0&&this.set([])}set(e){try{this._isChangingDecorations=!0,this._editor.changeDecorations(t=>{this._decorationIds=t.deltaDecorations(this._decorationIds,e)})}finally{this._isChangingDecorations=!1}return this._decorationIds}append(e){let t=[];try{this._isChangingDecorations=!0,this._editor.changeDecorations(i=>{t=i.deltaDecorations([],e),this._decorationIds=this._decorationIds.concat(t)})}finally{this._isChangingDecorations=!1}return t}}const Vce=encodeURIComponent("<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 6 3' enable-background='new 0 0 6 3' height='3' width='6'><g fill='"),Hce=encodeURIComponent("'><polygon points='5.5,0 2.5,3 1.1,3 4.1,0'/><polygon points='4,0 6,2 6,0.6 5.4,0'/><polygon points='0,2 1,3 2.4,3 0,0.6'/></g></svg>");function LI(s){return Vce+encodeURIComponent(s.toString())+Hce}const zce=encodeURIComponent('<svg xmlns="http://www.w3.org/2000/svg" height="3" width="12"><g fill="'),Uce=encodeURIComponent('"><circle cx="1" cy="1" r="1"/><circle cx="5" cy="1" r="1"/><circle cx="9" cy="1" r="1"/></g></svg>');function $ce(s){return zce+encodeURIComponent(s.toString())+Uce}ia((s,e)=>{const t=s.getColor(Nl);t&&e.addRule(`.monaco-editor .squiggly-error { background: url("data:image/svg+xml,${LI(t)}") repeat-x bottom left; }`);const i=s.getColor(Yo);i&&e.addRule(`.monaco-editor .squiggly-warning { background: url("data:image/svg+xml,${LI(i)}") repeat-x bottom left; }`);const n=s.getColor(Xs);n&&e.addRule(`.monaco-editor .squiggly-info { background: url("data:image/svg+xml,${LI(n)}") repeat-x bottom left; }`);const o=s.getColor(_se);o&&e.addRule(`.monaco-editor .squiggly-hint { background: url("data:image/svg+xml,${$ce(o)}") no-repeat bottom left; }`);const r=s.getColor(Ere);r&&e.addRule(`.monaco-editor.showUnused .squiggly-inline-unnecessary { opacity: ${r.rgba.a}; }`)});var jce=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Kce=function(s,e){return function(t,i){e(t,i,s)}};let HT=class extends j{constructor(e){super(),this._themeService=e,this._onWillCreateCodeEditor=this._register(new W),this._onCodeEditorAdd=this._register(new W),this.onCodeEditorAdd=this._onCodeEditorAdd.event,this._onCodeEditorRemove=this._register(new W),this.onCodeEditorRemove=this._onCodeEditorRemove.event,this._onWillCreateDiffEditor=this._register(new W),this._onDiffEditorAdd=this._register(new W),this.onDiffEditorAdd=this._onDiffEditorAdd.event,this._onDiffEditorRemove=this._register(new W),this.onDiffEditorRemove=this._onDiffEditorRemove.event,this._decorationOptionProviders=new Map,this._codeEditorOpenHandlers=new Ms,this._modelProperties=new Map,this._codeEditors=Object.create(null),this._diffEditors=Object.create(null),this._globalStyleSheet=null}willCreateCodeEditor(){this._onWillCreateCodeEditor.fire()}addCodeEditor(e){this._codeEditors[e.getId()]=e,this._onCodeEditorAdd.fire(e)}removeCodeEditor(e){delete this._codeEditors[e.getId()]&&this._onCodeEditorRemove.fire(e)}listCodeEditors(){return Object.keys(this._codeEditors).map(e=>this._codeEditors[e])}willCreateDiffEditor(){this._onWillCreateDiffEditor.fire()}addDiffEditor(e){this._diffEditors[e.getId()]=e,this._onDiffEditorAdd.fire(e)}listDiffEditors(){return Object.keys(this._diffEditors).map(e=>this._diffEditors[e])}getFocusedCodeEditor(){let e=null;const t=this.listCodeEditors();for(const i of t){if(i.hasTextFocus())return i;i.hasWidgetFocus()&&(e=i)}return e}removeDecorationType(e){const t=this._decorationOptionProviders.get(e);t&&(t.refCount--,t.refCount<=0&&(this._decorationOptionProviders.delete(e),t.dispose(),this.listCodeEditors().forEach(i=>i.removeDecorationsByType(e))))}setModelProperty(e,t,i){const n=e.toString();let o;this._modelProperties.has(n)?o=this._modelProperties.get(n):(o=new Map,this._modelProperties.set(n,o)),o.set(t,i)}getModelProperty(e,t){const i=e.toString();if(this._modelProperties.has(i))return this._modelProperties.get(i).get(t)}async openCodeEditor(e,t,i){for(const n of this._codeEditorOpenHandlers){const o=await n(e,t,i);if(o!==null)return o}return null}registerCodeEditorOpenHandler(e){const t=this._codeEditorOpenHandlers.unshift(e);return Fe(t)}};HT=jce([Kce(0,Cn)],HT);var qce=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},A7=function(s,e){return function(t,i){e(t,i,s)}};let hy=class extends HT{constructor(e,t){super(t),this._register(this.onCodeEditorAdd(()=>this._checkContextKey())),this._register(this.onCodeEditorRemove(()=>this._checkContextKey())),this._editorIsOpen=e.createKey("editorIsOpen",!1),this._activeCodeEditor=null,this._register(this.registerCodeEditorOpenHandler(async(i,n,o)=>n?this.doOpenEditor(n,i):null))}_checkContextKey(){let e=!1;for(const t of this.listCodeEditors())if(!t.isSimpleWidget){e=!0;break}this._editorIsOpen.set(e)}setActiveCodeEditor(e){this._activeCodeEditor=e}getActiveCodeEditor(){return this._activeCodeEditor}doOpenEditor(e,t){if(!this.findModel(e,t.resource)){if(t.resource){const o=t.resource.scheme;if(o===it.http||o===it.https)return xV(t.resource.toString()),e}return null}const n=t.options?t.options.selection:null;if(n)if(typeof n.endLineNumber=="number"&&typeof n.endColumn=="number")e.setSelection(n),e.revealRangeInCenter(n,1);else{const o={lineNumber:n.startLineNumber,column:n.startColumn};e.setPosition(o),e.revealPositionInCenter(o,1)}return e}findModel(e,t){const i=e.getModel();return i&&i.uri.toString()!==t.toString()?null:i}};hy=qce([A7(0,je),A7(1,Cn)],hy);_t(It,hy,0);const d_=ut("layoutService");var pz=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},mz=function(s,e){return function(t,i){e(t,i,s)}};let gy=class{get mainContainer(){var e,t;return(t=(e=wA(this._codeEditorService.listCodeEditors()))===null||e===void 0?void 0:e.getContainerDomNode())!==null&&t!==void 0?t:Ci.document.body}get activeContainer(){var e,t;const i=(e=this._codeEditorService.getFocusedCodeEditor())!==null&&e!==void 0?e:this._codeEditorService.getActiveCodeEditor();return(t=i==null?void 0:i.getContainerDomNode())!==null&&t!==void 0?t:this.mainContainer}get mainContainerDimension(){return Nu(this.mainContainer)}get activeContainerDimension(){return Nu(this.activeContainer)}get containers(){return Ba(this._codeEditorService.listCodeEditors().map(e=>e.getContainerDomNode()))}getContainer(){return this.activeContainer}focus(){var e;(e=this._codeEditorService.getFocusedCodeEditor())===null||e===void 0||e.focus()}constructor(e){this._codeEditorService=e,this.onDidLayoutMainContainer=ge.None,this.onDidLayoutActiveContainer=ge.None,this.onDidLayoutContainer=ge.None,this.onDidChangeActiveContainer=ge.None,this.onDidAddContainer=ge.None,this.mainContainerOffset={top:0,quickPickTop:0},this.activeContainerOffset={top:0,quickPickTop:0}}};gy=pz([mz(0,It)],gy);let zT=class extends gy{get mainContainer(){return this._container}constructor(e,t){super(t),this._container=e}};zT=pz([mz(1,It)],zT);_t(d_,gy,1);const vC=ut("dialogService");var Gce=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},P7=function(s,e){return function(t,i){e(t,i,s)}};function E1(s){return s.scheme===it.file?s.fsPath:s.path}let _z=0;class N1{constructor(e,t,i,n,o,r,a){this.id=++_z,this.type=0,this.actual=e,this.label=e.label,this.confirmBeforeUndo=e.confirmBeforeUndo||!1,this.resourceLabel=t,this.strResource=i,this.resourceLabels=[this.resourceLabel],this.strResources=[this.strResource],this.groupId=n,this.groupOrder=o,this.sourceId=r,this.sourceOrder=a,this.isValid=!0}setValid(e){this.isValid=e}toString(){return`[id:${this.id}] [group:${this.groupId}] [${this.isValid?"  VALID":"INVALID"}] ${this.actual.constructor.name} - ${this.actual}`}}class O7{constructor(e,t){this.resourceLabel=e,this.reason=t}}class F7{constructor(){this.elements=new Map}createMessage(){const e=[],t=[];for(const[,n]of this.elements)(n.reason===0?e:t).push(n.resourceLabel);const i=[];return e.length>0&&i.push(p({key:"externalRemoval",comment:["{0} is a list of filenames"]},"The following files have been closed and modified on disk: {0}.",e.join(", "))),t.length>0&&i.push(p({key:"noParallelUniverses",comment:["{0} is a list of filenames"]},"The following files have been modified in an incompatible way: {0}.",t.join(", "))),i.join(`
`)}get size(){return this.elements.size}has(e){return this.elements.has(e)}set(e,t){this.elements.set(e,t)}delete(e){return this.elements.delete(e)}}class Zce{constructor(e,t,i,n,o,r,a){this.id=++_z,this.type=1,this.actual=e,this.label=e.label,this.confirmBeforeUndo=e.confirmBeforeUndo||!1,this.resourceLabels=t,this.strResources=i,this.groupId=n,this.groupOrder=o,this.sourceId=r,this.sourceOrder=a,this.removedResources=null,this.invalidatedResources=null}canSplit(){return typeof this.actual.split=="function"}removeResource(e,t,i){this.removedResources||(this.removedResources=new F7),this.removedResources.has(t)||this.removedResources.set(t,new O7(e,i))}setValid(e,t,i){i?this.invalidatedResources&&(this.invalidatedResources.delete(t),this.invalidatedResources.size===0&&(this.invalidatedResources=null)):(this.invalidatedResources||(this.invalidatedResources=new F7),this.invalidatedResources.has(t)||this.invalidatedResources.set(t,new O7(e,0)))}toString(){return`[id:${this.id}] [group:${this.groupId}] [${this.invalidatedResources?"INVALID":"  VALID"}] ${this.actual.constructor.name} - ${this.actual}`}}class vz{constructor(e,t){this.resourceLabel=e,this.strResource=t,this._past=[],this._future=[],this.locked=!1,this.versionId=1}dispose(){for(const e of this._past)e.type===1&&e.removeResource(this.resourceLabel,this.strResource,0);for(const e of this._future)e.type===1&&e.removeResource(this.resourceLabel,this.strResource,0);this.versionId++}toString(){const e=[];e.push(`* ${this.strResource}:`);for(let t=0;t<this._past.length;t++)e.push(`   * [UNDO] ${this._past[t]}`);for(let t=this._future.length-1;t>=0;t--)e.push(`   * [REDO] ${this._future[t]}`);return e.join(`
`)}flushAllElements(){this._past=[],this._future=[],this.versionId++}_setElementValidFlag(e,t){e.type===1?e.setValid(this.resourceLabel,this.strResource,t):e.setValid(t)}setElementsValidFlag(e,t){for(const i of this._past)t(i.actual)&&this._setElementValidFlag(i,e);for(const i of this._future)t(i.actual)&&this._setElementValidFlag(i,e)}pushElement(e){for(const t of this._future)t.type===1&&t.removeResource(this.resourceLabel,this.strResource,1);this._future=[],this._past.push(e),this.versionId++}createSnapshot(e){const t=[];for(let i=0,n=this._past.length;i<n;i++)t.push(this._past[i].id);for(let i=this._future.length-1;i>=0;i--)t.push(this._future[i].id);return new dz(e,t)}restoreSnapshot(e){const t=e.elements.length;let i=!0,n=0,o=-1;for(let a=0,l=this._past.length;a<l;a++,n++){const d=this._past[a];i&&(n>=t||d.id!==e.elements[n])&&(i=!1,o=0),!i&&d.type===1&&d.removeResource(this.resourceLabel,this.strResource,0)}let r=-1;for(let a=this._future.length-1;a>=0;a--,n++){const l=this._future[a];i&&(n>=t||l.id!==e.elements[n])&&(i=!1,r=a),!i&&l.type===1&&l.removeResource(this.resourceLabel,this.strResource,0)}o!==-1&&(this._past=this._past.slice(0,o)),r!==-1&&(this._future=this._future.slice(r+1)),this.versionId++}getElements(){const e=[],t=[];for(const i of this._past)e.push(i.actual);for(const i of this._future)t.push(i.actual);return{past:e,future:t}}getClosestPastElement(){return this._past.length===0?null:this._past[this._past.length-1]}getSecondClosestPastElement(){return this._past.length<2?null:this._past[this._past.length-2]}getClosestFutureElement(){return this._future.length===0?null:this._future[this._future.length-1]}hasPastElements(){return this._past.length>0}hasFutureElements(){return this._future.length>0}splitPastWorkspaceElement(e,t){for(let i=this._past.length-1;i>=0;i--)if(this._past[i]===e){t.has(this.strResource)?this._past[i]=t.get(this.strResource):this._past.splice(i,1);break}this.versionId++}splitFutureWorkspaceElement(e,t){for(let i=this._future.length-1;i>=0;i--)if(this._future[i]===e){t.has(this.strResource)?this._future[i]=t.get(this.strResource):this._future.splice(i,1);break}this.versionId++}moveBackward(e){this._past.pop(),this._future.push(e),this.versionId++}moveForward(e){this._future.pop(),this._past.push(e),this.versionId++}}class xI{constructor(e){this.editStacks=e,this._versionIds=[];for(let t=0,i=this.editStacks.length;t<i;t++)this._versionIds[t]=this.editStacks[t].versionId}isValid(){for(let e=0,t=this.editStacks.length;e<t;e++)if(this._versionIds[e]!==this.editStacks[e].versionId)return!1;return!0}}const bz=new vz("","");bz.locked=!0;let UT=class{constructor(e,t){this._dialogService=e,this._notificationService=t,this._editStacks=new Map,this._uriComparisonKeyComputers=[]}getUriComparisonKey(e){for(const t of this._uriComparisonKeyComputers)if(t[0]===e.scheme)return t[1].getComparisonKey(e);return e.toString()}_print(e){console.log("------------------------------------"),console.log(`AFTER ${e}: `);const t=[];for(const i of this._editStacks)t.push(i[1].toString());console.log(t.join(`
`))}pushElement(e,t=ym.None,i=Cl.None){if(e.type===0){const n=E1(e.resource),o=this.getUriComparisonKey(e.resource);this._pushElement(new N1(e,n,o,t.id,t.nextOrder(),i.id,i.nextOrder()))}else{const n=new Set,o=[],r=[];for(const a of e.resources){const l=E1(a),d=this.getUriComparisonKey(a);n.has(d)||(n.add(d),o.push(l),r.push(d))}o.length===1?this._pushElement(new N1(e,o[0],r[0],t.id,t.nextOrder(),i.id,i.nextOrder())):this._pushElement(new Zce(e,o,r,t.id,t.nextOrder(),i.id,i.nextOrder()))}}_pushElement(e){for(let t=0,i=e.strResources.length;t<i;t++){const n=e.resourceLabels[t],o=e.strResources[t];let r;this._editStacks.has(o)?r=this._editStacks.get(o):(r=new vz(n,o),this._editStacks.set(o,r)),r.pushElement(e)}}getLastElement(e){const t=this.getUriComparisonKey(e);if(this._editStacks.has(t)){const i=this._editStacks.get(t);if(i.hasFutureElements())return null;const n=i.getClosestPastElement();return n?n.actual:null}return null}_splitPastWorkspaceElement(e,t){const i=e.actual.split(),n=new Map;for(const o of i){const r=E1(o.resource),a=this.getUriComparisonKey(o.resource),l=new N1(o,r,a,0,0,0,0);n.set(l.strResource,l)}for(const o of e.strResources){if(t&&t.has(o))continue;this._editStacks.get(o).splitPastWorkspaceElement(e,n)}}_splitFutureWorkspaceElement(e,t){const i=e.actual.split(),n=new Map;for(const o of i){const r=E1(o.resource),a=this.getUriComparisonKey(o.resource),l=new N1(o,r,a,0,0,0,0);n.set(l.strResource,l)}for(const o of e.strResources){if(t&&t.has(o))continue;this._editStacks.get(o).splitFutureWorkspaceElement(e,n)}}removeElements(e){const t=typeof e=="string"?e:this.getUriComparisonKey(e);this._editStacks.has(t)&&(this._editStacks.get(t).dispose(),this._editStacks.delete(t))}setElementsValidFlag(e,t,i){const n=this.getUriComparisonKey(e);this._editStacks.has(n)&&this._editStacks.get(n).setElementsValidFlag(t,i)}createSnapshot(e){const t=this.getUriComparisonKey(e);return this._editStacks.has(t)?this._editStacks.get(t).createSnapshot(e):new dz(e,[])}restoreSnapshot(e){const t=this.getUriComparisonKey(e.resource);if(this._editStacks.has(t)){const i=this._editStacks.get(t);i.restoreSnapshot(e),!i.hasPastElements()&&!i.hasFutureElements()&&(i.dispose(),this._editStacks.delete(t))}}getElements(e){const t=this.getUriComparisonKey(e);return this._editStacks.has(t)?this._editStacks.get(t).getElements():{past:[],future:[]}}_findClosestUndoElementWithSource(e){if(!e)return[null,null];let t=null,i=null;for(const[n,o]of this._editStacks){const r=o.getClosestPastElement();r&&r.sourceId===e&&(!t||r.sourceOrder>t.sourceOrder)&&(t=r,i=n)}return[t,i]}canUndo(e){if(e instanceof Cl){const[,i]=this._findClosestUndoElementWithSource(e.id);return!!i}const t=this.getUriComparisonKey(e);return this._editStacks.has(t)?this._editStacks.get(t).hasPastElements():!1}_onError(e,t){et(e);for(const i of t.strResources)this.removeElements(i);this._notificationService.error(e)}_acquireLocks(e){for(const t of e.editStacks)if(t.locked)throw new Error("Cannot acquire edit stack lock");for(const t of e.editStacks)t.locked=!0;return()=>{for(const t of e.editStacks)t.locked=!1}}_safeInvokeWithLocks(e,t,i,n,o){const r=this._acquireLocks(i);let a;try{a=t()}catch(l){return r(),n.dispose(),this._onError(l,e)}return a?a.then(()=>(r(),n.dispose(),o()),l=>(r(),n.dispose(),this._onError(l,e))):(r(),n.dispose(),o())}async _invokeWorkspacePrepare(e){if(typeof e.actual.prepareUndoRedo>"u")return j.None;const t=e.actual.prepareUndoRedo();return typeof t>"u"?j.None:t}_invokeResourcePrepare(e,t){if(e.actual.type!==1||typeof e.actual.prepareUndoRedo>"u")return t(j.None);const i=e.actual.prepareUndoRedo();return i?EA(i)?t(i):i.then(n=>t(n)):t(j.None)}_getAffectedEditStacks(e){const t=[];for(const i of e.strResources)t.push(this._editStacks.get(i)||bz);return new xI(t)}_tryToSplitAndUndo(e,t,i,n){if(t.canSplit())return this._splitPastWorkspaceElement(t,i),this._notificationService.warn(n),new T1(this._undo(e,0,!0));for(const o of t.strResources)this.removeElements(o);return this._notificationService.warn(n),new T1}_checkWorkspaceUndo(e,t,i,n){if(t.removedResources)return this._tryToSplitAndUndo(e,t,t.removedResources,p({key:"cannotWorkspaceUndo",comment:["{0} is a label for an operation. {1} is another message."]},"Could not undo '{0}' across all files. {1}",t.label,t.removedResources.createMessage()));if(n&&t.invalidatedResources)return this._tryToSplitAndUndo(e,t,t.invalidatedResources,p({key:"cannotWorkspaceUndo",comment:["{0} is a label for an operation. {1} is another message."]},"Could not undo '{0}' across all files. {1}",t.label,t.invalidatedResources.createMessage()));const o=[];for(const a of i.editStacks)a.getClosestPastElement()!==t&&o.push(a.resourceLabel);if(o.length>0)return this._tryToSplitAndUndo(e,t,null,p({key:"cannotWorkspaceUndoDueToChanges",comment:["{0} is a label for an operation. {1} is a list of filenames."]},"Could not undo '{0}' across all files because changes were made to {1}",t.label,o.join(", ")));const r=[];for(const a of i.editStacks)a.locked&&r.push(a.resourceLabel);return r.length>0?this._tryToSplitAndUndo(e,t,null,p({key:"cannotWorkspaceUndoDueToInProgressUndoRedo",comment:["{0} is a label for an operation. {1} is a list of filenames."]},"Could not undo '{0}' across all files because there is already an undo or redo operation running on {1}",t.label,r.join(", "))):i.isValid()?null:this._tryToSplitAndUndo(e,t,null,p({key:"cannotWorkspaceUndoDueToInMeantimeUndoRedo",comment:["{0} is a label for an operation. {1} is a list of filenames."]},"Could not undo '{0}' across all files because an undo or redo operation occurred in the meantime",t.label))}_workspaceUndo(e,t,i){const n=this._getAffectedEditStacks(t),o=this._checkWorkspaceUndo(e,t,n,!1);return o?o.returnValue:this._confirmAndExecuteWorkspaceUndo(e,t,n,i)}_isPartOfUndoGroup(e){if(!e.groupId)return!1;for(const[,t]of this._editStacks){const i=t.getClosestPastElement();if(i){if(i===e){const n=t.getSecondClosestPastElement();if(n&&n.groupId===e.groupId)return!0}if(i.groupId===e.groupId)return!0}}return!1}async _confirmAndExecuteWorkspaceUndo(e,t,i,n){if(t.canSplit()&&!this._isPartOfUndoGroup(t)){let a;(function(c){c[c.All=0]="All",c[c.This=1]="This",c[c.Cancel=2]="Cancel"})(a||(a={}));const{result:l}=await this._dialogService.prompt({type:Wi.Info,message:p("confirmWorkspace","Would you like to undo '{0}' across all files?",t.label),buttons:[{label:p({key:"ok",comment:["{0} denotes a number that is > 1, && denotes a mnemonic"]},"&&Undo in {0} Files",i.editStacks.length),run:()=>a.All},{label:p({key:"nok",comment:["&& denotes a mnemonic"]},"Undo this &&File"),run:()=>a.This}],cancelButton:{run:()=>a.Cancel}});if(l===a.Cancel)return;if(l===a.This)return this._splitPastWorkspaceElement(t,null),this._undo(e,0,!0);const d=this._checkWorkspaceUndo(e,t,i,!1);if(d)return d.returnValue;n=!0}let o;try{o=await this._invokeWorkspacePrepare(t)}catch(a){return this._onError(a,t)}const r=this._checkWorkspaceUndo(e,t,i,!0);if(r)return o.dispose(),r.returnValue;for(const a of i.editStacks)a.moveBackward(t);return this._safeInvokeWithLocks(t,()=>t.actual.undo(),i,o,()=>this._continueUndoInGroup(t.groupId,n))}_resourceUndo(e,t,i){if(!t.isValid){e.flushAllElements();return}if(e.locked){const n=p({key:"cannotResourceUndoDueToInProgressUndoRedo",comment:["{0} is a label for an operation."]},"Could not undo '{0}' because there is already an undo or redo operation running.",t.label);this._notificationService.warn(n);return}return this._invokeResourcePrepare(t,n=>(e.moveBackward(t),this._safeInvokeWithLocks(t,()=>t.actual.undo(),new xI([e]),n,()=>this._continueUndoInGroup(t.groupId,i))))}_findClosestUndoElementInGroup(e){if(!e)return[null,null];let t=null,i=null;for(const[n,o]of this._editStacks){const r=o.getClosestPastElement();r&&r.groupId===e&&(!t||r.groupOrder>t.groupOrder)&&(t=r,i=n)}return[t,i]}_continueUndoInGroup(e,t){if(!e)return;const[,i]=this._findClosestUndoElementInGroup(e);if(i)return this._undo(i,0,t)}undo(e){if(e instanceof Cl){const[,t]=this._findClosestUndoElementWithSource(e.id);return t?this._undo(t,e.id,!1):void 0}return typeof e=="string"?this._undo(e,0,!1):this._undo(this.getUriComparisonKey(e),0,!1)}_undo(e,t=0,i){if(!this._editStacks.has(e))return;const n=this._editStacks.get(e),o=n.getClosestPastElement();if(!o)return;if(o.groupId){const[a,l]=this._findClosestUndoElementInGroup(o.groupId);if(o!==a&&l)return this._undo(l,t,i)}if((o.sourceId!==t||o.confirmBeforeUndo)&&!i)return this._confirmAndContinueUndo(e,t,o);try{return o.type===1?this._workspaceUndo(e,o,i):this._resourceUndo(n,o,i)}finally{}}async _confirmAndContinueUndo(e,t,i){if((await this._dialogService.confirm({message:p("confirmDifferentSource","Would you like to undo '{0}'?",i.label),primaryButton:p({key:"confirmDifferentSource.yes",comment:["&& denotes a mnemonic"]},"&&Yes"),cancelButton:p("confirmDifferentSource.no","No")})).confirmed)return this._undo(e,t,!0)}_findClosestRedoElementWithSource(e){if(!e)return[null,null];let t=null,i=null;for(const[n,o]of this._editStacks){const r=o.getClosestFutureElement();r&&r.sourceId===e&&(!t||r.sourceOrder<t.sourceOrder)&&(t=r,i=n)}return[t,i]}canRedo(e){if(e instanceof Cl){const[,i]=this._findClosestRedoElementWithSource(e.id);return!!i}const t=this.getUriComparisonKey(e);return this._editStacks.has(t)?this._editStacks.get(t).hasFutureElements():!1}_tryToSplitAndRedo(e,t,i,n){if(t.canSplit())return this._splitFutureWorkspaceElement(t,i),this._notificationService.warn(n),new T1(this._redo(e));for(const o of t.strResources)this.removeElements(o);return this._notificationService.warn(n),new T1}_checkWorkspaceRedo(e,t,i,n){if(t.removedResources)return this._tryToSplitAndRedo(e,t,t.removedResources,p({key:"cannotWorkspaceRedo",comment:["{0} is a label for an operation. {1} is another message."]},"Could not redo '{0}' across all files. {1}",t.label,t.removedResources.createMessage()));if(n&&t.invalidatedResources)return this._tryToSplitAndRedo(e,t,t.invalidatedResources,p({key:"cannotWorkspaceRedo",comment:["{0} is a label for an operation. {1} is another message."]},"Could not redo '{0}' across all files. {1}",t.label,t.invalidatedResources.createMessage()));const o=[];for(const a of i.editStacks)a.getClosestFutureElement()!==t&&o.push(a.resourceLabel);if(o.length>0)return this._tryToSplitAndRedo(e,t,null,p({key:"cannotWorkspaceRedoDueToChanges",comment:["{0} is a label for an operation. {1} is a list of filenames."]},"Could not redo '{0}' across all files because changes were made to {1}",t.label,o.join(", ")));const r=[];for(const a of i.editStacks)a.locked&&r.push(a.resourceLabel);return r.length>0?this._tryToSplitAndRedo(e,t,null,p({key:"cannotWorkspaceRedoDueToInProgressUndoRedo",comment:["{0} is a label for an operation. {1} is a list of filenames."]},"Could not redo '{0}' across all files because there is already an undo or redo operation running on {1}",t.label,r.join(", "))):i.isValid()?null:this._tryToSplitAndRedo(e,t,null,p({key:"cannotWorkspaceRedoDueToInMeantimeUndoRedo",comment:["{0} is a label for an operation. {1} is a list of filenames."]},"Could not redo '{0}' across all files because an undo or redo operation occurred in the meantime",t.label))}_workspaceRedo(e,t){const i=this._getAffectedEditStacks(t),n=this._checkWorkspaceRedo(e,t,i,!1);return n?n.returnValue:this._executeWorkspaceRedo(e,t,i)}async _executeWorkspaceRedo(e,t,i){let n;try{n=await this._invokeWorkspacePrepare(t)}catch(r){return this._onError(r,t)}const o=this._checkWorkspaceRedo(e,t,i,!0);if(o)return n.dispose(),o.returnValue;for(const r of i.editStacks)r.moveForward(t);return this._safeInvokeWithLocks(t,()=>t.actual.redo(),i,n,()=>this._continueRedoInGroup(t.groupId))}_resourceRedo(e,t){if(!t.isValid){e.flushAllElements();return}if(e.locked){const i=p({key:"cannotResourceRedoDueToInProgressUndoRedo",comment:["{0} is a label for an operation."]},"Could not redo '{0}' because there is already an undo or redo operation running.",t.label);this._notificationService.warn(i);return}return this._invokeResourcePrepare(t,i=>(e.moveForward(t),this._safeInvokeWithLocks(t,()=>t.actual.redo(),new xI([e]),i,()=>this._continueRedoInGroup(t.groupId))))}_findClosestRedoElementInGroup(e){if(!e)return[null,null];let t=null,i=null;for(const[n,o]of this._editStacks){const r=o.getClosestFutureElement();r&&r.groupId===e&&(!t||r.groupOrder<t.groupOrder)&&(t=r,i=n)}return[t,i]}_continueRedoInGroup(e){if(!e)return;const[,t]=this._findClosestRedoElementInGroup(e);if(t)return this._redo(t)}redo(e){if(e instanceof Cl){const[,t]=this._findClosestRedoElementWithSource(e.id);return t?this._redo(t):void 0}return typeof e=="string"?this._redo(e):this._redo(this.getUriComparisonKey(e))}_redo(e){if(!this._editStacks.has(e))return;const t=this._editStacks.get(e),i=t.getClosestFutureElement();if(i){if(i.groupId){const[n,o]=this._findClosestRedoElementInGroup(i.groupId);if(i!==n&&o)return this._redo(o)}try{return i.type===1?this._workspaceRedo(e,i):this._resourceRedo(t,i)}finally{}}}};UT=Gce([P7(0,vC),P7(1,Qi)],UT);class T1{constructor(e){this.returnValue=e}}_t(Mx,UT,1);function co(s,e,t){return Math.min(Math.max(s,e),t)}class Cz{constructor(){this._n=1,this._val=0}update(e){return this._val=this._val+(e-this._val)/this._n,this._n+=1,this._val}get value(){return this._val}}class Yce{constructor(e){this._n=0,this._val=0,this._values=[],this._index=0,this._sum=0,this._values=new Array(e),this._values.fill(0,0,e)}update(e){const t=this._values[this._index];return this._values[this._index]=e,this._index=(this._index+1)%this._values.length,this._sum-=t,this._sum+=e,this._n<this._values.length&&(this._n+=1),this._val=this._sum/this._n,this._val}get value(){return this._val}}const YP=ut("environmentService");var Xce=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},B7=function(s,e){return function(t,i){e(t,i,s)}};const Er=ut("ILanguageFeatureDebounceService");var fy;(function(s){const e=new WeakMap;let t=0;function i(n){let o=e.get(n);return o===void 0&&(o=++t,e.set(n,o)),o}s.of=i})(fy||(fy={}));class Qce{constructor(e){this._default=e}get(e){return this._default}update(e,t){return this._default}default(){return this._default}}class Jce{constructor(e,t,i,n,o,r){this._logService=e,this._name=t,this._registry=i,this._default=n,this._min=o,this._max=r,this._cache=new nh(50,.7)}_key(e){return e.id+this._registry.all(e).reduce((t,i)=>rx(fy.of(i),t),0)}get(e){const t=this._key(e),i=this._cache.get(t);return i?co(i.value,this._min,this._max):this.default()}update(e,t){const i=this._key(e);let n=this._cache.get(i);n||(n=new Yce(6),this._cache.set(i,n));const o=co(n.update(t),this._min,this._max);return YA(e.uri,"output")||this._logService.trace(`[DEBOUNCE: ${this._name}] for ${e.uri.toString()} is ${o}ms`),o}_overall(){const e=new Cz;for(const[,t]of this._cache)e.update(t.value);return e.value}default(){const e=this._overall()|0||this._default;return co(e,this._min,this._max)}}let $T=class{constructor(e,t){this._logService=e,this._data=new Map,this._isDev=t.isExtensionDevelopment||!t.isBuilt}for(e,t,i){var n,o,r;const a=(n=i==null?void 0:i.min)!==null&&n!==void 0?n:50,l=(o=i==null?void 0:i.max)!==null&&o!==void 0?o:a**2,d=(r=i==null?void 0:i.key)!==null&&r!==void 0?r:void 0,c=`${fy.of(e)},${a}${d?","+d:""}`;let u=this._data.get(c);return u||(this._isDev?u=new Jce(this._logService,t,e,this._overallAverage()|0||a*1.5,a,l):(this._logService.debug(`[DEBOUNCE: ${t}] is disabled in developed mode`),u=new Qce(a*1.5)),this._data.set(c,u)),u}_overallAverage(){const e=new Cz;for(const t of this._data.values())e.update(t.default());return e.value}};$T=Xce([B7(0,ko),B7(1,YP)],$T);_t(Er,$T,1);class Yv{static create(e,t){return new Yv(e,new py(t))}get startLineNumber(){return this._startLineNumber}get endLineNumber(){return this._endLineNumber}constructor(e,t){this._startLineNumber=e,this._tokens=t,this._endLineNumber=this._startLineNumber+this._tokens.getMaxDeltaLine()}toString(){return this._tokens.toString(this._startLineNumber)}_updateEndLineNumber(){this._endLineNumber=this._startLineNumber+this._tokens.getMaxDeltaLine()}isEmpty(){return this._tokens.isEmpty()}getLineTokens(e){return this._startLineNumber<=e&&e<=this._endLineNumber?this._tokens.getLineTokens(e-this._startLineNumber):null}getRange(){const e=this._tokens.getRange();return e&&new D(this._startLineNumber+e.startLineNumber,e.startColumn,this._startLineNumber+e.endLineNumber,e.endColumn)}removeTokens(e){const t=e.startLineNumber-this._startLineNumber,i=e.endLineNumber-this._startLineNumber;this._startLineNumber+=this._tokens.removeTokens(t,e.startColumn-1,i,e.endColumn-1),this._updateEndLineNumber()}split(e){const t=e.startLineNumber-this._startLineNumber,i=e.endLineNumber-this._startLineNumber,[n,o,r]=this._tokens.split(t,e.startColumn-1,i,e.endColumn-1);return[new Yv(this._startLineNumber,n),new Yv(this._startLineNumber+r,o)]}applyEdit(e,t){const[i,n,o]=Ou(t);this.acceptEdit(e,i,n,o,t.length>0?t.charCodeAt(0):0)}acceptEdit(e,t,i,n,o){this._acceptDeleteRange(e),this._acceptInsertText(new H(e.startLineNumber,e.startColumn),t,i,n,o),this._updateEndLineNumber()}_acceptDeleteRange(e){if(e.startLineNumber===e.endLineNumber&&e.startColumn===e.endColumn)return;const t=e.startLineNumber-this._startLineNumber,i=e.endLineNumber-this._startLineNumber;if(i<0){const o=i-t;this._startLineNumber-=o;return}const n=this._tokens.getMaxDeltaLine();if(!(t>=n+1)){if(t<0&&i>=n+1){this._startLineNumber=0,this._tokens.clear();return}if(t<0){const o=-t;this._startLineNumber-=o,this._tokens.acceptDeleteRange(e.startColumn-1,0,0,i,e.endColumn-1)}else this._tokens.acceptDeleteRange(0,t,e.startColumn-1,i,e.endColumn-1)}}_acceptInsertText(e,t,i,n,o){if(t===0&&i===0)return;const r=e.lineNumber-this._startLineNumber;if(r<0){this._startLineNumber+=t;return}const a=this._tokens.getMaxDeltaLine();r>=a+1||this._tokens.acceptInsertText(r,e.column-1,t,i,n,o)}}class py{constructor(e){this._tokens=e,this._tokenCount=e.length/4}toString(e){const t=[];for(let i=0;i<this._tokenCount;i++)t.push(`(${this._getDeltaLine(i)+e},${this._getStartCharacter(i)}-${this._getEndCharacter(i)})`);return`[${t.join(",")}]`}getMaxDeltaLine(){const e=this._getTokenCount();return e===0?-1:this._getDeltaLine(e-1)}getRange(){const e=this._getTokenCount();if(e===0)return null;const t=this._getStartCharacter(0),i=this._getDeltaLine(e-1),n=this._getEndCharacter(e-1);return new D(0,t+1,i,n+1)}_getTokenCount(){return this._tokenCount}_getDeltaLine(e){return this._tokens[4*e]}_getStartCharacter(e){return this._tokens[4*e+1]}_getEndCharacter(e){return this._tokens[4*e+2]}isEmpty(){return this._getTokenCount()===0}getLineTokens(e){let t=0,i=this._getTokenCount()-1;for(;t<i;){const n=t+Math.floor((i-t)/2),o=this._getDeltaLine(n);if(o<e)t=n+1;else if(o>e)i=n-1;else{let r=n;for(;r>t&&this._getDeltaLine(r-1)===e;)r--;let a=n;for(;a<i&&this._getDeltaLine(a+1)===e;)a++;return new W7(this._tokens.subarray(4*r,4*a+4))}}return this._getDeltaLine(t)===e?new W7(this._tokens.subarray(4*t,4*t+4)):null}clear(){this._tokenCount=0}removeTokens(e,t,i,n){const o=this._tokens,r=this._tokenCount;let a=0,l=!1,d=0;for(let c=0;c<r;c++){const u=4*c,h=o[u],g=o[u+1],f=o[u+2],m=o[u+3];if((h>e||h===e&&f>=t)&&(h<i||h===i&&g<=n))l=!0;else{if(a===0&&(d=h),l){const _=4*a;o[_]=h-d,o[_+1]=g,o[_+2]=f,o[_+3]=m}a++}}return this._tokenCount=a,d}split(e,t,i,n){const o=this._tokens,r=this._tokenCount,a=[],l=[];let d=a,c=0,u=0;for(let h=0;h<r;h++){const g=4*h,f=o[g],m=o[g+1],_=o[g+2],v=o[g+3];if(f>e||f===e&&_>=t){if(f<i||f===i&&m<=n)continue;d!==l&&(d=l,c=0,u=f)}d[c++]=f-u,d[c++]=m,d[c++]=_,d[c++]=v}return[new py(new Uint32Array(a)),new py(new Uint32Array(l)),u]}acceptDeleteRange(e,t,i,n,o){const r=this._tokens,a=this._tokenCount,l=n-t;let d=0,c=!1;for(let u=0;u<a;u++){const h=4*u;let g=r[h],f=r[h+1],m=r[h+2];const _=r[h+3];if(g<t||g===t&&m<=i){d++;continue}else if(g===t&&f<i)g===n&&m>o?m-=o-i:m=i;else if(g===t&&f===i)if(g===n&&m>o)m-=o-i;else{c=!0;continue}else if(g<n||g===n&&f<o)if(g===n&&m>o)g=t,f=i,m=f+(m-o);else{c=!0;continue}else if(g>n){if(l===0&&!c){d=a;break}g-=l}else if(g===n&&f>=o)e&&g===0&&(f+=e,m+=e),g-=l,f-=o-i,m-=o-i;else throw new Error("Not possible!");const v=4*d;r[v]=g,r[v+1]=f,r[v+2]=m,r[v+3]=_,d++}this._tokenCount=d}acceptInsertText(e,t,i,n,o,r){const a=i===0&&n===1&&(r>=48&&r<=57||r>=65&&r<=90||r>=97&&r<=122),l=this._tokens,d=this._tokenCount;for(let c=0;c<d;c++){const u=4*c;let h=l[u],g=l[u+1],f=l[u+2];if(!(h<e||h===e&&f<t)){if(h===e&&f===t)if(a)f+=1;else continue;else if(h===e&&g<t&&t<f)i===0?f+=n:f=t;else{if(h===e&&g===t&&a)continue;if(h===e)if(h+=i,i===0)g+=n,f+=n;else{const m=f-g;g=o+(g-t),f=g+m}else h+=i}l[u]=h,l[u+1]=g,l[u+2]=f}}}}class W7{constructor(e){this._tokens=e}getCount(){return this._tokens.length/4}getStartCharacter(e){return this._tokens[4*e+1]}getEndCharacter(e){return this._tokens[4*e+2]}getMetadata(e){return this._tokens[4*e+3]}}var eue=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},DI=function(s,e){return function(t,i){e(t,i,s)}};let jT=class{constructor(e,t,i,n){this._legend=e,this._themeService=t,this._languageService=i,this._logService=n,this._hasWarnedOverlappingTokens=!1,this._hasWarnedInvalidLengthTokens=!1,this._hasWarnedInvalidEditStart=!1,this._hashTable=new Dd}getMetadata(e,t,i){const n=this._languageService.languageIdCodec.encodeLanguageId(i),o=this._hashTable.get(e,t,n);let r;if(o)r=o.metadata,this._logService.getLevel()===Gn.Trace&&this._logService.trace(`SemanticTokensProviderStyling [CACHED] ${e} / ${t}: foreground ${Zn.getForeground(r)}, fontStyle ${Zn.getFontStyle(r).toString(2)}`);else{let a=this._legend.tokenTypes[e];const l=[];if(a){let d=t;for(let u=0;d>0&&u<this._legend.tokenModifiers.length;u++)d&1&&l.push(this._legend.tokenModifiers[u]),d=d>>1;d>0&&this._logService.getLevel()===Gn.Trace&&(this._logService.trace(`SemanticTokensProviderStyling: unknown token modifier index: ${t.toString(2)} for legend: ${JSON.stringify(this._legend.tokenModifiers)}`),l.push("not-in-legend"));const c=this._themeService.getColorTheme().getTokenStyleMetadata(a,l,i);if(typeof c>"u")r=2147483647;else{if(r=0,typeof c.italic<"u"){const u=(c.italic?1:0)<<11;r|=u|1}if(typeof c.bold<"u"){const u=(c.bold?2:0)<<11;r|=u|2}if(typeof c.underline<"u"){const u=(c.underline?4:0)<<11;r|=u|4}if(typeof c.strikethrough<"u"){const u=(c.strikethrough?8:0)<<11;r|=u|8}if(c.foreground){const u=c.foreground<<15;r|=u|16}r===0&&(r=2147483647)}}else this._logService.getLevel()===Gn.Trace&&this._logService.trace(`SemanticTokensProviderStyling: unknown token type index: ${e} for legend: ${JSON.stringify(this._legend.tokenTypes)}`),r=2147483647,a="not-in-legend";this._hashTable.add(e,t,n,r),this._logService.getLevel()===Gn.Trace&&this._logService.trace(`SemanticTokensProviderStyling ${e} (${a}) / ${t} (${l.join(" ")}): foreground ${Zn.getForeground(r)}, fontStyle ${Zn.getFontStyle(r).toString(2)}`)}return r}warnOverlappingSemanticTokens(e,t){this._hasWarnedOverlappingTokens||(this._hasWarnedOverlappingTokens=!0,console.warn(`Overlapping semantic tokens detected at lineNumber ${e}, column ${t}`))}warnInvalidLengthSemanticTokens(e,t){this._hasWarnedInvalidLengthTokens||(this._hasWarnedInvalidLengthTokens=!0,console.warn(`Semantic token with invalid length detected at lineNumber ${e}, column ${t}`))}warnInvalidEditStart(e,t,i,n,o){this._hasWarnedInvalidEditStart||(this._hasWarnedInvalidEditStart=!0,console.warn(`Invalid semantic tokens edit detected (previousResultId: ${e}, resultId: ${t}) at edit #${i}: The provided start offset ${n} is outside the previous data (length ${o}).`))}};jT=eue([DI(1,Cn),DI(2,fi),DI(3,ko)],jT);function wz(s,e,t){const i=s.data,n=s.data.length/5|0,o=Math.max(Math.ceil(n/1024),400),r=[];let a=0,l=1,d=0;for(;a<n;){const c=a;let u=Math.min(c+o,n);if(u<n){let b=u;for(;b-1>c&&i[5*b]===0;)b--;if(b-1===c){let C=u;for(;C+1<n&&i[5*C]===0;)C++;u=C}else u=b}let h=new Uint32Array((u-c)*4),g=0,f=0,m=0,_=0;for(;a<u;){const b=5*a,C=i[b],w=i[b+1],S=l+C|0,x=C===0?d+w|0:w,L=i[b+2],k=x+L|0,I=i[b+3],P=i[b+4];if(k<=x)e.warnInvalidLengthSemanticTokens(S,x+1);else if(m===S&&_>x)e.warnOverlappingSemanticTokens(S,x+1);else{const $=e.getMetadata(I,P,t);$!==2147483647&&(f===0&&(f=S),h[g]=S-f,h[g+1]=x,h[g+2]=k,h[g+3]=$,g+=4,m=S,_=k)}l=S,d=x,a++}g!==h.length&&(h=h.subarray(0,g));const v=Yv.create(f,h);r.push(v)}return r}class tue{constructor(e,t,i,n){this.tokenTypeIndex=e,this.tokenModifierSet=t,this.languageId=i,this.metadata=n,this.next=null}}class Dd{constructor(){this._elementsCount=0,this._currentLengthIndex=0,this._currentLength=Dd._SIZES[this._currentLengthIndex],this._growCount=Math.round(this._currentLengthIndex+1<Dd._SIZES.length?2/3*this._currentLength:0),this._elements=[],Dd._nullOutEntries(this._elements,this._currentLength)}static _nullOutEntries(e,t){for(let i=0;i<t;i++)e[i]=null}_hash2(e,t){return(e<<5)-e+t|0}_hashFunc(e,t,i){return this._hash2(this._hash2(e,t),i)%this._currentLength}get(e,t,i){const n=this._hashFunc(e,t,i);let o=this._elements[n];for(;o;){if(o.tokenTypeIndex===e&&o.tokenModifierSet===t&&o.languageId===i)return o;o=o.next}return null}add(e,t,i,n){if(this._elementsCount++,this._growCount!==0&&this._elementsCount>=this._growCount){const o=this._elements;this._currentLengthIndex++,this._currentLength=Dd._SIZES[this._currentLengthIndex],this._growCount=Math.round(this._currentLengthIndex+1<Dd._SIZES.length?2/3*this._currentLength:0),this._elements=[],Dd._nullOutEntries(this._elements,this._currentLength);for(const r of o){let a=r;for(;a;){const l=a.next;a.next=null,this._add(a),a=l}}}this._add(new tue(e,t,i,n))}_add(e){const t=this._hashFunc(e.tokenTypeIndex,e.tokenModifierSet,e.languageId);e.next=this._elements[t],this._elements[t]=e}}Dd._SIZES=[3,7,13,31,61,127,251,509,1021,2039,4093,8191,16381,32749,65521,131071,262139,524287,1048573,2097143];const Ax=ut("semanticTokensStylingService");var iue=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},kI=function(s,e){return function(t,i){e(t,i,s)}};let KT=class extends j{constructor(e,t,i){super(),this._themeService=e,this._logService=t,this._languageService=i,this._caches=new WeakMap,this._register(this._themeService.onDidColorThemeChange(()=>{this._caches=new WeakMap}))}getStyling(e){return this._caches.has(e)||this._caches.set(e,new jT(e.getLegend(),this._themeService,this._languageService,this._logService)),this._caches.get(e)}};KT=iue([kI(0,Cn),kI(1,ko),kI(2,fi)],KT);_t(Ax,KT,1);const M1="**",V7="/",$w="[/\\\\]",jw="[^/\\\\]",nue=/\//g;function H7(s,e){switch(s){case 0:return"";case 1:return`${jw}*?`;default:return`(?:${$w}|${jw}+${$w}${e?`|${$w}${jw}+`:""})*?`}}function z7(s,e){if(!s)return[];const t=[];let i=!1,n=!1,o="";for(const r of s){switch(r){case e:if(!i&&!n){t.push(o),o="";continue}break;case"{":i=!0;break;case"}":i=!1;break;case"[":n=!0;break;case"]":n=!1;break}o+=r}return o&&t.push(o),t}function Sz(s){if(!s)return"";let e="";const t=z7(s,V7);if(t.every(i=>i===M1))e=".*";else{let i=!1;t.forEach((n,o)=>{if(n===M1){if(i)return;e+=H7(2,o===t.length-1)}else{let r=!1,a="",l=!1,d="";for(const c of n){if(c!=="}"&&r){a+=c;continue}if(l&&(c!=="]"||!d)){let u;c==="-"?u=c:(c==="^"||c==="!")&&!d?u="^":c===V7?u="":u=ir(c),d+=u;continue}switch(c){case"{":r=!0;continue;case"[":l=!0;continue;case"}":{const h=`(?:${z7(a,",").map(g=>Sz(g)).join("|")})`;e+=h,r=!1,a="";break}case"]":{e+="["+d+"]",l=!1,d="";break}case"?":e+=jw;continue;case"*":e+=H7(1);continue;default:e+=ir(c)}}o<t.length-1&&(t[o+1]!==M1||o+2<t.length)&&(e+=$w)}i=n===M1})}return e}const sue=/^\*\*\/\*\.[\w\.-]+$/,oue=/^\*\*\/([\w\.-]+)\/?$/,rue=/^{\*\*\/\*?[\w\.-]+\/?(,\*\*\/\*?[\w\.-]+\/?)*}$/,aue=/^{\*\*\/\*?[\w\.-]+(\/(\*\*)?)?(,\*\*\/\*?[\w\.-]+(\/(\*\*)?)?)*}$/,lue=/^\*\*((\/[\w\.-]+)+)\/?$/,due=/^([\w\.-]+(\/[\w\.-]+)*)\/?$/,U7=new nh(1e4),$7=function(){return!1},Hl=function(){return null};function XP(s,e){if(!s)return Hl;let t;typeof s!="string"?t=s.pattern:t=s,t=t.trim();const i=`${t}_${!!e.trimForExclusions}`;let n=U7.get(i);if(n)return j7(n,s);let o;return sue.test(t)?n=cue(t.substr(4),t):(o=oue.exec(II(t,e)))?n=uue(o[1],t):(e.trimForExclusions?aue:rue).test(t)?n=hue(t,e):(o=lue.exec(II(t,e)))?n=K7(o[1].substr(1),t,!0):(o=due.exec(II(t,e)))?n=K7(o[1],t,!1):n=gue(t),U7.set(i,n),j7(n,s)}function j7(s,e){if(typeof e=="string")return s;const t=function(i,n){return ET(i,e.base,!Ss)?s(iC(i.substr(e.base.length),Aa),n):null};return t.allBasenames=s.allBasenames,t.allPaths=s.allPaths,t.basenames=s.basenames,t.patterns=s.patterns,t}function II(s,e){return e.trimForExclusions&&s.endsWith("/**")?s.substr(0,s.length-2):s}function cue(s,e){return function(t,i){return typeof t=="string"&&t.endsWith(s)?e:null}}function uue(s,e){const t=`/${s}`,i=`\\${s}`,n=function(r,a){return typeof r!="string"?null:a?a===s?e:null:r===s||r.endsWith(t)||r.endsWith(i)?e:null},o=[s];return n.basenames=o,n.patterns=[e],n.allBasenames=o,n}function hue(s,e){const t=Lz(s.slice(1,-1).split(",").map(a=>XP(a,e)).filter(a=>a!==Hl),s),i=t.length;if(!i)return Hl;if(i===1)return t[0];const n=function(a,l){for(let d=0,c=t.length;d<c;d++)if(t[d](a,l))return s;return null},o=t.find(a=>!!a.allBasenames);o&&(n.allBasenames=o.allBasenames);const r=t.reduce((a,l)=>l.allPaths?a.concat(l.allPaths):a,[]);return r.length&&(n.allPaths=r),n}function K7(s,e,t){const i=Aa===an.sep,n=i?s:s.replace(nue,Aa),o=Aa+n,r=an.sep+s;let a;return t?a=function(l,d){return typeof l=="string"&&(l===n||l.endsWith(o)||!i&&(l===s||l.endsWith(r)))?e:null}:a=function(l,d){return typeof l=="string"&&(l===n||!i&&l===s)?e:null},a.allPaths=[(t?"*/":"./")+s],a}function gue(s){try{const e=new RegExp(`^${Sz(s)}$`);return function(t){return e.lastIndex=0,typeof t=="string"&&e.test(t)?s:null}}catch{return Hl}}function fue(s,e,t){return!s||typeof e!="string"?!1:yz(s)(e,void 0,t)}function yz(s,e={}){if(!s)return $7;if(typeof s=="string"||pue(s)){const t=XP(s,e);if(t===Hl)return $7;const i=function(n,o){return!!t(n,o)};return t.allBasenames&&(i.allBasenames=t.allBasenames),t.allPaths&&(i.allPaths=t.allPaths),i}return mue(s,e)}function pue(s){const e=s;return e?typeof e.base=="string"&&typeof e.pattern=="string":!1}function mue(s,e){const t=Lz(Object.getOwnPropertyNames(s).map(a=>_ue(a,s[a],e)).filter(a=>a!==Hl)),i=t.length;if(!i)return Hl;if(!t.some(a=>!!a.requiresSiblings)){if(i===1)return t[0];const a=function(c,u){let h;for(let g=0,f=t.length;g<f;g++){const m=t[g](c,u);if(typeof m=="string")return m;qN(m)&&(h||(h=[]),h.push(m))}return h?(async()=>{for(const g of h){const f=await g;if(typeof f=="string")return f}return null})():null},l=t.find(c=>!!c.allBasenames);l&&(a.allBasenames=l.allBasenames);const d=t.reduce((c,u)=>u.allPaths?c.concat(u.allPaths):c,[]);return d.length&&(a.allPaths=d),a}const n=function(a,l,d){let c,u;for(let h=0,g=t.length;h<g;h++){const f=t[h];f.requiresSiblings&&d&&(l||(l=ru(a)),c||(c=l.substr(0,l.length-FQ(a).length)));const m=f(a,l,c,d);if(typeof m=="string")return m;qN(m)&&(u||(u=[]),u.push(m))}return u?(async()=>{for(const h of u){const g=await h;if(typeof g=="string")return g}return null})():null},o=t.find(a=>!!a.allBasenames);o&&(n.allBasenames=o.allBasenames);const r=t.reduce((a,l)=>l.allPaths?a.concat(l.allPaths):a,[]);return r.length&&(n.allPaths=r),n}function _ue(s,e,t){if(e===!1)return Hl;const i=XP(s,t);if(i===Hl)return Hl;if(typeof e=="boolean")return i;if(e){const n=e.when;if(typeof n=="string"){const o=(r,a,l,d)=>{if(!d||!i(r,a))return null;const c=n.replace("$(basename)",()=>l),u=d(c);return qN(u)?u.then(h=>h?s:null):u?s:null};return o.requiresSiblings=!0,o}}return i}function Lz(s,e){const t=s.filter(a=>!!a.basenames);if(t.length<2)return s;const i=t.reduce((a,l)=>{const d=l.basenames;return d?a.concat(d):a},[]);let n;if(e){n=[];for(let a=0,l=i.length;a<l;a++)n.push(e)}else n=t.reduce((a,l)=>{const d=l.patterns;return d?a.concat(d):a},[]);const o=function(a,l){if(typeof a!="string")return null;if(!l){let c;for(c=a.length;c>0;c--){const u=a.charCodeAt(c-1);if(u===47||u===92)break}l=a.substr(c)}const d=i.indexOf(l);return d!==-1?n[d]:null};o.basenames=i,o.patterns=n,o.allBasenames=i;const r=s.filter(a=>!a.basenames);return r.push(o),r}function QP(s,e,t,i,n,o){if(Array.isArray(s)){let r=0;for(const a of s){const l=QP(a,e,t,i,n,o);if(l===10)return l;l>r&&(r=l)}return r}else{if(typeof s=="string")return i?s==="*"?5:s===t?10:0:0;if(s){const{language:r,pattern:a,scheme:l,hasAccessToAllModels:d,notebookType:c}=s;if(!i&&!d)return 0;c&&n&&(e=n);let u=0;if(l)if(l===e.scheme)u=10;else if(l==="*")u=5;else return 0;if(r)if(r===t)u=10;else if(r==="*")u=Math.max(u,5);else return 0;if(c)if(c===o)u=10;else if(c==="*"&&o!==void 0)u=Math.max(u,5);else return 0;if(a){let h;if(typeof a=="string"?h=a:h={...a,base:MW(a.base)},h===e.fsPath||fue(h,e.fsPath))u=10;else return 0}return u}else return 0}}function xz(s){return typeof s=="string"?!1:Array.isArray(s)?s.every(xz):!!s.exclusive}class q7{constructor(e,t,i,n){this.uri=e,this.languageId=t,this.notebookUri=i,this.notebookType=n}equals(e){var t,i;return this.notebookType===e.notebookType&&this.languageId===e.languageId&&this.uri.toString()===e.uri.toString()&&((t=this.notebookUri)===null||t===void 0?void 0:t.toString())===((i=e.notebookUri)===null||i===void 0?void 0:i.toString())}}class Li{constructor(e){this._notebookInfoResolver=e,this._clock=0,this._entries=[],this._onDidChange=new W,this.onDidChange=this._onDidChange.event}register(e,t){let i={selector:e,provider:t,_score:-1,_time:this._clock++};return this._entries.push(i),this._lastCandidate=void 0,this._onDidChange.fire(this._entries.length),Fe(()=>{if(i){const n=this._entries.indexOf(i);n>=0&&(this._entries.splice(n,1),this._lastCandidate=void 0,this._onDidChange.fire(this._entries.length),i=void 0)}})}has(e){return this.all(e).length>0}all(e){if(!e)return[];this._updateScores(e);const t=[];for(const i of this._entries)i._score>0&&t.push(i.provider);return t}ordered(e){const t=[];return this._orderedForEach(e,i=>t.push(i.provider)),t}orderedGroups(e){const t=[];let i,n;return this._orderedForEach(e,o=>{i&&n===o._score?i.push(o.provider):(n=o._score,i=[o.provider],t.push(i))}),t}_orderedForEach(e,t){this._updateScores(e);for(const i of this._entries)i._score>0&&t(i)}_updateScores(e){var t,i;const n=(t=this._notebookInfoResolver)===null||t===void 0?void 0:t.call(this,e.uri),o=n?new q7(e.uri,e.getLanguageId(),n.uri,n.type):new q7(e.uri,e.getLanguageId(),void 0,void 0);if(!(!((i=this._lastCandidate)===null||i===void 0)&&i.equals(o))){this._lastCandidate=o;for(const r of this._entries)if(r._score=QP(r.selector,o.uri,o.languageId,mie(e),o.notebookUri,o.notebookType),xz(r.selector)&&r._score>0){for(const a of this._entries)a._score=0;r._score=1e3;break}this._entries.sort(Li._compareByScoreAndTime)}}static _compareByScoreAndTime(e,t){return e._score<t._score?1:e._score>t._score?-1:_v(e.selector)&&!_v(t.selector)?1:!_v(e.selector)&&_v(t.selector)?-1:e._time<t._time?1:e._time>t._time?-1:0}}function _v(s){return typeof s=="string"?!1:Array.isArray(s)?s.some(_v):!!s.isBuiltin}class vue{constructor(){this.referenceProvider=new Li(this._score.bind(this)),this.renameProvider=new Li(this._score.bind(this)),this.codeActionProvider=new Li(this._score.bind(this)),this.definitionProvider=new Li(this._score.bind(this)),this.typeDefinitionProvider=new Li(this._score.bind(this)),this.declarationProvider=new Li(this._score.bind(this)),this.implementationProvider=new Li(this._score.bind(this)),this.documentSymbolProvider=new Li(this._score.bind(this)),this.inlayHintsProvider=new Li(this._score.bind(this)),this.colorProvider=new Li(this._score.bind(this)),this.codeLensProvider=new Li(this._score.bind(this)),this.documentFormattingEditProvider=new Li(this._score.bind(this)),this.documentRangeFormattingEditProvider=new Li(this._score.bind(this)),this.onTypeFormattingEditProvider=new Li(this._score.bind(this)),this.signatureHelpProvider=new Li(this._score.bind(this)),this.hoverProvider=new Li(this._score.bind(this)),this.documentHighlightProvider=new Li(this._score.bind(this)),this.multiDocumentHighlightProvider=new Li(this._score.bind(this)),this.selectionRangeProvider=new Li(this._score.bind(this)),this.foldingRangeProvider=new Li(this._score.bind(this)),this.linkProvider=new Li(this._score.bind(this)),this.inlineCompletionsProvider=new Li(this._score.bind(this)),this.completionProvider=new Li(this._score.bind(this)),this.linkedEditingRangeProvider=new Li(this._score.bind(this)),this.documentRangeSemanticTokensProvider=new Li(this._score.bind(this)),this.documentSemanticTokensProvider=new Li(this._score.bind(this)),this.documentOnDropEditProvider=new Li(this._score.bind(this)),this.documentPasteEditProvider=new Li(this._score.bind(this))}_score(e){var t;return(t=this._notebookTypeResolver)===null||t===void 0?void 0:t.call(this,e)}}_t(xe,vue,1);const bC=ut("IWorkspaceEditService");class JP{constructor(e){this.metadata=e}static convert(e){return e.edits.map(t=>{if(qd.is(t))return qd.lift(t);if(qp.is(t))return qp.lift(t);throw new Error("Unsupported edit")})}}class qd extends JP{static is(e){return e instanceof qd?!0:Ts(e)&&Pe.isUri(e.resource)&&Ts(e.textEdit)}static lift(e){return e instanceof qd?e:new qd(e.resource,e.textEdit,e.versionId,e.metadata)}constructor(e,t,i=void 0,n){super(n),this.resource=e,this.textEdit=t,this.versionId=i}}class qp extends JP{static is(e){return e instanceof qp?!0:Ts(e)&&(!!e.newResource||!!e.oldResource)}static lift(e){return e instanceof qp?e:new qp(e.oldResource,e.newResource,e.options,e.metadata)}constructor(e,t,i={},n){super(n),this.oldResource=e,this.newResource=t,this.options=i}}const ps={enableSplitViewResizing:!0,splitViewDefaultRatio:.5,renderSideBySide:!0,renderMarginRevertIcon:!0,maxComputationTime:5e3,maxFileSize:50,ignoreTrimWhitespace:!0,renderIndicators:!0,originalEditable:!1,diffCodeLens:!1,renderOverviewRuler:!0,diffWordWrap:"inherit",diffAlgorithm:"advanced",accessibilityVerbose:!1,experimental:{showMoves:!1,showEmptyDecorations:!0},hideUnchangedRegions:{enabled:!1,contextLineCount:3,minimumLineCount:3,revealLineCount:20},isInEmbeddedEditor:!1,onlyShowAccessibleDiffViewer:!1,renderSideBySideInlineBreakpoint:900,useInlineViewWhenSpaceIsLimited:!0},Px=Object.freeze({id:"editor",order:5,type:"object",title:p("editorConfigurationTitle","Editor"),scope:5}),my={...Px,properties:{"editor.tabSize":{type:"number",default:os.tabSize,minimum:1,markdownDescription:p("tabSize","The number of spaces a tab is equal to. This setting is overridden based on the file contents when {0} is on.","`#editor.detectIndentation#`")},"editor.indentSize":{anyOf:[{type:"string",enum:["tabSize"]},{type:"number",minimum:1}],default:"tabSize",markdownDescription:p("indentSize",'The number of spaces used for indentation or `"tabSize"` to use the value from `#editor.tabSize#`. This setting is overridden based on the file contents when `#editor.detectIndentation#` is on.')},"editor.insertSpaces":{type:"boolean",default:os.insertSpaces,markdownDescription:p("insertSpaces","Insert spaces when pressing `Tab`. This setting is overridden based on the file contents when {0} is on.","`#editor.detectIndentation#`")},"editor.detectIndentation":{type:"boolean",default:os.detectIndentation,markdownDescription:p("detectIndentation","Controls whether {0} and {1} will be automatically detected when a file is opened based on the file contents.","`#editor.tabSize#`","`#editor.insertSpaces#`")},"editor.trimAutoWhitespace":{type:"boolean",default:os.trimAutoWhitespace,description:p("trimAutoWhitespace","Remove trailing auto inserted whitespace.")},"editor.largeFileOptimizations":{type:"boolean",default:os.largeFileOptimizations,description:p("largeFileOptimizations","Special handling for large files to disable certain memory intensive features.")},"editor.wordBasedSuggestions":{enum:["off","currentDocument","matchingDocuments","allDocuments"],default:"matchingDocuments",enumDescriptions:[p("wordBasedSuggestions.off","Turn off Word Based Suggestions."),p("wordBasedSuggestions.currentDocument","Only suggest words from the active document."),p("wordBasedSuggestions.matchingDocuments","Suggest words from all open documents of the same language."),p("wordBasedSuggestions.allDocuments","Suggest words from all open documents.")],description:p("wordBasedSuggestions","Controls whether completions should be computed based on words in the document and from which documents they are computed.")},"editor.semanticHighlighting.enabled":{enum:[!0,!1,"configuredByTheme"],enumDescriptions:[p("semanticHighlighting.true","Semantic highlighting enabled for all color themes."),p("semanticHighlighting.false","Semantic highlighting disabled for all color themes."),p("semanticHighlighting.configuredByTheme","Semantic highlighting is configured by the current color theme's `semanticHighlighting` setting.")],default:"configuredByTheme",description:p("semanticHighlighting.enabled","Controls whether the semanticHighlighting is shown for the languages that support it.")},"editor.stablePeek":{type:"boolean",default:!1,markdownDescription:p("stablePeek","Keep peek editors open even when double-clicking their content or when hitting `Escape`.")},"editor.maxTokenizationLineLength":{type:"integer",default:2e4,description:p("maxTokenizationLineLength","Lines above this length will not be tokenized for performance reasons")},"editor.experimental.asyncTokenization":{type:"boolean",default:!1,description:p("editor.experimental.asyncTokenization","Controls whether the tokenization should happen asynchronously on a web worker."),tags:["experimental"]},"editor.experimental.asyncTokenizationLogging":{type:"boolean",default:!1,description:p("editor.experimental.asyncTokenizationLogging","Controls whether async tokenization should be logged. For debugging only.")},"editor.experimental.asyncTokenizationVerification":{type:"boolean",default:!1,description:p("editor.experimental.asyncTokenizationVerification","Controls whether async tokenization should be verified against legacy background tokenization. Might slow down tokenization. For debugging only."),tags:["experimental"]},"editor.language.brackets":{type:["array","null"],default:null,description:p("schema.brackets","Defines the bracket symbols that increase or decrease the indentation."),items:{type:"array",items:[{type:"string",description:p("schema.openBracket","The opening bracket character or string sequence.")},{type:"string",description:p("schema.closeBracket","The closing bracket character or string sequence.")}]}},"editor.language.colorizedBracketPairs":{type:["array","null"],default:null,description:p("schema.colorizedBracketPairs","Defines the bracket pairs that are colorized by their nesting level if bracket pair colorization is enabled."),items:{type:"array",items:[{type:"string",description:p("schema.openBracket","The opening bracket character or string sequence.")},{type:"string",description:p("schema.closeBracket","The closing bracket character or string sequence.")}]}},"diffEditor.maxComputationTime":{type:"number",default:ps.maxComputationTime,description:p("maxComputationTime","Timeout in milliseconds after which diff computation is cancelled. Use 0 for no timeout.")},"diffEditor.maxFileSize":{type:"number",default:ps.maxFileSize,description:p("maxFileSize","Maximum file size in MB for which to compute diffs. Use 0 for no limit.")},"diffEditor.renderSideBySide":{type:"boolean",default:ps.renderSideBySide,description:p("sideBySide","Controls whether the diff editor shows the diff side by side or inline.")},"diffEditor.renderSideBySideInlineBreakpoint":{type:"number",default:ps.renderSideBySideInlineBreakpoint,description:p("renderSideBySideInlineBreakpoint","If the diff editor width is smaller than this value, the inline view is used.")},"diffEditor.useInlineViewWhenSpaceIsLimited":{type:"boolean",default:ps.useInlineViewWhenSpaceIsLimited,description:p("useInlineViewWhenSpaceIsLimited","If enabled and the editor width is too small, the inline view is used.")},"diffEditor.renderMarginRevertIcon":{type:"boolean",default:ps.renderMarginRevertIcon,description:p("renderMarginRevertIcon","When enabled, the diff editor shows arrows in its glyph margin to revert changes.")},"diffEditor.ignoreTrimWhitespace":{type:"boolean",default:ps.ignoreTrimWhitespace,description:p("ignoreTrimWhitespace","When enabled, the diff editor ignores changes in leading or trailing whitespace.")},"diffEditor.renderIndicators":{type:"boolean",default:ps.renderIndicators,description:p("renderIndicators","Controls whether the diff editor shows +/- indicators for added/removed changes.")},"diffEditor.codeLens":{type:"boolean",default:ps.diffCodeLens,description:p("codeLens","Controls whether the editor shows CodeLens.")},"diffEditor.wordWrap":{type:"string",enum:["off","on","inherit"],default:ps.diffWordWrap,markdownEnumDescriptions:[p("wordWrap.off","Lines will never wrap."),p("wordWrap.on","Lines will wrap at the viewport width."),p("wordWrap.inherit","Lines will wrap according to the {0} setting.","`#editor.wordWrap#`")]},"diffEditor.diffAlgorithm":{type:"string",enum:["legacy","advanced"],default:ps.diffAlgorithm,markdownEnumDescriptions:[p("diffAlgorithm.legacy","Uses the legacy diffing algorithm."),p("diffAlgorithm.advanced","Uses the advanced diffing algorithm.")],tags:["experimental"]},"diffEditor.hideUnchangedRegions.enabled":{type:"boolean",default:ps.hideUnchangedRegions.enabled,markdownDescription:p("hideUnchangedRegions.enabled","Controls whether the diff editor shows unchanged regions.")},"diffEditor.hideUnchangedRegions.revealLineCount":{type:"integer",default:ps.hideUnchangedRegions.revealLineCount,markdownDescription:p("hideUnchangedRegions.revealLineCount","Controls how many lines are used for unchanged regions."),minimum:1},"diffEditor.hideUnchangedRegions.minimumLineCount":{type:"integer",default:ps.hideUnchangedRegions.minimumLineCount,markdownDescription:p("hideUnchangedRegions.minimumLineCount","Controls how many lines are used as a minimum for unchanged regions."),minimum:1},"diffEditor.hideUnchangedRegions.contextLineCount":{type:"integer",default:ps.hideUnchangedRegions.contextLineCount,markdownDescription:p("hideUnchangedRegions.contextLineCount","Controls how many lines are used as context when comparing unchanged regions."),minimum:1},"diffEditor.experimental.showMoves":{type:"boolean",default:ps.experimental.showMoves,markdownDescription:p("showMoves","Controls whether the diff editor should show detected code moves.")},"diffEditor.experimental.showEmptyDecorations":{type:"boolean",default:ps.experimental.showEmptyDecorations,description:p("showEmptyDecorations","Controls whether the diff editor shows empty decorations to see where characters got inserted or deleted.")}}};function bue(s){return typeof s.type<"u"||typeof s.anyOf<"u"}for(const s of ip){const e=s.schema;if(typeof e<"u")if(bue(e))my.properties[`editor.${s.name}`]=e;else for(const t in e)Object.hasOwnProperty.call(e,t)&&(my.properties[t]=e[t])}let R1=null;function Dz(){return R1===null&&(R1=Object.create(null),Object.keys(my.properties).forEach(s=>{R1[s]=!0})),R1}function Cue(s){return Dz()[`editor.${s}`]||!1}function wue(s){return Dz()[`diffEditor.${s}`]||!1}const Sue=Si.as(Za.Configuration);Sue.registerConfiguration(my);class _i{static insert(e,t){return{range:new D(e.lineNumber,e.column,e.lineNumber,e.column),text:t,forceMoveMarkers:!0}}static delete(e){return{range:e,text:null}}static replace(e,t){return{range:e,text:t}}static replaceMove(e,t){return{range:e,text:t,forceMoveMarkers:!0}}}function EI(s){return Object.isFrozen(s)?s:aX(s)}class ss{constructor(e={},t=[],i=[],n){this._contents=e,this._keys=t,this._overrides=i,this.raw=n,this.overrideConfigurations=new Map}get rawConfiguration(){var e;if(!this._rawConfiguration)if(!((e=this.raw)===null||e===void 0)&&e.length){const t=this.raw.map(i=>{if(i instanceof ss)return i;const n=new yue("");return n.parseRaw(i),n.configurationModel});this._rawConfiguration=t.reduce((i,n)=>n===i?n:i.merge(n),t[0])}else this._rawConfiguration=this;return this._rawConfiguration}get contents(){return this._contents}get overrides(){return this._overrides}get keys(){return this._keys}isEmpty(){return this._keys.length===0&&Object.keys(this._contents).length===0&&this._overrides.length===0}getValue(e){return e?P5(this.contents,e):this.contents}inspect(e,t){const i=this.rawConfiguration.getValue(e),n=t?this.rawConfiguration.getOverrideValue(e,t):void 0,o=t?this.rawConfiguration.override(t).getValue(e):i;return{value:i,override:n,merged:o}}getOverrideValue(e,t){const i=this.getContentsForOverrideIdentifer(t);return i?e?P5(i,e):i:void 0}override(e){let t=this.overrideConfigurations.get(e);return t||(t=this.createOverrideConfigurationModel(e),this.overrideConfigurations.set(e,t)),t}merge(...e){var t,i;const n=yd(this.contents),o=yd(this.overrides),r=[...this.keys],a=!((t=this.raw)===null||t===void 0)&&t.length?[...this.raw]:[this];for(const l of e)if(a.push(...!((i=l.raw)===null||i===void 0)&&i.length?l.raw:[l]),!l.isEmpty()){this.mergeContents(n,l.contents);for(const d of l.overrides){const[c]=o.filter(u=>Ai(u.identifiers,d.identifiers));c?(this.mergeContents(c.contents,d.contents),c.keys.push(...d.keys),c.keys=Lu(c.keys)):o.push(yd(d))}for(const d of l.keys)r.indexOf(d)===-1&&r.push(d)}return new ss(n,r,o,a.every(l=>l instanceof ss)?void 0:a)}createOverrideConfigurationModel(e){const t=this.getContentsForOverrideIdentifer(e);if(!t||typeof t!="object"||!Object.keys(t).length)return this;const i={};for(const n of Lu([...Object.keys(this.contents),...Object.keys(t)])){let o=this.contents[n];const r=t[n];r&&(typeof o=="object"&&typeof r=="object"?(o=yd(o),this.mergeContents(o,r)):o=r),i[n]=o}return new ss(i,this.keys,this.overrides)}mergeContents(e,t){for(const i of Object.keys(t)){if(i in e&&Ts(e[i])&&Ts(t[i])){this.mergeContents(e[i],t[i]);continue}e[i]=yd(t[i])}}getContentsForOverrideIdentifer(e){let t=null,i=null;const n=o=>{o&&(i?this.mergeContents(i,o):i=yd(o))};for(const o of this.overrides)o.identifiers.length===1&&o.identifiers[0]===e?t=o.contents:o.identifiers.includes(e)&&n(o.contents);return n(t),i}toJSON(){return{contents:this.contents,overrides:this.overrides,keys:this.keys}}addValue(e,t){this.updateValue(e,t,!0)}setValue(e,t){this.updateValue(e,t,!1)}removeValue(e){const t=this.keys.indexOf(e);t!==-1&&(this.keys.splice(t,1),Ote(this.contents,e),Mu.test(e)&&this.overrides.splice(this.overrides.findIndex(i=>Ai(i.identifiers,HS(e))),1))}updateValue(e,t,i){FV(this.contents,e,t,n=>console.error(n)),i=i||this.keys.indexOf(e)===-1,i&&this.keys.push(e),Mu.test(e)&&this.overrides.push({identifiers:HS(e),keys:Object.keys(this.contents[e]),contents:JN(this.contents[e],n=>console.error(n))})}}class yue{constructor(e){this._name=e,this._raw=null,this._configurationModel=null,this._restrictedConfigurations=[]}get configurationModel(){return this._configurationModel||new ss}parseRaw(e,t){this._raw=e;const{contents:i,keys:n,overrides:o,restricted:r,hasExcludedProperties:a}=this.doParseRaw(e,t);this._configurationModel=new ss(i,n,o,a?[e]:void 0),this._restrictedConfigurations=r||[]}doParseRaw(e,t){const i=Si.as(Za.Configuration).getConfigurationProperties(),n=this.filter(e,i,!0,t);e=n.raw;const o=JN(e,l=>console.error(`Conflict in settings file ${this._name}: ${l}`)),r=Object.keys(e),a=this.toOverrides(e,l=>console.error(`Conflict in settings file ${this._name}: ${l}`));return{contents:o,keys:r,overrides:a,restricted:n.restricted,hasExcludedProperties:n.hasExcludedProperties}}filter(e,t,i,n){var o,r,a;let l=!1;if(!(n!=null&&n.scopes)&&!(n!=null&&n.skipRestricted)&&!(!((o=n==null?void 0:n.exclude)===null||o===void 0)&&o.length))return{raw:e,restricted:[],hasExcludedProperties:l};const d={},c=[];for(const u in e)if(Mu.test(u)&&i){const h=this.filter(e[u],t,!1,n);d[u]=h.raw,l=l||h.hasExcludedProperties,c.push(...h.restricted)}else{const h=t[u],g=h?typeof h.scope<"u"?h.scope:3:void 0;h!=null&&h.restricted&&c.push(u),!(!((r=n.exclude)===null||r===void 0)&&r.includes(u))&&(!((a=n.include)===null||a===void 0)&&a.includes(u)||(g===void 0||n.scopes===void 0||n.scopes.includes(g))&&!(n.skipRestricted&&(h!=null&&h.restricted)))?d[u]=e[u]:l=!0}return{raw:d,restricted:c,hasExcludedProperties:l}}toOverrides(e,t){const i=[];for(const n of Object.keys(e))if(Mu.test(n)){const o={};for(const r in e[n])o[r]=e[n][r];i.push({identifiers:HS(n),keys:Object.keys(o),contents:JN(o,t)})}return i}}class Lue{constructor(e,t,i,n,o,r,a,l,d,c,u,h,g){this.key=e,this.overrides=t,this._value=i,this.overrideIdentifiers=n,this.defaultConfiguration=o,this.policyConfiguration=r,this.applicationConfiguration=a,this.userConfiguration=l,this.localUserConfiguration=d,this.remoteUserConfiguration=c,this.workspaceConfiguration=u,this.folderConfigurationModel=h,this.memoryConfigurationModel=g}inspect(e,t,i){const n=e.inspect(t,i);return{get value(){return EI(n.value)},get override(){return EI(n.override)},get merged(){return EI(n.merged)}}}get userInspectValue(){return this._userInspectValue||(this._userInspectValue=this.inspect(this.userConfiguration,this.key,this.overrides.overrideIdentifier)),this._userInspectValue}get user(){return this.userInspectValue.value!==void 0||this.userInspectValue.override!==void 0?{value:this.userInspectValue.value,override:this.userInspectValue.override}:void 0}}class Ox{constructor(e,t,i,n,o=new ss,r=new ss,a=new zi,l=new ss,d=new zi){this._defaultConfiguration=e,this._policyConfiguration=t,this._applicationConfiguration=i,this._localUserConfiguration=n,this._remoteUserConfiguration=o,this._workspaceConfiguration=r,this._folderConfigurations=a,this._memoryConfiguration=l,this._memoryConfigurationByResource=d,this._workspaceConsolidatedConfiguration=null,this._foldersConsolidatedConfigurations=new zi,this._userConfiguration=null}getValue(e,t,i){return this.getConsolidatedConfigurationModel(e,t,i).getValue(e)}updateValue(e,t,i={}){let n;i.resource?(n=this._memoryConfigurationByResource.get(i.resource),n||(n=new ss,this._memoryConfigurationByResource.set(i.resource,n))):n=this._memoryConfiguration,t===void 0?n.removeValue(e):n.setValue(e,t),i.resource||(this._workspaceConsolidatedConfiguration=null)}inspect(e,t,i){const n=this.getConsolidatedConfigurationModel(e,t,i),o=this.getFolderConfigurationModelForResource(t.resource,i),r=t.resource?this._memoryConfigurationByResource.get(t.resource)||this._memoryConfiguration:this._memoryConfiguration,a=new Set;for(const l of n.overrides)for(const d of l.identifiers)n.getOverrideValue(e,d)!==void 0&&a.add(d);return new Lue(e,t,n.getValue(e),a.size?[...a]:void 0,this._defaultConfiguration,this._policyConfiguration.isEmpty()?void 0:this._policyConfiguration,this.applicationConfiguration.isEmpty()?void 0:this.applicationConfiguration,this.userConfiguration,this.localUserConfiguration,this.remoteUserConfiguration,i?this._workspaceConfiguration:void 0,o||void 0,r)}get applicationConfiguration(){return this._applicationConfiguration}get userConfiguration(){return this._userConfiguration||(this._userConfiguration=this._remoteUserConfiguration.isEmpty()?this._localUserConfiguration:this._localUserConfiguration.merge(this._remoteUserConfiguration)),this._userConfiguration}get localUserConfiguration(){return this._localUserConfiguration}get remoteUserConfiguration(){return this._remoteUserConfiguration}getConsolidatedConfigurationModel(e,t,i){let n=this.getConsolidatedConfigurationModelForResource(t,i);return t.overrideIdentifier&&(n=n.override(t.overrideIdentifier)),!this._policyConfiguration.isEmpty()&&this._policyConfiguration.getValue(e)!==void 0&&(n=n.merge(this._policyConfiguration)),n}getConsolidatedConfigurationModelForResource({resource:e},t){let i=this.getWorkspaceConsolidatedConfiguration();if(t&&e){const n=t.getFolder(e);n&&(i=this.getFolderConsolidatedConfiguration(n.uri)||i);const o=this._memoryConfigurationByResource.get(e);o&&(i=i.merge(o))}return i}getWorkspaceConsolidatedConfiguration(){return this._workspaceConsolidatedConfiguration||(this._workspaceConsolidatedConfiguration=this._defaultConfiguration.merge(this.applicationConfiguration,this.userConfiguration,this._workspaceConfiguration,this._memoryConfiguration)),this._workspaceConsolidatedConfiguration}getFolderConsolidatedConfiguration(e){let t=this._foldersConsolidatedConfigurations.get(e);if(!t){const i=this.getWorkspaceConsolidatedConfiguration(),n=this._folderConfigurations.get(e);n?(t=i.merge(n),this._foldersConsolidatedConfigurations.set(e,t)):t=i}return t}getFolderConfigurationModelForResource(e,t){if(t&&e){const i=t.getFolder(e);if(i)return this._folderConfigurations.get(i.uri)}}toData(){return{defaults:{contents:this._defaultConfiguration.contents,overrides:this._defaultConfiguration.overrides,keys:this._defaultConfiguration.keys},policy:{contents:this._policyConfiguration.contents,overrides:this._policyConfiguration.overrides,keys:this._policyConfiguration.keys},application:{contents:this.applicationConfiguration.contents,overrides:this.applicationConfiguration.overrides,keys:this.applicationConfiguration.keys},user:{contents:this.userConfiguration.contents,overrides:this.userConfiguration.overrides,keys:this.userConfiguration.keys},workspace:{contents:this._workspaceConfiguration.contents,overrides:this._workspaceConfiguration.overrides,keys:this._workspaceConfiguration.keys},folders:[...this._folderConfigurations.keys()].reduce((e,t)=>{const{contents:i,overrides:n,keys:o}=this._folderConfigurations.get(t);return e.push([t,{contents:i,overrides:n,keys:o}]),e},[])}}static parse(e){const t=this.parseConfigurationModel(e.defaults),i=this.parseConfigurationModel(e.policy),n=this.parseConfigurationModel(e.application),o=this.parseConfigurationModel(e.user),r=this.parseConfigurationModel(e.workspace),a=e.folders.reduce((l,d)=>(l.set(Pe.revive(d[0]),this.parseConfigurationModel(d[1])),l),new zi);return new Ox(t,i,n,o,new ss,r,a,new ss,new zi)}static parseConfigurationModel(e){return new ss(e.contents,e.keys,e.overrides)}}class xue{constructor(e,t,i,n){this.change=e,this.previous=t,this.currentConfiguraiton=i,this.currentWorkspace=n,this._marker=`
`,this._markerCode1=this._marker.charCodeAt(0),this._markerCode2=46,this.affectedKeys=new Set,this._previousConfiguration=void 0;for(const o of e.keys)this.affectedKeys.add(o);for(const[,o]of e.overrides)for(const r of o)this.affectedKeys.add(r);this._affectsConfigStr=this._marker;for(const o of this.affectedKeys)this._affectsConfigStr+=o+this._marker}get previousConfiguration(){return!this._previousConfiguration&&this.previous&&(this._previousConfiguration=Ox.parse(this.previous.data)),this._previousConfiguration}affectsConfiguration(e,t){var i;const n=this._marker+e,o=this._affectsConfigStr.indexOf(n);if(o<0)return!1;const r=o+n.length;if(r>=this._affectsConfigStr.length)return!1;const a=this._affectsConfigStr.charCodeAt(r);if(a!==this._markerCode1&&a!==this._markerCode2)return!1;if(t){const l=this.previousConfiguration?this.previousConfiguration.getValue(e,t,(i=this.previous)===null||i===void 0?void 0:i.workspace):void 0,d=this.currentConfiguraiton.getValue(e,t,this.currentWorkspace);return!Qo(l,d)}return!0}}const _y={kind:0},Due={kind:1};function kue(s,e,t){return{kind:2,commandId:s,commandArgs:e,isBubble:t}}class Xv{constructor(e,t,i){var n;this._log=i,this._defaultKeybindings=e,this._defaultBoundCommands=new Map;for(const o of e){const r=o.command;r&&r.charAt(0)!=="-"&&this._defaultBoundCommands.set(r,!0)}this._map=new Map,this._lookupMap=new Map,this._keybindings=Xv.handleRemovals([].concat(e).concat(t));for(let o=0,r=this._keybindings.length;o<r;o++){const a=this._keybindings[o];if(a.chords.length===0)continue;const l=(n=a.when)===null||n===void 0?void 0:n.substituteConstants();l&&l.type===0||this._addKeyPress(a.chords[0],a)}}static _isTargetedForRemoval(e,t,i){if(t){for(let n=0;n<t.length;n++)if(t[n]!==e.chords[n])return!1}return!(i&&i.type!==1&&(!e.when||!FJ(i,e.when)))}static handleRemovals(e){const t=new Map;for(let n=0,o=e.length;n<o;n++){const r=e[n];if(r.command&&r.command.charAt(0)==="-"){const a=r.command.substring(1);t.has(a)?t.get(a).push(r):t.set(a,[r])}}if(t.size===0)return e;const i=[];for(let n=0,o=e.length;n<o;n++){const r=e[n];if(!r.command||r.command.length===0){i.push(r);continue}if(r.command.charAt(0)==="-")continue;const a=t.get(r.command);if(!a||!r.isDefault){i.push(r);continue}let l=!1;for(const d of a){const c=d.when;if(this._isTargetedForRemoval(r,d.chords,c)){l=!0;break}}if(!l){i.push(r);continue}}return i}_addKeyPress(e,t){const i=this._map.get(e);if(typeof i>"u"){this._map.set(e,[t]),this._addToLookupMap(t);return}for(let n=i.length-1;n>=0;n--){const o=i[n];if(o.command===t.command)continue;let r=!0;for(let a=1;a<o.chords.length&&a<t.chords.length;a++)if(o.chords[a]!==t.chords[a]){r=!1;break}r&&Xv.whenIsEntirelyIncluded(o.when,t.when)&&this._removeFromLookupMap(o)}i.push(t),this._addToLookupMap(t)}_addToLookupMap(e){if(!e.command)return;let t=this._lookupMap.get(e.command);typeof t>"u"?(t=[e],this._lookupMap.set(e.command,t)):t.push(e)}_removeFromLookupMap(e){if(!e.command)return;const t=this._lookupMap.get(e.command);if(!(typeof t>"u")){for(let i=0,n=t.length;i<n;i++)if(t[i]===e){t.splice(i,1);return}}}static whenIsEntirelyIncluded(e,t){return!t||t.type===1?!0:!e||e.type===1?!1:jN(e,t)}getKeybindings(){return this._keybindings}lookupPrimaryKeybinding(e,t){const i=this._lookupMap.get(e);if(typeof i>"u"||i.length===0)return null;if(i.length===1)return i[0];for(let n=i.length-1;n>=0;n--){const o=i[n];if(t.contextMatchesRules(o.when))return o}return i[i.length-1]}resolve(e,t,i){const n=[...t,i];this._log(`| Resolving ${n}`);const o=this._map.get(n[0]);if(o===void 0)return this._log("\\ No keybinding entries."),_y;let r=null;if(n.length<2)r=o;else{r=[];for(let l=0,d=o.length;l<d;l++){const c=o[l];if(n.length>c.chords.length)continue;let u=!0;for(let h=1;h<n.length;h++)if(c.chords[h]!==n[h]){u=!1;break}u&&r.push(c)}}const a=this._findCommand(e,r);return a?n.length<a.chords.length?(this._log(`\\ From ${r.length} keybinding entries, awaiting ${a.chords.length-n.length} more chord(s), when: ${G7(a.when)}, source: ${Z7(a)}.`),Due):(this._log(`\\ From ${r.length} keybinding entries, matched ${a.command}, when: ${G7(a.when)}, source: ${Z7(a)}.`),kue(a.command,a.commandArgs,a.bubble)):(this._log(`\\ From ${r.length} keybinding entries, no when clauses matched the context.`),_y)}_findCommand(e,t){for(let i=t.length-1;i>=0;i--){const n=t[i];if(Xv._contextMatchesRules(e,n.when))return n}return null}static _contextMatchesRules(e,t){return t?t.evaluate(e):!0}}function G7(s){return s?`${s.serialize()}`:"no when condition"}function Z7(s){return s.extensionId?s.isBuiltinExtension?`built-in extension ${s.extensionId}`:`user extension ${s.extensionId}`:s.isDefault?"built-in":"user"}const Iue=/^(cursor|delete|undo|redo|tab|editor\.action\.clipboard)/;class Eue extends j{get onDidUpdateKeybindings(){return this._onDidUpdateKeybindings?this._onDidUpdateKeybindings.event:ge.None}get inChordMode(){return this._currentChords.length>0}constructor(e,t,i,n,o){super(),this._contextKeyService=e,this._commandService=t,this._telemetryService=i,this._notificationService=n,this._logService=o,this._onDidUpdateKeybindings=this._register(new W),this._currentChords=[],this._currentChordChecker=new ZA,this._currentChordStatusMessage=null,this._ignoreSingleModifiers=_p.EMPTY,this._currentSingleModifier=null,this._currentSingleModifierClearTimeout=new ea,this._logging=!1}dispose(){super.dispose()}_log(e){this._logging&&this._logService.info(`[KeybindingService]: ${e}`)}getKeybindings(){return this._getResolver().getKeybindings()}lookupKeybinding(e,t){const i=this._getResolver().lookupPrimaryKeybinding(e,t||this._contextKeyService);if(i)return i.resolvedKeybinding}dispatchEvent(e,t){return this._dispatch(e,t)}softDispatch(e,t){this._log("/ Soft dispatching keyboard event");const i=this.resolveKeyboardEvent(e);if(i.hasMultipleChords())return console.warn("keyboard event should not be mapped to multiple chords"),_y;const[n]=i.getDispatchChords();if(n===null)return this._log("\\ Keyboard event cannot be dispatched"),_y;const o=this._contextKeyService.getContext(t),r=this._currentChords.map(({keypress:a})=>a);return this._getResolver().resolve(o,r,n)}_scheduleLeaveChordMode(){const e=Date.now();this._currentChordChecker.cancelAndSet(()=>{if(!this._documentHasFocus()){this._leaveChordMode();return}Date.now()-e>5e3&&this._leaveChordMode()},500)}_expectAnotherChord(e,t){switch(this._currentChords.push({keypress:e,label:t}),this._currentChords.length){case 0:throw IA("impossible");case 1:this._currentChordStatusMessage=this._notificationService.status(p("first.chord","({0}) was pressed. Waiting for second key of chord...",t));break;default:{const i=this._currentChords.map(({label:n})=>n).join(", ");this._currentChordStatusMessage=this._notificationService.status(p("next.chord","({0}) was pressed. Waiting for next key of chord...",i))}}this._scheduleLeaveChordMode(),Fv.enabled&&Fv.disable()}_leaveChordMode(){this._currentChordStatusMessage&&(this._currentChordStatusMessage.dispose(),this._currentChordStatusMessage=null),this._currentChordChecker.cancel(),this._currentChords=[],Fv.enable()}_dispatch(e,t){return this._doDispatch(this.resolveKeyboardEvent(e),t,!1)}_singleModifierDispatch(e,t){const i=this.resolveKeyboardEvent(e),[n]=i.getSingleModifierDispatchChords();if(n)return this._ignoreSingleModifiers.has(n)?(this._log(`+ Ignoring single modifier ${n} due to it being pressed together with other keys.`),this._ignoreSingleModifiers=_p.EMPTY,this._currentSingleModifierClearTimeout.cancel(),this._currentSingleModifier=null,!1):(this._ignoreSingleModifiers=_p.EMPTY,this._currentSingleModifier===null?(this._log(`+ Storing single modifier for possible chord ${n}.`),this._currentSingleModifier=n,this._currentSingleModifierClearTimeout.cancelAndSet(()=>{this._log("+ Clearing single modifier due to 300ms elapsed."),this._currentSingleModifier=null},300),!1):n===this._currentSingleModifier?(this._log(`/ Dispatching single modifier chord ${n} ${n}`),this._currentSingleModifierClearTimeout.cancel(),this._currentSingleModifier=null,this._doDispatch(i,t,!0)):(this._log(`+ Clearing single modifier due to modifier mismatch: ${this._currentSingleModifier} ${n}`),this._currentSingleModifierClearTimeout.cancel(),this._currentSingleModifier=null,!1));const[o]=i.getChords();return this._ignoreSingleModifiers=new _p(o),this._currentSingleModifier!==null&&this._log("+ Clearing single modifier due to other key up."),this._currentSingleModifierClearTimeout.cancel(),this._currentSingleModifier=null,!1}_doDispatch(e,t,i=!1){var n;let o=!1;if(e.hasMultipleChords())return console.warn("Unexpected keyboard event mapped to multiple chords"),!1;let r=null,a=null;if(i){const[u]=e.getSingleModifierDispatchChords();r=u,a=u?[u]:[]}else[r]=e.getDispatchChords(),a=this._currentChords.map(({keypress:u})=>u);if(r===null)return this._log("\\ Keyboard event cannot be dispatched in keydown phase."),o;const l=this._contextKeyService.getContext(t),d=e.getLabel(),c=this._getResolver().resolve(l,a,r);switch(c.kind){case 0:{if(this._logService.trace("KeybindingService#dispatch",d,"[ No matching keybinding ]"),this.inChordMode){const u=this._currentChords.map(({label:h})=>h).join(", ");this._log(`+ Leaving multi-chord mode: Nothing bound to "${u}, ${d}".`),this._notificationService.status(p("missing.chord","The key combination ({0}, {1}) is not a command.",u,d),{hideAfter:10*1e3}),this._leaveChordMode(),o=!0}return o}case 1:return this._logService.trace("KeybindingService#dispatch",d,"[ Several keybindings match - more chords needed ]"),o=!0,this._expectAnotherChord(r,d),this._log(this._currentChords.length===1?"+ Entering multi-chord mode...":"+ Continuing multi-chord mode..."),o;case 2:{if(this._logService.trace("KeybindingService#dispatch",d,`[ Will dispatch command ${c.commandId} ]`),c.commandId===null||c.commandId===""){if(this.inChordMode){const u=this._currentChords.map(({label:h})=>h).join(", ");this._log(`+ Leaving chord mode: Nothing bound to "${u}, ${d}".`),this._notificationService.status(p("missing.chord","The key combination ({0}, {1}) is not a command.",u,d),{hideAfter:10*1e3}),this._leaveChordMode(),o=!0}}else this.inChordMode&&this._leaveChordMode(),c.isBubble||(o=!0),this._log(`+ Invoking command ${c.commandId}.`),typeof c.commandArgs>"u"?this._commandService.executeCommand(c.commandId).then(void 0,u=>this._notificationService.warn(u)):this._commandService.executeCommand(c.commandId,c.commandArgs).then(void 0,u=>this._notificationService.warn(u)),Iue.test(c.commandId)||this._telemetryService.publicLog2("workbenchActionExecuted",{id:c.commandId,from:"keybinding",detail:(n=e.getUserSettingsLabel())!==null&&n!==void 0?n:void 0});return o}}}mightProducePrintableCharacter(e){return e.ctrlKey||e.metaKey?!1:e.keyCode>=31&&e.keyCode<=56||e.keyCode>=21&&e.keyCode<=30}}class _p{constructor(e){this._ctrlKey=e?e.ctrlKey:!1,this._shiftKey=e?e.shiftKey:!1,this._altKey=e?e.altKey:!1,this._metaKey=e?e.metaKey:!1}has(e){switch(e){case"ctrl":return this._ctrlKey;case"shift":return this._shiftKey;case"alt":return this._altKey;case"meta":return this._metaKey}}}_p.EMPTY=new _p(null);class Y7{constructor(e,t,i,n,o,r,a){this._resolvedKeybindingItemBrand=void 0,this.resolvedKeybinding=e,this.chords=e?qT(e.getDispatchChords()):[],e&&this.chords.length===0&&(this.chords=qT(e.getSingleModifierDispatchChords())),this.bubble=t?t.charCodeAt(0)===94:!1,this.command=this.bubble?t.substr(1):t,this.commandArgs=i,this.when=n,this.isDefault=o,this.extensionId=r,this.isBuiltinExtension=a}}function qT(s){const e=[];for(let t=0,i=s.length;t<i;t++){const n=s[t];if(!n)return[];e.push(n)}return e}class Fx{constructor(e,t,i=t){this.modifierLabels=[null],this.modifierLabels[2]=e,this.modifierLabels[1]=t,this.modifierLabels[3]=i}toLabel(e,t,i){if(t.length===0)return null;const n=[];for(let o=0,r=t.length;o<r;o++){const a=t[o],l=i(a);if(l===null)return null;n[o]=Rue(a,l,this.modifierLabels[e])}return n.join(" ")}}const eO=new Fx({ctrlKey:"⌃",shiftKey:"⇧",altKey:"⌥",metaKey:"⌘",separator:""},{ctrlKey:p({key:"ctrlKey",comment:["This is the short form for the Control key on the keyboard"]},"Ctrl"),shiftKey:p({key:"shiftKey",comment:["This is the short form for the Shift key on the keyboard"]},"Shift"),altKey:p({key:"altKey",comment:["This is the short form for the Alt key on the keyboard"]},"Alt"),metaKey:p({key:"windowsKey",comment:["This is the short form for the Windows key on the keyboard"]},"Windows"),separator:"+"},{ctrlKey:p({key:"ctrlKey",comment:["This is the short form for the Control key on the keyboard"]},"Ctrl"),shiftKey:p({key:"shiftKey",comment:["This is the short form for the Shift key on the keyboard"]},"Shift"),altKey:p({key:"altKey",comment:["This is the short form for the Alt key on the keyboard"]},"Alt"),metaKey:p({key:"superKey",comment:["This is the short form for the Super key on the keyboard"]},"Super"),separator:"+"}),Nue=new Fx({ctrlKey:p({key:"ctrlKey.long",comment:["This is the long form for the Control key on the keyboard"]},"Control"),shiftKey:p({key:"shiftKey.long",comment:["This is the long form for the Shift key on the keyboard"]},"Shift"),altKey:p({key:"optKey.long",comment:["This is the long form for the Alt/Option key on the keyboard"]},"Option"),metaKey:p({key:"cmdKey.long",comment:["This is the long form for the Command key on the keyboard"]},"Command"),separator:"+"},{ctrlKey:p({key:"ctrlKey.long",comment:["This is the long form for the Control key on the keyboard"]},"Control"),shiftKey:p({key:"shiftKey.long",comment:["This is the long form for the Shift key on the keyboard"]},"Shift"),altKey:p({key:"altKey.long",comment:["This is the long form for the Alt key on the keyboard"]},"Alt"),metaKey:p({key:"windowsKey.long",comment:["This is the long form for the Windows key on the keyboard"]},"Windows"),separator:"+"},{ctrlKey:p({key:"ctrlKey.long",comment:["This is the long form for the Control key on the keyboard"]},"Control"),shiftKey:p({key:"shiftKey.long",comment:["This is the long form for the Shift key on the keyboard"]},"Shift"),altKey:p({key:"altKey.long",comment:["This is the long form for the Alt key on the keyboard"]},"Alt"),metaKey:p({key:"superKey.long",comment:["This is the long form for the Super key on the keyboard"]},"Super"),separator:"+"}),Tue=new Fx({ctrlKey:"Ctrl",shiftKey:"Shift",altKey:"Alt",metaKey:"Cmd",separator:"+"},{ctrlKey:"Ctrl",shiftKey:"Shift",altKey:"Alt",metaKey:"Super",separator:"+"}),Mue=new Fx({ctrlKey:"ctrl",shiftKey:"shift",altKey:"alt",metaKey:"cmd",separator:"+"},{ctrlKey:"ctrl",shiftKey:"shift",altKey:"alt",metaKey:"win",separator:"+"},{ctrlKey:"ctrl",shiftKey:"shift",altKey:"alt",metaKey:"meta",separator:"+"});function Rue(s,e,t){if(e===null)return"";const i=[];return s.ctrlKey&&i.push(t.ctrlKey),s.shiftKey&&i.push(t.shiftKey),s.altKey&&i.push(t.altKey),s.metaKey&&i.push(t.metaKey),e!==""&&i.push(e),i.join(t.separator)}class Aue extends WJ{constructor(e,t){if(super(),t.length===0)throw Cr("chords");this._os=e,this._chords=t}getLabel(){return eO.toLabel(this._os,this._chords,e=>this._getLabel(e))}getAriaLabel(){return Nue.toLabel(this._os,this._chords,e=>this._getAriaLabel(e))}getElectronAccelerator(){return this._chords.length>1||this._chords[0].isDuplicateModifierCase()?null:Tue.toLabel(this._os,this._chords,e=>this._getElectronAccelerator(e))}getUserSettingsLabel(){return Mue.toLabel(this._os,this._chords,e=>this._getUserSettingsLabel(e))}hasMultipleChords(){return this._chords.length>1}getChords(){return this._chords.map(e=>this._getChord(e))}_getChord(e){return new BJ(e.ctrlKey,e.shiftKey,e.altKey,e.metaKey,this._getLabel(e),this._getAriaLabel(e))}getDispatchChords(){return this._chords.map(e=>this._getChordDispatch(e))}getSingleModifierDispatchChords(){return this._chords.map(e=>this._getSingleModifierChordDispatch(e))}}class nb extends Aue{constructor(e,t){super(t,e)}_keyCodeToUILabel(e){if(this._os===2)switch(e){case 15:return"←";case 16:return"↑";case 17:return"→";case 18:return"↓"}return Id.toString(e)}_getLabel(e){return e.isDuplicateModifierCase()?"":this._keyCodeToUILabel(e.keyCode)}_getAriaLabel(e){return e.isDuplicateModifierCase()?"":Id.toString(e.keyCode)}_getElectronAccelerator(e){return Id.toElectronAccelerator(e.keyCode)}_getUserSettingsLabel(e){if(e.isDuplicateModifierCase())return"";const t=Id.toUserSettingsUS(e.keyCode);return t&&t.toLowerCase()}_getChordDispatch(e){return nb.getDispatchStr(e)}static getDispatchStr(e){if(e.isModifierKey())return null;let t="";return e.ctrlKey&&(t+="ctrl+"),e.shiftKey&&(t+="shift+"),e.altKey&&(t+="alt+"),e.metaKey&&(t+="meta+"),t+=Id.toString(e.keyCode),t}_getSingleModifierChordDispatch(e){return e.keyCode===5&&!e.shiftKey&&!e.altKey&&!e.metaKey?"ctrl":e.keyCode===4&&!e.ctrlKey&&!e.altKey&&!e.metaKey?"shift":e.keyCode===6&&!e.ctrlKey&&!e.shiftKey&&!e.metaKey?"alt":e.keyCode===57&&!e.ctrlKey&&!e.shiftKey&&!e.altKey?"meta":null}static _scanCodeToKeyCode(e){const t=AA[e];if(t!==-1)return t;switch(e){case 10:return 31;case 11:return 32;case 12:return 33;case 13:return 34;case 14:return 35;case 15:return 36;case 16:return 37;case 17:return 38;case 18:return 39;case 19:return 40;case 20:return 41;case 21:return 42;case 22:return 43;case 23:return 44;case 24:return 45;case 25:return 46;case 26:return 47;case 27:return 48;case 28:return 49;case 29:return 50;case 30:return 51;case 31:return 52;case 32:return 53;case 33:return 54;case 34:return 55;case 35:return 56;case 36:return 22;case 37:return 23;case 38:return 24;case 39:return 25;case 40:return 26;case 41:return 27;case 42:return 28;case 43:return 29;case 44:return 30;case 45:return 21;case 51:return 88;case 52:return 86;case 53:return 92;case 54:return 94;case 55:return 93;case 56:return 0;case 57:return 85;case 58:return 95;case 59:return 91;case 60:return 87;case 61:return 89;case 62:return 90;case 106:return 97}return 0}static _toKeyCodeChord(e){if(!e)return null;if(e instanceof ec)return e;const t=this._scanCodeToKeyCode(e.scanCode);return t===0?null:new ec(e.ctrlKey,e.shiftKey,e.altKey,e.metaKey,t)}static resolveKeybinding(e,t){const i=qT(e.chords.map(n=>this._toKeyCodeChord(n)));return i.length>0?[new nb(i,t)]:[]}}const xm=ut("labelService"),kz=ut("progressService");class Gd{constructor(e){this.callback=e}report(e){this._value=e,this.callback(this._value)}}Gd.None=Object.freeze({report(){}});const rh=ut("editorProgressService");class Pue{constructor(){this._value="",this._pos=0}reset(e){return this._value=e,this._pos=0,this}next(){return this._pos+=1,this}hasNext(){return this._pos<this._value.length-1}cmp(e){const t=e.charCodeAt(0),i=this._value.charCodeAt(this._pos);return t-i}value(){return this._value[this._pos]}}class Oue{constructor(e=!0){this._caseSensitive=e}reset(e){return this._value=e,this._from=0,this._to=0,this.next()}hasNext(){return this._to<this._value.length}next(){this._from=this._to;let e=!0;for(;this._to<this._value.length;this._to++)if(this._value.charCodeAt(this._to)===46)if(e)this._from++;else break;else e=!1;return this}cmp(e){return this._caseSensitive?OA(e,this._value,0,e.length,this._from,this._to):nC(e,this._value,0,e.length,this._from,this._to)}value(){return this._value.substring(this._from,this._to)}}class Fue{constructor(e=!0,t=!0){this._splitOnBackslash=e,this._caseSensitive=t}reset(e){this._from=0,this._to=0,this._value=e,this._valueLen=e.length;for(let t=e.length-1;t>=0;t--,this._valueLen--){const i=this._value.charCodeAt(t);if(!(i===47||this._splitOnBackslash&&i===92))break}return this.next()}hasNext(){return this._to<this._valueLen}next(){this._from=this._to;let e=!0;for(;this._to<this._valueLen;this._to++){const t=this._value.charCodeAt(this._to);if(t===47||this._splitOnBackslash&&t===92)if(e)this._from++;else break;else e=!1}return this}cmp(e){return this._caseSensitive?OA(e,this._value,0,e.length,this._from,this._to):nC(e,this._value,0,e.length,this._from,this._to)}value(){return this._value.substring(this._from,this._to)}}class Bue{constructor(e,t){this._ignorePathCasing=e,this._ignoreQueryAndFragment=t,this._states=[],this._stateIdx=0}reset(e){return this._value=e,this._states=[],this._value.scheme&&this._states.push(1),this._value.authority&&this._states.push(2),this._value.path&&(this._pathIterator=new Fue(!1,!this._ignorePathCasing(e)),this._pathIterator.reset(e.path),this._pathIterator.value()&&this._states.push(3)),this._ignoreQueryAndFragment(e)||(this._value.query&&this._states.push(4),this._value.fragment&&this._states.push(5)),this._stateIdx=0,this}next(){return this._states[this._stateIdx]===3&&this._pathIterator.hasNext()?this._pathIterator.next():this._stateIdx+=1,this}hasNext(){return this._states[this._stateIdx]===3&&this._pathIterator.hasNext()||this._stateIdx<this._states.length-1}cmp(e){if(this._states[this._stateIdx]===1)return WN(e,this._value.scheme);if(this._states[this._stateIdx]===2)return WN(e,this._value.authority);if(this._states[this._stateIdx]===3)return this._pathIterator.cmp(e);if(this._states[this._stateIdx]===4)return x0(e,this._value.query);if(this._states[this._stateIdx]===5)return x0(e,this._value.fragment);throw new Error}value(){if(this._states[this._stateIdx]===1)return this._value.scheme;if(this._states[this._stateIdx]===2)return this._value.authority;if(this._states[this._stateIdx]===3)return this._pathIterator.value();if(this._states[this._stateIdx]===4)return this._value.query;if(this._states[this._stateIdx]===5)return this._value.fragment;throw new Error}}class A1{constructor(){this.height=1}rotateLeft(){const e=this.right;return this.right=e.left,e.left=this,this.updateHeight(),e.updateHeight(),e}rotateRight(){const e=this.left;return this.left=e.right,e.right=this,this.updateHeight(),e.updateHeight(),e}updateHeight(){this.height=1+Math.max(this.heightLeft,this.heightRight)}balanceFactor(){return this.heightRight-this.heightLeft}get heightLeft(){var e,t;return(t=(e=this.left)===null||e===void 0?void 0:e.height)!==null&&t!==void 0?t:0}get heightRight(){var e,t;return(t=(e=this.right)===null||e===void 0?void 0:e.height)!==null&&t!==void 0?t:0}}class Gp{static forUris(e=()=>!1,t=()=>!1){return new Gp(new Bue(e,t))}static forStrings(){return new Gp(new Pue)}static forConfigKeys(){return new Gp(new Oue)}constructor(e){this._iter=e}clear(){this._root=void 0}set(e,t){const i=this._iter.reset(e);let n;this._root||(this._root=new A1,this._root.segment=i.value());const o=[];for(n=this._root;;){const a=i.cmp(n.segment);if(a>0)n.left||(n.left=new A1,n.left.segment=i.value()),o.push([-1,n]),n=n.left;else if(a<0)n.right||(n.right=new A1,n.right.segment=i.value()),o.push([1,n]),n=n.right;else if(i.hasNext())i.next(),n.mid||(n.mid=new A1,n.mid.segment=i.value()),o.push([0,n]),n=n.mid;else break}const r=n.value;n.value=t,n.key=e;for(let a=o.length-1;a>=0;a--){const l=o[a][1];l.updateHeight();const d=l.balanceFactor();if(d<-1||d>1){const c=o[a][0],u=o[a+1][0];if(c===1&&u===1)o[a][1]=l.rotateLeft();else if(c===-1&&u===-1)o[a][1]=l.rotateRight();else if(c===1&&u===-1)l.right=o[a+1][1]=o[a+1][1].rotateRight(),o[a][1]=l.rotateLeft();else if(c===-1&&u===1)l.left=o[a+1][1]=o[a+1][1].rotateLeft(),o[a][1]=l.rotateRight();else throw new Error;if(a>0)switch(o[a-1][0]){case-1:o[a-1][1].left=o[a][1];break;case 1:o[a-1][1].right=o[a][1];break;case 0:o[a-1][1].mid=o[a][1];break}else this._root=o[0][1]}}return r}get(e){var t;return(t=this._getNode(e))===null||t===void 0?void 0:t.value}_getNode(e){const t=this._iter.reset(e);let i=this._root;for(;i;){const n=t.cmp(i.segment);if(n>0)i=i.left;else if(n<0)i=i.right;else if(t.hasNext())t.next(),i=i.mid;else break}return i}has(e){const t=this._getNode(e);return!((t==null?void 0:t.value)===void 0&&(t==null?void 0:t.mid)===void 0)}delete(e){return this._delete(e,!1)}deleteSuperstr(e){return this._delete(e,!0)}_delete(e,t){var i;const n=this._iter.reset(e),o=[];let r=this._root;for(;r;){const a=n.cmp(r.segment);if(a>0)o.push([-1,r]),r=r.left;else if(a<0)o.push([1,r]),r=r.right;else if(n.hasNext())n.next(),o.push([0,r]),r=r.mid;else break}if(r){if(t?(r.left=void 0,r.mid=void 0,r.right=void 0,r.height=1):(r.key=void 0,r.value=void 0),!r.mid&&!r.value)if(r.left&&r.right){const a=this._min(r.right);if(a.key){const{key:l,value:d,segment:c}=a;this._delete(a.key,!1),r.key=l,r.value=d,r.segment=c}}else{const a=(i=r.left)!==null&&i!==void 0?i:r.right;if(o.length>0){const[l,d]=o[o.length-1];switch(l){case-1:d.left=a;break;case 0:d.mid=a;break;case 1:d.right=a;break}}else this._root=a}for(let a=o.length-1;a>=0;a--){const l=o[a][1];l.updateHeight();const d=l.balanceFactor();if(d>1?(l.right.balanceFactor()>=0||(l.right=l.right.rotateRight()),o[a][1]=l.rotateLeft()):d<-1&&(l.left.balanceFactor()<=0||(l.left=l.left.rotateLeft()),o[a][1]=l.rotateRight()),a>0)switch(o[a-1][0]){case-1:o[a-1][1].left=o[a][1];break;case 1:o[a-1][1].right=o[a][1];break;case 0:o[a-1][1].mid=o[a][1];break}else this._root=o[0][1]}}}_min(e){for(;e.left;)e=e.left;return e}findSubstr(e){const t=this._iter.reset(e);let i=this._root,n;for(;i;){const o=t.cmp(i.segment);if(o>0)i=i.left;else if(o<0)i=i.right;else if(t.hasNext())t.next(),n=i.value||n,i=i.mid;else break}return i&&i.value||n}findSuperstr(e){return this._findSuperstrOrElement(e,!1)}_findSuperstrOrElement(e,t){const i=this._iter.reset(e);let n=this._root;for(;n;){const o=i.cmp(n.segment);if(o>0)n=n.left;else if(o<0)n=n.right;else if(i.hasNext())i.next(),n=n.mid;else return n.mid?this._entries(n.mid):t?n.value:void 0}}forEach(e){for(const[t,i]of this)e(i,t)}*[Symbol.iterator](){yield*this._entries(this._root)}_entries(e){const t=[];return this._dfsEntries(e,t),t[Symbol.iterator]()}_dfsEntries(e,t){e&&(e.left&&this._dfsEntries(e.left,t),e.value&&t.push([e.key,e.value]),e.mid&&this._dfsEntries(e.mid,t),e.right&&this._dfsEntries(e.right,t))}}const Ag=ut("contextService");function GT(s){const e=s;return typeof(e==null?void 0:e.id)=="string"&&Pe.isUri(e.uri)}function Wue(s){const e=s;return typeof(e==null?void 0:e.id)=="string"&&!GT(s)&&!Uue(s)}const Vue={id:"ext-dev"},Hue={id:"empty-window"};function zue(s,e){if(typeof s=="string"||typeof s>"u")return typeof s=="string"?{id:ru(s)}:e?Vue:Hue;const t=s;return t.configuration?{id:t.id,configPath:t.configuration}:t.folders.length===1?{id:t.id,uri:t.folders[0].uri}:{id:t.id}}function Uue(s){const e=s;return typeof(e==null?void 0:e.id)=="string"&&Pe.isUri(e.configPath)}class $ue{constructor(e,t){this.raw=t,this.uri=e.uri,this.index=e.index,this.name=e.name}toJSON(){return{uri:this.uri,name:this.name,index:this.index}}}const ZT="code-workspace";p("codeWorkspace","Code Workspace");const Iz="4064f6ec-cb38-4ad0-af64-ee6467e63c82";function jue(s){return s.id===Iz}var YT;(function(s){s.inspectTokensAction=p("inspectTokens","Developer: Inspect Tokens")})(YT||(YT={}));var vy;(function(s){s.gotoLineActionLabel=p("gotoLineActionLabel","Go to Line/Column...")})(vy||(vy={}));var XT;(function(s){s.helpQuickAccessActionLabel=p("helpQuickAccess","Show all Quick Access Providers")})(XT||(XT={}));var by;(function(s){s.quickCommandActionLabel=p("quickCommandActionLabel","Command Palette"),s.quickCommandHelp=p("quickCommandActionHelp","Show And Run Commands")})(by||(by={}));var sb;(function(s){s.quickOutlineActionLabel=p("quickOutlineActionLabel","Go to Symbol..."),s.quickOutlineByCategoryActionLabel=p("quickOutlineByCategoryActionLabel","Go to Symbol by Category...")})(sb||(sb={}));var Cy;(function(s){s.editorViewAccessibleLabel=p("editorViewAccessibleLabel","Editor content"),s.accessibilityHelpMessage=p("accessibilityHelpMessage","Press Alt+F1 for Accessibility Options.")})(Cy||(Cy={}));var QT;(function(s){s.toggleHighContrast=p("toggleHighContrast","Toggle High Contrast Theme")})(QT||(QT={}));var JT;(function(s){s.bulkEditServiceSummary=p("bulkEditServiceSummary","Made {0} edits in {1} files")})(JT||(JT={}));const Ez=ut("workspaceTrustManagementService"),rc=ut("contextViewService"),Nr=ut("contextMenuService");var is;(function(s){function e(o,r){if(o.start>=r.end||r.start>=o.end)return{start:0,end:0};const a=Math.max(o.start,r.start),l=Math.min(o.end,r.end);return l-a<=0?{start:0,end:0}:{start:a,end:l}}s.intersect=e;function t(o){return o.end-o.start<=0}s.isEmpty=t;function i(o,r){return!t(e(o,r))}s.intersects=i;function n(o,r){const a=[],l={start:o.start,end:Math.min(r.start,o.end)},d={start:Math.max(r.end,o.start),end:o.end};return t(l)||a.push(l),t(d)||a.push(d),a}s.relativeComplement=n})(is||(is={}));function Kue(s){const e=s;return!!e&&typeof e.x=="number"&&typeof e.y=="number"}var Gc;(function(s){s[s.AVOID=0]="AVOID",s[s.ALIGN=1]="ALIGN"})(Gc||(Gc={}));function vp(s,e,t){const i=t.mode===Gc.ALIGN?t.offset:t.offset+t.size,n=t.mode===Gc.ALIGN?t.offset+t.size:t.offset;return t.position===0?e<=s-i?i:e<=n?n-e:Math.max(s-e,0):e<=n?n-e:e<=s-i?i:0}class Dm extends j{constructor(e,t){super(),this.container=null,this.useFixedPosition=!1,this.useShadowDOM=!1,this.delegate=null,this.toDisposeOnClean=j.None,this.toDisposeOnSetContainer=j.None,this.shadowRoot=null,this.shadowRootHostElement=null,this.view=se(".context-view"),ks(this.view),this.setContainer(e,t),this._register(Fe(()=>this.setContainer(null,1)))}setContainer(e,t){var i;this.useFixedPosition=t!==1;const n=this.useShadowDOM;if(this.useShadowDOM=t===3,!(e===this.container&&n!==this.useShadowDOM)&&(this.container&&(this.toDisposeOnSetContainer.dispose(),this.shadowRoot?(this.shadowRoot.removeChild(this.view),this.shadowRoot=null,(i=this.shadowRootHostElement)===null||i===void 0||i.remove(),this.shadowRootHostElement=null):this.container.removeChild(this.view),this.container=null),e)){if(this.container=e,this.useShadowDOM){this.shadowRootHostElement=se(".shadow-root-host"),this.container.appendChild(this.shadowRootHostElement),this.shadowRoot=this.shadowRootHostElement.attachShadow({mode:"open"});const r=document.createElement("style");r.textContent=que,this.shadowRoot.appendChild(r),this.shadowRoot.appendChild(this.view),this.shadowRoot.appendChild(se("slot"))}else this.container.appendChild(this.view);const o=new ie;Dm.BUBBLE_UP_EVENTS.forEach(r=>{o.add(Pi(this.container,r,a=>{this.onDOMEvent(a,!1)}))}),Dm.BUBBLE_DOWN_EVENTS.forEach(r=>{o.add(Pi(this.container,r,a=>{this.onDOMEvent(a,!0)},!0))}),this.toDisposeOnSetContainer=o}}show(e){var t,i;this.isVisible()&&this.hide(),Vn(this.view),this.view.className="context-view",this.view.style.top="0px",this.view.style.left="0px",this.view.style.zIndex="2575",this.view.style.position=this.useFixedPosition?"fixed":"absolute",go(this.view),this.toDisposeOnClean=e.render(this.view)||j.None,this.delegate=e,this.doLayout(),(i=(t=this.delegate).focus)===null||i===void 0||i.call(t)}getViewElement(){return this.view}layout(){if(this.isVisible()){if(this.delegate.canRelayout===!1&&!(Wa&&qA.pointerEvents)){this.hide();return}this.delegate.layout&&this.delegate.layout(),this.doLayout()}}doLayout(){if(!this.isVisible())return;const e=this.delegate.getAnchor();let t;if(e instanceof HTMLElement){const h=ln(e),g=Hee(e);t={top:h.top*g,left:h.left*g,width:h.width*g,height:h.height*g}}else Kue(e)?t={top:e.y,left:e.x,width:e.width||1,height:e.height||2}:t={top:e.posy,left:e.posx,width:2,height:2};const i=js(this.view),n=Qh(this.view),o=this.delegate.anchorPosition||0,r=this.delegate.anchorAlignment||0,a=this.delegate.anchorAxisAlignment||0;let l,d;const c=jee();if(a===0){const h={offset:t.top-c.pageYOffset,size:t.height,position:o===0?0:1},g={offset:t.left,size:t.width,position:r===0?0:1,mode:Gc.ALIGN};l=vp(c.innerHeight,n,h)+c.pageYOffset,is.intersects({start:l,end:l+n},{start:h.offset,end:h.offset+h.size})&&(g.mode=Gc.AVOID),d=vp(c.innerWidth,i,g)}else{const h={offset:t.left,size:t.width,position:r===0?0:1},g={offset:t.top,size:t.height,position:o===0?0:1,mode:Gc.ALIGN};d=vp(c.innerWidth,i,h),is.intersects({start:d,end:d+i},{start:h.offset,end:h.offset+h.size})&&(g.mode=Gc.AVOID),l=vp(c.innerHeight,n,g)+c.pageYOffset}this.view.classList.remove("top","bottom","left","right"),this.view.classList.add(o===0?"bottom":"top"),this.view.classList.add(r===0?"left":"right"),this.view.classList.toggle("fixed",this.useFixedPosition);const u=ln(this.container);this.view.style.top=`${l-(this.useFixedPosition?ln(this.view).top:u.top)}px`,this.view.style.left=`${d-(this.useFixedPosition?ln(this.view).left:u.left)}px`,this.view.style.width="initial"}hide(e){const t=this.delegate;this.delegate=null,t!=null&&t.onHide&&t.onHide(e),this.toDisposeOnClean.dispose(),ks(this.view)}isVisible(){return!!this.delegate}onDOMEvent(e,t){this.delegate&&(this.delegate.onDOMEvent?this.delegate.onDOMEvent(e,Xe(e).document.activeElement):t&&!Yn(e.target,this.container)&&this.hide())}dispose(){this.hide(),super.dispose()}}Dm.BUBBLE_UP_EVENTS=["click","keydown","focus","blur"];Dm.BUBBLE_DOWN_EVENTS=["click"];const que=`
	:host {
		all: initial; /* 1st rule so subsequent properties are reset. */
	}

	.codicon[class*='codicon-'] {
		font: normal normal normal 16px/1 codicon;
		display: inline-block;
		text-decoration: none;
		text-rendering: auto;
		text-align: center;
		-webkit-font-smoothing: antialiased;
		-moz-osx-font-smoothing: grayscale;
		user-select: none;
		-webkit-user-select: none;
		-ms-user-select: none;
	}

	:host {
		font-family: -apple-system, BlinkMacSystemFont, "Segoe WPC", "Segoe UI", "HelveticaNeue-Light", system-ui, "Ubuntu", "Droid Sans", sans-serif;
	}

	:host-context(.mac) { font-family: -apple-system, BlinkMacSystemFont, sans-serif; }
	:host-context(.mac:lang(zh-Hans)) { font-family: -apple-system, BlinkMacSystemFont, "PingFang SC", "Hiragino Sans GB", sans-serif; }
	:host-context(.mac:lang(zh-Hant)) { font-family: -apple-system, BlinkMacSystemFont, "PingFang TC", sans-serif; }
	:host-context(.mac:lang(ja)) { font-family: -apple-system, BlinkMacSystemFont, "Hiragino Kaku Gothic Pro", sans-serif; }
	:host-context(.mac:lang(ko)) { font-family: -apple-system, BlinkMacSystemFont, "Nanum Gothic", "Apple SD Gothic Neo", "AppleGothic", sans-serif; }

	:host-context(.windows) { font-family: "Segoe WPC", "Segoe UI", sans-serif; }
	:host-context(.windows:lang(zh-Hans)) { font-family: "Segoe WPC", "Segoe UI", "Microsoft YaHei", sans-serif; }
	:host-context(.windows:lang(zh-Hant)) { font-family: "Segoe WPC", "Segoe UI", "Microsoft Jhenghei", sans-serif; }
	:host-context(.windows:lang(ja)) { font-family: "Segoe WPC", "Segoe UI", "Yu Gothic UI", "Meiryo UI", sans-serif; }
	:host-context(.windows:lang(ko)) { font-family: "Segoe WPC", "Segoe UI", "Malgun Gothic", "Dotom", sans-serif; }

	:host-context(.linux) { font-family: system-ui, "Ubuntu", "Droid Sans", sans-serif; }
	:host-context(.linux:lang(zh-Hans)) { font-family: system-ui, "Ubuntu", "Droid Sans", "Source Han Sans SC", "Source Han Sans CN", "Source Han Sans", sans-serif; }
	:host-context(.linux:lang(zh-Hant)) { font-family: system-ui, "Ubuntu", "Droid Sans", "Source Han Sans TC", "Source Han Sans TW", "Source Han Sans", sans-serif; }
	:host-context(.linux:lang(ja)) { font-family: system-ui, "Ubuntu", "Droid Sans", "Source Han Sans J", "Source Han Sans JP", "Source Han Sans", sans-serif; }
	:host-context(.linux:lang(ko)) { font-family: system-ui, "Ubuntu", "Droid Sans", "Source Han Sans K", "Source Han Sans JR", "Source Han Sans", "UnDotum", "FBaekmuk Gulim", sans-serif; }
`;var Gue=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Zue=function(s,e){return function(t,i){e(t,i,s)}};let e2=class extends j{constructor(e){super(),this.layoutService=e,this.currentViewDisposable=j.None,this.contextView=this._register(new Dm(this.layoutService.mainContainer,1)),this.layout(),this._register(e.onDidLayoutContainer(()=>this.layout()))}showContextView(e,t,i){let n;t?t===this.layoutService.getContainer(Xe(t))?n=1:i?n=3:n=2:n=1,this.contextView.setContainer(t??this.layoutService.activeContainer,n),this.contextView.show(e);const o=Fe(()=>{this.currentViewDisposable===o&&this.hideContextView()});return this.currentViewDisposable=o,o}getContextViewElement(){return this.contextView.getViewElement()}layout(){this.contextView.layout()}hideContextView(e){this.contextView.hide(e)}dispose(){super.dispose(),this.currentViewDisposable.dispose(),this.currentViewDisposable=j.None}};e2=Gue([Zue(0,d_)],e2);let km=[],tO=[],Nz=[];function P1(s,e=!1){Yue(s,!1,e)}function Yue(s,e,t){const i=Xue(s,e);km.push(i),i.userConfigured?Nz.push(i):tO.push(i),t&&!i.userConfigured&&km.forEach(n=>{n.mime===i.mime||n.userConfigured||(i.extension&&n.extension===i.extension&&console.warn(`Overwriting extension <<${i.extension}>> to now point to mime <<${i.mime}>>`),i.filename&&n.filename===i.filename&&console.warn(`Overwriting filename <<${i.filename}>> to now point to mime <<${i.mime}>>`),i.filepattern&&n.filepattern===i.filepattern&&console.warn(`Overwriting filepattern <<${i.filepattern}>> to now point to mime <<${i.mime}>>`),i.firstline&&n.firstline===i.firstline&&console.warn(`Overwriting firstline <<${i.firstline}>> to now point to mime <<${i.mime}>>`))})}function Xue(s,e){return{id:s.id,mime:s.mime,filename:s.filename,extension:s.extension,filepattern:s.filepattern,firstline:s.firstline,userConfigured:e,filenameLowercase:s.filename?s.filename.toLowerCase():void 0,extensionLowercase:s.extension?s.extension.toLowerCase():void 0,filepatternLowercase:s.filepattern?yz(s.filepattern.toLowerCase()):void 0,filepatternOnPath:s.filepattern?s.filepattern.indexOf(an.sep)>=0:!1}}function Que(){km=km.filter(s=>s.userConfigured),tO=[]}function Jue(s,e){return ehe(s,e).map(t=>t.id)}function ehe(s,e){let t;if(s)switch(s.scheme){case it.file:t=s.fsPath;break;case it.data:{t=Fu.parseMetaData(s).get(Fu.META_DATA_LABEL);break}case it.vscodeNotebookCell:t=void 0;break;default:t=s.path}if(!t)return[{id:"unknown",mime:Hi.unknown}];t=t.toLowerCase();const i=ru(t),n=X7(t,i,Nz);if(n)return[n,{id:er,mime:Hi.text}];const o=X7(t,i,tO);if(o)return[o,{id:er,mime:Hi.text}];if(e){const r=the(e);if(r)return[r,{id:er,mime:Hi.text}]}return[{id:"unknown",mime:Hi.unknown}]}function X7(s,e,t){var i;let n,o,r;for(let a=t.length-1;a>=0;a--){const l=t[a];if(e===l.filenameLowercase){n=l;break}if(l.filepattern&&(!o||l.filepattern.length>o.filepattern.length)){const d=l.filepatternOnPath?s:e;!((i=l.filepatternLowercase)===null||i===void 0)&&i.call(l,d)&&(o=l)}l.extension&&(!r||l.extension.length>r.extension.length)&&e.endsWith(l.extensionLowercase)&&(r=l)}if(n)return n;if(o)return o;if(r)return r}function the(s){if(zA(s)&&(s=s.substr(1)),s.length>0)for(let e=km.length-1;e>=0;e--){const t=km[e];if(!t.firstline)continue;const i=s.match(t.firstline);if(i&&i.length>0)return t}}const O1=Object.prototype.hasOwnProperty,Q7="vs.editor.nullLanguage";class ihe{constructor(){this._languageIdToLanguage=[],this._languageToLanguageId=new Map,this._register(Q7,0),this._register(er,1),this._nextLanguageId=2}_register(e,t){this._languageIdToLanguage[t]=e,this._languageToLanguageId.set(e,t)}register(e){if(this._languageToLanguageId.has(e))return;const t=this._nextLanguageId++;this._register(e,t)}encodeLanguageId(e){return this._languageToLanguageId.get(e)||0}decodeLanguageId(e){return this._languageIdToLanguage[e]||Q7}}class ob extends j{constructor(e=!0,t=!1){super(),this._onDidChange=this._register(new W),this.onDidChange=this._onDidChange.event,ob.instanceCount++,this._warnOnOverwrite=t,this.languageIdCodec=new ihe,this._dynamicLanguages=[],this._languages={},this._mimeTypesMap={},this._nameMap={},this._lowercaseNameMap={},e&&(this._initializeFromRegistry(),this._register(hm.onDidChangeLanguages(i=>{this._initializeFromRegistry()})))}dispose(){ob.instanceCount--,super.dispose()}_initializeFromRegistry(){this._languages={},this._mimeTypesMap={},this._nameMap={},this._lowercaseNameMap={},Que();const e=[].concat(hm.getLanguages()).concat(this._dynamicLanguages);this._registerLanguages(e)}_registerLanguages(e){for(const t of e)this._registerLanguage(t);this._mimeTypesMap={},this._nameMap={},this._lowercaseNameMap={},Object.keys(this._languages).forEach(t=>{const i=this._languages[t];i.name&&(this._nameMap[i.name]=i.identifier),i.aliases.forEach(n=>{this._lowercaseNameMap[n.toLowerCase()]=i.identifier}),i.mimetypes.forEach(n=>{this._mimeTypesMap[n]=i.identifier})}),Si.as(Za.Configuration).registerOverrideIdentifiers(this.getRegisteredLanguageIds()),this._onDidChange.fire()}_registerLanguage(e){const t=e.id;let i;O1.call(this._languages,t)?i=this._languages[t]:(this.languageIdCodec.register(t),i={identifier:t,name:null,mimetypes:[],aliases:[],extensions:[],filenames:[],configurationFiles:[],icons:[]},this._languages[t]=i),this._mergeLanguage(i,e)}_mergeLanguage(e,t){const i=t.id;let n=null;if(Array.isArray(t.mimetypes)&&t.mimetypes.length>0&&(e.mimetypes.push(...t.mimetypes),n=t.mimetypes[0]),n||(n=`text/x-${i}`,e.mimetypes.push(n)),Array.isArray(t.extensions)){t.configuration?e.extensions=t.extensions.concat(e.extensions):e.extensions=e.extensions.concat(t.extensions);for(const a of t.extensions)P1({id:i,mime:n,extension:a},this._warnOnOverwrite)}if(Array.isArray(t.filenames))for(const a of t.filenames)P1({id:i,mime:n,filename:a},this._warnOnOverwrite),e.filenames.push(a);if(Array.isArray(t.filenamePatterns))for(const a of t.filenamePatterns)P1({id:i,mime:n,filepattern:a},this._warnOnOverwrite);if(typeof t.firstLine=="string"&&t.firstLine.length>0){let a=t.firstLine;a.charAt(0)!=="^"&&(a="^"+a);try{const l=new RegExp(a);sJ(l)||P1({id:i,mime:n,firstline:l},this._warnOnOverwrite)}catch(l){console.warn(`[${t.id}]: Invalid regular expression \`${a}\`: `,l)}}e.aliases.push(i);let o=null;if(typeof t.aliases<"u"&&Array.isArray(t.aliases)&&(t.aliases.length===0?o=[null]:o=t.aliases),o!==null)for(const a of o)!a||a.length===0||e.aliases.push(a);const r=o!==null&&o.length>0;if(!(r&&o[0]===null)){const a=(r?o[0]:null)||i;(r||!e.name)&&(e.name=a)}t.configuration&&e.configurationFiles.push(t.configuration),t.icon&&e.icons.push(t.icon)}isRegisteredLanguageId(e){return e?O1.call(this._languages,e):!1}getRegisteredLanguageIds(){return Object.keys(this._languages)}getLanguageIdByLanguageName(e){const t=e.toLowerCase();return O1.call(this._lowercaseNameMap,t)?this._lowercaseNameMap[t]:null}getLanguageIdByMimeType(e){return e&&O1.call(this._mimeTypesMap,e)?this._mimeTypesMap[e]:null}guessLanguageIdByFilepathOrFirstLine(e,t){return!e&&!t?[]:Jue(e,t)}}ob.instanceCount=0;class rb extends j{constructor(e=!1){super(),this._onDidRequestBasicLanguageFeatures=this._register(new W),this.onDidRequestBasicLanguageFeatures=this._onDidRequestBasicLanguageFeatures.event,this._onDidRequestRichLanguageFeatures=this._register(new W),this.onDidRequestRichLanguageFeatures=this._onDidRequestRichLanguageFeatures.event,this._onDidChange=this._register(new W({leakWarningThreshold:200})),this.onDidChange=this._onDidChange.event,this._requestedBasicLanguages=new Set,this._requestedRichLanguages=new Set,rb.instanceCount++,this._registry=this._register(new ob(!0,e)),this.languageIdCodec=this._registry.languageIdCodec,this._register(this._registry.onDidChange(()=>this._onDidChange.fire()))}dispose(){rb.instanceCount--,super.dispose()}isRegisteredLanguageId(e){return this._registry.isRegisteredLanguageId(e)}getLanguageIdByLanguageName(e){return this._registry.getLanguageIdByLanguageName(e)}getLanguageIdByMimeType(e){return this._registry.getLanguageIdByMimeType(e)}guessLanguageIdByFilepathOrFirstLine(e,t){const i=this._registry.guessLanguageIdByFilepathOrFirstLine(e,t);return wA(i,null)}createById(e){return new J7(this.onDidChange,()=>this._createAndGetLanguageIdentifier(e))}createByFilepathOrFirstLine(e,t){return new J7(this.onDidChange,()=>{const i=this.guessLanguageIdByFilepathOrFirstLine(e,t);return this._createAndGetLanguageIdentifier(i)})}_createAndGetLanguageIdentifier(e){return(!e||!this.isRegisteredLanguageId(e))&&(e=er),e}requestBasicLanguageFeatures(e){this._requestedBasicLanguages.has(e)||(this._requestedBasicLanguages.add(e),this._onDidRequestBasicLanguageFeatures.fire(e))}requestRichLanguageFeatures(e){this._requestedRichLanguages.has(e)||(this._requestedRichLanguages.add(e),this.requestBasicLanguageFeatures(e),xi.getOrCreate(e),this._onDidRequestRichLanguageFeatures.fire(e))}}rb.instanceCount=0;class J7{constructor(e,t){this._onDidChangeLanguages=e,this._selector=t,this._listener=null,this._emitter=null,this.languageId=this._selector()}_dispose(){this._listener&&(this._listener.dispose(),this._listener=null),this._emitter&&(this._emitter.dispose(),this._emitter=null)}get onDidChange(){return this._listener||(this._listener=this._onDidChangeLanguages(()=>this._evaluate())),this._emitter||(this._emitter=new W({onDidRemoveLastListener:()=>{this._dispose()}})),this._emitter.event}_evaluate(){var e;const t=this._selector();t!==this.languageId&&(this.languageId=t,(e=this._emitter)===null||e===void 0||e.fire(this.languageId))}}const ab={RESOURCES:"ResourceURLs",DOWNLOAD_URL:"DownloadURL",FILES:"Files",TEXT:Hi.text,INTERNAL_URI_LIST:"application/vnd.code.uri-list"};function nhe(s){const e=she(s);if(e&&e.length>0)return new Uint32Array(e)}let Fo=0;const Bc=new Uint32Array(10);function she(s){if(Fo=0,tl(s,NI,4352),Fo>0||(tl(s,TI,4449),Fo>0)||(tl(s,MI,4520),Fo>0)||(tl(s,Sh,12593),Fo))return Bc.subarray(0,Fo);if(s>=44032&&s<=55203){const e=s-44032,t=e%588,i=Math.floor(e/588),n=Math.floor(t/28),o=t%28-1;if(i<NI.length?tl(i,NI,0):4352+i-12593<Sh.length&&tl(4352+i,Sh,12593),n<TI.length?tl(n,TI,0):4449+n-12593<Sh.length&&tl(4449+n-12593,Sh,12593),o>=0&&(o<MI.length?tl(o,MI,0):4520+o-12593<Sh.length&&tl(4520+o-12593,Sh,12593)),Fo>0)return Bc.subarray(0,Fo)}}function tl(s,e,t){s>=t&&s<t+e.length&&ohe(e[s-t])}function ohe(s){s!==0&&(Bc[Fo++]=s&255,s>>8&&(Bc[Fo++]=s>>8&255),s>>16&&(Bc[Fo++]=s>>16&255))}const NI=new Uint8Array([114,82,115,101,69,102,97,113,81,116,84,100,119,87,99,122,120,118,103]),TI=new Uint16Array([107,111,105,79,106,112,117,80,104,27496,28520,27752,121,110,27246,28782,27758,98,109,27757,108]),MI=new Uint16Array([114,82,29810,115,30579,26483,101,102,29286,24934,29030,29798,30822,30310,26470,97,113,29809,116,84,100,119,99,122,120,118,103]),Sh=new Uint16Array([114,82,29810,115,30579,26483,101,69,102,29286,24934,29030,29798,30822,30310,26470,97,113,81,29809,116,84,100,119,87,99,122,120,118,103,107,111,105,79,106,112,117,80,104,27496,28520,27752,121,110,27246,28782,27758,98,109,27757,108]);function iO(...s){return function(e,t){for(let i=0,n=s.length;i<n;i++){const o=s[i](e,t);if(o)return o}return null}}Tz.bind(void 0,!1);const lb=Tz.bind(void 0,!0);function Tz(s,e,t){if(!t||t.length<e.length)return null;let i;return s?i=FA(t,e):i=t.indexOf(e)===0,i?e.length>0?[{start:0,end:e.length}]:[]:null}function Mz(s,e){const t=e.toLowerCase().indexOf(s.toLowerCase());return t===-1?null:[{start:t,end:t+s.length}]}function Rz(s,e){return t2(s.toLowerCase(),e.toLowerCase(),0,0)}function t2(s,e,t,i){if(t===s.length)return[];if(i===e.length)return null;if(s[t]===e[i]){let n=null;return(n=t2(s,e,t+1,i+1))?oO({start:i,end:i+1},n):null}return t2(s,e,t,i+1)}function nO(s){return 97<=s&&s<=122}function Bx(s){return 65<=s&&s<=90}function sO(s){return 48<=s&&s<=57}function Az(s){return s===32||s===9||s===10||s===13}const Pz=new Set;"()[]{}<>`'\"-/;:,.?!".split("").forEach(s=>Pz.add(s.charCodeAt(0)));function wy(s){return Az(s)||Pz.has(s)}function e9(s,e){return s===e||wy(s)&&wy(e)}const RI=new Map;function t9(s){if(RI.has(s))return RI.get(s);let e;const t=nhe(s);return t&&(e=t),RI.set(s,e),e}function Oz(s){return nO(s)||Bx(s)||sO(s)}function oO(s,e){return e.length===0?e=[s]:s.end===e[0].start?e[0].start=s.start:e.unshift(s),e}function Fz(s,e){for(let t=e;t<s.length;t++){const i=s.charCodeAt(t);if(Bx(i)||sO(i)||t>0&&!Oz(s.charCodeAt(t-1)))return t}return s.length}function i2(s,e,t,i){if(t===s.length)return[];if(i===e.length)return null;if(s[t]!==e[i].toLowerCase())return null;{let n=null,o=i+1;for(n=i2(s,e,t+1,i+1);!n&&(o=Fz(e,o))<e.length;)n=i2(s,e,t+1,o),o++;return n===null?null:oO({start:i,end:i+1},n)}}function rhe(s){let e=0,t=0,i=0,n=0,o=0;for(let c=0;c<s.length;c++)o=s.charCodeAt(c),Bx(o)&&e++,nO(o)&&t++,Oz(o)&&i++,sO(o)&&n++;const r=e/s.length,a=t/s.length,l=i/s.length,d=n/s.length;return{upperPercent:r,lowerPercent:a,alphaPercent:l,numericPercent:d}}function ahe(s){const{upperPercent:e,lowerPercent:t}=s;return t===0&&e>.6}function lhe(s){const{upperPercent:e,lowerPercent:t,alphaPercent:i,numericPercent:n}=s;return t>.2&&e<.8&&i>.6&&n<.2}function dhe(s){let e=0,t=0,i=0,n=0;for(let o=0;o<s.length;o++)i=s.charCodeAt(o),Bx(i)&&e++,nO(i)&&t++,Az(i)&&n++;return(e===0||t===0)&&n===0?s.length<=30:e<=5}function Bz(s,e){if(!e||(e=e.trim(),e.length===0)||!dhe(s)||e.length>60)return null;const t=rhe(e);if(!lhe(t)){if(!ahe(t))return null;e=e.toLowerCase()}let i=null,n=0;for(s=s.toLowerCase();n<e.length&&(i=i2(s,e,0,n))===null;)n=Fz(e,n+1);return i}function che(s,e,t=!1){if(!e||e.length===0)return null;let i=null,n=0;for(s=s.toLowerCase(),e=e.toLowerCase();n<e.length&&(i=n2(s,e,0,n,t),i===null);)n=Wz(e,n+1);return i}function n2(s,e,t,i,n){let o=0;if(t===s.length)return[];if(i===e.length)return null;if(!e9(s.charCodeAt(t),e.charCodeAt(i))){const l=t9(s.charCodeAt(t));if(!l)return null;for(let d=0;d<l.length;d++)if(!e9(l[d],e.charCodeAt(i+d)))return null;o+=l.length-1}let r=null,a=i+o+1;if(r=n2(s,e,t+1,a,n),!n)for(;!r&&(a=Wz(e,a))<e.length;)r=n2(s,e,t+1,a,n),a++;if(!r)return null;if(s.charCodeAt(t)!==e.charCodeAt(i)){const l=t9(s.charCodeAt(t));if(!l)return r;for(let d=0;d<l.length;d++)if(l[d]!==e.charCodeAt(i+d))return r}return oO({start:i,end:i+o+1},r)}function Wz(s,e){for(let t=e;t<s.length;t++)if(wy(s.charCodeAt(t))||t>0&&wy(s.charCodeAt(t-1)))return t;return s.length}const uhe=iO(lb,Bz,Mz),hhe=iO(lb,Bz,Rz),i9=new nh(1e4);function n9(s,e,t=!1){if(typeof s!="string"||typeof e!="string")return null;let i=i9.get(s);i||(i=new RegExp(iJ(s),"i"),i9.set(s,i));const n=i.exec(e);return n?[{start:n.index,end:n.index+n[0].length}]:t?hhe(s,e):uhe(s,e)}function ghe(s,e){const t=Pg(s,s.toLowerCase(),0,e,e.toLowerCase(),0,{firstMatchCanBeWeak:!0,boostFullMatch:!0});return t?CC(t):null}function fhe(s,e,t,i,n,o){const r=Math.min(13,s.length);for(;t<r;t++){const a=Pg(s,e,t,i,n,o,{firstMatchCanBeWeak:!0,boostFullMatch:!0});if(a)return a}return[0,o]}function CC(s){if(typeof s>"u")return[];const e=[],t=s[1];for(let i=s.length-1;i>1;i--){const n=s[i]+t,o=e[e.length-1];o&&o.end===n?o.end=n+1:e.push({start:n,end:n+1})}return e}const Zc=128;function rO(){const s=[],e=[];for(let t=0;t<=Zc;t++)e[t]=0;for(let t=0;t<=Zc;t++)s.push(e.slice(0));return s}function Vz(s){const e=[];for(let t=0;t<=s;t++)e[t]=0;return e}const Hz=Vz(2*Zc),s2=Vz(2*Zc),gd=rO(),yh=rO(),F1=rO();function B1(s,e){if(e<0||e>=s.length)return!1;const t=s.codePointAt(e);switch(t){case 95:case 45:case 46:case 32:case 47:case 92:case 39:case 34:case 58:case 36:case 60:case 62:case 40:case 41:case 91:case 93:case 123:case 125:return!0;case void 0:return!1;default:return!!HA(t)}}function s9(s,e){if(e<0||e>=s.length)return!1;switch(s.charCodeAt(e)){case 32:case 9:return!0;default:return!1}}function Kw(s,e,t){return e[s]!==t[s]}function phe(s,e,t,i,n,o,r=!1){for(;e<t&&n<o;)s[e]===i[n]&&(r&&(Hz[e]=n),e+=1),n+=1;return e===t}var Fa;(function(s){s.Default=[-100,0];function e(t){return!t||t.length===2&&t[0]===-100&&t[1]===0}s.isDefault=e})(Fa||(Fa={}));class Wx{constructor(e,t){this.firstMatchCanBeWeak=e,this.boostFullMatch=t}}Wx.default={boostFullMatch:!0,firstMatchCanBeWeak:!1};function Pg(s,e,t,i,n,o,r=Wx.default){const a=s.length>Zc?Zc:s.length,l=i.length>Zc?Zc:i.length;if(t>=a||o>=l||a-t>l-o||!phe(e,t,a,n,o,l,!0))return;mhe(a,l,t,o,e,n);let d=1,c=1,u=t,h=o;const g=[!1];for(d=1,u=t;u<a;d++,u++){const b=Hz[u],C=s2[u],w=u+1<a?s2[u+1]:l;for(c=b-o+1,h=b;h<w;c++,h++){let S=Number.MIN_SAFE_INTEGER,x=!1;h<=C&&(S=_he(s,e,u,t,i,n,h,l,o,gd[d-1][c-1]===0,g));let L=0;S!==Number.MAX_SAFE_INTEGER&&(x=!0,L=S+yh[d-1][c-1]);const k=h>b,I=k?yh[d][c-1]+(gd[d][c-1]>0?-5:0):0,P=h>b+1&&gd[d][c-1]>0,$=P?yh[d][c-2]+(gd[d][c-2]>0?-5:0):0;if(P&&(!k||$>=I)&&(!x||$>=L))yh[d][c]=$,F1[d][c]=3,gd[d][c]=0;else if(k&&(!x||I>=L))yh[d][c]=I,F1[d][c]=2,gd[d][c]=0;else if(x)yh[d][c]=L,F1[d][c]=1,gd[d][c]=gd[d-1][c-1]+1;else throw new Error("not possible")}}if(!g[0]&&!r.firstMatchCanBeWeak)return;d--,c--;const f=[yh[d][c],o];let m=0,_=0;for(;d>=1;){let b=c;do{const C=F1[d][b];if(C===3)b=b-2;else if(C===2)b=b-1;else break}while(b>=1);m>1&&e[t+d-1]===n[o+c-1]&&!Kw(b+o-1,i,n)&&m+1>gd[d][b]&&(b=c),b===c?m++:m=1,_||(_=b),d--,c=b-1,f.push(c)}l===a&&r.boostFullMatch&&(f[0]+=2);const v=_-a;return f[0]-=v,f}function mhe(s,e,t,i,n,o){let r=s-1,a=e-1;for(;r>=t&&a>=i;)n[r]===o[a]&&(s2[r]=a,r--),a--}function _he(s,e,t,i,n,o,r,a,l,d,c){if(e[t]!==o[r])return Number.MIN_SAFE_INTEGER;let u=1,h=!1;return r===t-i?u=s[t]===n[r]?7:5:Kw(r,n,o)&&(r===0||!Kw(r-1,n,o))?(u=s[t]===n[r]?7:5,h=!0):B1(o,r)&&(r===0||!B1(o,r-1))?u=5:(B1(o,r-1)||s9(o,r-1))&&(u=5,h=!0),u>1&&t===i&&(c[0]=!0),h||(h=Kw(r,n,o)||B1(o,r-1)||s9(o,r-1)),t===i?r>l&&(u-=h?3:5):d?u+=h?2:0:u+=h?0:1,r+1===a&&(u-=h?3:5),u}function vhe(s,e,t,i,n,o,r){return bhe(s,e,t,i,n,o,!0,r)}function bhe(s,e,t,i,n,o,r,a){let l=Pg(s,e,t,i,n,o,a);if(l&&!r)return l;if(s.length>=3){const d=Math.min(7,s.length-1);for(let c=t+1;c<d;c++){const u=Che(s,c);if(u){const h=Pg(u,u.toLowerCase(),t,i,n,o,a);h&&(h[0]-=3,(!l||h[0]>l[0])&&(l=h))}}}return l}function Che(s,e){if(e+1>=s.length)return;const t=s[e],i=s[e+1];if(t!==i)return s.slice(0,e)+i+t+s.slice(e+2)}const whe="$(",aO=new RegExp(`\\$\\(${Oe.iconNameExpression}(?:${Oe.iconModifierExpression})?\\)`,"g"),She=new RegExp(`(\\\\)?${aO.source}`,"g");function yhe(s){return s.replace(She,(e,t)=>t?e:`\\${e}`)}const Lhe=new RegExp(`\\\\${aO.source}`,"g");function xhe(s){return s.replace(Lhe,e=>`\\${e}`)}const Dhe=new RegExp(`(\\s)?(\\\\)?${aO.source}(\\s)?`,"g");function lO(s){return s.indexOf(whe)===-1?s:s.replace(Dhe,(e,t,i,n)=>i?e:t||n||"")}function khe(s){return s?s.replace(/\$\((.*?)\)/g,(e,t)=>` ${t} `).trim():""}const AI=new RegExp(`\\$\\(${Oe.iconNameCharacter}+\\)`,"g");function vv(s){AI.lastIndex=0;let e="";const t=[];let i=0;for(;;){const n=AI.lastIndex,o=AI.exec(s),r=s.substring(n,o==null?void 0:o.index);if(r.length>0){e+=r;for(let a=0;a<r.length;a++)t.push(i)}if(!o)break;i+=o[0].length}return{text:e,iconOffsets:t}}function PI(s,e,t=!1){const{text:i,iconOffsets:n}=e;if(!n||n.length===0)return n9(s,i,t);const o=iC(i," "),r=i.length-o.length,a=n9(s,o,t);if(a)for(const l of a){const d=n[l.start+r]+r;l.start+=d,l.end+=d}return a}class rs{constructor(e="",t=!1){var i,n,o;if(this.value=e,typeof this.value!="string")throw Cr("value");typeof t=="boolean"?(this.isTrusted=t,this.supportThemeIcons=!1,this.supportHtml=!1):(this.isTrusted=(i=t.isTrusted)!==null&&i!==void 0?i:void 0,this.supportThemeIcons=(n=t.supportThemeIcons)!==null&&n!==void 0?n:!1,this.supportHtml=(o=t.supportHtml)!==null&&o!==void 0?o:!1)}appendText(e,t=0){return this.value+=Ehe(this.supportThemeIcons?yhe(e):e).replace(/([ \t]+)/g,(i,n)=>"&nbsp;".repeat(n.length)).replace(/\>/gm,"\\>").replace(/\n/g,t===1?`\\
`:`

`),this}appendMarkdown(e){return this.value+=e,this}appendCodeblock(e,t){return this.value+="\n```",this.value+=e,this.value+=`
`,this.value+=t,this.value+="\n```\n",this}appendLink(e,t,i){return this.value+="[",this.value+=this._escape(t,"]"),this.value+="](",this.value+=this._escape(String(e),")"),i&&(this.value+=` "${this._escape(this._escape(i,'"'),")")}"`),this.value+=")",this}_escape(e,t){const i=new RegExp(ir(t),"g");return e.replace(i,(n,o)=>e.charAt(o-1)!=="\\"?`\\${n}`:n)}}function Im(s){return uu(s)?!s.value:Array.isArray(s)?s.every(Im):!0}function uu(s){return s instanceof rs?!0:s&&typeof s=="object"?typeof s.value=="string"&&(typeof s.isTrusted=="boolean"||typeof s.isTrusted=="object"||s.isTrusted===void 0)&&(typeof s.supportThemeIcons=="boolean"||s.supportThemeIcons===void 0):!1}function Ihe(s,e){return s===e?!0:!s||!e?!1:s.value===e.value&&s.isTrusted===e.isTrusted&&s.supportThemeIcons===e.supportThemeIcons&&s.supportHtml===e.supportHtml&&(s.baseUri===e.baseUri||!!s.baseUri&&!!e.baseUri&&PP(Pe.from(s.baseUri),Pe.from(e.baseUri)))}function Ehe(s){return s.replace(/[\\`*_{}[\]()#+\-!~]/g,"\\$&")}function W1(s){return s.replace(/"/g,"&quot;")}function OI(s){return s&&s.replace(/\\([\\`*_{}[\]()#+\-.!~])/g,"$1")}function Nhe(s){const e=[],t=s.split("|").map(n=>n.trim());s=t[0];const i=t[1];if(i){const n=/height=(\d+)/.exec(i),o=/width=(\d+)/.exec(i),r=n?n[1]:"",a=o?o[1]:"",l=isFinite(parseInt(a)),d=isFinite(parseInt(r));l&&e.push(`width="${a}"`),d&&e.push(`height="${r}"`)}return{href:s,dimensions:e}}function The(s,e){Ps(e)?s.title=lO(e):e!=null&&e.markdownNotSupportedFallback?s.title=e.markdownNotSupportedFallback:s.removeAttribute("title")}class Mhe{constructor(e,t,i){this.hoverDelegate=e,this.target=t,this.fadeInAnimation=i}async update(e,t,i){var n;if(this._cancellationTokenSource&&(this._cancellationTokenSource.dispose(!0),this._cancellationTokenSource=void 0),this.isDisposed)return;let o;if(e===void 0||Ps(e)||e instanceof HTMLElement)o=e;else if(!C0(e.markdown))o=(n=e.markdown)!==null&&n!==void 0?n:e.markdownNotSupportedFallback;else{this._hoverWidget||this.show(p("iconLabel.loading","Loading..."),t),this._cancellationTokenSource=new Yi;const r=this._cancellationTokenSource.token;if(o=await e.markdown(r),o===void 0&&(o=e.markdownNotSupportedFallback),this.isDisposed||r.isCancellationRequested)return}this.show(o,t,i)}show(e,t,i){const n=this._hoverWidget;if(this.hasContent(e)){const o={content:e,target:this.target,appearance:{showPointer:this.hoverDelegate.placement==="element",skipFadeInAnimation:!this.fadeInAnimation||!!n},position:{hoverPosition:2},...i};this._hoverWidget=this.hoverDelegate.showHover(o,t)}n==null||n.dispose()}hasContent(e){return e?uu(e)?!!e.value:!0:!1}get isDisposed(){var e;return(e=this._hoverWidget)===null||e===void 0?void 0:e.isDisposed}dispose(){var e,t;(e=this._hoverWidget)===null||e===void 0||e.dispose(),(t=this._cancellationTokenSource)===null||t===void 0||t.dispose(!0),this._cancellationTokenSource=void 0}}function zz(s,e,t,i){let n,o;const r=(g,f)=>{var m;const _=o!==void 0;g&&(o==null||o.dispose(),o=void 0),f&&(n==null||n.dispose(),n=void 0),_&&((m=s.onDidHideHover)===null||m===void 0||m.call(s))},a=(g,f,m)=>new ea(async()=>{(!o||o.isDisposed)&&(o=new Mhe(s,m||e,g>0),await o.update(t,f,i))},g),l=()=>{if(n)return;const g=new ie,f=v=>r(!1,v.fromElement===e);g.add(Y(e,he.MOUSE_LEAVE,f,!0));const m=()=>r(!0,!0);g.add(Y(e,he.MOUSE_DOWN,m,!0));const _={targetElements:[e],dispose:()=>{}};if(s.placement===void 0||s.placement==="mouse"){const v=b=>{_.x=b.x+10,b.target instanceof HTMLElement&&b.target.classList.contains("action-label")&&r(!0,!0)};g.add(Y(e,he.MOUSE_MOVE,v,!0))}g.add(a(s.delay,!1,_)),n=g},d=Y(e,he.MOUSE_OVER,l,!0),c=()=>{if(n)return;const g={targetElements:[e],dispose:()=>{}},f=new ie,m=()=>r(!0,!0);f.add(Y(e,he.BLUR,m,!0)),f.add(a(s.delay,!1,g)),n=f},u=Y(e,he.FOCUS,c,!0);return{show:g=>{r(!1,!0),a(0,g)},hide:()=>{r(!0,!0)},update:async(g,f)=>{t=g,await(o==null?void 0:o.update(t,void 0,f))},dispose:()=>{d.dispose(),u.dispose(),r(!0,!0)}}}function Rhe(s,e={}){const t=dO(e);return t.textContent=s,t}function Ahe(s,e={}){const t=dO(e);return Uz(t,Ohe(s,!!e.renderCodeSegments),e.actionHandler,e.renderCodeSegments),t}function dO(s){const e=s.inline?"span":"div",t=document.createElement(e);return s.className&&(t.className=s.className),t}class Phe{constructor(e){this.source=e,this.index=0}eos(){return this.index>=this.source.length}next(){const e=this.peek();return this.advance(),e}peek(){return this.source[this.index]}advance(){this.index++}}function Uz(s,e,t,i){let n;if(e.type===2)n=document.createTextNode(e.content||"");else if(e.type===3)n=document.createElement("b");else if(e.type===4)n=document.createElement("i");else if(e.type===7&&i)n=document.createElement("code");else if(e.type===5&&t){const o=document.createElement("a");t.disposables.add(Pi(o,"click",r=>{t.callback(String(e.index),r)})),n=o}else e.type===8?n=document.createElement("br"):e.type===1&&(n=s);n&&s!==n&&s.appendChild(n),n&&Array.isArray(e.children)&&e.children.forEach(o=>{Uz(n,o,t,i)})}function Ohe(s,e){const t={type:1,children:[]};let i=0,n=t;const o=[],r=new Phe(s);for(;!r.eos();){let a=r.next();const l=a==="\\"&&o2(r.peek(),e)!==0;if(l&&(a=r.next()),!l&&Fhe(a,e)&&a===r.peek()){r.advance(),n.type===2&&(n=o.pop());const d=o2(a,e);if(n.type===d||n.type===5&&d===6)n=o.pop();else{const c={type:d,children:[]};d===5&&(c.index=i,i++),n.children.push(c),o.push(n),n=c}}else if(a===`
`)n.type===2&&(n=o.pop()),n.children.push({type:8});else if(n.type!==2){const d={type:2,content:a};n.children.push(d),o.push(n),n=d}else n.content+=a}return n.type===2&&(n=o.pop()),t}function Fhe(s,e){return o2(s,e)!==0}function o2(s,e){switch(s){case"*":return 3;case"_":return 4;case"[":return 5;case"]":return 6;case"`":return e?7:0;default:return 0}}const Bhe=new RegExp(`(\\\\)?\\$\\((${Oe.iconNameExpression}(?:${Oe.iconModifierExpression})?)\\)`,"g");function hu(s){const e=new Array;let t,i=0,n=0;for(;(t=Bhe.exec(s))!==null;){n=t.index||0,i<n&&e.push(s.substring(i,n)),i=(t.index||0)+t[0].length;const[,o,r]=t;e.push(o?`$(${r})`:Sy({id:r}))}return i<s.length&&e.push(s.substring(i)),e}function Sy(s){const e=se("span");return e.classList.add(...Oe.asClassNameArray(s)),e}class cO{constructor(e){this._prefix=e,this._lastId=0}nextId(){return this._prefix+ ++this._lastId}}const r2=new cO("id#");let Vs={};(function(){function s(e,t){t(Vs)}s.amd=!0,function(e,t){typeof s=="function"&&s.amd?s(["exports"],t):typeof exports=="object"&&typeof module<"u"?t(exports):(e=typeof globalThis<"u"?globalThis:e||self,t(e.marked={}))}(this,function(e){function t(U,V){for(var F=0;F<V.length;F++){var E=V[F];E.enumerable=E.enumerable||!1,E.configurable=!0,"value"in E&&(E.writable=!0),Object.defineProperty(U,E.key,E)}}function i(U,V,F){return V&&t(U.prototype,V),F&&t(U,F),Object.defineProperty(U,"prototype",{writable:!1}),U}function n(U,V){if(U){if(typeof U=="string")return o(U,V);var F=Object.prototype.toString.call(U).slice(8,-1);if(F==="Object"&&U.constructor&&(F=U.constructor.name),F==="Map"||F==="Set")return Array.from(U);if(F==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(F))return o(U,V)}}function o(U,V){(V==null||V>U.length)&&(V=U.length);for(var F=0,E=new Array(V);F<V;F++)E[F]=U[F];return E}function r(U,V){var F=typeof Symbol<"u"&&U[Symbol.iterator]||U["@@iterator"];if(F)return(F=F.call(U)).next.bind(F);if(Array.isArray(U)||(F=n(U))||V&&U&&typeof U.length=="number"){F&&(U=F);var E=0;return function(){return E>=U.length?{done:!0}:{done:!1,value:U[E++]}}}throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function a(){return{async:!1,baseUrl:null,breaks:!1,extensions:null,gfm:!0,headerIds:!0,headerPrefix:"",highlight:null,langPrefix:"language-",mangle:!0,pedantic:!1,renderer:null,sanitize:!1,sanitizer:null,silent:!1,smartLists:!1,smartypants:!1,tokenizer:null,walkTokens:null,xhtml:!1}}e.defaults=a();function l(U){e.defaults=U}var d=/[&<>"']/,c=/[&<>"']/g,u=/[<>"']|&(?!#?\w+;)/,h=/[<>"']|&(?!#?\w+;)/g,g={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"},f=function(V){return g[V]};function m(U,V){if(V){if(d.test(U))return U.replace(c,f)}else if(u.test(U))return U.replace(h,f);return U}var _=/&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/ig;function v(U){return U.replace(_,function(V,F){return F=F.toLowerCase(),F==="colon"?":":F.charAt(0)==="#"?F.charAt(1)==="x"?String.fromCharCode(parseInt(F.substring(2),16)):String.fromCharCode(+F.substring(1)):""})}var b=/(^|[^\[])\^/g;function C(U,V){U=typeof U=="string"?U:U.source,V=V||"";var F={replace:function(M,B){return B=B.source||B,B=B.replace(b,"$1"),U=U.replace(M,B),F},getRegex:function(){return new RegExp(U,V)}};return F}var w=/[^\w:]/g,S=/^$|^[a-z][a-z0-9+.-]*:|^[?#]/i;function x(U,V,F){if(U){var E;try{E=decodeURIComponent(v(F)).replace(w,"").toLowerCase()}catch{return null}if(E.indexOf("javascript:")===0||E.indexOf("vbscript:")===0||E.indexOf("data:")===0)return null}V&&!S.test(F)&&(F=$(V,F));try{F=encodeURI(F).replace(/%25/g,"%")}catch{return null}return F}var L={},k=/^[^:]+:\/*[^/]*$/,I=/^([^:]+:)[\s\S]*$/,P=/^([^:]+:\/*[^/]*)[\s\S]*$/;function $(U,V){L[" "+U]||(k.test(U)?L[" "+U]=U+"/":L[" "+U]=Q(U,"/",!0)),U=L[" "+U];var F=U.indexOf(":")===-1;return V.substring(0,2)==="//"?F?V:U.replace(I,"$1")+V:V.charAt(0)==="/"?F?V:U.replace(P,"$1")+V:U+V}var A={exec:function(){}};function z(U){for(var V=1,F,E;V<arguments.length;V++){F=arguments[V];for(E in F)Object.prototype.hasOwnProperty.call(F,E)&&(U[E]=F[E])}return U}function K(U,V){var F=U.replace(/\|/g,function(B,O,X){for(var ce=!1,Se=O;--Se>=0&&X[Se]==="\\";)ce=!ce;return ce?"|":" |"}),E=F.split(/ \|/),M=0;if(E[0].trim()||E.shift(),E.length>0&&!E[E.length-1].trim()&&E.pop(),E.length>V)E.splice(V);else for(;E.length<V;)E.push("");for(;M<E.length;M++)E[M]=E[M].trim().replace(/\\\|/g,"|");return E}function Q(U,V,F){var E=U.length;if(E===0)return"";for(var M=0;M<E;){var B=U.charAt(E-M-1);if(B===V&&!F)M++;else if(B!==V&&F)M++;else break}return U.slice(0,E-M)}function ne(U,V){if(U.indexOf(V[1])===-1)return-1;for(var F=U.length,E=0,M=0;M<F;M++)if(U[M]==="\\")M++;else if(U[M]===V[0])E++;else if(U[M]===V[1]&&(E--,E<0))return M;return-1}function fe(U){U&&U.sanitize&&!U.silent&&console.warn("marked(): sanitize and sanitizer parameters are deprecated since version 0.7.0, should not be used and will be removed in the future. Read more here: https://marked.js.org/#/USING_ADVANCED.md#options")}function ve(U,V){if(V<1)return"";for(var F="";V>1;)V&1&&(F+=U),V>>=1,U+=U;return F+U}function ye(U,V,F,E){var M=V.href,B=V.title?m(V.title):null,O=U[1].replace(/\\([\[\]])/g,"$1");if(U[0].charAt(0)!=="!"){E.state.inLink=!0;var X={type:"link",raw:F,href:M,title:B,text:O,tokens:E.inlineTokens(O)};return E.state.inLink=!1,X}return{type:"image",raw:F,href:M,title:B,text:m(O)}}function Be(U,V){var F=U.match(/^(\s+)(?:```)/);if(F===null)return V;var E=F[1];return V.split(`
`).map(function(M){var B=M.match(/^\s+/);if(B===null)return M;var O=B[0];return O.length>=E.length?M.slice(E.length):M}).join(`
`)}var Ve=function(){function U(F){this.options=F||e.defaults}var V=U.prototype;return V.space=function(E){var M=this.rules.block.newline.exec(E);if(M&&M[0].length>0)return{type:"space",raw:M[0]}},V.code=function(E){var M=this.rules.block.code.exec(E);if(M){var B=M[0].replace(/^ {1,4}/gm,"");return{type:"code",raw:M[0],codeBlockStyle:"indented",text:this.options.pedantic?B:Q(B,`
`)}}},V.fences=function(E){var M=this.rules.block.fences.exec(E);if(M){var B=M[0],O=Be(B,M[3]||"");return{type:"code",raw:B,lang:M[2]?M[2].trim():M[2],text:O}}},V.heading=function(E){var M=this.rules.block.heading.exec(E);if(M){var B=M[2].trim();if(/#$/.test(B)){var O=Q(B,"#");(this.options.pedantic||!O||/ $/.test(O))&&(B=O.trim())}return{type:"heading",raw:M[0],depth:M[1].length,text:B,tokens:this.lexer.inline(B)}}},V.hr=function(E){var M=this.rules.block.hr.exec(E);if(M)return{type:"hr",raw:M[0]}},V.blockquote=function(E){var M=this.rules.block.blockquote.exec(E);if(M){var B=M[0].replace(/^ *>[ \t]?/gm,"");return{type:"blockquote",raw:M[0],tokens:this.lexer.blockTokens(B,[]),text:B}}},V.list=function(E){var M=this.rules.block.list.exec(E);if(M){var B,O,X,ce,Se,ke,Ke,Ye,Kt,At,qe,Ot,$t=M[1].trim(),so=$t.length>1,Ft={type:"list",raw:"",ordered:so,start:so?+$t.slice(0,-1):"",loose:!1,items:[]};$t=so?"\\d{1,9}\\"+$t.slice(-1):"\\"+$t,this.options.pedantic&&($t=so?$t:"[*+-]");for(var cn=new RegExp("^( {0,3}"+$t+")((?:[	 ][^\\n]*)?(?:\\n|$))");E&&(Ot=!1,!(!(M=cn.exec(E))||this.rules.block.hr.test(E)));){if(B=M[0],E=E.substring(B.length),Ye=M[2].split(`
`,1)[0],Kt=E.split(`
`,1)[0],this.options.pedantic?(ce=2,qe=Ye.trimLeft()):(ce=M[2].search(/[^ ]/),ce=ce>4?1:ce,qe=Ye.slice(ce),ce+=M[1].length),ke=!1,!Ye&&/^ *$/.test(Kt)&&(B+=Kt+`
`,E=E.substring(Kt.length+1),Ot=!0),!Ot)for(var gh=new RegExp("^ {0,"+Math.min(3,ce-1)+"}(?:[*+-]|\\d{1,9}[.)])((?: [^\\n]*)?(?:\\n|$))"),fh=new RegExp("^ {0,"+Math.min(3,ce-1)+"}((?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$)"),ra=new RegExp("^ {0,"+Math.min(3,ce-1)+"}(?:```|~~~)"),hc=new RegExp("^ {0,"+Math.min(3,ce-1)+"}#");E&&(At=E.split(`
`,1)[0],Ye=At,this.options.pedantic&&(Ye=Ye.replace(/^ {1,4}(?=( {4})*[^ ])/g,"  ")),!(ra.test(Ye)||hc.test(Ye)||gh.test(Ye)||fh.test(E)));){if(Ye.search(/[^ ]/)>=ce||!Ye.trim())qe+=`
`+Ye.slice(ce);else if(!ke)qe+=`
`+Ye;else break;!ke&&!Ye.trim()&&(ke=!0),B+=At+`
`,E=E.substring(At.length+1)}Ft.loose||(Ke?Ft.loose=!0:/\n *\n *$/.test(B)&&(Ke=!0)),this.options.gfm&&(O=/^\[[ xX]\] /.exec(qe),O&&(X=O[0]!=="[ ] ",qe=qe.replace(/^\[[ xX]\] +/,""))),Ft.items.push({type:"list_item",raw:B,task:!!O,checked:X,loose:!1,text:qe}),Ft.raw+=B}Ft.items[Ft.items.length-1].raw=B.trimRight(),Ft.items[Ft.items.length-1].text=qe.trimRight(),Ft.raw=Ft.raw.trimRight();var ph=Ft.items.length;for(Se=0;Se<ph;Se++){this.lexer.state.top=!1,Ft.items[Se].tokens=this.lexer.blockTokens(Ft.items[Se].text,[]);var mh=Ft.items[Se].tokens.filter(function(_h){return _h.type==="space"}),yf=mh.every(function(_h){for(var dk=_h.raw.split(""),Qa=0,L_=r(dk),x_;!(x_=L_()).done;){var KC=x_.value;if(KC===`
`&&(Qa+=1),Qa>1)return!0}return!1});!Ft.loose&&mh.length&&yf&&(Ft.loose=!0,Ft.items[Se].loose=!0)}return Ft}},V.html=function(E){var M=this.rules.block.html.exec(E);if(M){var B={type:"html",raw:M[0],pre:!this.options.sanitizer&&(M[1]==="pre"||M[1]==="script"||M[1]==="style"),text:M[0]};if(this.options.sanitize){var O=this.options.sanitizer?this.options.sanitizer(M[0]):m(M[0]);B.type="paragraph",B.text=O,B.tokens=this.lexer.inline(O)}return B}},V.def=function(E){var M=this.rules.block.def.exec(E);if(M){M[3]&&(M[3]=M[3].substring(1,M[3].length-1));var B=M[1].toLowerCase().replace(/\s+/g," ");return{type:"def",tag:B,raw:M[0],href:M[2],title:M[3]}}},V.table=function(E){var M=this.rules.block.table.exec(E);if(M){var B={type:"table",header:K(M[1]).map(function(Ke){return{text:Ke}}),align:M[2].replace(/^ *|\| *$/g,"").split(/ *\| */),rows:M[3]&&M[3].trim()?M[3].replace(/\n[ \t]*$/,"").split(`
`):[]};if(B.header.length===B.align.length){B.raw=M[0];var O=B.align.length,X,ce,Se,ke;for(X=0;X<O;X++)/^ *-+: *$/.test(B.align[X])?B.align[X]="right":/^ *:-+: *$/.test(B.align[X])?B.align[X]="center":/^ *:-+ *$/.test(B.align[X])?B.align[X]="left":B.align[X]=null;for(O=B.rows.length,X=0;X<O;X++)B.rows[X]=K(B.rows[X],B.header.length).map(function(Ke){return{text:Ke}});for(O=B.header.length,ce=0;ce<O;ce++)B.header[ce].tokens=this.lexer.inline(B.header[ce].text);for(O=B.rows.length,ce=0;ce<O;ce++)for(ke=B.rows[ce],Se=0;Se<ke.length;Se++)ke[Se].tokens=this.lexer.inline(ke[Se].text);return B}}},V.lheading=function(E){var M=this.rules.block.lheading.exec(E);if(M)return{type:"heading",raw:M[0],depth:M[2].charAt(0)==="="?1:2,text:M[1],tokens:this.lexer.inline(M[1])}},V.paragraph=function(E){var M=this.rules.block.paragraph.exec(E);if(M){var B=M[1].charAt(M[1].length-1)===`
`?M[1].slice(0,-1):M[1];return{type:"paragraph",raw:M[0],text:B,tokens:this.lexer.inline(B)}}},V.text=function(E){var M=this.rules.block.text.exec(E);if(M)return{type:"text",raw:M[0],text:M[0],tokens:this.lexer.inline(M[0])}},V.escape=function(E){var M=this.rules.inline.escape.exec(E);if(M)return{type:"escape",raw:M[0],text:m(M[1])}},V.tag=function(E){var M=this.rules.inline.tag.exec(E);if(M)return!this.lexer.state.inLink&&/^<a /i.test(M[0])?this.lexer.state.inLink=!0:this.lexer.state.inLink&&/^<\/a>/i.test(M[0])&&(this.lexer.state.inLink=!1),!this.lexer.state.inRawBlock&&/^<(pre|code|kbd|script)(\s|>)/i.test(M[0])?this.lexer.state.inRawBlock=!0:this.lexer.state.inRawBlock&&/^<\/(pre|code|kbd|script)(\s|>)/i.test(M[0])&&(this.lexer.state.inRawBlock=!1),{type:this.options.sanitize?"text":"html",raw:M[0],inLink:this.lexer.state.inLink,inRawBlock:this.lexer.state.inRawBlock,text:this.options.sanitize?this.options.sanitizer?this.options.sanitizer(M[0]):m(M[0]):M[0]}},V.link=function(E){var M=this.rules.inline.link.exec(E);if(M){var B=M[2].trim();if(!this.options.pedantic&&/^</.test(B)){if(!/>$/.test(B))return;var O=Q(B.slice(0,-1),"\\");if((B.length-O.length)%2===0)return}else{var X=ne(M[2],"()");if(X>-1){var ce=M[0].indexOf("!")===0?5:4,Se=ce+M[1].length+X;M[2]=M[2].substring(0,X),M[0]=M[0].substring(0,Se).trim(),M[3]=""}}var ke=M[2],Ke="";if(this.options.pedantic){var Ye=/^([^'"]*[^\s])\s+(['"])(.*)\2/.exec(ke);Ye&&(ke=Ye[1],Ke=Ye[3])}else Ke=M[3]?M[3].slice(1,-1):"";return ke=ke.trim(),/^</.test(ke)&&(this.options.pedantic&&!/>$/.test(B)?ke=ke.slice(1):ke=ke.slice(1,-1)),ye(M,{href:ke&&ke.replace(this.rules.inline._escapes,"$1"),title:Ke&&Ke.replace(this.rules.inline._escapes,"$1")},M[0],this.lexer)}},V.reflink=function(E,M){var B;if((B=this.rules.inline.reflink.exec(E))||(B=this.rules.inline.nolink.exec(E))){var O=(B[2]||B[1]).replace(/\s+/g," ");if(O=M[O.toLowerCase()],!O||!O.href){var X=B[0].charAt(0);return{type:"text",raw:X,text:X}}return ye(B,O,B[0],this.lexer)}},V.emStrong=function(E,M,B){B===void 0&&(B="");var O=this.rules.inline.emStrong.lDelim.exec(E);if(O&&!(O[3]&&B.match(/(?:[0-9A-Za-z\xAA\xB2\xB3\xB5\xB9\xBA\xBC-\xBE\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u0660-\u0669\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07C0-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u0870-\u0887\u0889-\u088E\u08A0-\u08C9\u0904-\u0939\u093D\u0950\u0958-\u0961\u0966-\u096F\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09E6-\u09F1\u09F4-\u09F9\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A66-\u0A6F\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AE6-\u0AEF\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B66-\u0B6F\u0B71-\u0B77\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0BE6-\u0BF2\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C5D\u0C60\u0C61\u0C66-\u0C6F\u0C78-\u0C7E\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDD\u0CDE\u0CE0\u0CE1\u0CE6-\u0CEF\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D58-\u0D61\u0D66-\u0D78\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DE6-\u0DEF\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F20-\u0F33\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F-\u1049\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u1090-\u1099\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1369-\u137C\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u1711\u171F-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1820-\u1878\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A16\u1A20-\u1A54\u1A80-\u1A89\u1A90-\u1A99\u1AA7\u1B05-\u1B33\u1B45-\u1B4C\u1B50-\u1B59\u1B83-\u1BA0\u1BAE-\u1BE5\u1C00-\u1C23\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2070\u2071\u2074-\u2079\u207F-\u2089\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2150-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2C00-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2CFD\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u3192-\u3195\u31A0-\u31BF\u31F0-\u31FF\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\u3400-\u4DBF\u4E00-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7CA\uA7D0\uA7D1\uA7D3\uA7D5-\uA7D9\uA7F2-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA830-\uA835\uA840-\uA873\uA882-\uA8B3\uA8D0-\uA8D9\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA900-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF-\uA9D9\uA9E0-\uA9E4\uA9E6-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA50-\uAA59\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD07-\uDD33\uDD40-\uDD78\uDD8A\uDD8B\uDE80-\uDE9C\uDEA0-\uDED0\uDEE1-\uDEFB\uDF00-\uDF23\uDF2D-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDD70-\uDD7A\uDD7C-\uDD8A\uDD8C-\uDD92\uDD94\uDD95\uDD97-\uDDA1\uDDA3-\uDDB1\uDDB3-\uDDB9\uDDBB\uDDBC\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67\uDF80-\uDF85\uDF87-\uDFB0\uDFB2-\uDFBA]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC58-\uDC76\uDC79-\uDC9E\uDCA7-\uDCAF\uDCE0-\uDCF2\uDCF4\uDCF5\uDCFB-\uDD1B\uDD20-\uDD39\uDD80-\uDDB7\uDDBC-\uDDCF\uDDD2-\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE35\uDE40-\uDE48\uDE60-\uDE7E\uDE80-\uDE9F\uDEC0-\uDEC7\uDEC9-\uDEE4\uDEEB-\uDEEF\uDF00-\uDF35\uDF40-\uDF55\uDF58-\uDF72\uDF78-\uDF91\uDFA9-\uDFAF]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2\uDCFA-\uDD23\uDD30-\uDD39\uDE60-\uDE7E\uDE80-\uDEA9\uDEB0\uDEB1\uDF00-\uDF27\uDF30-\uDF45\uDF51-\uDF54\uDF70-\uDF81\uDFB0-\uDFCB\uDFE0-\uDFF6]|\uD804[\uDC03-\uDC37\uDC52-\uDC6F\uDC71\uDC72\uDC75\uDC83-\uDCAF\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD03-\uDD26\uDD36-\uDD3F\uDD44\uDD47\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDD0-\uDDDA\uDDDC\uDDE1-\uDDF4\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDEF0-\uDEF9\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC50-\uDC59\uDC5F-\uDC61\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE50-\uDE59\uDE80-\uDEAA\uDEB8\uDEC0-\uDEC9\uDF00-\uDF1A\uDF30-\uDF3B\uDF40-\uDF46]|\uD806[\uDC00-\uDC2B\uDCA0-\uDCF2\uDCFF-\uDD06\uDD09\uDD0C-\uDD13\uDD15\uDD16\uDD18-\uDD2F\uDD3F\uDD41\uDD50-\uDD59\uDDA0-\uDDA7\uDDAA-\uDDD0\uDDE1\uDDE3\uDE00\uDE0B-\uDE32\uDE3A\uDE50\uDE5C-\uDE89\uDE9D\uDEB0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC50-\uDC6C\uDC72-\uDC8F\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD30\uDD46\uDD50-\uDD59\uDD60-\uDD65\uDD67\uDD68\uDD6A-\uDD89\uDD98\uDDA0-\uDDA9\uDEE0-\uDEF2\uDFB0\uDFC0-\uDFD4]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|\uD80B[\uDF90-\uDFF0]|[\uD80C\uD81C-\uD820\uD822\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879\uD880-\uD883][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDE70-\uDEBE\uDEC0-\uDEC9\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF50-\uDF59\uDF5B-\uDF61\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDE40-\uDE96\uDF00-\uDF4A\uDF50\uDF93-\uDF9F\uDFE0\uDFE1\uDFE3]|\uD821[\uDC00-\uDFF7]|\uD823[\uDC00-\uDCD5\uDD00-\uDD08]|\uD82B[\uDFF0-\uDFF3\uDFF5-\uDFFB\uDFFD\uDFFE]|\uD82C[\uDC00-\uDD22\uDD50-\uDD52\uDD64-\uDD67\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD834[\uDEE0-\uDEF3\uDF60-\uDF78]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD837[\uDF00-\uDF1E]|\uD838[\uDD00-\uDD2C\uDD37-\uDD3D\uDD40-\uDD49\uDD4E\uDE90-\uDEAD\uDEC0-\uDEEB\uDEF0-\uDEF9]|\uD839[\uDFE0-\uDFE6\uDFE8-\uDFEB\uDFED\uDFEE\uDFF0-\uDFFE]|\uD83A[\uDC00-\uDCC4\uDCC7-\uDCCF\uDD00-\uDD43\uDD4B\uDD50-\uDD59]|\uD83B[\uDC71-\uDCAB\uDCAD-\uDCAF\uDCB1-\uDCB4\uDD01-\uDD2D\uDD2F-\uDD3D\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD83C[\uDD00-\uDD0C]|\uD83E[\uDFF0-\uDFF9]|\uD869[\uDC00-\uDEDF\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF38\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]|\uD884[\uDC00-\uDF4A])/))){var X=O[1]||O[2]||"";if(!X||X&&(B===""||this.rules.inline.punctuation.exec(B))){var ce=O[0].length-1,Se,ke,Ke=ce,Ye=0,Kt=O[0][0]==="*"?this.rules.inline.emStrong.rDelimAst:this.rules.inline.emStrong.rDelimUnd;for(Kt.lastIndex=0,M=M.slice(-1*E.length+ce);(O=Kt.exec(M))!=null;)if(Se=O[1]||O[2]||O[3]||O[4]||O[5]||O[6],!!Se){if(ke=Se.length,O[3]||O[4]){Ke+=ke;continue}else if((O[5]||O[6])&&ce%3&&!((ce+ke)%3)){Ye+=ke;continue}if(Ke-=ke,!(Ke>0)){if(ke=Math.min(ke,ke+Ke+Ye),Math.min(ce,ke)%2){var At=E.slice(1,ce+O.index+ke);return{type:"em",raw:E.slice(0,ce+O.index+ke+1),text:At,tokens:this.lexer.inlineTokens(At)}}var qe=E.slice(2,ce+O.index+ke-1);return{type:"strong",raw:E.slice(0,ce+O.index+ke+1),text:qe,tokens:this.lexer.inlineTokens(qe)}}}}}},V.codespan=function(E){var M=this.rules.inline.code.exec(E);if(M){var B=M[2].replace(/\n/g," "),O=/[^ ]/.test(B),X=/^ /.test(B)&&/ $/.test(B);return O&&X&&(B=B.substring(1,B.length-1)),B=m(B,!0),{type:"codespan",raw:M[0],text:B}}},V.br=function(E){var M=this.rules.inline.br.exec(E);if(M)return{type:"br",raw:M[0]}},V.del=function(E){var M=this.rules.inline.del.exec(E);if(M)return{type:"del",raw:M[0],text:M[2],tokens:this.lexer.inlineTokens(M[2])}},V.autolink=function(E,M){var B=this.rules.inline.autolink.exec(E);if(B){var O,X;return B[2]==="@"?(O=m(this.options.mangle?M(B[1]):B[1]),X="mailto:"+O):(O=m(B[1]),X=O),{type:"link",raw:B[0],text:O,href:X,tokens:[{type:"text",raw:O,text:O}]}}},V.url=function(E,M){var B;if(B=this.rules.inline.url.exec(E)){var O,X;if(B[2]==="@")O=m(this.options.mangle?M(B[0]):B[0]),X="mailto:"+O;else{var ce;do ce=B[0],B[0]=this.rules.inline._backpedal.exec(B[0])[0];while(ce!==B[0]);O=m(B[0]),B[1]==="www."?X="http://"+O:X=O}return{type:"link",raw:B[0],text:O,href:X,tokens:[{type:"text",raw:O,text:O}]}}},V.inlineText=function(E,M){var B=this.rules.inline.text.exec(E);if(B){var O;return this.lexer.state.inRawBlock?O=this.options.sanitize?this.options.sanitizer?this.options.sanitizer(B[0]):m(B[0]):B[0]:O=m(this.options.smartypants?M(B[0]):B[0]),{type:"text",raw:B[0],text:O}}},U}(),Ie={newline:/^(?: *(?:\n|$))+/,code:/^( {4}[^\n]+(?:\n(?: *(?:\n|$))*)?)+/,fences:/^ {0,3}(`{3,}(?=[^`\n]*\n)|~{3,})([^\n]*)\n(?:|([\s\S]*?)\n)(?: {0,3}\1[~`]* *(?=\n|$)|$)/,hr:/^ {0,3}((?:-[\t ]*){3,}|(?:_[ \t]*){3,}|(?:\*[ \t]*){3,})(?:\n+|$)/,heading:/^ {0,3}(#{1,6})(?=\s|$)(.*)(?:\n+|$)/,blockquote:/^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/,list:/^( {0,3}bull)([ \t][^\n]+?)?(?:\n|$)/,html:"^ {0,3}(?:<(script|pre|style|textarea)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)|comment[^\\n]*(\\n+|$)|<\\?[\\s\\S]*?(?:\\?>\\n*|$)|<![A-Z][\\s\\S]*?(?:>\\n*|$)|<!\\[CDATA\\[[\\s\\S]*?(?:\\]\\]>\\n*|$)|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:(?:\\n *)+\\n|$)|<(?!script|pre|style|textarea)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$)|</(?!script|pre|style|textarea)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$))",def:/^ {0,3}\[(label)\]: *(?:\n *)?<?([^\s>]+)>?(?:(?: +(?:\n *)?| *\n *)(title))? *(?:\n+|$)/,table:A,lheading:/^([^\n]+)\n {0,3}(=+|-+) *(?:\n+|$)/,_paragraph:/^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html|table| +\n)[^\n]+)*)/,text:/^[^\n]+/};Ie._label=/(?!\s*\])(?:\\.|[^\[\]\\])+/,Ie._title=/(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/,Ie.def=C(Ie.def).replace("label",Ie._label).replace("title",Ie._title).getRegex(),Ie.bullet=/(?:[*+-]|\d{1,9}[.)])/,Ie.listItemStart=C(/^( *)(bull) */).replace("bull",Ie.bullet).getRegex(),Ie.list=C(Ie.list).replace(/bull/g,Ie.bullet).replace("hr","\\n+(?=\\1?(?:(?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$))").replace("def","\\n+(?="+Ie.def.source+")").getRegex(),Ie._tag="address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option|p|param|section|source|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul",Ie._comment=/<!--(?!-?>)[\s\S]*?(?:-->|$)/,Ie.html=C(Ie.html,"i").replace("comment",Ie._comment).replace("tag",Ie._tag).replace("attribute",/ +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex(),Ie.paragraph=C(Ie._paragraph).replace("hr",Ie.hr).replace("heading"," {0,3}#{1,6} ").replace("|lheading","").replace("|table","").replace("blockquote"," {0,3}>").replace("fences"," {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag",Ie._tag).getRegex(),Ie.blockquote=C(Ie.blockquote).replace("paragraph",Ie.paragraph).getRegex(),Ie.normal=z({},Ie),Ie.gfm=z({},Ie.normal,{table:"^ *([^\\n ].*\\|.*)\\n {0,3}(?:\\| *)?(:?-+:? *(?:\\| *:?-+:? *)*)(?:\\| *)?(?:\\n((?:(?! *\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)"}),Ie.gfm.table=C(Ie.gfm.table).replace("hr",Ie.hr).replace("heading"," {0,3}#{1,6} ").replace("blockquote"," {0,3}>").replace("code"," {4}[^\\n]").replace("fences"," {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag",Ie._tag).getRegex(),Ie.gfm.paragraph=C(Ie._paragraph).replace("hr",Ie.hr).replace("heading"," {0,3}#{1,6} ").replace("|lheading","").replace("table",Ie.gfm.table).replace("blockquote"," {0,3}>").replace("fences"," {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag",Ie._tag).getRegex(),Ie.pedantic=z({},Ie.normal,{html:C(`^ *(?:comment *(?:\\n|\\s*$)|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)|<tag(?:"[^"]*"|'[^']*'|\\s[^'"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))`).replace("comment",Ie._comment).replace(/tag/g,"(?!(?:a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)\\b)\\w+(?!:|[^\\w\\s@]*@)\\b").getRegex(),def:/^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/,heading:/^(#{1,6})(.*)(?:\n+|$)/,fences:A,paragraph:C(Ie.normal._paragraph).replace("hr",Ie.hr).replace("heading",` *#{1,6} *[^
]`).replace("lheading",Ie.lheading).replace("blockquote"," {0,3}>").replace("|fences","").replace("|list","").replace("|html","").getRegex()});var pe={escape:/^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/,autolink:/^<(scheme:[^\s\x00-\x1f<>]*|email)>/,url:A,tag:"^comment|^</[a-zA-Z][\\w:-]*\\s*>|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>|^<\\?[\\s\\S]*?\\?>|^<![a-zA-Z]+\\s[\\s\\S]*?>|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>",link:/^!?\[(label)\]\(\s*(href)(?:\s+(title))?\s*\)/,reflink:/^!?\[(label)\]\[(ref)\]/,nolink:/^!?\[(ref)\](?:\[\])?/,reflinkSearch:"reflink|nolink(?!\\()",emStrong:{lDelim:/^(?:\*+(?:([punct_])|[^\s*]))|^_+(?:([punct*])|([^\s_]))/,rDelimAst:/^[^_*]*?\_\_[^_*]*?\*[^_*]*?(?=\_\_)|[^*]+(?=[^*])|[punct_](\*+)(?=[\s]|$)|[^punct*_\s](\*+)(?=[punct_\s]|$)|[punct_\s](\*+)(?=[^punct*_\s])|[\s](\*+)(?=[punct_])|[punct_](\*+)(?=[punct_])|[^punct*_\s](\*+)(?=[^punct*_\s])/,rDelimUnd:/^[^_*]*?\*\*[^_*]*?\_[^_*]*?(?=\*\*)|[^_]+(?=[^_])|[punct*](\_+)(?=[\s]|$)|[^punct*_\s](\_+)(?=[punct*\s]|$)|[punct*\s](\_+)(?=[^punct*_\s])|[\s](\_+)(?=[punct*])|[punct*](\_+)(?=[punct*])/},code:/^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/,br:/^( {2,}|\\)\n(?!\s*$)/,del:A,text:/^(`+|[^`])(?:(?= {2,}\n)|[\s\S]*?(?:(?=[\\<!\[`*_]|\b_|$)|[^ ](?= {2,}\n)))/,punctuation:/^([\spunctuation])/};pe._punctuation="!\"#$%&'()+\\-.,/:;<=>?@\\[\\]`^{|}~",pe.punctuation=C(pe.punctuation).replace(/punctuation/g,pe._punctuation).getRegex(),pe.blockSkip=/\[[^\]]*?\]\([^\)]*?\)|`[^`]*?`|<[^>]*?>/g,pe.escapedEmSt=/\\\*|\\_/g,pe._comment=C(Ie._comment).replace("(?:-->|$)","-->").getRegex(),pe.emStrong.lDelim=C(pe.emStrong.lDelim).replace(/punct/g,pe._punctuation).getRegex(),pe.emStrong.rDelimAst=C(pe.emStrong.rDelimAst,"g").replace(/punct/g,pe._punctuation).getRegex(),pe.emStrong.rDelimUnd=C(pe.emStrong.rDelimUnd,"g").replace(/punct/g,pe._punctuation).getRegex(),pe._escapes=/\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/g,pe._scheme=/[a-zA-Z][a-zA-Z0-9+.-]{1,31}/,pe._email=/[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/,pe.autolink=C(pe.autolink).replace("scheme",pe._scheme).replace("email",pe._email).getRegex(),pe._attribute=/\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/,pe.tag=C(pe.tag).replace("comment",pe._comment).replace("attribute",pe._attribute).getRegex(),pe._label=/(?:\[(?:\\.|[^\[\]\\])*\]|\\.|`[^`]*`|[^\[\]\\`])*?/,pe._href=/<(?:\\.|[^\n<>\\])+>|[^\s\x00-\x1f]*/,pe._title=/"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/,pe.link=C(pe.link).replace("label",pe._label).replace("href",pe._href).replace("title",pe._title).getRegex(),pe.reflink=C(pe.reflink).replace("label",pe._label).replace("ref",Ie._label).getRegex(),pe.nolink=C(pe.nolink).replace("ref",Ie._label).getRegex(),pe.reflinkSearch=C(pe.reflinkSearch,"g").replace("reflink",pe.reflink).replace("nolink",pe.nolink).getRegex(),pe.normal=z({},pe),pe.pedantic=z({},pe.normal,{strong:{start:/^__|\*\*/,middle:/^__(?=\S)([\s\S]*?\S)__(?!_)|^\*\*(?=\S)([\s\S]*?\S)\*\*(?!\*)/,endAst:/\*\*(?!\*)/g,endUnd:/__(?!_)/g},em:{start:/^_|\*/,middle:/^()\*(?=\S)([\s\S]*?\S)\*(?!\*)|^_(?=\S)([\s\S]*?\S)_(?!_)/,endAst:/\*(?!\*)/g,endUnd:/_(?!_)/g},link:C(/^!?\[(label)\]\((.*?)\)/).replace("label",pe._label).getRegex(),reflink:C(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace("label",pe._label).getRegex()}),pe.gfm=z({},pe.normal,{escape:C(pe.escape).replace("])","~|])").getRegex(),_extended_email:/[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/,url:/^((?:ftp|https?):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/,_backpedal:/(?:[^?!.,:;*_~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_~)]+(?!$))+/,del:/^(~~?)(?=[^\s~])([\s\S]*?[^\s~])\1(?=[^~]|$)/,text:/^([`~]+|[^`~])(?:(?= {2,}\n)|(?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)|[\s\S]*?(?:(?=[\\<!\[`*~_]|\b_|https?:\/\/|ftp:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)))/}),pe.gfm.url=C(pe.gfm.url,"i").replace("email",pe.gfm._extended_email).getRegex(),pe.breaks=z({},pe.gfm,{br:C(pe.br).replace("{2,}","*").getRegex(),text:C(pe.gfm.text).replace("\\b_","\\b_| {2,}\\n").replace(/\{2,\}/g,"*").getRegex()});function Ji(U){return U.replace(/---/g,"—").replace(/--/g,"–").replace(/(^|[-\u2014/(\[{"\s])'/g,"$1‘").replace(/'/g,"’").replace(/(^|[-\u2014/(\[{\u2018\s])"/g,"$1“").replace(/"/g,"”").replace(/\.{3}/g,"…")}function wn(U){var V="",F,E,M=U.length;for(F=0;F<M;F++)E=U.charCodeAt(F),Math.random()>.5&&(E="x"+E.toString(16)),V+="&#"+E+";";return V}var ni=function(){function U(F){this.tokens=[],this.tokens.links=Object.create(null),this.options=F||e.defaults,this.options.tokenizer=this.options.tokenizer||new Ve,this.tokenizer=this.options.tokenizer,this.tokenizer.options=this.options,this.tokenizer.lexer=this,this.inlineQueue=[],this.state={inLink:!1,inRawBlock:!1,top:!0};var E={block:Ie.normal,inline:pe.normal};this.options.pedantic?(E.block=Ie.pedantic,E.inline=pe.pedantic):this.options.gfm&&(E.block=Ie.gfm,this.options.breaks?E.inline=pe.breaks:E.inline=pe.gfm),this.tokenizer.rules=E}U.lex=function(E,M){var B=new U(M);return B.lex(E)},U.lexInline=function(E,M){var B=new U(M);return B.inlineTokens(E)};var V=U.prototype;return V.lex=function(E){E=E.replace(/\r\n|\r/g,`
`),this.blockTokens(E,this.tokens);for(var M;M=this.inlineQueue.shift();)this.inlineTokens(M.src,M.tokens);return this.tokens},V.blockTokens=function(E,M){var B=this;M===void 0&&(M=[]),this.options.pedantic?E=E.replace(/\t/g,"    ").replace(/^ +$/gm,""):E=E.replace(/^( *)(\t+)/gm,function(Ke,Ye,Kt){return Ye+"    ".repeat(Kt.length)});for(var O,X,ce,Se;E;)if(!(this.options.extensions&&this.options.extensions.block&&this.options.extensions.block.some(function(Ke){return(O=Ke.call({lexer:B},E,M))?(E=E.substring(O.raw.length),M.push(O),!0):!1}))){if(O=this.tokenizer.space(E)){E=E.substring(O.raw.length),O.raw.length===1&&M.length>0?M[M.length-1].raw+=`
`:M.push(O);continue}if(O=this.tokenizer.code(E)){E=E.substring(O.raw.length),X=M[M.length-1],X&&(X.type==="paragraph"||X.type==="text")?(X.raw+=`
`+O.raw,X.text+=`
`+O.text,this.inlineQueue[this.inlineQueue.length-1].src=X.text):M.push(O);continue}if(O=this.tokenizer.fences(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.heading(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.hr(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.blockquote(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.list(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.html(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.def(E)){E=E.substring(O.raw.length),X=M[M.length-1],X&&(X.type==="paragraph"||X.type==="text")?(X.raw+=`
`+O.raw,X.text+=`
`+O.raw,this.inlineQueue[this.inlineQueue.length-1].src=X.text):this.tokens.links[O.tag]||(this.tokens.links[O.tag]={href:O.href,title:O.title});continue}if(O=this.tokenizer.table(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.lheading(E)){E=E.substring(O.raw.length),M.push(O);continue}if(ce=E,this.options.extensions&&this.options.extensions.startBlock&&function(){var Ke=1/0,Ye=E.slice(1),Kt=void 0;B.options.extensions.startBlock.forEach(function(At){Kt=At.call({lexer:this},Ye),typeof Kt=="number"&&Kt>=0&&(Ke=Math.min(Ke,Kt))}),Ke<1/0&&Ke>=0&&(ce=E.substring(0,Ke+1))}(),this.state.top&&(O=this.tokenizer.paragraph(ce))){X=M[M.length-1],Se&&X.type==="paragraph"?(X.raw+=`
`+O.raw,X.text+=`
`+O.text,this.inlineQueue.pop(),this.inlineQueue[this.inlineQueue.length-1].src=X.text):M.push(O),Se=ce.length!==E.length,E=E.substring(O.raw.length);continue}if(O=this.tokenizer.text(E)){E=E.substring(O.raw.length),X=M[M.length-1],X&&X.type==="text"?(X.raw+=`
`+O.raw,X.text+=`
`+O.text,this.inlineQueue.pop(),this.inlineQueue[this.inlineQueue.length-1].src=X.text):M.push(O);continue}if(E){var ke="Infinite loop on byte: "+E.charCodeAt(0);if(this.options.silent){console.error(ke);break}else throw new Error(ke)}}return this.state.top=!0,M},V.inline=function(E,M){return M===void 0&&(M=[]),this.inlineQueue.push({src:E,tokens:M}),M},V.inlineTokens=function(E,M){var B=this;M===void 0&&(M=[]);var O,X,ce,Se=E,ke,Ke,Ye;if(this.tokens.links){var Kt=Object.keys(this.tokens.links);if(Kt.length>0)for(;(ke=this.tokenizer.rules.inline.reflinkSearch.exec(Se))!=null;)Kt.includes(ke[0].slice(ke[0].lastIndexOf("[")+1,-1))&&(Se=Se.slice(0,ke.index)+"["+ve("a",ke[0].length-2)+"]"+Se.slice(this.tokenizer.rules.inline.reflinkSearch.lastIndex))}for(;(ke=this.tokenizer.rules.inline.blockSkip.exec(Se))!=null;)Se=Se.slice(0,ke.index)+"["+ve("a",ke[0].length-2)+"]"+Se.slice(this.tokenizer.rules.inline.blockSkip.lastIndex);for(;(ke=this.tokenizer.rules.inline.escapedEmSt.exec(Se))!=null;)Se=Se.slice(0,ke.index)+"++"+Se.slice(this.tokenizer.rules.inline.escapedEmSt.lastIndex);for(;E;)if(Ke||(Ye=""),Ke=!1,!(this.options.extensions&&this.options.extensions.inline&&this.options.extensions.inline.some(function(qe){return(O=qe.call({lexer:B},E,M))?(E=E.substring(O.raw.length),M.push(O),!0):!1}))){if(O=this.tokenizer.escape(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.tag(E)){E=E.substring(O.raw.length),X=M[M.length-1],X&&O.type==="text"&&X.type==="text"?(X.raw+=O.raw,X.text+=O.text):M.push(O);continue}if(O=this.tokenizer.link(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.reflink(E,this.tokens.links)){E=E.substring(O.raw.length),X=M[M.length-1],X&&O.type==="text"&&X.type==="text"?(X.raw+=O.raw,X.text+=O.text):M.push(O);continue}if(O=this.tokenizer.emStrong(E,Se,Ye)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.codespan(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.br(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.del(E)){E=E.substring(O.raw.length),M.push(O);continue}if(O=this.tokenizer.autolink(E,wn)){E=E.substring(O.raw.length),M.push(O);continue}if(!this.state.inLink&&(O=this.tokenizer.url(E,wn))){E=E.substring(O.raw.length),M.push(O);continue}if(ce=E,this.options.extensions&&this.options.extensions.startInline&&function(){var qe=1/0,Ot=E.slice(1),$t=void 0;B.options.extensions.startInline.forEach(function(so){$t=so.call({lexer:this},Ot),typeof $t=="number"&&$t>=0&&(qe=Math.min(qe,$t))}),qe<1/0&&qe>=0&&(ce=E.substring(0,qe+1))}(),O=this.tokenizer.inlineText(ce,Ji)){E=E.substring(O.raw.length),O.raw.slice(-1)!=="_"&&(Ye=O.raw.slice(-1)),Ke=!0,X=M[M.length-1],X&&X.type==="text"?(X.raw+=O.raw,X.text+=O.text):M.push(O);continue}if(E){var At="Infinite loop on byte: "+E.charCodeAt(0);if(this.options.silent){console.error(At);break}else throw new Error(At)}}return M},i(U,null,[{key:"rules",get:function(){return{block:Ie,inline:pe}}}]),U}(),wt=function(){function U(F){this.options=F||e.defaults}var V=U.prototype;return V.code=function(E,M,B){var O=(M||"").match(/\S*/)[0];if(this.options.highlight){var X=this.options.highlight(E,O);X!=null&&X!==E&&(B=!0,E=X)}return E=E.replace(/\n$/,"")+`
`,O?'<pre><code class="'+this.options.langPrefix+m(O,!0)+'">'+(B?E:m(E,!0))+`</code></pre>
`:"<pre><code>"+(B?E:m(E,!0))+`</code></pre>
`},V.blockquote=function(E){return`<blockquote>
`+E+`</blockquote>
`},V.html=function(E){return E},V.heading=function(E,M,B,O){if(this.options.headerIds){var X=this.options.headerPrefix+O.slug(B);return"<h"+M+' id="'+X+'">'+E+"</h"+M+`>
`}return"<h"+M+">"+E+"</h"+M+`>
`},V.hr=function(){return this.options.xhtml?`<hr/>
`:`<hr>
`},V.list=function(E,M,B){var O=M?"ol":"ul",X=M&&B!==1?' start="'+B+'"':"";return"<"+O+X+`>
`+E+"</"+O+`>
`},V.listitem=function(E){return"<li>"+E+`</li>
`},V.checkbox=function(E){return"<input "+(E?'checked="" ':"")+'disabled="" type="checkbox"'+(this.options.xhtml?" /":"")+"> "},V.paragraph=function(E){return"<p>"+E+`</p>
`},V.table=function(E,M){return M&&(M="<tbody>"+M+"</tbody>"),`<table>
<thead>
`+E+`</thead>
`+M+`</table>
`},V.tablerow=function(E){return`<tr>
`+E+`</tr>
`},V.tablecell=function(E,M){var B=M.header?"th":"td",O=M.align?"<"+B+' align="'+M.align+'">':"<"+B+">";return O+E+("</"+B+`>
`)},V.strong=function(E){return"<strong>"+E+"</strong>"},V.em=function(E){return"<em>"+E+"</em>"},V.codespan=function(E){return"<code>"+E+"</code>"},V.br=function(){return this.options.xhtml?"<br/>":"<br>"},V.del=function(E){return"<del>"+E+"</del>"},V.link=function(E,M,B){if(E=x(this.options.sanitize,this.options.baseUrl,E),E===null)return B;var O='<a href="'+m(E)+'"';return M&&(O+=' title="'+M+'"'),O+=">"+B+"</a>",O},V.image=function(E,M,B){if(E=x(this.options.sanitize,this.options.baseUrl,E),E===null)return B;var O='<img src="'+E+'" alt="'+B+'"';return M&&(O+=' title="'+M+'"'),O+=this.options.xhtml?"/>":">",O},V.text=function(E){return E},U}(),$i=function(){function U(){}var V=U.prototype;return V.strong=function(E){return E},V.em=function(E){return E},V.codespan=function(E){return E},V.del=function(E){return E},V.html=function(E){return E},V.text=function(E){return E},V.link=function(E,M,B){return""+B},V.image=function(E,M,B){return""+B},V.br=function(){return""},U}(),no=function(){function U(){this.seen={}}var V=U.prototype;return V.serialize=function(E){return E.toLowerCase().trim().replace(/<[!\/a-z].*?>/ig,"").replace(/[\u2000-\u206F\u2E00-\u2E7F\\'!"#$%&()*+,./:;<=>?@[\]^`{|}~]/g,"").replace(/\s/g,"-")},V.getNextSafeSlug=function(E,M){var B=E,O=0;if(this.seen.hasOwnProperty(B)){O=this.seen[E];do O++,B=E+"-"+O;while(this.seen.hasOwnProperty(B))}return M||(this.seen[E]=O,this.seen[B]=0),B},V.slug=function(E,M){M===void 0&&(M={});var B=this.serialize(E);return this.getNextSafeSlug(B,M.dryrun)},U}(),ji=function(){function U(F){this.options=F||e.defaults,this.options.renderer=this.options.renderer||new wt,this.renderer=this.options.renderer,this.renderer.options=this.options,this.textRenderer=new $i,this.slugger=new no}U.parse=function(E,M){var B=new U(M);return B.parse(E)},U.parseInline=function(E,M){var B=new U(M);return B.parseInline(E)};var V=U.prototype;return V.parse=function(E,M){M===void 0&&(M=!0);var B="",O,X,ce,Se,ke,Ke,Ye,Kt,At,qe,Ot,$t,so,Ft,cn,gh,fh,ra,hc,ph=E.length;for(O=0;O<ph;O++){if(qe=E[O],this.options.extensions&&this.options.extensions.renderers&&this.options.extensions.renderers[qe.type]&&(hc=this.options.extensions.renderers[qe.type].call({parser:this},qe),hc!==!1||!["space","hr","heading","code","table","blockquote","list","html","paragraph","text"].includes(qe.type))){B+=hc||"";continue}switch(qe.type){case"space":continue;case"hr":{B+=this.renderer.hr();continue}case"heading":{B+=this.renderer.heading(this.parseInline(qe.tokens),qe.depth,v(this.parseInline(qe.tokens,this.textRenderer)),this.slugger);continue}case"code":{B+=this.renderer.code(qe.text,qe.lang,qe.escaped);continue}case"table":{for(Kt="",Ye="",Se=qe.header.length,X=0;X<Se;X++)Ye+=this.renderer.tablecell(this.parseInline(qe.header[X].tokens),{header:!0,align:qe.align[X]});for(Kt+=this.renderer.tablerow(Ye),At="",Se=qe.rows.length,X=0;X<Se;X++){for(Ke=qe.rows[X],Ye="",ke=Ke.length,ce=0;ce<ke;ce++)Ye+=this.renderer.tablecell(this.parseInline(Ke[ce].tokens),{header:!1,align:qe.align[ce]});At+=this.renderer.tablerow(Ye)}B+=this.renderer.table(Kt,At);continue}case"blockquote":{At=this.parse(qe.tokens),B+=this.renderer.blockquote(At);continue}case"list":{for(Ot=qe.ordered,$t=qe.start,so=qe.loose,Se=qe.items.length,At="",X=0;X<Se;X++)cn=qe.items[X],gh=cn.checked,fh=cn.task,Ft="",cn.task&&(ra=this.renderer.checkbox(gh),so?cn.tokens.length>0&&cn.tokens[0].type==="paragraph"?(cn.tokens[0].text=ra+" "+cn.tokens[0].text,cn.tokens[0].tokens&&cn.tokens[0].tokens.length>0&&cn.tokens[0].tokens[0].type==="text"&&(cn.tokens[0].tokens[0].text=ra+" "+cn.tokens[0].tokens[0].text)):cn.tokens.unshift({type:"text",text:ra}):Ft+=ra),Ft+=this.parse(cn.tokens,so),At+=this.renderer.listitem(Ft,fh,gh);B+=this.renderer.list(At,Ot,$t);continue}case"html":{B+=this.renderer.html(qe.text);continue}case"paragraph":{B+=this.renderer.paragraph(this.parseInline(qe.tokens));continue}case"text":{for(At=qe.tokens?this.parseInline(qe.tokens):qe.text;O+1<ph&&E[O+1].type==="text";)qe=E[++O],At+=`
`+(qe.tokens?this.parseInline(qe.tokens):qe.text);B+=M?this.renderer.paragraph(At):At;continue}default:{var mh='Token with "'+qe.type+'" type was not found.';if(this.options.silent){console.error(mh);return}else throw new Error(mh)}}}return B},V.parseInline=function(E,M){M=M||this.renderer;var B="",O,X,ce,Se=E.length;for(O=0;O<Se;O++){if(X=E[O],this.options.extensions&&this.options.extensions.renderers&&this.options.extensions.renderers[X.type]&&(ce=this.options.extensions.renderers[X.type].call({parser:this},X),ce!==!1||!["escape","html","link","image","strong","em","codespan","br","del","text"].includes(X.type))){B+=ce||"";continue}switch(X.type){case"escape":{B+=M.text(X.text);break}case"html":{B+=M.html(X.text);break}case"link":{B+=M.link(X.href,X.title,this.parseInline(X.tokens,M));break}case"image":{B+=M.image(X.href,X.title,X.text);break}case"strong":{B+=M.strong(this.parseInline(X.tokens,M));break}case"em":{B+=M.em(this.parseInline(X.tokens,M));break}case"codespan":{B+=M.codespan(X.text);break}case"br":{B+=M.br();break}case"del":{B+=M.del(this.parseInline(X.tokens,M));break}case"text":{B+=M.text(X.text);break}default:{var ke='Token with "'+X.type+'" type was not found.';if(this.options.silent){console.error(ke);return}else throw new Error(ke)}}}return B},U}();function Ze(U,V,F){if(typeof U>"u"||U===null)throw new Error("marked(): input parameter is undefined or null");if(typeof U!="string")throw new Error("marked(): input parameter is of type "+Object.prototype.toString.call(U)+", string expected");if(typeof V=="function"&&(F=V,V=null),V=z({},Ze.defaults,V||{}),fe(V),F){var E=V.highlight,M;try{M=ni.lex(U,V)}catch(Se){return F(Se)}var B=function(ke){var Ke;if(!ke)try{V.walkTokens&&Ze.walkTokens(M,V.walkTokens),Ke=ji.parse(M,V)}catch(Ye){ke=Ye}return V.highlight=E,ke?F(ke):F(null,Ke)};if(!E||E.length<3||(delete V.highlight,!M.length))return B();var O=0;Ze.walkTokens(M,function(Se){Se.type==="code"&&(O++,setTimeout(function(){E(Se.text,Se.lang,function(ke,Ke){if(ke)return B(ke);Ke!=null&&Ke!==Se.text&&(Se.text=Ke,Se.escaped=!0),O--,O===0&&B()})},0))}),O===0&&B();return}function X(Se){if(Se.message+=`
Please report this to https://github.com/markedjs/marked.`,V.silent)return"<p>An error occurred:</p><pre>"+m(Se.message+"",!0)+"</pre>";throw Se}try{var ce=ni.lex(U,V);if(V.walkTokens){if(V.async)return Promise.all(Ze.walkTokens(ce,V.walkTokens)).then(function(){return ji.parse(ce,V)}).catch(X);Ze.walkTokens(ce,V.walkTokens)}return ji.parse(ce,V)}catch(Se){X(Se)}}Ze.options=Ze.setOptions=function(U){return z(Ze.defaults,U),l(Ze.defaults),Ze},Ze.getDefaults=a,Ze.defaults=e.defaults,Ze.use=function(){for(var U=arguments.length,V=new Array(U),F=0;F<U;F++)V[F]=arguments[F];var E=z.apply(void 0,[{}].concat(V)),M=Ze.defaults.extensions||{renderers:{},childTokens:{}},B;V.forEach(function(O){if(O.extensions&&(B=!0,O.extensions.forEach(function(ce){if(!ce.name)throw new Error("extension name required");if(ce.renderer){var Se=M.renderers?M.renderers[ce.name]:null;Se?M.renderers[ce.name]=function(){for(var ke=arguments.length,Ke=new Array(ke),Ye=0;Ye<ke;Ye++)Ke[Ye]=arguments[Ye];var Kt=ce.renderer.apply(this,Ke);return Kt===!1&&(Kt=Se.apply(this,Ke)),Kt}:M.renderers[ce.name]=ce.renderer}if(ce.tokenizer){if(!ce.level||ce.level!=="block"&&ce.level!=="inline")throw new Error("extension level must be 'block' or 'inline'");M[ce.level]?M[ce.level].unshift(ce.tokenizer):M[ce.level]=[ce.tokenizer],ce.start&&(ce.level==="block"?M.startBlock?M.startBlock.push(ce.start):M.startBlock=[ce.start]:ce.level==="inline"&&(M.startInline?M.startInline.push(ce.start):M.startInline=[ce.start]))}ce.childTokens&&(M.childTokens[ce.name]=ce.childTokens)})),O.renderer&&function(){var ce=Ze.defaults.renderer||new wt,Se=function(Ye){var Kt=ce[Ye];ce[Ye]=function(){for(var At=arguments.length,qe=new Array(At),Ot=0;Ot<At;Ot++)qe[Ot]=arguments[Ot];var $t=O.renderer[Ye].apply(ce,qe);return $t===!1&&($t=Kt.apply(ce,qe)),$t}};for(var ke in O.renderer)Se(ke);E.renderer=ce}(),O.tokenizer&&function(){var ce=Ze.defaults.tokenizer||new Ve,Se=function(Ye){var Kt=ce[Ye];ce[Ye]=function(){for(var At=arguments.length,qe=new Array(At),Ot=0;Ot<At;Ot++)qe[Ot]=arguments[Ot];var $t=O.tokenizer[Ye].apply(ce,qe);return $t===!1&&($t=Kt.apply(ce,qe)),$t}};for(var ke in O.tokenizer)Se(ke);E.tokenizer=ce}(),O.walkTokens){var X=Ze.defaults.walkTokens;E.walkTokens=function(ce){var Se=[];return Se.push(O.walkTokens.call(this,ce)),X&&(Se=Se.concat(X.call(this,ce))),Se}}B&&(E.extensions=M),Ze.setOptions(E)})},Ze.walkTokens=function(U,V){for(var F=[],E=function(){var X=B.value;switch(F=F.concat(V.call(Ze,X)),X.type){case"table":{for(var ce=r(X.header),Se;!(Se=ce()).done;){var ke=Se.value;F=F.concat(Ze.walkTokens(ke.tokens,V))}for(var Ke=r(X.rows),Ye;!(Ye=Ke()).done;)for(var Kt=Ye.value,At=r(Kt),qe;!(qe=At()).done;){var Ot=qe.value;F=F.concat(Ze.walkTokens(Ot.tokens,V))}break}case"list":{F=F.concat(Ze.walkTokens(X.items,V));break}default:Ze.defaults.extensions&&Ze.defaults.extensions.childTokens&&Ze.defaults.extensions.childTokens[X.type]?Ze.defaults.extensions.childTokens[X.type].forEach(function($t){F=F.concat(Ze.walkTokens(X[$t],V))}):X.tokens&&(F=F.concat(Ze.walkTokens(X.tokens,V)))}},M=r(U),B;!(B=M()).done;)E();return F},Ze.parseInline=function(U,V){if(typeof U>"u"||U===null)throw new Error("marked.parseInline(): input parameter is undefined or null");if(typeof U!="string")throw new Error("marked.parseInline(): input parameter is of type "+Object.prototype.toString.call(U)+", string expected");V=z({},Ze.defaults,V||{}),fe(V);try{var F=ni.lexInline(U,V);return V.walkTokens&&Ze.walkTokens(F,V.walkTokens),ji.parseInline(F,V)}catch(E){if(E.message+=`
Please report this to https://github.com/markedjs/marked.`,V.silent)return"<p>An error occurred:</p><pre>"+m(E.message+"",!0)+"</pre>";throw E}},Ze.Parser=ji,Ze.parser=ji.parse,Ze.Renderer=wt,Ze.TextRenderer=$i,Ze.Lexer=ni,Ze.lexer=ni.lex,Ze.Tokenizer=Ve,Ze.Slugger=no,Ze.parse=Ze;var zn=Ze.options,q=Ze.setOptions,Z=Ze.use,ae=Ze.walkTokens,be=Ze.parseInline,Le=Ze,Re=ji.parse,ze=ni.lex;e.Lexer=ni,e.Parser=ji,e.Renderer=wt,e.Slugger=no,e.TextRenderer=$i,e.Tokenizer=Ve,e.getDefaults=a,e.lexer=ze,e.marked=Ze,e.options=zn,e.parse=Le,e.parseInline=be,e.parser=Re,e.setOptions=q,e.use=Z,e.walkTokens=ae,Object.defineProperty(e,"__esModule",{value:!0})})})();Vs.Lexer||exports.Lexer;Vs.Parser||exports.Parser;Vs.Renderer||exports.Renderer;Vs.Slugger||exports.Slugger;Vs.TextRenderer||exports.TextRenderer;Vs.Tokenizer||exports.Tokenizer;Vs.getDefaults||exports.getDefaults;Vs.lexer||exports.lexer;var wl=Vs.marked||exports.marked;Vs.options||exports.options;Vs.parse||exports.parse;Vs.parseInline||exports.parseInline;Vs.parser||exports.parser;Vs.setOptions||exports.setOptions;Vs.use||exports.use;Vs.walkTokens||exports.walkTokens;function Whe(s){return JSON.stringify(s,Vhe)}function a2(s){let e=JSON.parse(s);return e=l2(e),e}function Vhe(s,e){return e instanceof RegExp?{$mid:2,source:e.source,flags:e.flags}:e}function l2(s,e=0){if(!s||e>200)return s;if(typeof s=="object"){switch(s.$mid){case 1:return Pe.revive(s);case 2:return new RegExp(s.source,s.flags);case 17:return new Date(s.source)}if(s instanceof gx||s instanceof Uint8Array)return s;if(Array.isArray(s))for(let t=0;t<s.length;++t)s[t]=l2(s[t],e+1);else for(const t in s)Object.hasOwnProperty.call(s,t)&&(s[t]=l2(s[t],e+1))}return s}const FI=Object.freeze({image:(s,e,t)=>{let i=[],n=[];return s&&({href:s,dimensions:i}=Nhe(s),n.push(`src="${W1(s)}"`)),t&&n.push(`alt="${W1(t)}"`),e&&n.push(`title="${W1(e)}"`),i.length&&(n=n.concat(i)),"<img "+n.join(" ")+">"},paragraph:s=>`<p>${s}</p>`,link:(s,e,t)=>typeof s!="string"?"":(s===t&&(t=OI(t)),e=typeof e=="string"?W1(OI(e)):"",s=OI(s),s=s.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/'/g,"&#39;"),`<a href="${s}" title="${e||s}" draggable="false">${t}</a>`)});function Vx(s,e={},t={}){var i,n;const o=new ie;let r=!1;const a=dO(e),l=function(v){let b;try{b=a2(decodeURIComponent(v))}catch{}return b?(b=fW(b,C=>{if(s.uris&&s.uris[C])return Pe.revive(s.uris[C])}),encodeURIComponent(JSON.stringify(b))):v},d=function(v,b){const C=s.uris&&s.uris[v];let w=Pe.revive(C);return b?v.startsWith(it.data+":")?v:(w||(w=Pe.parse(v)),pV.uriToBrowserUri(w).toString(!0)):!w||Pe.parse(v).toString()===w.toString()?v:(w.query&&(w=w.with({query:l(w.query)})),w.toString())},c=new wl.Renderer;c.image=FI.image,c.link=FI.link,c.paragraph=FI.paragraph;const u=[],h=[];if(e.codeBlockRendererSync?c.code=(v,b)=>{const C=r2.nextId(),w=e.codeBlockRendererSync(o9(b),v);return h.push([C,w]),`<div class="code" data-code="${C}">${MS(v)}</div>`}:e.codeBlockRenderer&&(c.code=(v,b)=>{const C=r2.nextId(),w=e.codeBlockRenderer(o9(b),v);return u.push(w.then(S=>[C,S])),`<div class="code" data-code="${C}">${MS(v)}</div>`}),e.actionHandler){const v=function(w){let S=w.target;if(!(S.tagName!=="A"&&(S=S.parentElement,!S||S.tagName!=="A")))try{let x=S.dataset.href;x&&(s.baseUri&&(x=BI(Pe.from(s.baseUri),x)),e.actionHandler.callback(x,w))}catch(x){et(x)}finally{w.preventDefault()}},b=e.actionHandler.disposables.add(new gt(a,"click")),C=e.actionHandler.disposables.add(new gt(a,"auxclick"));e.actionHandler.disposables.add(ge.any(b.event,C.event)(w=>{const S=new zr(Xe(a),w);!S.leftButton&&!S.middleButton||v(S)})),e.actionHandler.disposables.add(Y(a,"keydown",w=>{const S=new ri(w);!S.equals(10)&&!S.equals(3)||v(S)}))}s.supportHtml||(t.sanitizer=v=>(s.isTrusted?v.match(/^(<span[^>]+>)|(<\/\s*span>)$/):void 0)?v:"",t.sanitize=!0,t.silent=!0),t.renderer=c;let g=(i=s.value)!==null&&i!==void 0?i:"";g.length>1e5&&(g=`${g.substr(0,1e5)}…`),s.supportThemeIcons&&(g=xhe(g));let f;if(e.fillInIncompleteTokens){const v={...wl.defaults,...t},b=wl.lexer(g,v),C=Ghe(b);f=wl.parser(C,v)}else f=wl.parse(g,t);s.supportThemeIcons&&(f=hu(f).map(b=>typeof b=="string"?b:b.outerHTML).join(""));const _=new DOMParser().parseFromString(d2(s,f),"text/html");if(_.body.querySelectorAll("img").forEach(v=>{const b=v.getAttribute("src");if(b){let C=b;try{s.baseUri&&(C=BI(Pe.from(s.baseUri),C))}catch{}v.src=d(C,!0)}}),_.body.querySelectorAll("a").forEach(v=>{const b=v.getAttribute("href");if(v.setAttribute("href",""),!b||/^data:|javascript:/i.test(b)||/^command:/i.test(b)&&!s.isTrusted||/^command:(\/\/\/)?_workbench\.downloadResource/i.test(b))v.replaceWith(...v.childNodes);else{let C=d(b,!1);s.baseUri&&(C=BI(Pe.from(s.baseUri),b)),v.dataset.href=C}}),a.innerHTML=d2(s,_.body.innerHTML),u.length>0)Promise.all(u).then(v=>{var b,C;if(r)return;const w=new Map(v),S=a.querySelectorAll("div[data-code]");for(const x of S){const L=w.get((b=x.dataset.code)!==null&&b!==void 0?b:"");L&&Qn(x,L)}(C=e.asyncRenderCallback)===null||C===void 0||C.call(e)});else if(h.length>0){const v=new Map(h),b=a.querySelectorAll("div[data-code]");for(const C of b){const w=v.get((n=C.dataset.code)!==null&&n!==void 0?n:"");w&&Qn(C,w)}}if(e.asyncRenderCallback)for(const v of a.getElementsByTagName("img")){const b=o.add(Y(v,"load",()=>{b.dispose(),e.asyncRenderCallback()}))}return{element:a,dispose:()=>{r=!0,o.dispose()}}}function o9(s){if(!s)return"";const e=s.split(/[\s+|:|,|\{|\?]/,1);return e.length?e[0]:s}function BI(s,e){return/^\w[\w\d+.-]*:/.test(e)?e:s.path.endsWith("/")?n7(s,e).toString():n7(Tx(s),e).toString()}function d2(s,e){const{config:t,allowedSchemes:i}=zhe(s);hV("uponSanitizeAttribute",(o,r)=>{if(r.attrName==="style"||r.attrName==="class"){if(o.tagName==="SPAN"){if(r.attrName==="style"){r.keepAttr=/^(color\:(#[0-9a-fA-F]+|var\(--vscode(-[a-zA-Z]+)+\));)?(background-color\:(#[0-9a-fA-F]+|var\(--vscode(-[a-zA-Z]+)+\));)?$/.test(r.attrValue);return}else if(r.attrName==="class"){r.keepAttr=/^codicon codicon-[a-z\-]+( codicon-modifier-[a-z\-]+)?$/.test(r.attrValue);return}}r.keepAttr=!1;return}});const n=ite(i);try{return uV(e,{...t,RETURN_TRUSTED_TYPE:!0})}finally{gV("uponSanitizeAttribute"),n.dispose()}}const Hhe=["align","autoplay","alt","class","controls","data-code","data-href","draggable","height","href","loop","muted","playsinline","poster","src","style","target","title","width","start"];function zhe(s){const e=[it.http,it.https,it.mailto,it.data,it.file,it.vscodeFileResource,it.vscodeRemote,it.vscodeRemoteResource];return s.isTrusted&&e.push(it.command),{config:{ALLOWED_TAGS:[...nte],ALLOWED_ATTR:Hhe,ALLOW_UNKNOWN_PROTOCOLS:!0},allowedSchemes:e}}function Uhe(s){return typeof s=="string"?s:$he(s)}function $he(s){var e;let t=(e=s.value)!==null&&e!==void 0?e:"";t.length>1e5&&(t=`${t.substr(0,1e5)}…`);const i=wl.parse(t,{renderer:Khe.value}).replace(/&(#\d+|[a-zA-Z]+);/g,n=>{var o;return(o=jhe.get(n))!==null&&o!==void 0?o:n});return d2({isTrusted:!1},i).toString()}const jhe=new Map([["&quot;",'"'],["&nbsp;"," "],["&amp;","&"],["&#39;","'"],["&lt;","<"],["&gt;",">"]]),Khe=new ih(()=>{const s=new wl.Renderer;return s.code=e=>e,s.blockquote=e=>e,s.html=e=>"",s.heading=(e,t,i)=>e+`
`,s.hr=()=>"",s.list=(e,t)=>e,s.listitem=e=>e+`
`,s.paragraph=e=>e+`
`,s.table=(e,t)=>e+t+`
`,s.tablerow=e=>e,s.tablecell=(e,t)=>e+" ",s.strong=e=>e,s.em=e=>e,s.codespan=e=>e,s.br=()=>`
`,s.del=e=>e,s.image=(e,t,i)=>"",s.text=e=>e,s.link=(e,t,i)=>i,s});function uO(s){let e="";return s.forEach(t=>{e+=t.raw}),e}function qhe(s){for(const e of s.tokens)if(e.type==="text"){const t=e.raw.split(`
`),i=t[t.length-1];if(i.includes("`"))return Yhe(s);if(i.includes("**"))return tge(s);if(i.match(/\*\w/))return Xhe(s);if(i.match(/(^|\s)__\w/))return ige(s);if(i.match(/(^|\s)_\w/))return Qhe(s);if(i.match(/(^|\s)\[.*\]\(\w*/))return Jhe(s);if(i.match(/(^|\s)\[\w/))return ege(s)}}function Ghe(s){let e,t;for(e=0;e<s.length;e++){const i=s[e];if(i.type==="paragraph"&&i.raw.match(/(\n|^)```/)){t=Zhe(s.slice(e));break}if(i.type==="paragraph"&&i.raw.match(/(\n|^)\|/)){t=nge(s.slice(e));break}if(e===s.length-1&&i.type==="paragraph"){const n=qhe(i);if(n){t=[n];break}}}if(t){const i=[...s.slice(0,e),...t];return i.links=s.links,i}return s}function Zhe(s){const e=uO(s);return wl.lexer(e+"\n```")}function Yhe(s){return uf(s,"`")}function Xhe(s){return uf(s,"*")}function Qhe(s){return uf(s,"_")}function Jhe(s){return uf(s,")")}function ege(s){return uf(s,"](about:blank)")}function tge(s){return uf(s,"**")}function ige(s){return uf(s,"__")}function uf(s,e){const t=uO(Array.isArray(s)?s:[s]);return wl.lexer(t+e)[0]}function nge(s){const e=uO(s),t=e.split(`
`);let i,n=!1;for(let o=0;o<t.length;o++){const r=t[o].trim();if(typeof i>"u"&&r.match(/^\s*\|/)){const a=r.match(/(\|[^\|]+)(?=\||$)/g);a&&(i=a.length)}else if(typeof i=="number")if(r.match(/^\s*\|/)){if(o!==t.length-1)return;n=!0}else return}if(typeof i=="number"&&i>0){const o=n?t.slice(0,-1).join(`
`):e,r=!!o.match(/\|\s*$/),a=o+(r?"":"|")+`
|${" --- |".repeat(i)}`;return wl.lexer(a)}}class sge{constructor(e){this.spliceables=e}splice(e,t,i){this.spliceables.forEach(n=>n.splice(e,t,i))}}class Lh extends Error{constructor(e,t){super(`ListError [${e}] ${t}`)}}function r9(s,e){const t=[];for(const i of e){if(s.start>=i.range.end)continue;if(s.end<i.range.start)break;const n=is.intersect(s,i.range);is.isEmpty(n)||t.push({range:n,size:i.size})}return t}function c2({start:s,end:e},t){return{start:s+t,end:e+t}}function oge(s){const e=[];let t=null;for(const i of s){const n=i.range.start,o=i.range.end,r=i.size;if(t&&r===t.size){t.range.end=o;continue}t={range:{start:n,end:o},size:r},e.push(t)}return e}function rge(...s){return oge(s.reduce((e,t)=>e.concat(t),[]))}class a9{get paddingTop(){return this._paddingTop}set paddingTop(e){this._size=this._size+e-this._paddingTop,this._paddingTop=e}constructor(e){this.groups=[],this._size=0,this._paddingTop=0,this._paddingTop=e??0,this._size=this._paddingTop}splice(e,t,i=[]){const n=i.length-t,o=r9({start:0,end:e},this.groups),r=r9({start:e+t,end:Number.POSITIVE_INFINITY},this.groups).map(l=>({range:c2(l.range,n),size:l.size})),a=i.map((l,d)=>({range:{start:e+d,end:e+d+1},size:l.size}));this.groups=rge(o,a,r),this._size=this._paddingTop+this.groups.reduce((l,d)=>l+d.size*(d.range.end-d.range.start),0)}get count(){const e=this.groups.length;return e?this.groups[e-1].range.end:0}get size(){return this._size}indexAt(e){if(e<0)return-1;if(e<this._paddingTop)return 0;let t=0,i=this._paddingTop;for(const n of this.groups){const o=n.range.end-n.range.start,r=i+o*n.size;if(e<r)return t+Math.floor((e-i)/n.size);t+=o,i=r}return t}indexAfter(e){return Math.min(this.indexAt(e)+1,this.count)}positionAt(e){if(e<0)return-1;let t=0,i=0;for(const n of this.groups){const o=n.range.end-n.range.start,r=i+o;if(e<r)return this._paddingTop+t+(e-i)*n.size;t+=o*n.size,i=r}return-1}}function age(s){var e;try{(e=s.parentElement)===null||e===void 0||e.removeChild(s)}catch{}}class lge{constructor(e){this.renderers=e,this.cache=new Map,this.transactionNodesPendingRemoval=new Set,this.inTransaction=!1}alloc(e){let t=this.getTemplateCache(e).pop(),i=!1;if(t)i=this.transactionNodesPendingRemoval.has(t.domNode),i&&this.transactionNodesPendingRemoval.delete(t.domNode);else{const n=se(".monaco-list-row"),r=this.getRenderer(e).renderTemplate(n);t={domNode:n,templateId:e,templateData:r}}return{row:t,isReusingConnectedDomNode:i}}release(e){e&&this.releaseRow(e)}transact(e){if(this.inTransaction)throw new Error("Already in transaction");this.inTransaction=!0;try{e()}finally{for(const t of this.transactionNodesPendingRemoval)this.doRemoveNode(t);this.transactionNodesPendingRemoval.clear(),this.inTransaction=!1}}releaseRow(e){const{domNode:t,templateId:i}=e;t&&(this.inTransaction?this.transactionNodesPendingRemoval.add(t):this.doRemoveNode(t)),this.getTemplateCache(i).push(e)}doRemoveNode(e){e.classList.remove("scrolling"),age(e)}getTemplateCache(e){let t=this.cache.get(e);return t||(t=[],this.cache.set(e,t)),t}dispose(){this.cache.forEach((e,t)=>{for(const i of e)this.getRenderer(t).disposeTemplate(i.templateData),i.templateData=null}),this.cache.clear(),this.transactionNodesPendingRemoval.clear()}getRenderer(e){const t=this.renderers.get(e);if(!t)throw new Error(`No renderer found for ${e}`);return t}}var ac=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o};const xh={CurrentDragAndDropData:void 0},il={useShadows:!0,verticalScrollMode:1,setRowLineHeight:!0,setRowHeight:!0,supportDynamicHeights:!1,dnd:{getDragElements(s){return[s]},getDragURI(){return null},onDragStart(){},onDragOver(){return!1},drop(){},dispose(){}},horizontalScrolling:!1,transformOptimization:!0,alwaysConsumeMouseWheel:!0};class wC{constructor(e){this.elements=e}update(){}getData(){return this.elements}}class dge{constructor(e){this.elements=e}update(){}getData(){return this.elements}}class cge{constructor(){this.types=[],this.files=[]}update(e){if(e.types&&this.types.splice(0,this.types.length,...e.types),e.files){this.files.splice(0,this.files.length);for(let t=0;t<e.files.length;t++){const i=e.files.item(t);i&&(i.size||i.type)&&this.files.push(i)}}}getData(){return{types:this.types,files:this.files}}}function uge(s,e){return Array.isArray(s)&&Array.isArray(e)?Ai(s,e):s===e}class hge{constructor(e){e!=null&&e.getSetSize?this.getSetSize=e.getSetSize.bind(e):this.getSetSize=(t,i,n)=>n,e!=null&&e.getPosInSet?this.getPosInSet=e.getPosInSet.bind(e):this.getPosInSet=(t,i)=>i+1,e!=null&&e.getRole?this.getRole=e.getRole.bind(e):this.getRole=t=>"listitem",e!=null&&e.isChecked?this.isChecked=e.isChecked.bind(e):this.isChecked=t=>{}}}class Tr{get contentHeight(){return this.rangeMap.size}get onDidScroll(){return this.scrollableElement.onScroll}get scrollableElementDomNode(){return this.scrollableElement.getDomNode()}get horizontalScrolling(){return this._horizontalScrolling}set horizontalScrolling(e){if(e!==this._horizontalScrolling){if(e&&this.supportDynamicHeights)throw new Error("Horizontal scrolling and dynamic heights not supported simultaneously");if(this._horizontalScrolling=e,this.domNode.classList.toggle("horizontal-scrolling",this._horizontalScrolling),this._horizontalScrolling){for(const t of this.items)this.measureItemWidth(t);this.updateScrollWidth(),this.scrollableElement.setScrollDimensions({width:Hk(this.domNode)}),this.rowsContainer.style.width=`${Math.max(this.scrollWidth||0,this.renderWidth)}px`}else this.scrollableElementWidthDelayer.cancel(),this.scrollableElement.setScrollDimensions({width:this.renderWidth,scrollWidth:this.renderWidth}),this.rowsContainer.style.width=""}}constructor(e,t,i,n=il){var o,r,a,l,d,c,u,h,g,f,m,_,v;if(this.virtualDelegate=t,this.domId=`list_id_${++Tr.InstanceCount}`,this.renderers=new Map,this.renderWidth=0,this._scrollHeight=0,this.scrollableElementUpdateDisposable=null,this.scrollableElementWidthDelayer=new Qr(50),this.splicing=!1,this.dragOverAnimationStopDisposable=j.None,this.dragOverMouseY=0,this.canDrop=!1,this.currentDragFeedbackDisposable=j.None,this.onDragLeaveTimeout=j.None,this.disposables=new ie,this._onDidChangeContentHeight=new W,this._onDidChangeContentWidth=new W,this.onDidChangeContentHeight=ge.latch(this._onDidChangeContentHeight.event,void 0,this.disposables),this._horizontalScrolling=!1,n.horizontalScrolling&&n.supportDynamicHeights)throw new Error("Horizontal scrolling and dynamic heights not supported simultaneously");this.items=[],this.itemId=0,this.rangeMap=new a9((o=n.paddingTop)!==null&&o!==void 0?o:0);for(const C of i)this.renderers.set(C.templateId,C);this.cache=this.disposables.add(new lge(this.renderers)),this.lastRenderTop=0,this.lastRenderHeight=0,this.domNode=document.createElement("div"),this.domNode.className="monaco-list",this.domNode.classList.add(this.domId),this.domNode.tabIndex=0,this.domNode.classList.toggle("mouse-support",typeof n.mouseSupport=="boolean"?n.mouseSupport:!0),this._horizontalScrolling=(r=n.horizontalScrolling)!==null&&r!==void 0?r:il.horizontalScrolling,this.domNode.classList.toggle("horizontal-scrolling",this._horizontalScrolling),this.paddingBottom=typeof n.paddingBottom>"u"?0:n.paddingBottom,this.accessibilityProvider=new hge(n.accessibilityProvider),this.rowsContainer=document.createElement("div"),this.rowsContainer.className="monaco-list-rows",((a=n.transformOptimization)!==null&&a!==void 0?a:il.transformOptimization)&&(this.rowsContainer.style.transform="translate3d(0px, 0px, 0px)",this.rowsContainer.style.overflow="hidden",this.rowsContainer.style.contain="strict"),this.disposables.add(Xt.addTarget(this.rowsContainer)),this.scrollable=this.disposables.add(new a_({forceIntegerValues:!0,smoothScrollDuration:(l=n.smoothScrolling)!==null&&l!==void 0&&l?125:0,scheduleAtNextAnimationFrame:C=>yo(Xe(this.domNode),C)})),this.scrollableElement=this.disposables.add(new Lx(this.rowsContainer,{alwaysConsumeMouseWheel:(d=n.alwaysConsumeMouseWheel)!==null&&d!==void 0?d:il.alwaysConsumeMouseWheel,horizontal:1,vertical:(c=n.verticalScrollMode)!==null&&c!==void 0?c:il.verticalScrollMode,useShadows:(u=n.useShadows)!==null&&u!==void 0?u:il.useShadows,mouseWheelScrollSensitivity:n.mouseWheelScrollSensitivity,fastScrollSensitivity:n.fastScrollSensitivity,scrollByPage:n.scrollByPage},this.scrollable)),this.domNode.appendChild(this.scrollableElement.getDomNode()),e.appendChild(this.domNode),this.scrollableElement.onScroll(this.onScroll,this,this.disposables),this.disposables.add(Y(this.rowsContainer,Qt.Change,C=>this.onTouchChange(C))),this.disposables.add(Y(this.scrollableElement.getDomNode(),"scroll",C=>C.target.scrollTop=0)),this.disposables.add(Y(this.domNode,"dragover",C=>this.onDragOver(this.toDragEvent(C)))),this.disposables.add(Y(this.domNode,"drop",C=>this.onDrop(this.toDragEvent(C)))),this.disposables.add(Y(this.domNode,"dragleave",C=>this.onDragLeave(this.toDragEvent(C)))),this.disposables.add(Y(this.domNode,"dragend",C=>this.onDragEnd(C))),this.setRowLineHeight=(h=n.setRowLineHeight)!==null&&h!==void 0?h:il.setRowLineHeight,this.setRowHeight=(g=n.setRowHeight)!==null&&g!==void 0?g:il.setRowHeight,this.supportDynamicHeights=(f=n.supportDynamicHeights)!==null&&f!==void 0?f:il.supportDynamicHeights,this.dnd=(m=n.dnd)!==null&&m!==void 0?m:this.disposables.add(il.dnd),this.layout((_=n.initialSize)===null||_===void 0?void 0:_.height,(v=n.initialSize)===null||v===void 0?void 0:v.width)}updateOptions(e){e.paddingBottom!==void 0&&(this.paddingBottom=e.paddingBottom,this.scrollableElement.setScrollDimensions({scrollHeight:this.scrollHeight})),e.smoothScrolling!==void 0&&this.scrollable.setSmoothScrollDuration(e.smoothScrolling?125:0),e.horizontalScrolling!==void 0&&(this.horizontalScrolling=e.horizontalScrolling);let t;if(e.scrollByPage!==void 0&&(t={...t??{},scrollByPage:e.scrollByPage}),e.mouseWheelScrollSensitivity!==void 0&&(t={...t??{},mouseWheelScrollSensitivity:e.mouseWheelScrollSensitivity}),e.fastScrollSensitivity!==void 0&&(t={...t??{},fastScrollSensitivity:e.fastScrollSensitivity}),t&&this.scrollableElement.updateOptions(t),e.paddingTop!==void 0&&e.paddingTop!==this.rangeMap.paddingTop){const i=this.getRenderRange(this.lastRenderTop,this.lastRenderHeight),n=e.paddingTop-this.rangeMap.paddingTop;this.rangeMap.paddingTop=e.paddingTop,this.render(i,Math.max(0,this.lastRenderTop+n),this.lastRenderHeight,void 0,void 0,!0),this.setScrollTop(this.lastRenderTop),this.eventuallyUpdateScrollDimensions(),this.supportDynamicHeights&&this._rerender(this.lastRenderTop,this.lastRenderHeight)}}splice(e,t,i=[]){if(this.splicing)throw new Error("Can't run recursive splices.");this.splicing=!0;try{return this._splice(e,t,i)}finally{this.splicing=!1,this._onDidChangeContentHeight.fire(this.contentHeight)}}_splice(e,t,i=[]){const n=this.getRenderRange(this.lastRenderTop,this.lastRenderHeight),o={start:e,end:e+t},r=is.intersect(n,o),a=new Map;for(let x=r.end-1;x>=r.start;x--){const L=this.items[x];if(L.dragStartDisposable.dispose(),L.checkedDisposable.dispose(),L.row){let k=a.get(L.templateId);k||(k=[],a.set(L.templateId,k));const I=this.renderers.get(L.templateId);I&&I.disposeElement&&I.disposeElement(L.element,x,L.row.templateData,L.size),k.push(L.row)}L.row=null}const l={start:e+t,end:this.items.length},d=is.intersect(l,n),c=is.relativeComplement(l,n),u=i.map(x=>({id:String(this.itemId++),element:x,templateId:this.virtualDelegate.getTemplateId(x),size:this.virtualDelegate.getHeight(x),width:void 0,hasDynamicHeight:!!this.virtualDelegate.hasDynamicHeight&&this.virtualDelegate.hasDynamicHeight(x),lastDynamicHeightWidth:void 0,row:null,uri:void 0,dropTarget:!1,dragStartDisposable:j.None,checkedDisposable:j.None}));let h;e===0&&t>=this.items.length?(this.rangeMap=new a9(this.rangeMap.paddingTop),this.rangeMap.splice(0,0,u),h=this.items,this.items=u):(this.rangeMap.splice(e,t,u),h=this.items.splice(e,t,...u));const g=i.length-t,f=this.getRenderRange(this.lastRenderTop,this.lastRenderHeight),m=c2(d,g),_=is.intersect(f,m);for(let x=_.start;x<_.end;x++)this.updateItemInDOM(this.items[x],x);const v=is.relativeComplement(m,f);for(const x of v)for(let L=x.start;L<x.end;L++)this.removeItemFromDOM(L);const b=c.map(x=>c2(x,g)),w=[{start:e,end:e+i.length},...b].map(x=>is.intersect(f,x)),S=this.getNextToLastElement(w);for(const x of w)for(let L=x.start;L<x.end;L++){const k=this.items[L],I=a.get(k.templateId),P=I==null?void 0:I.pop();this.insertItemInDOM(L,S,P)}for(const x of a.values())for(const L of x)this.cache.release(L);return this.eventuallyUpdateScrollDimensions(),this.supportDynamicHeights&&this._rerender(this.scrollTop,this.renderHeight),h.map(x=>x.element)}eventuallyUpdateScrollDimensions(){this._scrollHeight=this.contentHeight,this.rowsContainer.style.height=`${this._scrollHeight}px`,this.scrollableElementUpdateDisposable||(this.scrollableElementUpdateDisposable=yo(Xe(this.domNode),()=>{this.scrollableElement.setScrollDimensions({scrollHeight:this.scrollHeight}),this.updateScrollWidth(),this.scrollableElementUpdateDisposable=null}))}eventuallyUpdateScrollWidth(){if(!this.horizontalScrolling){this.scrollableElementWidthDelayer.cancel();return}this.scrollableElementWidthDelayer.trigger(()=>this.updateScrollWidth())}updateScrollWidth(){if(!this.horizontalScrolling)return;let e=0;for(const t of this.items)typeof t.width<"u"&&(e=Math.max(e,t.width));this.scrollWidth=e,this.scrollableElement.setScrollDimensions({scrollWidth:e===0?0:e+10}),this._onDidChangeContentWidth.fire(this.scrollWidth)}rerender(){if(this.supportDynamicHeights){for(const e of this.items)e.lastDynamicHeightWidth=void 0;this._rerender(this.lastRenderTop,this.lastRenderHeight)}}get length(){return this.items.length}get renderHeight(){return this.scrollableElement.getScrollDimensions().height}get firstVisibleIndex(){return this.getRenderRange(this.lastRenderTop,this.lastRenderHeight).start}element(e){return this.items[e].element}indexOf(e){return this.items.findIndex(t=>t.element===e)}domElement(e){const t=this.items[e].row;return t&&t.domNode}elementHeight(e){return this.items[e].size}elementTop(e){return this.rangeMap.positionAt(e)}indexAt(e){return this.rangeMap.indexAt(e)}indexAfter(e){return this.rangeMap.indexAfter(e)}layout(e,t){const i={height:typeof e=="number"?e:zee(this.domNode)};this.scrollableElementUpdateDisposable&&(this.scrollableElementUpdateDisposable.dispose(),this.scrollableElementUpdateDisposable=null,i.scrollHeight=this.scrollHeight),this.scrollableElement.setScrollDimensions(i),typeof t<"u"&&(this.renderWidth=t,this.supportDynamicHeights&&this._rerender(this.scrollTop,this.renderHeight)),this.horizontalScrolling&&this.scrollableElement.setScrollDimensions({width:typeof t=="number"?t:Hk(this.domNode)})}render(e,t,i,n,o,r=!1){const a=this.getRenderRange(t,i),l=is.relativeComplement(a,e),d=is.relativeComplement(e,a),c=this.getNextToLastElement(l);if(r){const u=is.intersect(e,a);for(let h=u.start;h<u.end;h++)this.updateItemInDOM(this.items[h],h)}this.cache.transact(()=>{for(const u of d)for(let h=u.start;h<u.end;h++)this.removeItemFromDOM(h);for(const u of l)for(let h=u.start;h<u.end;h++)this.insertItemInDOM(h,c)}),n!==void 0&&(this.rowsContainer.style.left=`-${n}px`),this.rowsContainer.style.top=`-${t}px`,this.horizontalScrolling&&o!==void 0&&(this.rowsContainer.style.width=`${Math.max(o,this.renderWidth)}px`),this.lastRenderTop=t,this.lastRenderHeight=i}insertItemInDOM(e,t,i){const n=this.items[e];let o=!1;if(!n.row)if(i)n.row=i;else{const c=this.cache.alloc(n.templateId);n.row=c.row,o=c.isReusingConnectedDomNode}const r=this.accessibilityProvider.getRole(n.element)||"listitem";n.row.domNode.setAttribute("role",r);const a=this.accessibilityProvider.isChecked(n.element);if(typeof a=="boolean")n.row.domNode.setAttribute("aria-checked",String(!!a));else if(a){const c=u=>n.row.domNode.setAttribute("aria-checked",String(!!u));c(a.value),n.checkedDisposable=a.onDidChange(c)}(o||!n.row.domNode.parentElement)&&(t?this.rowsContainer.insertBefore(n.row.domNode,t):this.rowsContainer.appendChild(n.row.domNode)),this.updateItemInDOM(n,e);const l=this.renderers.get(n.templateId);if(!l)throw new Error(`No renderer found for template id ${n.templateId}`);l==null||l.renderElement(n.element,e,n.row.templateData,n.size);const d=this.dnd.getDragURI(n.element);n.dragStartDisposable.dispose(),n.row.domNode.draggable=!!d,d&&(n.dragStartDisposable=Y(n.row.domNode,"dragstart",c=>this.onDragStart(n.element,d,c))),this.horizontalScrolling&&(this.measureItemWidth(n),this.eventuallyUpdateScrollWidth())}measureItemWidth(e){if(!e.row||!e.row.domNode)return;e.row.domNode.style.width="fit-content",e.width=Hk(e.row.domNode);const t=Xe(e.row.domNode).getComputedStyle(e.row.domNode);t.paddingLeft&&(e.width+=parseFloat(t.paddingLeft)),t.paddingRight&&(e.width+=parseFloat(t.paddingRight)),e.row.domNode.style.width=""}updateItemInDOM(e,t){e.row.domNode.style.top=`${this.elementTop(t)}px`,this.setRowHeight&&(e.row.domNode.style.height=`${e.size}px`),this.setRowLineHeight&&(e.row.domNode.style.lineHeight=`${e.size}px`),e.row.domNode.setAttribute("data-index",`${t}`),e.row.domNode.setAttribute("data-last-element",t===this.length-1?"true":"false"),e.row.domNode.setAttribute("data-parity",t%2===0?"even":"odd"),e.row.domNode.setAttribute("aria-setsize",String(this.accessibilityProvider.getSetSize(e.element,t,this.length))),e.row.domNode.setAttribute("aria-posinset",String(this.accessibilityProvider.getPosInSet(e.element,t))),e.row.domNode.setAttribute("id",this.getElementDomId(t)),e.row.domNode.classList.toggle("drop-target",e.dropTarget)}removeItemFromDOM(e){const t=this.items[e];if(t.dragStartDisposable.dispose(),t.checkedDisposable.dispose(),t.row){const i=this.renderers.get(t.templateId);i&&i.disposeElement&&i.disposeElement(t.element,e,t.row.templateData,t.size),this.cache.release(t.row),t.row=null}this.horizontalScrolling&&this.eventuallyUpdateScrollWidth()}getScrollTop(){return this.scrollableElement.getScrollPosition().scrollTop}setScrollTop(e,t){this.scrollableElementUpdateDisposable&&(this.scrollableElementUpdateDisposable.dispose(),this.scrollableElementUpdateDisposable=null,this.scrollableElement.setScrollDimensions({scrollHeight:this.scrollHeight})),this.scrollableElement.setScrollPosition({scrollTop:e,reuseAnimation:t})}get scrollTop(){return this.getScrollTop()}set scrollTop(e){this.setScrollTop(e)}get scrollHeight(){return this._scrollHeight+(this.horizontalScrolling?10:0)+this.paddingBottom}get onMouseClick(){return ge.map(this.disposables.add(new gt(this.domNode,"click")).event,e=>this.toMouseEvent(e),this.disposables)}get onMouseDblClick(){return ge.map(this.disposables.add(new gt(this.domNode,"dblclick")).event,e=>this.toMouseEvent(e),this.disposables)}get onMouseMiddleClick(){return ge.filter(ge.map(this.disposables.add(new gt(this.domNode,"auxclick")).event,e=>this.toMouseEvent(e),this.disposables),e=>e.browserEvent.button===1,this.disposables)}get onMouseDown(){return ge.map(this.disposables.add(new gt(this.domNode,"mousedown")).event,e=>this.toMouseEvent(e),this.disposables)}get onMouseOver(){return ge.map(this.disposables.add(new gt(this.domNode,"mouseover")).event,e=>this.toMouseEvent(e),this.disposables)}get onMouseOut(){return ge.map(this.disposables.add(new gt(this.domNode,"mouseout")).event,e=>this.toMouseEvent(e),this.disposables)}get onContextMenu(){return ge.any(ge.map(this.disposables.add(new gt(this.domNode,"contextmenu")).event,e=>this.toMouseEvent(e),this.disposables),ge.map(this.disposables.add(new gt(this.domNode,Qt.Contextmenu)).event,e=>this.toGestureEvent(e),this.disposables))}get onTouchStart(){return ge.map(this.disposables.add(new gt(this.domNode,"touchstart")).event,e=>this.toTouchEvent(e),this.disposables)}get onTap(){return ge.map(this.disposables.add(new gt(this.rowsContainer,Qt.Tap)).event,e=>this.toGestureEvent(e),this.disposables)}toMouseEvent(e){const t=this.getItemIndexFromEventTarget(e.target||null),i=typeof t>"u"?void 0:this.items[t],n=i&&i.element;return{browserEvent:e,index:t,element:n}}toTouchEvent(e){const t=this.getItemIndexFromEventTarget(e.target||null),i=typeof t>"u"?void 0:this.items[t],n=i&&i.element;return{browserEvent:e,index:t,element:n}}toGestureEvent(e){const t=this.getItemIndexFromEventTarget(e.initialTarget||null),i=typeof t>"u"?void 0:this.items[t],n=i&&i.element;return{browserEvent:e,index:t,element:n}}toDragEvent(e){const t=this.getItemIndexFromEventTarget(e.target||null),i=typeof t>"u"?void 0:this.items[t],n=i&&i.element;return{browserEvent:e,index:t,element:n}}onScroll(e){try{const t=this.getRenderRange(this.lastRenderTop,this.lastRenderHeight);this.render(t,e.scrollTop,e.height,e.scrollLeft,e.scrollWidth),this.supportDynamicHeights&&this._rerender(e.scrollTop,e.height,e.inSmoothScrolling)}catch(t){throw console.error("Got bad scroll event:",e),t}}onTouchChange(e){e.preventDefault(),e.stopPropagation(),this.scrollTop-=e.translationY}onDragStart(e,t,i){var n,o;if(!i.dataTransfer)return;const r=this.dnd.getDragElements(e);if(i.dataTransfer.effectAllowed="copyMove",i.dataTransfer.setData(ab.TEXT,t),i.dataTransfer.setDragImage){let a;this.dnd.getDragLabel&&(a=this.dnd.getDragLabel(r,i)),typeof a>"u"&&(a=String(r.length));const l=se(".monaco-drag-image");l.textContent=a;const c=(u=>{for(;u&&!u.classList.contains("monaco-workbench");)u=u.parentElement;return u||this.domNode.ownerDocument})(this.domNode);c.appendChild(l),i.dataTransfer.setDragImage(l,-10,-10),setTimeout(()=>c.removeChild(l),0)}this.domNode.classList.add("dragging"),this.currentDragData=new wC(r),xh.CurrentDragAndDropData=new dge(r),(o=(n=this.dnd).onDragStart)===null||o===void 0||o.call(n,this.currentDragData,i)}onDragOver(e){var t;if(e.browserEvent.preventDefault(),this.onDragLeaveTimeout.dispose(),xh.CurrentDragAndDropData&&xh.CurrentDragAndDropData.getData()==="vscode-ui"||(this.setupDragAndDropScrollTopAnimation(e.browserEvent),!e.browserEvent.dataTransfer))return!1;if(!this.currentDragData)if(xh.CurrentDragAndDropData)this.currentDragData=xh.CurrentDragAndDropData;else{if(!e.browserEvent.dataTransfer.types)return!1;this.currentDragData=new cge}const i=this.dnd.onDragOver(this.currentDragData,e.element,e.index,e.browserEvent);if(this.canDrop=typeof i=="boolean"?i:i.accept,!this.canDrop)return this.currentDragFeedback=void 0,this.currentDragFeedbackDisposable.dispose(),!1;e.browserEvent.dataTransfer.dropEffect=typeof i!="boolean"&&i.effect===0?"copy":"move";let n;if(typeof i!="boolean"&&i.feedback?n=i.feedback:typeof e.index>"u"?n=[-1]:n=[e.index],n=Lu(n).filter(o=>o>=-1&&o<this.length).sort((o,r)=>o-r),n=n[0]===-1?[-1]:n,uge(this.currentDragFeedback,n))return!0;if(this.currentDragFeedback=n,this.currentDragFeedbackDisposable.dispose(),n[0]===-1)this.domNode.classList.add("drop-target"),this.rowsContainer.classList.add("drop-target"),this.currentDragFeedbackDisposable=Fe(()=>{this.domNode.classList.remove("drop-target"),this.rowsContainer.classList.remove("drop-target")});else{for(const o of n){const r=this.items[o];r.dropTarget=!0,(t=r.row)===null||t===void 0||t.domNode.classList.add("drop-target")}this.currentDragFeedbackDisposable=Fe(()=>{var o;for(const r of n){const a=this.items[r];a.dropTarget=!1,(o=a.row)===null||o===void 0||o.domNode.classList.remove("drop-target")}})}return!0}onDragLeave(e){var t,i;this.onDragLeaveTimeout.dispose(),this.onDragLeaveTimeout=Eu(()=>this.clearDragOverFeedback(),100,this.disposables),this.currentDragData&&((i=(t=this.dnd).onDragLeave)===null||i===void 0||i.call(t,this.currentDragData,e.element,e.index,e.browserEvent))}onDrop(e){if(!this.canDrop)return;const t=this.currentDragData;this.teardownDragAndDropScrollTopAnimation(),this.clearDragOverFeedback(),this.domNode.classList.remove("dragging"),this.currentDragData=void 0,xh.CurrentDragAndDropData=void 0,!(!t||!e.browserEvent.dataTransfer)&&(e.browserEvent.preventDefault(),t.update(e.browserEvent.dataTransfer),this.dnd.drop(t,e.element,e.index,e.browserEvent))}onDragEnd(e){var t,i;this.canDrop=!1,this.teardownDragAndDropScrollTopAnimation(),this.clearDragOverFeedback(),this.domNode.classList.remove("dragging"),this.currentDragData=void 0,xh.CurrentDragAndDropData=void 0,(i=(t=this.dnd).onDragEnd)===null||i===void 0||i.call(t,e)}clearDragOverFeedback(){this.currentDragFeedback=void 0,this.currentDragFeedbackDisposable.dispose(),this.currentDragFeedbackDisposable=j.None}setupDragAndDropScrollTopAnimation(e){if(!this.dragOverAnimationDisposable){const t=vV(this.domNode).top;this.dragOverAnimationDisposable=tte(Xe(this.domNode),this.animateDragAndDropScrollTop.bind(this,t))}this.dragOverAnimationStopDisposable.dispose(),this.dragOverAnimationStopDisposable=Eu(()=>{this.dragOverAnimationDisposable&&(this.dragOverAnimationDisposable.dispose(),this.dragOverAnimationDisposable=void 0)},1e3,this.disposables),this.dragOverMouseY=e.pageY}animateDragAndDropScrollTop(e){if(this.dragOverMouseY===void 0)return;const t=this.dragOverMouseY-e,i=this.renderHeight-35;t<35?this.scrollTop+=Math.max(-14,Math.floor(.3*(t-35))):t>i&&(this.scrollTop+=Math.min(14,Math.floor(.3*(t-i))))}teardownDragAndDropScrollTopAnimation(){this.dragOverAnimationStopDisposable.dispose(),this.dragOverAnimationDisposable&&(this.dragOverAnimationDisposable.dispose(),this.dragOverAnimationDisposable=void 0)}getItemIndexFromEventTarget(e){const t=this.scrollableElement.getDomNode();let i=e;for(;i instanceof HTMLElement&&i!==this.rowsContainer&&t.contains(i);){const n=i.getAttribute("data-index");if(n){const o=Number(n);if(!isNaN(o))return o}i=i.parentElement}}getRenderRange(e,t){return{start:this.rangeMap.indexAt(e),end:this.rangeMap.indexAfter(e+t-1)}}_rerender(e,t,i){const n=this.getRenderRange(e,t);let o,r;e===this.elementTop(n.start)?(o=n.start,r=0):n.end-n.start>1&&(o=n.start+1,r=this.elementTop(o)-e);let a=0;for(;;){const l=this.getRenderRange(e,t);let d=!1;for(let c=l.start;c<l.end;c++){const u=this.probeDynamicHeight(c);u!==0&&this.rangeMap.splice(c,1,[this.items[c]]),a+=u,d=d||u!==0}if(!d){a!==0&&this.eventuallyUpdateScrollDimensions();const c=is.relativeComplement(n,l);for(const h of c)for(let g=h.start;g<h.end;g++)this.items[g].row&&this.removeItemFromDOM(g);const u=is.relativeComplement(l,n);for(const h of u)for(let g=h.start;g<h.end;g++){const f=g+1,m=f<this.items.length?this.items[f].row:null,_=m?m.domNode:null;this.insertItemInDOM(g,_)}for(let h=l.start;h<l.end;h++)this.items[h].row&&this.updateItemInDOM(this.items[h],h);if(typeof o=="number"){const h=this.scrollable.getFutureScrollPosition().scrollTop-e,g=this.elementTop(o)-r+h;this.setScrollTop(g,i)}this._onDidChangeContentHeight.fire(this.contentHeight);return}}}probeDynamicHeight(e){var t,i,n;const o=this.items[e];if(this.virtualDelegate.getDynamicHeight){const d=this.virtualDelegate.getDynamicHeight(o.element);if(d!==null){const c=o.size;return o.size=d,o.lastDynamicHeightWidth=this.renderWidth,d-c}}if(!o.hasDynamicHeight||o.lastDynamicHeightWidth===this.renderWidth||this.virtualDelegate.hasDynamicHeight&&!this.virtualDelegate.hasDynamicHeight(o.element))return 0;const r=o.size;if(o.row)return o.row.domNode.style.height="",o.size=o.row.domNode.offsetHeight,o.lastDynamicHeightWidth=this.renderWidth,o.size-r;const{row:a}=this.cache.alloc(o.templateId);a.domNode.style.height="",this.rowsContainer.appendChild(a.domNode);const l=this.renderers.get(o.templateId);if(!l)throw new pi("Missing renderer for templateId: "+o.templateId);return l.renderElement(o.element,e,a.templateData,void 0),o.size=a.domNode.offsetHeight,(t=l.disposeElement)===null||t===void 0||t.call(l,o.element,e,a.templateData,void 0),(n=(i=this.virtualDelegate).setDynamicHeight)===null||n===void 0||n.call(i,o.element,o.size),o.lastDynamicHeightWidth=this.renderWidth,this.rowsContainer.removeChild(a.domNode),this.cache.release(a),o.size-r}getNextToLastElement(e){const t=e[e.length-1];if(!t)return null;const i=this.items[t.end];return!i||!i.row?null:i.row.domNode}getElementDomId(e){return`${this.domId}_${e}`}dispose(){var e,t;for(const i of this.items)if(i.dragStartDisposable.dispose(),i.checkedDisposable.dispose(),i.row){const n=this.renderers.get(i.row.templateId);n&&((e=n.disposeElement)===null||e===void 0||e.call(n,i.element,-1,i.row.templateData,void 0),n.disposeTemplate(i.row.templateData))}this.items=[],this.domNode&&this.domNode.parentNode&&this.domNode.parentNode.removeChild(this.domNode),(t=this.dragOverAnimationDisposable)===null||t===void 0||t.dispose(),this.disposables.dispose()}}Tr.InstanceCount=0;ac([Xi],Tr.prototype,"onMouseClick",null);ac([Xi],Tr.prototype,"onMouseDblClick",null);ac([Xi],Tr.prototype,"onMouseMiddleClick",null);ac([Xi],Tr.prototype,"onMouseDown",null);ac([Xi],Tr.prototype,"onMouseOver",null);ac([Xi],Tr.prototype,"onMouseOut",null);ac([Xi],Tr.prototype,"onContextMenu",null);ac([Xi],Tr.prototype,"onTouchStart",null);ac([Xi],Tr.prototype,"onTap",null);var hf=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o};class gge{constructor(e){this.trait=e,this.renderedElements=[]}get templateId(){return`template:${this.trait.name}`}renderTemplate(e){return e}renderElement(e,t,i){const n=this.renderedElements.findIndex(o=>o.templateData===i);if(n>=0){const o=this.renderedElements[n];this.trait.unrender(i),o.index=t}else{const o={index:t,templateData:i};this.renderedElements.push(o)}this.trait.renderIndex(t,i)}splice(e,t,i){const n=[];for(const o of this.renderedElements)o.index<e?n.push(o):o.index>=e+t&&n.push({index:o.index+i-t,templateData:o.templateData});this.renderedElements=n}renderIndexes(e){for(const{index:t,templateData:i}of this.renderedElements)e.indexOf(t)>-1&&this.trait.renderIndex(t,i)}disposeTemplate(e){const t=this.renderedElements.findIndex(i=>i.templateData===e);t<0||this.renderedElements.splice(t,1)}}let yy=class{get name(){return this._trait}get renderer(){return new gge(this)}constructor(e){this._trait=e,this.length=0,this.indexes=[],this.sortedIndexes=[],this._onChange=new W,this.onChange=this._onChange.event}splice(e,t,i){var n;t=Math.max(0,Math.min(t,this.length-e));const o=i.length-t,r=e+t,a=[];let l=0;for(;l<this.sortedIndexes.length&&this.sortedIndexes[l]<e;)a.push(this.sortedIndexes[l++]);for(let c=0;c<i.length;c++)i[c]&&a.push(c+e);for(;l<this.sortedIndexes.length&&this.sortedIndexes[l]>=r;)a.push(this.sortedIndexes[l++]+o);const d=this.length+o;if(this.sortedIndexes.length>0&&a.length===0&&d>0){const c=(n=this.sortedIndexes.find(u=>u>=e))!==null&&n!==void 0?n:d-1;a.push(Math.min(c,d-1))}this.renderer.splice(e,t,i.length),this._set(a,a),this.length=d}renderIndex(e,t){t.classList.toggle(this._trait,this.contains(e))}unrender(e){e.classList.remove(this._trait)}set(e,t){return this._set(e,[...e].sort(d9),t)}_set(e,t,i){const n=this.indexes,o=this.sortedIndexes;this.indexes=e,this.sortedIndexes=t;const r=u2(o,e);return this.renderer.renderIndexes(r),this._onChange.fire({indexes:e,browserEvent:i}),n}get(){return this.indexes}contains(e){return _0(this.sortedIndexes,e,d9)>=0}dispose(){Bt(this._onChange)}};hf([Xi],yy.prototype,"renderer",null);class fge extends yy{constructor(e){super("selected"),this.setAriaSelected=e}renderIndex(e,t){super.renderIndex(e,t),this.setAriaSelected&&(this.contains(e)?t.setAttribute("aria-selected","true"):t.setAttribute("aria-selected","false"))}}class WI{constructor(e,t,i){this.trait=e,this.view=t,this.identityProvider=i}splice(e,t,i){if(!this.identityProvider)return this.trait.splice(e,t,new Array(i.length).fill(!1));const n=this.trait.get().map(a=>this.identityProvider.getId(this.view.element(a)).toString());if(n.length===0)return this.trait.splice(e,t,new Array(i.length).fill(!1));const o=new Set(n),r=i.map(a=>o.has(this.identityProvider.getId(a).toString()));this.trait.splice(e,t,r)}}function gu(s){return s.tagName==="INPUT"||s.tagName==="TEXTAREA"}function SC(s,e){return s.classList.contains(e)?!0:s.classList.contains("monaco-list")||!s.parentElement?!1:SC(s.parentElement,e)}function bv(s){return SC(s,"monaco-editor")}function pge(s){return SC(s,"monaco-custom-toggle")}function mge(s){return SC(s,"action-item")}function _ge(s){return SC(s,"monaco-tree-sticky-row")}function $z(s){return s.tagName==="A"&&s.classList.contains("monaco-button")||s.tagName==="DIV"&&s.classList.contains("monaco-button-dropdown")?!0:s.classList.contains("monaco-list")||!s.parentElement?!1:$z(s.parentElement)}class jz{get onKeyDown(){return ge.chain(this.disposables.add(new gt(this.view.domNode,"keydown")).event,e=>e.filter(t=>!gu(t.target)).map(t=>new ri(t)))}constructor(e,t,i){this.list=e,this.view=t,this.disposables=new ie,this.multipleSelectionDisposables=new ie,this.multipleSelectionSupport=i.multipleSelectionSupport,this.disposables.add(this.onKeyDown(n=>{switch(n.keyCode){case 3:return this.onEnter(n);case 16:return this.onUpArrow(n);case 18:return this.onDownArrow(n);case 11:return this.onPageUpArrow(n);case 12:return this.onPageDownArrow(n);case 9:return this.onEscape(n);case 31:this.multipleSelectionSupport&&(bt?n.metaKey:n.ctrlKey)&&this.onCtrlA(n)}}))}updateOptions(e){e.multipleSelectionSupport!==void 0&&(this.multipleSelectionSupport=e.multipleSelectionSupport)}onEnter(e){e.preventDefault(),e.stopPropagation(),this.list.setSelection(this.list.getFocus(),e.browserEvent)}onUpArrow(e){e.preventDefault(),e.stopPropagation(),this.list.focusPrevious(1,!1,e.browserEvent);const t=this.list.getFocus()[0];this.list.setAnchor(t),this.list.reveal(t),this.view.domNode.focus()}onDownArrow(e){e.preventDefault(),e.stopPropagation(),this.list.focusNext(1,!1,e.browserEvent);const t=this.list.getFocus()[0];this.list.setAnchor(t),this.list.reveal(t),this.view.domNode.focus()}onPageUpArrow(e){e.preventDefault(),e.stopPropagation(),this.list.focusPreviousPage(e.browserEvent);const t=this.list.getFocus()[0];this.list.setAnchor(t),this.list.reveal(t),this.view.domNode.focus()}onPageDownArrow(e){e.preventDefault(),e.stopPropagation(),this.list.focusNextPage(e.browserEvent);const t=this.list.getFocus()[0];this.list.setAnchor(t),this.list.reveal(t),this.view.domNode.focus()}onCtrlA(e){e.preventDefault(),e.stopPropagation(),this.list.setSelection(Ls(this.list.length),e.browserEvent),this.list.setAnchor(void 0),this.view.domNode.focus()}onEscape(e){this.list.getSelection().length&&(e.preventDefault(),e.stopPropagation(),this.list.setSelection([],e.browserEvent),this.list.setAnchor(void 0),this.view.domNode.focus())}dispose(){this.disposables.dispose(),this.multipleSelectionDisposables.dispose()}}hf([Xi],jz.prototype,"onKeyDown",null);var Sl;(function(s){s[s.Automatic=0]="Automatic",s[s.Trigger=1]="Trigger"})(Sl||(Sl={}));var bp;(function(s){s[s.Idle=0]="Idle",s[s.Typing=1]="Typing"})(bp||(bp={}));const vge=new class{mightProducePrintableCharacter(s){return s.ctrlKey||s.metaKey||s.altKey?!1:s.keyCode>=31&&s.keyCode<=56||s.keyCode>=21&&s.keyCode<=30||s.keyCode>=98&&s.keyCode<=107||s.keyCode>=85&&s.keyCode<=95}};class bge{constructor(e,t,i,n,o){this.list=e,this.view=t,this.keyboardNavigationLabelProvider=i,this.keyboardNavigationEventFilter=n,this.delegate=o,this.enabled=!1,this.state=bp.Idle,this.mode=Sl.Automatic,this.triggered=!1,this.previouslyFocused=-1,this.enabledDisposables=new ie,this.disposables=new ie,this.updateOptions(e.options)}updateOptions(e){var t,i;!((t=e.typeNavigationEnabled)!==null&&t!==void 0)||t?this.enable():this.disable(),this.mode=(i=e.typeNavigationMode)!==null&&i!==void 0?i:Sl.Automatic}enable(){if(this.enabled)return;let e=!1;const t=ge.chain(this.enabledDisposables.add(new gt(this.view.domNode,"keydown")).event,o=>o.filter(r=>!gu(r.target)).filter(()=>this.mode===Sl.Automatic||this.triggered).map(r=>new ri(r)).filter(r=>e||this.keyboardNavigationEventFilter(r)).filter(r=>this.delegate.mightProducePrintableCharacter(r)).forEach(r=>ot.stop(r,!0)).map(r=>r.browserEvent.key)),i=ge.debounce(t,()=>null,800,void 0,void 0,void 0,this.enabledDisposables);ge.reduce(ge.any(t,i),(o,r)=>r===null?null:(o||"")+r,void 0,this.enabledDisposables)(this.onInput,this,this.enabledDisposables),i(this.onClear,this,this.enabledDisposables),t(()=>e=!0,void 0,this.enabledDisposables),i(()=>e=!1,void 0,this.enabledDisposables),this.enabled=!0,this.triggered=!1}disable(){this.enabled&&(this.enabledDisposables.clear(),this.enabled=!1,this.triggered=!1)}onClear(){var e;const t=this.list.getFocus();if(t.length>0&&t[0]===this.previouslyFocused){const i=(e=this.list.options.accessibilityProvider)===null||e===void 0?void 0:e.getAriaLabel(this.list.element(t[0]));i&&Lo(i)}this.previouslyFocused=-1}onInput(e){if(!e){this.state=bp.Idle,this.triggered=!1;return}const t=this.list.getFocus(),i=t.length>0?t[0]:0,n=this.state===bp.Idle?1:0;this.state=bp.Typing;for(let o=0;o<this.list.length;o++){const r=(i+o+n)%this.list.length,a=this.keyboardNavigationLabelProvider.getKeyboardNavigationLabel(this.view.element(r)),l=a&&a.toString();if(this.list.options.typeNavigationEnabled){if(typeof l<"u"){if(lb(e,l)){this.previouslyFocused=i,this.list.setFocus([r]),this.list.reveal(r);return}const d=ghe(e,l);if(d&&d[0].end-d[0].start>1&&d.length===1){this.previouslyFocused=i,this.list.setFocus([r]),this.list.reveal(r);return}}}else if(typeof l>"u"||lb(e,l)){this.previouslyFocused=i,this.list.setFocus([r]),this.list.reveal(r);return}}}dispose(){this.disable(),this.enabledDisposables.dispose(),this.disposables.dispose()}}class Cge{constructor(e,t){this.list=e,this.view=t,this.disposables=new ie;const i=ge.chain(this.disposables.add(new gt(t.domNode,"keydown")).event,o=>o.filter(r=>!gu(r.target)).map(r=>new ri(r)));ge.chain(i,o=>o.filter(r=>r.keyCode===2&&!r.ctrlKey&&!r.metaKey&&!r.shiftKey&&!r.altKey))(this.onTab,this,this.disposables)}onTab(e){if(e.target!==this.view.domNode)return;const t=this.list.getFocus();if(t.length===0)return;const i=this.view.domElement(t[0]);if(!i)return;const n=i.querySelector("[tabIndex]");if(!n||!(n instanceof HTMLElement)||n.tabIndex===-1)return;const o=Xe(n).getComputedStyle(n);o.visibility==="hidden"||o.display==="none"||(e.preventDefault(),e.stopPropagation(),n.focus())}dispose(){this.disposables.dispose()}}function Kz(s){return bt?s.browserEvent.metaKey:s.browserEvent.ctrlKey}function qz(s){return s.browserEvent.shiftKey}function wge(s){return iP(s)&&s.button===2}const l9={isSelectionSingleChangeEvent:Kz,isSelectionRangeChangeEvent:qz};class Gz{constructor(e){this.list=e,this.disposables=new ie,this._onPointer=new W,this.onPointer=this._onPointer.event,e.options.multipleSelectionSupport!==!1&&(this.multipleSelectionController=this.list.options.multipleSelectionController||l9),this.mouseSupport=typeof e.options.mouseSupport>"u"||!!e.options.mouseSupport,this.mouseSupport&&(e.onMouseDown(this.onMouseDown,this,this.disposables),e.onContextMenu(this.onContextMenu,this,this.disposables),e.onMouseDblClick(this.onDoubleClick,this,this.disposables),e.onTouchStart(this.onMouseDown,this,this.disposables),this.disposables.add(Xt.addTarget(e.getHTMLElement()))),ge.any(e.onMouseClick,e.onMouseMiddleClick,e.onTap)(this.onViewPointer,this,this.disposables)}updateOptions(e){e.multipleSelectionSupport!==void 0&&(this.multipleSelectionController=void 0,e.multipleSelectionSupport&&(this.multipleSelectionController=this.list.options.multipleSelectionController||l9))}isSelectionSingleChangeEvent(e){return this.multipleSelectionController?this.multipleSelectionController.isSelectionSingleChangeEvent(e):!1}isSelectionRangeChangeEvent(e){return this.multipleSelectionController?this.multipleSelectionController.isSelectionRangeChangeEvent(e):!1}isSelectionChangeEvent(e){return this.isSelectionSingleChangeEvent(e)||this.isSelectionRangeChangeEvent(e)}onMouseDown(e){bv(e.browserEvent.target)||Jo()!==e.browserEvent.target&&this.list.domFocus()}onContextMenu(e){if(gu(e.browserEvent.target)||bv(e.browserEvent.target))return;const t=typeof e.index>"u"?[]:[e.index];this.list.setFocus(t,e.browserEvent)}onViewPointer(e){if(!this.mouseSupport||gu(e.browserEvent.target)||bv(e.browserEvent.target)||e.browserEvent.isHandledByList)return;e.browserEvent.isHandledByList=!0;const t=e.index;if(typeof t>"u"){this.list.setFocus([],e.browserEvent),this.list.setSelection([],e.browserEvent),this.list.setAnchor(void 0);return}if(this.isSelectionChangeEvent(e))return this.changeSelection(e);this.list.setFocus([t],e.browserEvent),this.list.setAnchor(t),wge(e.browserEvent)||this.list.setSelection([t],e.browserEvent),this._onPointer.fire(e)}onDoubleClick(e){if(gu(e.browserEvent.target)||bv(e.browserEvent.target)||this.isSelectionChangeEvent(e)||e.browserEvent.isHandledByList)return;e.browserEvent.isHandledByList=!0;const t=this.list.getFocus();this.list.setSelection(t,e.browserEvent)}changeSelection(e){const t=e.index;let i=this.list.getAnchor();if(this.isSelectionRangeChangeEvent(e)){if(typeof i>"u"){const c=this.list.getFocus()[0];i=c??t,this.list.setAnchor(i)}const n=Math.min(i,t),o=Math.max(i,t),r=Ls(n,o+1),a=this.list.getSelection(),l=Lge(u2(a,[i]),i);if(l.length===0)return;const d=u2(r,xge(a,l));this.list.setSelection(d,e.browserEvent),this.list.setFocus([t],e.browserEvent)}else if(this.isSelectionSingleChangeEvent(e)){const n=this.list.getSelection(),o=n.filter(r=>r!==t);this.list.setFocus([t]),this.list.setAnchor(t),n.length===o.length?this.list.setSelection([...o,t],e.browserEvent):this.list.setSelection(o,e.browserEvent)}}dispose(){this.disposables.dispose()}}class Zz{constructor(e,t){this.styleElement=e,this.selectorSuffix=t}style(e){var t,i;const n=this.selectorSuffix&&`.${this.selectorSuffix}`,o=[];e.listBackground&&o.push(`.monaco-list${n} .monaco-list-rows { background: ${e.listBackground}; }`),e.listFocusBackground&&(o.push(`.monaco-list${n}:focus .monaco-list-row.focused { background-color: ${e.listFocusBackground}; }`),o.push(`.monaco-list${n}:focus .monaco-list-row.focused:hover { background-color: ${e.listFocusBackground}; }`)),e.listFocusForeground&&o.push(`.monaco-list${n}:focus .monaco-list-row.focused { color: ${e.listFocusForeground}; }`),e.listActiveSelectionBackground&&(o.push(`.monaco-list${n}:focus .monaco-list-row.selected { background-color: ${e.listActiveSelectionBackground}; }`),o.push(`.monaco-list${n}:focus .monaco-list-row.selected:hover { background-color: ${e.listActiveSelectionBackground}; }`)),e.listActiveSelectionForeground&&o.push(`.monaco-list${n}:focus .monaco-list-row.selected { color: ${e.listActiveSelectionForeground}; }`),e.listActiveSelectionIconForeground&&o.push(`.monaco-list${n}:focus .monaco-list-row.selected .codicon { color: ${e.listActiveSelectionIconForeground}; }`),e.listFocusAndSelectionBackground&&o.push(`
				.monaco-drag-image,
				.monaco-list${n}:focus .monaco-list-row.selected.focused { background-color: ${e.listFocusAndSelectionBackground}; }
			`),e.listFocusAndSelectionForeground&&o.push(`
				.monaco-drag-image,
				.monaco-list${n}:focus .monaco-list-row.selected.focused { color: ${e.listFocusAndSelectionForeground}; }
			`),e.listInactiveFocusForeground&&(o.push(`.monaco-list${n} .monaco-list-row.focused { color:  ${e.listInactiveFocusForeground}; }`),o.push(`.monaco-list${n} .monaco-list-row.focused:hover { color:  ${e.listInactiveFocusForeground}; }`)),e.listInactiveSelectionIconForeground&&o.push(`.monaco-list${n} .monaco-list-row.focused .codicon { color:  ${e.listInactiveSelectionIconForeground}; }`),e.listInactiveFocusBackground&&(o.push(`.monaco-list${n} .monaco-list-row.focused { background-color:  ${e.listInactiveFocusBackground}; }`),o.push(`.monaco-list${n} .monaco-list-row.focused:hover { background-color:  ${e.listInactiveFocusBackground}; }`)),e.listInactiveSelectionBackground&&(o.push(`.monaco-list${n} .monaco-list-row.selected { background-color:  ${e.listInactiveSelectionBackground}; }`),o.push(`.monaco-list${n} .monaco-list-row.selected:hover { background-color:  ${e.listInactiveSelectionBackground}; }`)),e.listInactiveSelectionForeground&&o.push(`.monaco-list${n} .monaco-list-row.selected { color: ${e.listInactiveSelectionForeground}; }`),e.listHoverBackground&&o.push(`.monaco-list${n}:not(.drop-target):not(.dragging) .monaco-list-row:hover:not(.selected):not(.focused) { background-color: ${e.listHoverBackground}; }`),e.listHoverForeground&&o.push(`.monaco-list${n}:not(.drop-target):not(.dragging) .monaco-list-row:hover:not(.selected):not(.focused) { color:  ${e.listHoverForeground}; }`);const r=gg(e.listFocusAndSelectionOutline,gg(e.listSelectionOutline,(t=e.listFocusOutline)!==null&&t!==void 0?t:""));r&&o.push(`.monaco-list${n}:focus .monaco-list-row.focused.selected { outline: 1px solid ${r}; outline-offset: -1px;}`),e.listFocusOutline&&o.push(`
				.monaco-drag-image,
				.monaco-list${n}:focus .monaco-list-row.focused { outline: 1px solid ${e.listFocusOutline}; outline-offset: -1px; }
				.monaco-workbench.context-menu-visible .monaco-list${n}.last-focused .monaco-list-row.focused { outline: 1px solid ${e.listFocusOutline}; outline-offset: -1px; }
			`);const a=gg(e.listSelectionOutline,(i=e.listInactiveFocusOutline)!==null&&i!==void 0?i:"");a&&o.push(`.monaco-list${n} .monaco-list-row.focused.selected { outline: 1px dotted ${a}; outline-offset: -1px; }`),e.listSelectionOutline&&o.push(`.monaco-list${n} .monaco-list-row.selected { outline: 1px dotted ${e.listSelectionOutline}; outline-offset: -1px; }`),e.listInactiveFocusOutline&&o.push(`.monaco-list${n} .monaco-list-row.focused { outline: 1px dotted ${e.listInactiveFocusOutline}; outline-offset: -1px; }`),e.listHoverOutline&&o.push(`.monaco-list${n} .monaco-list-row:hover { outline: 1px dashed ${e.listHoverOutline}; outline-offset: -1px; }`),e.listDropBackground&&o.push(`
				.monaco-list${n}.drop-target,
				.monaco-list${n} .monaco-list-rows.drop-target,
				.monaco-list${n} .monaco-list-row.drop-target { background-color: ${e.listDropBackground} !important; color: inherit !important; }
			`),e.tableColumnsBorder&&o.push(`
				.monaco-table > .monaco-split-view2,
				.monaco-table > .monaco-split-view2 .monaco-sash.vertical::before,
				.monaco-workbench:not(.reduce-motion) .monaco-table:hover > .monaco-split-view2,
				.monaco-workbench:not(.reduce-motion) .monaco-table:hover > .monaco-split-view2 .monaco-sash.vertical::before {
					border-color: ${e.tableColumnsBorder};
				}

				.monaco-workbench:not(.reduce-motion) .monaco-table > .monaco-split-view2,
				.monaco-workbench:not(.reduce-motion) .monaco-table > .monaco-split-view2 .monaco-sash.vertical::before {
					border-color: transparent;
				}
			`),e.tableOddRowsBackgroundColor&&o.push(`
				.monaco-table .monaco-list-row[data-parity=odd]:not(.focused):not(.selected):not(:hover) .monaco-table-tr,
				.monaco-table .monaco-list:not(:focus) .monaco-list-row[data-parity=odd].focused:not(.selected):not(:hover) .monaco-table-tr,
				.monaco-table .monaco-list:not(.focused) .monaco-list-row[data-parity=odd].focused:not(.selected):not(:hover) .monaco-table-tr {
					background-color: ${e.tableOddRowsBackgroundColor};
				}
			`),this.styleElement.textContent=o.join(`
`)}}const Sge={listFocusBackground:"#7FB0D0",listActiveSelectionBackground:"#0E639C",listActiveSelectionForeground:"#FFFFFF",listActiveSelectionIconForeground:"#FFFFFF",listFocusAndSelectionOutline:"#90C2F9",listFocusAndSelectionBackground:"#094771",listFocusAndSelectionForeground:"#FFFFFF",listInactiveSelectionBackground:"#3F3F46",listInactiveSelectionIconForeground:"#FFFFFF",listHoverBackground:"#2A2D2E",listDropBackground:"#383B3D",treeIndentGuidesStroke:"#a9a9a9",treeInactiveIndentGuidesStroke:G.fromHex("#a9a9a9").transparent(.4).toString(),tableColumnsBorder:G.fromHex("#cccccc").transparent(.2).toString(),tableOddRowsBackgroundColor:G.fromHex("#cccccc").transparent(.04).toString(),listBackground:void 0,listFocusForeground:void 0,listInactiveSelectionForeground:void 0,listInactiveFocusForeground:void 0,listInactiveFocusBackground:void 0,listHoverForeground:void 0,listFocusOutline:void 0,listInactiveFocusOutline:void 0,listSelectionOutline:void 0,listHoverOutline:void 0},yge={keyboardSupport:!0,mouseSupport:!0,multipleSelectionSupport:!0,dnd:{getDragURI(){return null},onDragStart(){},onDragOver(){return!1},drop(){},dispose(){}}};function Lge(s,e){const t=s.indexOf(e);if(t===-1)return[];const i=[];let n=t-1;for(;n>=0&&s[n]===e-(t-n);)i.push(s[n--]);for(i.reverse(),n=t;n<s.length&&s[n]===e+(n-t);)i.push(s[n++]);return i}function u2(s,e){const t=[];let i=0,n=0;for(;i<s.length||n<e.length;)if(i>=s.length)t.push(e[n++]);else if(n>=e.length)t.push(s[i++]);else if(s[i]===e[n]){t.push(s[i]),i++,n++;continue}else s[i]<e[n]?t.push(s[i++]):t.push(e[n++]);return t}function xge(s,e){const t=[];let i=0,n=0;for(;i<s.length||n<e.length;)if(i>=s.length)t.push(e[n++]);else if(n>=e.length)t.push(s[i++]);else if(s[i]===e[n]){i++,n++;continue}else s[i]<e[n]?t.push(s[i++]):n++;return t}const d9=(s,e)=>s-e;class Dge{constructor(e,t){this._templateId=e,this.renderers=t}get templateId(){return this._templateId}renderTemplate(e){return this.renderers.map(t=>t.renderTemplate(e))}renderElement(e,t,i,n){let o=0;for(const r of this.renderers)r.renderElement(e,t,i[o++],n)}disposeElement(e,t,i,n){var o;let r=0;for(const a of this.renderers)(o=a.disposeElement)===null||o===void 0||o.call(a,e,t,i[r],n),r+=1}disposeTemplate(e){let t=0;for(const i of this.renderers)i.disposeTemplate(e[t++])}}class kge{constructor(e){this.accessibilityProvider=e,this.templateId="a18n"}renderTemplate(e){return e}renderElement(e,t,i){const n=this.accessibilityProvider.getAriaLabel(e);n?i.setAttribute("aria-label",n):i.removeAttribute("aria-label");const o=this.accessibilityProvider.getAriaLevel&&this.accessibilityProvider.getAriaLevel(e);typeof o=="number"?i.setAttribute("aria-level",`${o}`):i.removeAttribute("aria-level")}disposeTemplate(e){}}class Ige{constructor(e,t){this.list=e,this.dnd=t}getDragElements(e){const t=this.list.getSelectedElements();return t.indexOf(e)>-1?t:[e]}getDragURI(e){return this.dnd.getDragURI(e)}getDragLabel(e,t){if(this.dnd.getDragLabel)return this.dnd.getDragLabel(e,t)}onDragStart(e,t){var i,n;(n=(i=this.dnd).onDragStart)===null||n===void 0||n.call(i,e,t)}onDragOver(e,t,i,n){return this.dnd.onDragOver(e,t,i,n)}onDragLeave(e,t,i,n){var o,r;(r=(o=this.dnd).onDragLeave)===null||r===void 0||r.call(o,e,t,i,n)}onDragEnd(e){var t,i;(i=(t=this.dnd).onDragEnd)===null||i===void 0||i.call(t,e)}drop(e,t,i,n){this.dnd.drop(e,t,i,n)}dispose(){this.dnd.dispose()}}class na{get onDidChangeFocus(){return ge.map(this.eventBufferer.wrapEvent(this.focus.onChange),e=>this.toListEvent(e),this.disposables)}get onDidChangeSelection(){return ge.map(this.eventBufferer.wrapEvent(this.selection.onChange),e=>this.toListEvent(e),this.disposables)}get domId(){return this.view.domId}get onDidScroll(){return this.view.onDidScroll}get onMouseClick(){return this.view.onMouseClick}get onMouseDblClick(){return this.view.onMouseDblClick}get onMouseMiddleClick(){return this.view.onMouseMiddleClick}get onPointer(){return this.mouseController.onPointer}get onMouseDown(){return this.view.onMouseDown}get onMouseOver(){return this.view.onMouseOver}get onMouseOut(){return this.view.onMouseOut}get onTouchStart(){return this.view.onTouchStart}get onTap(){return this.view.onTap}get onContextMenu(){let e=!1;const t=ge.chain(this.disposables.add(new gt(this.view.domNode,"keydown")).event,o=>o.map(r=>new ri(r)).filter(r=>e=r.keyCode===58||r.shiftKey&&r.keyCode===68).map(r=>ot.stop(r,!0)).filter(()=>!1)),i=ge.chain(this.disposables.add(new gt(this.view.domNode,"keyup")).event,o=>o.forEach(()=>e=!1).map(r=>new ri(r)).filter(r=>r.keyCode===58||r.shiftKey&&r.keyCode===68).map(r=>ot.stop(r,!0)).map(({browserEvent:r})=>{const a=this.getFocus(),l=a.length?a[0]:void 0,d=typeof l<"u"?this.view.element(l):void 0,c=typeof l<"u"?this.view.domElement(l):this.view.domNode;return{index:l,element:d,anchor:c,browserEvent:r}})),n=ge.chain(this.view.onContextMenu,o=>o.filter(r=>!e).map(({element:r,index:a,browserEvent:l})=>({element:r,index:a,anchor:new zr(Xe(this.view.domNode),l),browserEvent:l})));return ge.any(t,i,n)}get onKeyDown(){return this.disposables.add(new gt(this.view.domNode,"keydown")).event}get onDidFocus(){return ge.signal(this.disposables.add(new gt(this.view.domNode,"focus",!0)).event)}constructor(e,t,i,n,o=yge){var r,a,l,d;this.user=e,this._options=o,this.focus=new yy("focused"),this.anchor=new yy("anchor"),this.eventBufferer=new MA,this._ariaLabel="",this.disposables=new ie,this._onDidDispose=new W,this.onDidDispose=this._onDidDispose.event;const c=this._options.accessibilityProvider&&this._options.accessibilityProvider.getWidgetRole?(r=this._options.accessibilityProvider)===null||r===void 0?void 0:r.getWidgetRole():"list";this.selection=new fge(c!=="listbox");const u=[this.focus.renderer,this.selection.renderer];this.accessibilityProvider=o.accessibilityProvider,this.accessibilityProvider&&(u.push(new kge(this.accessibilityProvider)),(l=(a=this.accessibilityProvider).onDidChangeActiveDescendant)===null||l===void 0||l.call(a,this.onDidChangeActiveDescendant,this,this.disposables)),n=n.map(g=>new Dge(g.templateId,[...u,g]));const h={...o,dnd:o.dnd&&new Ige(this,o.dnd)};if(this.view=this.createListView(t,i,n,h),this.view.domNode.setAttribute("role",c),o.styleController)this.styleController=o.styleController(this.view.domId);else{const g=Lr(this.view.domNode);this.styleController=new Zz(g,this.view.domId)}if(this.spliceable=new sge([new WI(this.focus,this.view,o.identityProvider),new WI(this.selection,this.view,o.identityProvider),new WI(this.anchor,this.view,o.identityProvider),this.view]),this.disposables.add(this.focus),this.disposables.add(this.selection),this.disposables.add(this.anchor),this.disposables.add(this.view),this.disposables.add(this._onDidDispose),this.disposables.add(new Cge(this,this.view)),(typeof o.keyboardSupport!="boolean"||o.keyboardSupport)&&(this.keyboardController=new jz(this,this.view,o),this.disposables.add(this.keyboardController)),o.keyboardNavigationLabelProvider){const g=o.keyboardNavigationDelegate||vge;this.typeNavigationController=new bge(this,this.view,o.keyboardNavigationLabelProvider,(d=o.keyboardNavigationEventFilter)!==null&&d!==void 0?d:()=>!0,g),this.disposables.add(this.typeNavigationController)}this.mouseController=this.createMouseController(o),this.disposables.add(this.mouseController),this.onDidChangeFocus(this._onFocusChange,this,this.disposables),this.onDidChangeSelection(this._onSelectionChange,this,this.disposables),this.accessibilityProvider&&(this.ariaLabel=this.accessibilityProvider.getWidgetAriaLabel()),this._options.multipleSelectionSupport!==!1&&this.view.domNode.setAttribute("aria-multiselectable","true")}createListView(e,t,i,n){return new Tr(e,t,i,n)}createMouseController(e){return new Gz(this)}updateOptions(e={}){var t,i;this._options={...this._options,...e},(t=this.typeNavigationController)===null||t===void 0||t.updateOptions(this._options),this._options.multipleSelectionController!==void 0&&(this._options.multipleSelectionSupport?this.view.domNode.setAttribute("aria-multiselectable","true"):this.view.domNode.removeAttribute("aria-multiselectable")),this.mouseController.updateOptions(e),(i=this.keyboardController)===null||i===void 0||i.updateOptions(e),this.view.updateOptions(e)}get options(){return this._options}splice(e,t,i=[]){if(e<0||e>this.view.length)throw new Lh(this.user,`Invalid start index: ${e}`);if(t<0)throw new Lh(this.user,`Invalid delete count: ${t}`);t===0&&i.length===0||this.eventBufferer.bufferEvents(()=>this.spliceable.splice(e,t,i))}rerender(){this.view.rerender()}element(e){return this.view.element(e)}indexOf(e){return this.view.indexOf(e)}get length(){return this.view.length}get contentHeight(){return this.view.contentHeight}get onDidChangeContentHeight(){return this.view.onDidChangeContentHeight}get scrollTop(){return this.view.getScrollTop()}set scrollTop(e){this.view.setScrollTop(e)}get scrollHeight(){return this.view.scrollHeight}get renderHeight(){return this.view.renderHeight}get firstVisibleIndex(){return this.view.firstVisibleIndex}get ariaLabel(){return this._ariaLabel}set ariaLabel(e){this._ariaLabel=e,this.view.domNode.setAttribute("aria-label",e)}domFocus(){this.view.domNode.focus({preventScroll:!0})}layout(e,t){this.view.layout(e,t)}setSelection(e,t){for(const i of e)if(i<0||i>=this.length)throw new Lh(this.user,`Invalid index ${i}`);this.selection.set(e,t)}getSelection(){return this.selection.get()}getSelectedElements(){return this.getSelection().map(e=>this.view.element(e))}setAnchor(e){if(typeof e>"u"){this.anchor.set([]);return}if(e<0||e>=this.length)throw new Lh(this.user,`Invalid index ${e}`);this.anchor.set([e])}getAnchor(){return wA(this.anchor.get(),void 0)}getAnchorElement(){const e=this.getAnchor();return typeof e>"u"?void 0:this.element(e)}setFocus(e,t){for(const i of e)if(i<0||i>=this.length)throw new Lh(this.user,`Invalid index ${i}`);this.focus.set(e,t)}focusNext(e=1,t=!1,i,n){if(this.length===0)return;const o=this.focus.get(),r=this.findNextIndex(o.length>0?o[0]+e:0,t,n);r>-1&&this.setFocus([r],i)}focusPrevious(e=1,t=!1,i,n){if(this.length===0)return;const o=this.focus.get(),r=this.findPreviousIndex(o.length>0?o[0]-e:0,t,n);r>-1&&this.setFocus([r],i)}async focusNextPage(e,t){let i=this.view.indexAt(this.view.getScrollTop()+this.view.renderHeight);i=i===0?0:i-1;const n=this.getFocus()[0];if(n!==i&&(n===void 0||i>n)){const o=this.findPreviousIndex(i,!1,t);o>-1&&n!==o?this.setFocus([o],e):this.setFocus([i],e)}else{const o=this.view.getScrollTop();let r=o+this.view.renderHeight;i>n&&(r-=this.view.elementHeight(i)),this.view.setScrollTop(r),this.view.getScrollTop()!==o&&(this.setFocus([]),await Iu(0),await this.focusNextPage(e,t))}}async focusPreviousPage(e,t){let i;const n=this.view.getScrollTop();n===0?i=this.view.indexAt(n):i=this.view.indexAfter(n-1);const o=this.getFocus()[0];if(o!==i&&(o===void 0||o>=i)){const r=this.findNextIndex(i,!1,t);r>-1&&o!==r?this.setFocus([r],e):this.setFocus([i],e)}else{const r=n;this.view.setScrollTop(n-this.view.renderHeight),this.view.getScrollTop()!==r&&(this.setFocus([]),await Iu(0),await this.focusPreviousPage(e,t))}}focusLast(e,t){if(this.length===0)return;const i=this.findPreviousIndex(this.length-1,!1,t);i>-1&&this.setFocus([i],e)}focusFirst(e,t){this.focusNth(0,e,t)}focusNth(e,t,i){if(this.length===0)return;const n=this.findNextIndex(e,!1,i);n>-1&&this.setFocus([n],t)}findNextIndex(e,t=!1,i){for(let n=0;n<this.length;n++){if(e>=this.length&&!t)return-1;if(e=e%this.length,!i||i(this.element(e)))return e;e++}return-1}findPreviousIndex(e,t=!1,i){for(let n=0;n<this.length;n++){if(e<0&&!t)return-1;if(e=(this.length+e%this.length)%this.length,!i||i(this.element(e)))return e;e--}return-1}getFocus(){return this.focus.get()}getFocusedElements(){return this.getFocus().map(e=>this.view.element(e))}reveal(e,t,i=0){if(e<0||e>=this.length)throw new Lh(this.user,`Invalid index ${e}`);const n=this.view.getScrollTop(),o=this.view.elementTop(e),r=this.view.elementHeight(e);if(xu(t)){const a=r-this.view.renderHeight+i;this.view.setScrollTop(a*co(t,0,1)+o-i)}else{const a=o+r,l=n+this.view.renderHeight;o<n+i&&a>=l||(o<n+i||a>=l&&r>=this.view.renderHeight?this.view.setScrollTop(o-i):a>=l&&this.view.setScrollTop(a-this.view.renderHeight))}}getRelativeTop(e,t=0){if(e<0||e>=this.length)throw new Lh(this.user,`Invalid index ${e}`);const i=this.view.getScrollTop(),n=this.view.elementTop(e),o=this.view.elementHeight(e);if(n<i+t||n+o>i+this.view.renderHeight)return null;const r=o-this.view.renderHeight+t;return Math.abs((i+t-n)/r)}getHTMLElement(){return this.view.domNode}getScrollableElement(){return this.view.scrollableElementDomNode}getElementID(e){return this.view.getElementDomId(e)}getElementTop(e){return this.view.elementTop(e)}style(e){this.styleController.style(e)}toListEvent({indexes:e,browserEvent:t}){return{indexes:e,elements:e.map(i=>this.view.element(i)),browserEvent:t}}_onFocusChange(){const e=this.focus.get();this.view.domNode.classList.toggle("element-focused",e.length>0),this.onDidChangeActiveDescendant()}onDidChangeActiveDescendant(){var e;const t=this.focus.get();if(t.length>0){let i;!((e=this.accessibilityProvider)===null||e===void 0)&&e.getActiveDescendantId&&(i=this.accessibilityProvider.getActiveDescendantId(this.view.element(t[0]))),this.view.domNode.setAttribute("aria-activedescendant",i||this.view.getElementDomId(t[0]))}else this.view.domNode.removeAttribute("aria-activedescendant")}_onSelectionChange(){const e=this.selection.get();this.view.domNode.classList.toggle("selection-none",e.length===0),this.view.domNode.classList.toggle("selection-single",e.length===1),this.view.domNode.classList.toggle("selection-multiple",e.length>1)}dispose(){this._onDidDispose.fire(),this.disposables.dispose(),this._onDidDispose.dispose()}}hf([Xi],na.prototype,"onDidChangeFocus",null);hf([Xi],na.prototype,"onDidChangeSelection",null);hf([Xi],na.prototype,"onContextMenu",null);hf([Xi],na.prototype,"onKeyDown",null);hf([Xi],na.prototype,"onDidFocus",null);const sg=se,Yz="selectOption.entry.template";class Ege{get templateId(){return Yz}renderTemplate(e){const t=Object.create(null);return t.root=e,t.text=te(e,sg(".option-text")),t.detail=te(e,sg(".option-detail")),t.decoratorRight=te(e,sg(".option-decorator-right")),t}renderElement(e,t,i){const n=i,o=e.text,r=e.detail,a=e.decoratorRight,l=e.isDisabled;n.text.textContent=o,n.detail.textContent=r||"",n.decoratorRight.innerText=a||"",l?n.root.classList.add("option-disabled"):n.root.classList.remove("option-disabled")}disposeTemplate(e){}}class yl extends j{constructor(e,t,i,n,o){super(),this.options=[],this._currentSelection=0,this._hasDetails=!1,this._skipLayout=!1,this._sticky=!1,this._isVisible=!1,this.styles=n,this.selectBoxOptions=o||Object.create(null),typeof this.selectBoxOptions.minBottomMargin!="number"?this.selectBoxOptions.minBottomMargin=yl.DEFAULT_DROPDOWN_MINIMUM_BOTTOM_MARGIN:this.selectBoxOptions.minBottomMargin<0&&(this.selectBoxOptions.minBottomMargin=0),this.selectElement=document.createElement("select"),this.selectElement.className="monaco-select-box monaco-select-box-dropdown-padding",typeof this.selectBoxOptions.ariaLabel=="string"&&this.selectElement.setAttribute("aria-label",this.selectBoxOptions.ariaLabel),typeof this.selectBoxOptions.ariaDescription=="string"&&this.selectElement.setAttribute("aria-description",this.selectBoxOptions.ariaDescription),this._onDidSelect=new W,this._register(this._onDidSelect),this.registerListeners(),this.constructSelectDropDown(i),this.selected=t||0,e&&this.setOptions(e,t),this.initStyleSheet()}getHeight(){return 22}getTemplateId(){return Yz}constructSelectDropDown(e){this.contextViewProvider=e,this.selectDropDownContainer=se(".monaco-select-box-dropdown-container"),this.selectDropDownContainer.classList.add("monaco-select-box-dropdown-padding"),this.selectionDetailsPane=te(this.selectDropDownContainer,sg(".select-box-details-pane"));const t=te(this.selectDropDownContainer,sg(".select-box-dropdown-container-width-control")),i=te(t,sg(".width-control-div"));this.widthControlElement=document.createElement("span"),this.widthControlElement.className="option-text-width-control",te(i,this.widthControlElement),this._dropDownPosition=0,this.styleElement=Lr(this.selectDropDownContainer),this.selectDropDownContainer.setAttribute("draggable","true"),this._register(Y(this.selectDropDownContainer,he.DRAG_START,n=>{ot.stop(n,!0)}))}registerListeners(){this._register(Pi(this.selectElement,"change",t=>{this.selected=t.target.selectedIndex,this._onDidSelect.fire({index:t.target.selectedIndex,selected:t.target.value}),this.options[this.selected]&&this.options[this.selected].text&&(this.selectElement.title=this.options[this.selected].text)})),this._register(Y(this.selectElement,he.CLICK,t=>{ot.stop(t),this._isVisible?this.hideSelectDropDown(!0):this.showSelectDropDown()})),this._register(Y(this.selectElement,he.MOUSE_DOWN,t=>{ot.stop(t)}));let e;this._register(Y(this.selectElement,"touchstart",t=>{e=this._isVisible})),this._register(Y(this.selectElement,"touchend",t=>{ot.stop(t),e?this.hideSelectDropDown(!0):this.showSelectDropDown()})),this._register(Y(this.selectElement,he.KEY_DOWN,t=>{const i=new ri(t);let n=!1;bt?(i.keyCode===18||i.keyCode===16||i.keyCode===10||i.keyCode===3)&&(n=!0):(i.keyCode===18&&i.altKey||i.keyCode===16&&i.altKey||i.keyCode===10||i.keyCode===3)&&(n=!0),n&&(this.showSelectDropDown(),ot.stop(t,!0))}))}get onDidSelect(){return this._onDidSelect.event}setOptions(e,t){Ai(this.options,e)||(this.options=e,this.selectElement.options.length=0,this._hasDetails=!1,this._cachedMaxDetailsHeight=void 0,this.options.forEach((i,n)=>{this.selectElement.add(this.createOption(i.text,n,i.isDisabled)),typeof i.description=="string"&&(this._hasDetails=!0)})),t!==void 0&&(this.select(t),this._currentSelection=this.selected)}setOptionsList(){var e;(e=this.selectList)===null||e===void 0||e.splice(0,this.selectList.length,this.options)}select(e){e>=0&&e<this.options.length?this.selected=e:e>this.options.length-1?this.select(this.options.length-1):this.selected<0&&(this.selected=0),this.selectElement.selectedIndex=this.selected,this.options[this.selected]&&this.options[this.selected].text&&(this.selectElement.title=this.options[this.selected].text)}focus(){this.selectElement&&(this.selectElement.tabIndex=0,this.selectElement.focus())}blur(){this.selectElement&&(this.selectElement.tabIndex=-1,this.selectElement.blur())}setFocusable(e){this.selectElement.tabIndex=e?0:-1}render(e){this.container=e,e.classList.add("select-container"),e.appendChild(this.selectElement),this.styleSelectElement()}initStyleSheet(){const e=[];this.styles.listFocusBackground&&e.push(`.monaco-select-box-dropdown-container > .select-box-dropdown-list-container .monaco-list .monaco-list-row.focused { background-color: ${this.styles.listFocusBackground} !important; }`),this.styles.listFocusForeground&&e.push(`.monaco-select-box-dropdown-container > .select-box-dropdown-list-container .monaco-list .monaco-list-row.focused { color: ${this.styles.listFocusForeground} !important; }`),this.styles.decoratorRightForeground&&e.push(`.monaco-select-box-dropdown-container > .select-box-dropdown-list-container .monaco-list .monaco-list-row:not(.focused) .option-decorator-right { color: ${this.styles.decoratorRightForeground}; }`),this.styles.selectBackground&&this.styles.selectBorder&&this.styles.selectBorder!==this.styles.selectBackground?(e.push(`.monaco-select-box-dropdown-container { border: 1px solid ${this.styles.selectBorder} } `),e.push(`.monaco-select-box-dropdown-container > .select-box-details-pane.border-top { border-top: 1px solid ${this.styles.selectBorder} } `),e.push(`.monaco-select-box-dropdown-container > .select-box-details-pane.border-bottom { border-bottom: 1px solid ${this.styles.selectBorder} } `)):this.styles.selectListBorder&&(e.push(`.monaco-select-box-dropdown-container > .select-box-details-pane.border-top { border-top: 1px solid ${this.styles.selectListBorder} } `),e.push(`.monaco-select-box-dropdown-container > .select-box-details-pane.border-bottom { border-bottom: 1px solid ${this.styles.selectListBorder} } `)),this.styles.listHoverForeground&&e.push(`.monaco-select-box-dropdown-container > .select-box-dropdown-list-container .monaco-list .monaco-list-row:not(.option-disabled):not(.focused):hover { color: ${this.styles.listHoverForeground} !important; }`),this.styles.listHoverBackground&&e.push(`.monaco-select-box-dropdown-container > .select-box-dropdown-list-container .monaco-list .monaco-list-row:not(.option-disabled):not(.focused):hover { background-color: ${this.styles.listHoverBackground} !important; }`),this.styles.listFocusOutline&&e.push(`.monaco-select-box-dropdown-container > .select-box-dropdown-list-container .monaco-list .monaco-list-row.focused { outline: 1.6px dotted ${this.styles.listFocusOutline} !important; outline-offset: -1.6px !important; }`),this.styles.listHoverOutline&&e.push(`.monaco-select-box-dropdown-container > .select-box-dropdown-list-container .monaco-list .monaco-list-row:not(.option-disabled):not(.focused):hover { outline: 1.6px dashed ${this.styles.listHoverOutline} !important; outline-offset: -1.6px !important; }`),e.push(".monaco-select-box-dropdown-container > .select-box-dropdown-list-container .monaco-list .monaco-list-row.option-disabled.focused { background-color: transparent !important; color: inherit !important; outline: none !important; }"),e.push(".monaco-select-box-dropdown-container > .select-box-dropdown-list-container .monaco-list .monaco-list-row.option-disabled:hover { background-color: transparent !important; color: inherit !important; outline: none !important; }"),this.styleElement.textContent=e.join(`
`)}styleSelectElement(){var e,t,i;const n=(e=this.styles.selectBackground)!==null&&e!==void 0?e:"",o=(t=this.styles.selectForeground)!==null&&t!==void 0?t:"",r=(i=this.styles.selectBorder)!==null&&i!==void 0?i:"";this.selectElement.style.backgroundColor=n,this.selectElement.style.color=o,this.selectElement.style.borderColor=r}styleList(){var e,t;const i=(e=this.styles.selectBackground)!==null&&e!==void 0?e:"",n=gg(this.styles.selectListBackground,i);this.selectDropDownListContainer.style.backgroundColor=n,this.selectionDetailsPane.style.backgroundColor=n;const o=(t=this.styles.focusBorder)!==null&&t!==void 0?t:"";this.selectDropDownContainer.style.outlineColor=o,this.selectDropDownContainer.style.outlineOffset="-1px",this.selectList.style(this.styles)}createOption(e,t,i){const n=document.createElement("option");return n.value=e,n.text=e,n.disabled=!!i,n}showSelectDropDown(){this.selectionDetailsPane.innerText="",!(!this.contextViewProvider||this._isVisible)&&(this.createSelectList(this.selectDropDownContainer),this.setOptionsList(),this.contextViewProvider.showContextView({getAnchor:()=>this.selectElement,render:e=>this.renderSelectDropDown(e,!0),layout:()=>{this.layoutSelectDropDown()},onHide:()=>{this.selectDropDownContainer.classList.remove("visible"),this.selectElement.classList.remove("synthetic-focus")},anchorPosition:this._dropDownPosition},this.selectBoxOptions.optionsAsChildren?this.container:void 0),this._isVisible=!0,this.hideSelectDropDown(!1),this.contextViewProvider.showContextView({getAnchor:()=>this.selectElement,render:e=>this.renderSelectDropDown(e),layout:()=>this.layoutSelectDropDown(),onHide:()=>{this.selectDropDownContainer.classList.remove("visible"),this.selectElement.classList.remove("synthetic-focus")},anchorPosition:this._dropDownPosition},this.selectBoxOptions.optionsAsChildren?this.container:void 0),this._currentSelection=this.selected,this._isVisible=!0,this.selectElement.setAttribute("aria-expanded","true"))}hideSelectDropDown(e){!this.contextViewProvider||!this._isVisible||(this._isVisible=!1,this.selectElement.setAttribute("aria-expanded","false"),e&&this.selectElement.focus(),this.contextViewProvider.hideContextView())}renderSelectDropDown(e,t){return e.appendChild(this.selectDropDownContainer),this.layoutSelectDropDown(t),{dispose:()=>{try{e.removeChild(this.selectDropDownContainer)}catch{}}}}measureMaxDetailsHeight(){let e=0;return this.options.forEach((t,i)=>{this.updateDetail(i),this.selectionDetailsPane.offsetHeight>e&&(e=this.selectionDetailsPane.offsetHeight)}),e}layoutSelectDropDown(e){if(this._skipLayout)return!1;if(this.selectList){this.selectDropDownContainer.classList.add("visible");const t=Xe(this.selectElement),i=ln(this.selectElement),n=Xe(this.selectElement).getComputedStyle(this.selectElement),o=parseFloat(n.getPropertyValue("--dropdown-padding-top"))+parseFloat(n.getPropertyValue("--dropdown-padding-bottom")),r=t.innerHeight-i.top-i.height-(this.selectBoxOptions.minBottomMargin||0),a=i.top-yl.DEFAULT_DROPDOWN_MINIMUM_TOP_MARGIN,l=this.selectElement.offsetWidth,d=this.setWidthControlElement(this.widthControlElement),c=Math.max(d,Math.round(l)).toString()+"px";this.selectDropDownContainer.style.width=c,this.selectList.getHTMLElement().style.height="",this.selectList.layout();let u=this.selectList.contentHeight;this._hasDetails&&this._cachedMaxDetailsHeight===void 0&&(this._cachedMaxDetailsHeight=this.measureMaxDetailsHeight());const h=this._hasDetails?this._cachedMaxDetailsHeight:0,g=u+o+h,f=Math.floor((r-o-h)/this.getHeight()),m=Math.floor((a-o-h)/this.getHeight());if(e)return i.top+i.height>t.innerHeight-22||i.top<yl.DEFAULT_DROPDOWN_MINIMUM_TOP_MARGIN||f<1&&m<1?!1:(f<yl.DEFAULT_MINIMUM_VISIBLE_OPTIONS&&m>f&&this.options.length>f?(this._dropDownPosition=1,this.selectDropDownContainer.removeChild(this.selectDropDownListContainer),this.selectDropDownContainer.removeChild(this.selectionDetailsPane),this.selectDropDownContainer.appendChild(this.selectionDetailsPane),this.selectDropDownContainer.appendChild(this.selectDropDownListContainer),this.selectionDetailsPane.classList.remove("border-top"),this.selectionDetailsPane.classList.add("border-bottom")):(this._dropDownPosition=0,this.selectDropDownContainer.removeChild(this.selectDropDownListContainer),this.selectDropDownContainer.removeChild(this.selectionDetailsPane),this.selectDropDownContainer.appendChild(this.selectDropDownListContainer),this.selectDropDownContainer.appendChild(this.selectionDetailsPane),this.selectionDetailsPane.classList.remove("border-bottom"),this.selectionDetailsPane.classList.add("border-top")),!0);if(i.top+i.height>t.innerHeight-22||i.top<yl.DEFAULT_DROPDOWN_MINIMUM_TOP_MARGIN||this._dropDownPosition===0&&f<1||this._dropDownPosition===1&&m<1)return this.hideSelectDropDown(!0),!1;if(this._dropDownPosition===0){if(this._isVisible&&f+m<1)return this.hideSelectDropDown(!0),!1;g>r&&(u=f*this.getHeight())}else g>a&&(u=m*this.getHeight());return this.selectList.layout(u),this.selectList.domFocus(),this.selectList.length>0&&(this.selectList.setFocus([this.selected||0]),this.selectList.reveal(this.selectList.getFocus()[0]||0)),this._hasDetails?(this.selectList.getHTMLElement().style.height=u+o+"px",this.selectDropDownContainer.style.height=""):this.selectDropDownContainer.style.height=u+o+"px",this.updateDetail(this.selected),this.selectDropDownContainer.style.width=c,this.selectDropDownListContainer.setAttribute("tabindex","0"),this.selectElement.classList.add("synthetic-focus"),this.selectDropDownContainer.classList.add("synthetic-focus"),!0}else return!1}setWidthControlElement(e){let t=0;if(e){let i=0,n=0;this.options.forEach((o,r)=>{const a=o.detail?o.detail.length:0,l=o.decoratorRight?o.decoratorRight.length:0,d=o.text.length+a+l;d>n&&(i=r,n=d)}),e.textContent=this.options[i].text+(this.options[i].decoratorRight?this.options[i].decoratorRight+" ":""),t=js(e)}return t}createSelectList(e){if(this.selectList)return;this.selectDropDownListContainer=te(e,sg(".select-box-dropdown-list-container")),this.listRenderer=new Ege,this.selectList=new na("SelectBoxCustom",this.selectDropDownListContainer,this,[this.listRenderer],{useShadows:!1,verticalScrollMode:3,keyboardSupport:!1,mouseSupport:!1,accessibilityProvider:{getAriaLabel:n=>{let o=n.text;return n.detail&&(o+=`. ${n.detail}`),n.decoratorRight&&(o+=`. ${n.decoratorRight}`),n.description&&(o+=`. ${n.description}`),o},getWidgetAriaLabel:()=>p({key:"selectBox",comment:["Behave like native select dropdown element."]},"Select Box"),getRole:()=>bt?"":"option",getWidgetRole:()=>"listbox"}}),this.selectBoxOptions.ariaLabel&&(this.selectList.ariaLabel=this.selectBoxOptions.ariaLabel);const t=this._register(new gt(this.selectDropDownListContainer,"keydown")),i=ge.chain(t.event,n=>n.filter(()=>this.selectList.length>0).map(o=>new ri(o)));this._register(ge.chain(i,n=>n.filter(o=>o.keyCode===3))(this.onEnter,this)),this._register(ge.chain(i,n=>n.filter(o=>o.keyCode===2))(this.onEnter,this)),this._register(ge.chain(i,n=>n.filter(o=>o.keyCode===9))(this.onEscape,this)),this._register(ge.chain(i,n=>n.filter(o=>o.keyCode===16))(this.onUpArrow,this)),this._register(ge.chain(i,n=>n.filter(o=>o.keyCode===18))(this.onDownArrow,this)),this._register(ge.chain(i,n=>n.filter(o=>o.keyCode===12))(this.onPageDown,this)),this._register(ge.chain(i,n=>n.filter(o=>o.keyCode===11))(this.onPageUp,this)),this._register(ge.chain(i,n=>n.filter(o=>o.keyCode===14))(this.onHome,this)),this._register(ge.chain(i,n=>n.filter(o=>o.keyCode===13))(this.onEnd,this)),this._register(ge.chain(i,n=>n.filter(o=>o.keyCode>=21&&o.keyCode<=56||o.keyCode>=85&&o.keyCode<=113))(this.onCharacter,this)),this._register(Y(this.selectList.getHTMLElement(),he.POINTER_UP,n=>this.onPointerUp(n))),this._register(this.selectList.onMouseOver(n=>typeof n.index<"u"&&this.selectList.setFocus([n.index]))),this._register(this.selectList.onDidChangeFocus(n=>this.onListFocus(n))),this._register(Y(this.selectDropDownContainer,he.FOCUS_OUT,n=>{!this._isVisible||Yn(n.relatedTarget,this.selectDropDownContainer)||this.onListBlur()})),this.selectList.getHTMLElement().setAttribute("aria-label",this.selectBoxOptions.ariaLabel||""),this.selectList.getHTMLElement().setAttribute("aria-expanded","true"),this.styleList()}onPointerUp(e){if(!this.selectList.length)return;ot.stop(e);const t=e.target;if(!t||t.classList.contains("slider"))return;const i=t.closest(".monaco-list-row");if(!i)return;const n=Number(i.getAttribute("data-index")),o=i.classList.contains("option-disabled");n>=0&&n<this.options.length&&!o&&(this.selected=n,this.select(this.selected),this.selectList.setFocus([this.selected]),this.selectList.reveal(this.selectList.getFocus()[0]),this.selected!==this._currentSelection&&(this._currentSelection=this.selected,this._onDidSelect.fire({index:this.selectElement.selectedIndex,selected:this.options[this.selected].text}),this.options[this.selected]&&this.options[this.selected].text&&(this.selectElement.title=this.options[this.selected].text)),this.hideSelectDropDown(!0))}onListBlur(){this._sticky||(this.selected!==this._currentSelection&&this.select(this._currentSelection),this.hideSelectDropDown(!1))}renderDescriptionMarkdown(e,t){const i=o=>{for(let r=0;r<o.childNodes.length;r++){const a=o.childNodes.item(r);(a.tagName&&a.tagName.toLowerCase())==="img"?o.removeChild(a):i(a)}},n=Vx({value:e,supportThemeIcons:!0},{actionHandler:t});return n.element.classList.add("select-box-description-markdown"),i(n.element),n.element}onListFocus(e){!this._isVisible||!this._hasDetails||this.updateDetail(e.indexes[0])}updateDetail(e){var t,i;this.selectionDetailsPane.innerText="";const n=this.options[e],o=(t=n==null?void 0:n.description)!==null&&t!==void 0?t:"",r=(i=n==null?void 0:n.descriptionIsMarkdown)!==null&&i!==void 0?i:!1;if(o){if(r){const a=n.descriptionMarkdownActionHandler;this.selectionDetailsPane.appendChild(this.renderDescriptionMarkdown(o,a))}else this.selectionDetailsPane.innerText=o;this.selectionDetailsPane.style.display="block"}else this.selectionDetailsPane.style.display="none";this._skipLayout=!0,this.contextViewProvider.layout(),this._skipLayout=!1}onEscape(e){ot.stop(e),this.select(this._currentSelection),this.hideSelectDropDown(!0)}onEnter(e){ot.stop(e),this.selected!==this._currentSelection&&(this._currentSelection=this.selected,this._onDidSelect.fire({index:this.selectElement.selectedIndex,selected:this.options[this.selected].text}),this.options[this.selected]&&this.options[this.selected].text&&(this.selectElement.title=this.options[this.selected].text)),this.hideSelectDropDown(!0)}onDownArrow(e){if(this.selected<this.options.length-1){ot.stop(e,!0);const t=this.options[this.selected+1].isDisabled;if(t&&this.options.length>this.selected+2)this.selected+=2;else{if(t)return;this.selected++}this.select(this.selected),this.selectList.setFocus([this.selected]),this.selectList.reveal(this.selectList.getFocus()[0])}}onUpArrow(e){this.selected>0&&(ot.stop(e,!0),this.options[this.selected-1].isDisabled&&this.selected>1?this.selected-=2:this.selected--,this.select(this.selected),this.selectList.setFocus([this.selected]),this.selectList.reveal(this.selectList.getFocus()[0]))}onPageUp(e){ot.stop(e),this.selectList.focusPreviousPage(),setTimeout(()=>{this.selected=this.selectList.getFocus()[0],this.options[this.selected].isDisabled&&this.selected<this.options.length-1&&(this.selected++,this.selectList.setFocus([this.selected])),this.selectList.reveal(this.selected),this.select(this.selected)},1)}onPageDown(e){ot.stop(e),this.selectList.focusNextPage(),setTimeout(()=>{this.selected=this.selectList.getFocus()[0],this.options[this.selected].isDisabled&&this.selected>0&&(this.selected--,this.selectList.setFocus([this.selected])),this.selectList.reveal(this.selected),this.select(this.selected)},1)}onHome(e){ot.stop(e),!(this.options.length<2)&&(this.selected=0,this.options[this.selected].isDisabled&&this.selected>1&&this.selected++,this.selectList.setFocus([this.selected]),this.selectList.reveal(this.selected),this.select(this.selected))}onEnd(e){ot.stop(e),!(this.options.length<2)&&(this.selected=this.options.length-1,this.options[this.selected].isDisabled&&this.selected>1&&this.selected--,this.selectList.setFocus([this.selected]),this.selectList.reveal(this.selected),this.select(this.selected))}onCharacter(e){const t=Id.toString(e.keyCode);let i=-1;for(let n=0;n<this.options.length-1;n++)if(i=(n+this.selected+1)%this.options.length,this.options[i].text.charAt(0).toUpperCase()===t&&!this.options[i].isDisabled){this.select(i),this.selectList.setFocus([i]),this.selectList.reveal(this.selectList.getFocus()[0]),ot.stop(e);break}}dispose(){this.hideSelectDropDown(!1),super.dispose()}}yl.DEFAULT_DROPDOWN_MINIMUM_BOTTOM_MARGIN=32;yl.DEFAULT_DROPDOWN_MINIMUM_TOP_MARGIN=2;yl.DEFAULT_MINIMUM_VISIBLE_OPTIONS=3;class Nge extends j{constructor(e,t,i,n){super(),this.selected=0,this.selectBoxOptions=n||Object.create(null),this.options=[],this.selectElement=document.createElement("select"),this.selectElement.className="monaco-select-box",typeof this.selectBoxOptions.ariaLabel=="string"&&this.selectElement.setAttribute("aria-label",this.selectBoxOptions.ariaLabel),typeof this.selectBoxOptions.ariaDescription=="string"&&this.selectElement.setAttribute("aria-description",this.selectBoxOptions.ariaDescription),this._onDidSelect=this._register(new W),this.styles=i,this.registerListeners(),this.setOptions(e,t)}registerListeners(){this._register(Xt.addTarget(this.selectElement)),[Qt.Tap].forEach(e=>{this._register(Y(this.selectElement,e,t=>{this.selectElement.focus()}))}),this._register(Pi(this.selectElement,"click",e=>{ot.stop(e,!0)})),this._register(Pi(this.selectElement,"change",e=>{this.selectElement.title=e.target.value,this._onDidSelect.fire({index:e.target.selectedIndex,selected:e.target.value})})),this._register(Pi(this.selectElement,"keydown",e=>{let t=!1;bt?(e.keyCode===18||e.keyCode===16||e.keyCode===10)&&(t=!0):(e.keyCode===18&&e.altKey||e.keyCode===10||e.keyCode===3)&&(t=!0),t&&e.stopPropagation()}))}get onDidSelect(){return this._onDidSelect.event}setOptions(e,t){(!this.options||!Ai(this.options,e))&&(this.options=e,this.selectElement.options.length=0,this.options.forEach((i,n)=>{this.selectElement.add(this.createOption(i.text,n,i.isDisabled))})),t!==void 0&&this.select(t)}select(e){this.options.length===0?this.selected=0:e>=0&&e<this.options.length?this.selected=e:e>this.options.length-1?this.select(this.options.length-1):this.selected<0&&(this.selected=0),this.selectElement.selectedIndex=this.selected,this.selected<this.options.length&&typeof this.options[this.selected].text=="string"?this.selectElement.title=this.options[this.selected].text:this.selectElement.title=""}focus(){this.selectElement&&(this.selectElement.tabIndex=0,this.selectElement.focus())}blur(){this.selectElement&&(this.selectElement.tabIndex=-1,this.selectElement.blur())}setFocusable(e){this.selectElement.tabIndex=e?0:-1}render(e){e.classList.add("select-container"),e.appendChild(this.selectElement),this.setOptions(this.options,this.selected),this.applyStyles()}applyStyles(){var e,t,i;this.selectElement&&(this.selectElement.style.backgroundColor=(e=this.styles.selectBackground)!==null&&e!==void 0?e:"",this.selectElement.style.color=(t=this.styles.selectForeground)!==null&&t!==void 0?t:"",this.selectElement.style.borderColor=(i=this.styles.selectBorder)!==null&&i!==void 0?i:"")}createOption(e,t,i){const n=document.createElement("option");return n.value=e,n.text=e,n.disabled=!!i,n}}class Tge extends ta{constructor(e,t,i,n,o){super(),bt&&!(o!=null&&o.useCustomDrawn)?this.selectBoxDelegate=new Nge(e,t,n,o):this.selectBoxDelegate=new yl(e,t,i,n,o),this._register(this.selectBoxDelegate)}get onDidSelect(){return this.selectBoxDelegate.onDidSelect}setOptions(e,t){this.selectBoxDelegate.setOptions(e,t)}select(e){this.selectBoxDelegate.select(e)}focus(){this.selectBoxDelegate.focus()}blur(){this.selectBoxDelegate.blur()}setFocusable(e){this.selectBoxDelegate.setFocusable(e)}render(e){this.selectBoxDelegate.render(e)}}class wa extends j{get action(){return this._action}constructor(e,t,i={}){super(),this.options=i,this._context=e||this,this._action=t,t instanceof Os&&this._register(t.onDidChange(n=>{this.element&&this.handleActionChangeEvent(n)}))}handleActionChangeEvent(e){e.enabled!==void 0&&this.updateEnabled(),e.checked!==void 0&&this.updateChecked(),e.class!==void 0&&this.updateClass(),e.label!==void 0&&(this.updateLabel(),this.updateTooltip()),e.tooltip!==void 0&&this.updateTooltip()}get actionRunner(){return this._actionRunner||(this._actionRunner=this._register(new Eg)),this._actionRunner}set actionRunner(e){this._actionRunner=e}isEnabled(){return this._action.enabled}setActionContext(e){this._context=e}render(e){const t=this.element=e;this._register(Xt.addTarget(e));const i=this.options&&this.options.draggable;i&&(e.draggable=!0,yr&&this._register(Y(e,he.DRAG_START,n=>{var o;return(o=n.dataTransfer)===null||o===void 0?void 0:o.setData(ab.TEXT,this._action.label)}))),this._register(Y(t,Qt.Tap,n=>this.onClick(n,!0))),this._register(Y(t,he.MOUSE_DOWN,n=>{i||ot.stop(n,!0),this._action.enabled&&n.button===0&&t.classList.add("active")})),bt&&this._register(Y(t,he.CONTEXT_MENU,n=>{n.button===0&&n.ctrlKey===!0&&this.onClick(n)})),this._register(Y(t,he.CLICK,n=>{ot.stop(n,!0),this.options&&this.options.isMenu||this.onClick(n)})),this._register(Y(t,he.DBLCLICK,n=>{ot.stop(n,!0)})),[he.MOUSE_UP,he.MOUSE_OUT].forEach(n=>{this._register(Y(t,n,o=>{ot.stop(o),t.classList.remove("active")}))})}onClick(e,t=!1){var i;ot.stop(e,!0);const n=Uo(this._context)?!((i=this.options)===null||i===void 0)&&i.useEventAsContext?e:{preserveFocus:t}:this._context;this.actionRunner.run(this._action,n)}focus(){this.element&&(this.element.tabIndex=0,this.element.focus(),this.element.classList.add("focused"))}blur(){this.element&&(this.element.blur(),this.element.tabIndex=-1,this.element.classList.remove("focused"))}setFocusable(e){this.element&&(this.element.tabIndex=e?0:-1)}get trapsArrowNavigation(){return!1}updateEnabled(){}updateLabel(){}getClass(){return this.action.class}getTooltip(){return this.action.tooltip}updateTooltip(){var e;if(!this.element)return;const t=(e=this.getTooltip())!==null&&e!==void 0?e:"";this.updateAriaLabel(),this.options.hoverDelegate?(this.element.title="",this.customHover?this.customHover.update(t):(this.customHover=zz(this.options.hoverDelegate,this.element,t),this._store.add(this.customHover))):this.element.title=t}updateAriaLabel(){var e;if(this.element){const t=(e=this.getTooltip())!==null&&e!==void 0?e:"";this.element.setAttribute("aria-label",t)}}updateClass(){}updateChecked(){}dispose(){this.element&&(this.element.remove(),this.element=void 0),this._context=void 0,super.dispose()}}class Em extends wa{constructor(e,t,i){super(e,t,i),this.options=i,this.options.icon=i.icon!==void 0?i.icon:!1,this.options.label=i.label!==void 0?i.label:!0,this.cssClass=""}render(e){super.render(e),zt(this.element);const t=document.createElement("a");if(t.classList.add("action-label"),t.setAttribute("role",this.getDefaultAriaRole()),this.label=t,this.element.appendChild(t),this.options.label&&this.options.keybinding){const i=document.createElement("span");i.classList.add("keybinding"),i.textContent=this.options.keybinding,this.element.appendChild(i)}this.updateClass(),this.updateLabel(),this.updateTooltip(),this.updateEnabled(),this.updateChecked()}getDefaultAriaRole(){return this._action.id===In.ID?"presentation":this.options.isMenu?"menuitem":"button"}focus(){this.label&&(this.label.tabIndex=0,this.label.focus())}blur(){this.label&&(this.label.tabIndex=-1)}setFocusable(e){this.label&&(this.label.tabIndex=e?0:-1)}updateLabel(){this.options.label&&this.label&&(this.label.textContent=this.action.label)}getTooltip(){let e=null;return this.action.tooltip?e=this.action.tooltip:!this.options.label&&this.action.label&&this.options.icon&&(e=this.action.label,this.options.keybinding&&(e=p({key:"titleLabel",comment:["action title","action keybinding"]},"{0} ({1})",e,this.options.keybinding))),e??void 0}updateClass(){var e;this.cssClass&&this.label&&this.label.classList.remove(...this.cssClass.split(" ")),this.options.icon?(this.cssClass=this.getClass(),this.label&&(this.label.classList.add("codicon"),this.cssClass&&this.label.classList.add(...this.cssClass.split(" "))),this.updateEnabled()):(e=this.label)===null||e===void 0||e.classList.remove("codicon")}updateEnabled(){var e,t;this.action.enabled?(this.label&&(this.label.removeAttribute("aria-disabled"),this.label.classList.remove("disabled")),(e=this.element)===null||e===void 0||e.classList.remove("disabled")):(this.label&&(this.label.setAttribute("aria-disabled","true"),this.label.classList.add("disabled")),(t=this.element)===null||t===void 0||t.classList.add("disabled"))}updateAriaLabel(){var e;if(this.label){const t=(e=this.getTooltip())!==null&&e!==void 0?e:"";this.label.setAttribute("aria-label",t)}}updateChecked(){this.label&&(this.action.checked!==void 0?(this.label.classList.toggle("checked",this.action.checked),this.label.setAttribute("aria-checked",this.action.checked?"true":"false"),this.label.setAttribute("role","checkbox")):(this.label.classList.remove("checked"),this.label.removeAttribute("aria-checked"),this.label.setAttribute("role",this.getDefaultAriaRole())))}}class Mge extends wa{constructor(e,t,i,n,o,r,a){super(e,t),this.selectBox=new Tge(i,n,o,r,a),this.selectBox.setFocusable(!1),this._register(this.selectBox),this.registerListeners()}select(e){this.selectBox.select(e)}registerListeners(){this._register(this.selectBox.onDidSelect(e=>this.runAction(e.selected,e.index)))}runAction(e,t){this.actionRunner.run(this._action,this.getActionContext(e,t))}getActionContext(e,t){return e}setFocusable(e){this.selectBox.setFocusable(e)}focus(){var e;(e=this.selectBox)===null||e===void 0||e.focus()}blur(){var e;(e=this.selectBox)===null||e===void 0||e.blur()}render(e){this.selectBox.render(e)}}class Rge extends Eg{constructor(e,t){super(),this._onDidChangeVisibility=this._register(new W),this.onDidChangeVisibility=this._onDidChangeVisibility.event,this._element=te(e,se(".monaco-dropdown")),this._label=te(this._element,se(".dropdown-label"));let i=t.labelRenderer;i||(i=o=>(o.textContent=t.label||"",null));for(const o of[he.CLICK,he.MOUSE_DOWN,Qt.Tap])this._register(Y(this.element,o,r=>ot.stop(r,!0)));for(const o of[he.MOUSE_DOWN,Qt.Tap])this._register(Y(this._label,o,r=>{iP(r)&&(r.detail>1||r.button!==0)||(this.visible?this.hide():this.show())}));this._register(Y(this._label,he.KEY_UP,o=>{const r=new ri(o);(r.equals(3)||r.equals(10))&&(ot.stop(o,!0),this.visible?this.hide():this.show())}));const n=i(this._label);n&&this._register(n),this._register(Xt.addTarget(this._label))}get element(){return this._element}show(){this.visible||(this.visible=!0,this._onDidChangeVisibility.fire(!0))}hide(){this.visible&&(this.visible=!1,this._onDidChangeVisibility.fire(!1))}dispose(){super.dispose(),this.hide(),this.boxContainer&&(this.boxContainer.remove(),this.boxContainer=void 0),this.contents&&(this.contents.remove(),this.contents=void 0),this._label&&(this._label.remove(),this._label=void 0)}}class Age extends Rge{constructor(e,t){super(e,t),this._options=t,this._actions=[],this.actions=t.actions||[]}set menuOptions(e){this._menuOptions=e}get menuOptions(){return this._menuOptions}get actions(){return this._options.actionProvider?this._options.actionProvider.getActions():this._actions}set actions(e){this._actions=e}show(){super.show(),this.element.classList.add("active"),this._options.contextMenuProvider.showContextMenu({getAnchor:()=>this.element,getActions:()=>this.actions,getActionsContext:()=>this.menuOptions?this.menuOptions.context:null,getActionViewItem:(e,t)=>this.menuOptions&&this.menuOptions.actionViewItemProvider?this.menuOptions.actionViewItemProvider(e,t):void 0,getKeyBinding:e=>this.menuOptions&&this.menuOptions.getKeyBinding?this.menuOptions.getKeyBinding(e):void 0,getMenuClassName:()=>this._options.menuClassName||"",onHide:()=>this.onHide(),actionRunner:this.menuOptions?this.menuOptions.actionRunner:void 0,anchorAlignment:this.menuOptions?this.menuOptions.anchorAlignment:0,domForShadowRoot:this._options.menuAsChild?this.element:void 0,skipTelemetry:this._options.skipTelemetry})}hide(){super.hide()}onHide(){this.hide(),this.element.classList.remove("active")}}class Ly extends wa{constructor(e,t,i,n=Object.create(null)){super(null,e,n),this.actionItem=null,this._onDidChangeVisibility=this._register(new W),this.onDidChangeVisibility=this._onDidChangeVisibility.event,this.menuActionsOrProvider=t,this.contextMenuProvider=i,this.options=n,this.options.actionRunner&&(this.actionRunner=this.options.actionRunner)}render(e){this.actionItem=e;const t=o=>{this.element=te(o,se("a.action-label"));let r=[];return typeof this.options.classNames=="string"?r=this.options.classNames.split(/\s+/g).filter(a=>!!a):this.options.classNames&&(r=this.options.classNames),r.find(a=>a==="icon")||r.push("codicon"),this.element.classList.add(...r),this.element.setAttribute("role","button"),this.element.setAttribute("aria-haspopup","true"),this.element.setAttribute("aria-expanded","false"),this.element.title=this._action.label||"",this.element.ariaLabel=this._action.label||"",null},i=Array.isArray(this.menuActionsOrProvider),n={contextMenuProvider:this.contextMenuProvider,labelRenderer:t,menuAsChild:this.options.menuAsChild,actions:i?this.menuActionsOrProvider:void 0,actionProvider:i?void 0:this.menuActionsOrProvider,skipTelemetry:this.options.skipTelemetry};if(this.dropdownMenu=this._register(new Age(e,n)),this._register(this.dropdownMenu.onDidChangeVisibility(o=>{var r;(r=this.element)===null||r===void 0||r.setAttribute("aria-expanded",`${o}`),this._onDidChangeVisibility.fire(o)})),this.dropdownMenu.menuOptions={actionViewItemProvider:this.options.actionViewItemProvider,actionRunner:this.actionRunner,getKeyBinding:this.options.keybindingProvider,context:this._context},this.options.anchorAlignmentProvider){const o=this;this.dropdownMenu.menuOptions={...this.dropdownMenu.menuOptions,get anchorAlignment(){return o.options.anchorAlignmentProvider()}}}this.updateTooltip(),this.updateEnabled()}getTooltip(){let e=null;return this.action.tooltip?e=this.action.tooltip:this.action.label&&(e=this.action.label),e??void 0}setActionContext(e){super.setActionContext(e),this.dropdownMenu&&(this.dropdownMenu.menuOptions?this.dropdownMenu.menuOptions.context=e:this.dropdownMenu.menuOptions={context:e})}show(){var e;(e=this.dropdownMenu)===null||e===void 0||e.show()}updateEnabled(){var e,t;const i=!this.action.enabled;(e=this.actionItem)===null||e===void 0||e.classList.toggle("disabled",i),(t=this.element)===null||t===void 0||t.classList.toggle("disabled",i)}}function Pge(s){return s?s.condition!==void 0:!1}var Zp;(function(s){s[s.STORAGE_DOES_NOT_EXIST=0]="STORAGE_DOES_NOT_EXIST",s[s.STORAGE_IN_MEMORY=1]="STORAGE_IN_MEMORY"})(Zp||(Zp={}));var Cp;(function(s){s[s.None=0]="None",s[s.Initialized=1]="Initialized",s[s.Closed=2]="Closed"})(Cp||(Cp={}));class Yp extends j{constructor(e,t=Object.create(null)){super(),this.database=e,this.options=t,this._onDidChangeStorage=this._register(new Lg),this.onDidChangeStorage=this._onDidChangeStorage.event,this.state=Cp.None,this.cache=new Map,this.flushDelayer=this._register(new sV(Yp.DEFAULT_FLUSH_DELAY)),this.pendingDeletes=new Set,this.pendingInserts=new Map,this.whenFlushedCallbacks=[],this.registerListeners()}registerListeners(){this._register(this.database.onDidChangeItemsExternal(e=>this.onDidChangeItemsExternal(e)))}onDidChangeItemsExternal(e){var t,i;this._onDidChangeStorage.pause();try{(t=e.changed)===null||t===void 0||t.forEach((n,o)=>this.acceptExternal(o,n)),(i=e.deleted)===null||i===void 0||i.forEach(n=>this.acceptExternal(n,void 0))}finally{this._onDidChangeStorage.resume()}}acceptExternal(e,t){if(this.state===Cp.Closed)return;let i=!1;Uo(t)?i=this.cache.delete(e):this.cache.get(e)!==t&&(this.cache.set(e,t),i=!0),i&&this._onDidChangeStorage.fire({key:e,external:!0})}get(e,t){const i=this.cache.get(e);return Uo(i)?t:i}getBoolean(e,t){const i=this.get(e);return Uo(i)?t:i==="true"}getNumber(e,t){const i=this.get(e);return Uo(i)?t:parseInt(i,10)}async set(e,t,i=!1){if(this.state===Cp.Closed)return;if(Uo(t))return this.delete(e,i);const n=Ts(t)||Array.isArray(t)?Whe(t):String(t);if(this.cache.get(e)!==n)return this.cache.set(e,n),this.pendingInserts.set(e,n),this.pendingDeletes.delete(e),this._onDidChangeStorage.fire({key:e,external:i}),this.doFlush()}async delete(e,t=!1){if(!(this.state===Cp.Closed||!this.cache.delete(e)))return this.pendingDeletes.has(e)||this.pendingDeletes.add(e),this.pendingInserts.delete(e),this._onDidChangeStorage.fire({key:e,external:t}),this.doFlush()}get hasPending(){return this.pendingInserts.size>0||this.pendingDeletes.size>0}async flushPending(){if(!this.hasPending)return;const e={insert:this.pendingInserts,delete:this.pendingDeletes};return this.pendingDeletes=new Set,this.pendingInserts=new Map,this.database.updateItems(e).finally(()=>{var t;if(!this.hasPending)for(;this.whenFlushedCallbacks.length;)(t=this.whenFlushedCallbacks.pop())===null||t===void 0||t()})}async doFlush(e){return this.options.hint===Zp.STORAGE_IN_MEMORY?this.flushPending():this.flushDelayer.trigger(()=>this.flushPending(),e)}}Yp.DEFAULT_FLUSH_DELAY=100;class VI{constructor(){this.onDidChangeItemsExternal=ge.None,this.items=new Map}async updateItems(e){var t,i;(t=e.insert)===null||t===void 0||t.forEach((n,o)=>this.items.set(o,n)),(i=e.delete)===null||i===void 0||i.forEach(n=>this.items.delete(n))}}const qw="__$__targetStorageMarker",sa=ut("storageService");var db;(function(s){s[s.NONE=0]="NONE",s[s.SHUTDOWN=1]="SHUTDOWN"})(db||(db={}));function Oge(s){const e=s.get(qw);if(e)try{return JSON.parse(e)}catch{}return Object.create(null)}class Hx extends j{constructor(e={flushInterval:Hx.DEFAULT_FLUSH_INTERVAL}){super(),this.options=e,this._onDidChangeValue=this._register(new Lg),this._onDidChangeTarget=this._register(new Lg),this._onWillSaveState=this._register(new W),this.onWillSaveState=this._onWillSaveState.event,this._workspaceKeyTargets=void 0,this._profileKeyTargets=void 0,this._applicationKeyTargets=void 0}onDidChangeValue(e,t,i){return ge.filter(this._onDidChangeValue.event,n=>n.scope===e&&(t===void 0||n.key===t),i)}emitDidChangeValue(e,t){const{key:i,external:n}=t;if(i===qw){switch(e){case-1:this._applicationKeyTargets=void 0;break;case 0:this._profileKeyTargets=void 0;break;case 1:this._workspaceKeyTargets=void 0;break}this._onDidChangeTarget.fire({scope:e})}else this._onDidChangeValue.fire({scope:e,key:i,target:this.getKeyTargets(e)[i],external:n})}get(e,t,i){var n;return(n=this.getStorage(t))===null||n===void 0?void 0:n.get(e,i)}getBoolean(e,t,i){var n;return(n=this.getStorage(t))===null||n===void 0?void 0:n.getBoolean(e,i)}getNumber(e,t,i){var n;return(n=this.getStorage(t))===null||n===void 0?void 0:n.getNumber(e,i)}store(e,t,i,n,o=!1){if(Uo(t)){this.remove(e,i,o);return}this.withPausedEmitters(()=>{var r;this.updateKeyTarget(e,i,n),(r=this.getStorage(i))===null||r===void 0||r.set(e,t,o)})}remove(e,t,i=!1){this.withPausedEmitters(()=>{var n;this.updateKeyTarget(e,t,void 0),(n=this.getStorage(t))===null||n===void 0||n.delete(e,i)})}withPausedEmitters(e){this._onDidChangeValue.pause(),this._onDidChangeTarget.pause();try{e()}finally{this._onDidChangeValue.resume(),this._onDidChangeTarget.resume()}}updateKeyTarget(e,t,i,n=!1){var o,r;const a=this.getKeyTargets(t);typeof i=="number"?a[e]!==i&&(a[e]=i,(o=this.getStorage(t))===null||o===void 0||o.set(qw,JSON.stringify(a),n)):typeof a[e]=="number"&&(delete a[e],(r=this.getStorage(t))===null||r===void 0||r.set(qw,JSON.stringify(a),n))}get workspaceKeyTargets(){return this._workspaceKeyTargets||(this._workspaceKeyTargets=this.loadKeyTargets(1)),this._workspaceKeyTargets}get profileKeyTargets(){return this._profileKeyTargets||(this._profileKeyTargets=this.loadKeyTargets(0)),this._profileKeyTargets}get applicationKeyTargets(){return this._applicationKeyTargets||(this._applicationKeyTargets=this.loadKeyTargets(-1)),this._applicationKeyTargets}getKeyTargets(e){switch(e){case-1:return this.applicationKeyTargets;case 0:return this.profileKeyTargets;default:return this.workspaceKeyTargets}}loadKeyTargets(e){const t=this.getStorage(e);return t?Oge(t):Object.create(null)}}Hx.DEFAULT_FLUSH_INTERVAL=60*1e3;class Fge extends Hx{constructor(){super(),this.applicationStorage=this._register(new Yp(new VI,{hint:Zp.STORAGE_IN_MEMORY})),this.profileStorage=this._register(new Yp(new VI,{hint:Zp.STORAGE_IN_MEMORY})),this.workspaceStorage=this._register(new Yp(new VI,{hint:Zp.STORAGE_IN_MEMORY})),this._register(this.workspaceStorage.onDidChangeStorage(e=>this.emitDidChangeValue(1,e))),this._register(this.profileStorage.onDidChangeStorage(e=>this.emitDidChangeValue(0,e))),this._register(this.applicationStorage.onDidChangeStorage(e=>this.emitDidChangeValue(-1,e)))}getStorage(e){switch(e){case-1:return this.applicationStorage;case 0:return this.profileStorage;default:return this.workspaceStorage}}}function Bge(s,e){const t={...e};for(const i in s){const n=s[i];t[i]=n!==void 0?_e(n):void 0}return t}const Wge={keybindingLabelBackground:_e(Sse),keybindingLabelForeground:_e(yse),keybindingLabelBorder:_e(Lse),keybindingLabelBottomBorder:_e(xse),keybindingLabelShadow:_e(Il)},Vge={buttonForeground:_e(rv),buttonSeparator:_e(lse),buttonBackground:_e(av),buttonHoverBackground:_e(dse),buttonSecondaryForeground:_e(use),buttonSecondaryBackground:_e(gT),buttonSecondaryHoverBackground:_e(hse),buttonBorder:_e(cse)},Hge={progressBarBackground:_e(pse)},xy={inputActiveOptionBorder:_e(bP),inputActiveOptionForeground:_e(CP),inputActiveOptionBackground:_e(Jh)};_e(soe),_e(roe),_e(ooe);_e(Ri),_e(Tl),_e(Il),_e(pt),_e(Soe),_e(yoe),_e(Loe),_e(Xne);const Dy={inputBackground:_e(oH),inputForeground:_e(rH),inputBorder:_e(aH),inputValidationInfoBorder:_e(ese),inputValidationInfoBackground:_e(Qne),inputValidationInfoForeground:_e(Jne),inputValidationWarningBorder:_e(nse),inputValidationWarningBackground:_e(tse),inputValidationWarningForeground:_e(ise),inputValidationErrorBorder:_e(rse),inputValidationErrorBackground:_e(sse),inputValidationErrorForeground:_e(ose)},zge={listFilterWidgetBackground:_e(Xse),listFilterWidgetOutline:_e(Qse),listFilterWidgetNoMatchesOutline:_e(Jse),listFilterWidgetShadow:_e(eoe),inputBoxStyles:Dy,toggleStyles:xy},Xz={badgeBackground:_e(Bw),badgeForeground:_e(gse),badgeBorder:_e(pt)};_e(poe),_e(foe),_e(y3),_e(y3),_e(moe);const gf={listBackground:void 0,listInactiveFocusForeground:void 0,listFocusBackground:_e(Hse),listFocusForeground:_e(zse),listFocusOutline:_e(Use),listActiveSelectionBackground:_e(Wd),listActiveSelectionForeground:_e(Al),listActiveSelectionIconForeground:_e(uv),listFocusAndSelectionOutline:_e($se),listFocusAndSelectionBackground:_e(Wd),listFocusAndSelectionForeground:_e(Al),listInactiveSelectionBackground:_e(jse),listInactiveSelectionIconForeground:_e(qse),listInactiveSelectionForeground:_e(Kse),listInactiveFocusBackground:_e(Gse),listInactiveFocusOutline:_e(Zse),listHoverBackground:_e(cH),listHoverForeground:_e(uH),listDropBackground:_e(Yse),listSelectionOutline:_e(ai),listHoverOutline:_e(ai),treeIndentGuidesStroke:_e(hv),treeInactiveIndentGuidesStroke:_e(toe),tableColumnsBorder:_e(ioe),tableOddRowsBackgroundColor:_e(noe)};function c_(s){return Bge(s,gf)}const Uge={selectBackground:_e(El),selectListBackground:_e(ase),selectForeground:_e(Od),decoratorRightForeground:_e(lH),selectBorder:_e(lp),focusBorder:_e(Zo),listFocusBackground:_e(tg),listInactiveSelectionIconForeground:_e(dp),listFocusForeground:_e(eg),listFocusOutline:Gne(ai,G.transparent.toString()),listHoverBackground:_e(cH),listHoverForeground:_e(uH),listHoverOutline:_e(ai),selectListBorder:_e(Ml),listBackground:void 0,listActiveSelectionBackground:void 0,listActiveSelectionForeground:void 0,listActiveSelectionIconForeground:void 0,listFocusAndSelectionBackground:void 0,listDropBackground:void 0,listInactiveSelectionBackground:void 0,listInactiveSelectionForeground:void 0,listInactiveFocusBackground:void 0,listInactiveFocusOutline:void 0,listSelectionOutline:void 0,listFocusAndSelectionForeground:void 0,listFocusAndSelectionOutline:void 0,listInactiveFocusForeground:void 0,tableColumnsBorder:void 0,tableOddRowsBackgroundColor:void 0,treeIndentGuidesStroke:void 0,treeInactiveIndentGuidesStroke:void 0},$ge={shadowColor:_e(Il),borderColor:_e(aoe),foregroundColor:_e(loe),backgroundColor:_e(doe),selectionForegroundColor:_e(coe),selectionBackgroundColor:_e(uoe),selectionBorderColor:_e(hoe),separatorColor:_e(goe),scrollbarShadow:_e(fse),scrollbarSliderBackground:_e(lv),scrollbarSliderHoverBackground:_e(dv),scrollbarSliderActiveBackground:_e(cv)};var zx=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Gs=function(s,e){return function(t,i){e(t,i,s)}};function jge(s,e,t,i){const n=s.getActions(e),o=Pd.getInstance(),r=o.keyStatus.altKey||(es||Ss)&&o.keyStatus.shiftKey;Qz(n,t,r,i?a=>a===i:a=>a==="navigation")}function hO(s,e,t,i,n,o){const r=s.getActions(e);Qz(r,t,!1,typeof i=="string"?l=>l===i:i,n,o)}function Qz(s,e,t,i=r=>r==="navigation",n=()=>!1,o=!1){let r,a;Array.isArray(e)?(r=e,a=e):(r=e.primary,a=e.secondary);const l=new Set;for(const[d,c]of s){let u;i(d)?(u=r,u.length>0&&o&&u.push(new In)):(u=a,u.length>0&&u.push(new In));for(let h of c){t&&(h=h instanceof Xr&&h.alt?h.alt:h);const g=u.push(h);h instanceof cm&&l.add({group:d,action:h,index:g-1})}}for(const{group:d,action:c,index:u}of l){const h=i(d)?r:a,g=c.actions;n(c,d,h.length)&&h.splice(u,1,...g)}}let Og=class extends Em{constructor(e,t,i,n,o,r,a,l){super(void 0,e,{icon:!!(e.class||e.item.icon),label:!e.class&&!e.item.icon,draggable:t==null?void 0:t.draggable,keybinding:t==null?void 0:t.keybinding,hoverDelegate:t==null?void 0:t.hoverDelegate}),this._keybindingService=i,this._notificationService=n,this._contextKeyService=o,this._themeService=r,this._contextMenuService=a,this._accessibilityService=l,this._wantsAltCommand=!1,this._itemClassDispose=this._register(new En),this._altKey=Pd.getInstance()}get _menuItemAction(){return this._action}get _commandAction(){return this._wantsAltCommand&&this._menuItemAction.alt||this._menuItemAction}async onClick(e){e.preventDefault(),e.stopPropagation();try{await this.actionRunner.run(this._commandAction,this._context)}catch(t){this._notificationService.error(t)}}render(e){if(super.render(e),e.classList.add("menu-entry"),this.options.icon&&this._updateItemClass(this._menuItemAction.item),this._menuItemAction.alt){let t=!1;const i=()=>{var n;const o=!!(!((n=this._menuItemAction.alt)===null||n===void 0)&&n.enabled)&&(!this._accessibilityService.isMotionReduced()||t)&&(this._altKey.keyStatus.altKey||this._altKey.keyStatus.shiftKey&&t);o!==this._wantsAltCommand&&(this._wantsAltCommand=o,this.updateLabel(),this.updateTooltip(),this.updateClass())};this._register(this._altKey.event(i)),this._register(Y(e,"mouseleave",n=>{t=!1,i()})),this._register(Y(e,"mouseenter",n=>{t=!0,i()})),i()}}updateLabel(){this.options.label&&this.label&&(this.label.textContent=this._commandAction.label)}getTooltip(){var e;const t=this._keybindingService.lookupKeybinding(this._commandAction.id,this._contextKeyService),i=t&&t.getLabel(),n=this._commandAction.tooltip||this._commandAction.label;let o=i?p("titleAndKb","{0} ({1})",n,i):n;if(!this._wantsAltCommand&&(!((e=this._menuItemAction.alt)===null||e===void 0)&&e.enabled)){const r=this._menuItemAction.alt.tooltip||this._menuItemAction.alt.label,a=this._keybindingService.lookupKeybinding(this._menuItemAction.alt.id,this._contextKeyService),l=a&&a.getLabel(),d=l?p("titleAndKb","{0} ({1})",r,l):r;o=p("titleAndKbAndAlt",`{0}
[{1}] {2}`,o,eO.modifierLabels[Go].altKey,d)}return o}updateClass(){this.options.icon&&(this._commandAction!==this._menuItemAction?this._menuItemAction.alt&&this._updateItemClass(this._menuItemAction.alt.item):this._updateItemClass(this._menuItemAction.item))}_updateItemClass(e){this._itemClassDispose.value=void 0;const{element:t,label:i}=this;if(!t||!i)return;const n=this._commandAction.checked&&Pge(e.toggled)&&e.toggled.icon?e.toggled.icon:e.icon;if(n)if(Oe.isThemeIcon(n)){const o=Oe.asClassNameArray(n);i.classList.add(...o),this._itemClassDispose.value=Fe(()=>{i.classList.remove(...o)})}else i.style.backgroundImage=bm(this._themeService.getColorTheme().type)?Tu(n.dark):Tu(n.light),i.classList.add("icon"),this._itemClassDispose.value=Gr(Fe(()=>{i.style.backgroundImage="",i.classList.remove("icon")}),this._themeService.onDidColorThemeChange(()=>{this.updateClass()}))}};Og=zx([Gs(2,qt),Gs(3,Qi),Gs(4,je),Gs(5,Cn),Gs(6,Nr),Gs(7,ad)],Og);let h2=class extends Ly{constructor(e,t,i,n,o){var r,a,l;const d={...t,menuAsChild:(r=t==null?void 0:t.menuAsChild)!==null&&r!==void 0?r:!1,classNames:(a=t==null?void 0:t.classNames)!==null&&a!==void 0?a:Oe.isThemeIcon(e.item.icon)?Oe.asClassName(e.item.icon):void 0,keybindingProvider:(l=t==null?void 0:t.keybindingProvider)!==null&&l!==void 0?l:c=>i.lookupKeybinding(c.id)};super(e,{getActions:()=>e.actions},n,d),this._keybindingService=i,this._contextMenuService=n,this._themeService=o}render(e){super.render(e),zt(this.element),e.classList.add("menu-entry");const t=this._action,{icon:i}=t.item;if(i&&!Oe.isThemeIcon(i)){this.element.classList.add("icon");const n=()=>{this.element&&(this.element.style.backgroundImage=bm(this._themeService.getColorTheme().type)?Tu(i.dark):Tu(i.light))};n(),this._register(this._themeService.onDidColorThemeChange(()=>{n()}))}}};h2=zx([Gs(2,qt),Gs(3,Nr),Gs(4,Cn)],h2);let g2=class extends wa{constructor(e,t,i,n,o,r,a,l){var d,c,u;super(null,e),this._keybindingService=i,this._notificationService=n,this._contextMenuService=o,this._menuService=r,this._instaService=a,this._storageService=l,this._container=null,this._options=t,this._storageKey=`${e.item.submenu.id}_lastActionId`;let h;const g=t!=null&&t.persistLastActionId?l.get(this._storageKey,1):void 0;g&&(h=e.actions.find(m=>g===m.id)),h||(h=e.actions[0]),this._defaultAction=this._instaService.createInstance(Og,h,{keybinding:this._getDefaultActionKeybindingLabel(h)});const f={keybindingProvider:m=>this._keybindingService.lookupKeybinding(m.id),...t,menuAsChild:(d=t==null?void 0:t.menuAsChild)!==null&&d!==void 0?d:!0,classNames:(c=t==null?void 0:t.classNames)!==null&&c!==void 0?c:["codicon","codicon-chevron-down"],actionRunner:(u=t==null?void 0:t.actionRunner)!==null&&u!==void 0?u:new Eg};this._dropdown=new Ly(e,e.actions,this._contextMenuService,f),this._dropdown.actionRunner.onDidRun(m=>{m.action instanceof Xr&&this.update(m.action)})}update(e){var t;!((t=this._options)===null||t===void 0)&&t.persistLastActionId&&this._storageService.store(this._storageKey,e.id,1,1),this._defaultAction.dispose(),this._defaultAction=this._instaService.createInstance(Og,e,{keybinding:this._getDefaultActionKeybindingLabel(e)}),this._defaultAction.actionRunner=new class extends Eg{async runAction(i,n){await i.run(void 0)}},this._container&&this._defaultAction.render(yV(this._container,se(".action-container")))}_getDefaultActionKeybindingLabel(e){var t;let i;if(!((t=this._options)===null||t===void 0)&&t.renderKeybindingWithDefaultActionLabel){const n=this._keybindingService.lookupKeybinding(e.id);n&&(i=`(${n.getLabel()})`)}return i}setActionContext(e){super.setActionContext(e),this._defaultAction.setActionContext(e),this._dropdown.setActionContext(e)}render(e){this._container=e,super.render(this._container),this._container.classList.add("monaco-dropdown-with-default");const t=se(".action-container");this._defaultAction.render(te(this._container,t)),this._register(Y(t,he.KEY_DOWN,n=>{const o=new ri(n);o.equals(17)&&(this._defaultAction.element.tabIndex=-1,this._dropdown.focus(),o.stopPropagation())}));const i=se(".dropdown-action-container");this._dropdown.render(te(this._container,i)),this._register(Y(i,he.KEY_DOWN,n=>{var o;const r=new ri(n);r.equals(15)&&(this._defaultAction.element.tabIndex=0,this._dropdown.setFocusable(!1),(o=this._defaultAction.element)===null||o===void 0||o.focus(),r.stopPropagation())}))}focus(e){e?this._dropdown.focus():(this._defaultAction.element.tabIndex=0,this._defaultAction.element.focus())}blur(){this._defaultAction.element.tabIndex=-1,this._dropdown.blur(),this._container.blur()}setFocusable(e){e?this._defaultAction.element.tabIndex=0:(this._defaultAction.element.tabIndex=-1,this._dropdown.setFocusable(!1))}dispose(){this._defaultAction.dispose(),this._dropdown.dispose(),super.dispose()}};g2=zx([Gs(2,qt),Gs(3,Qi),Gs(4,Nr),Gs(5,qa),Gs(6,We),Gs(7,sa)],g2);let f2=class extends Mge{constructor(e,t){super(null,e,e.actions.map(i=>({text:i.id===In.ID?"─────────":i.label,isDisabled:!i.enabled})),0,t,Uge,{ariaLabel:e.tooltip,optionsAsChildren:!0}),this.select(Math.max(0,e.actions.findIndex(i=>i.checked)))}render(e){super.render(e),e.style.borderColor=_e(lp)}runAction(e,t){const i=this.action.actions[t];i&&this.actionRunner.run(i)}};f2=zx([Gs(1,rc)],f2);function Kge(s,e,t){return e instanceof Xr?s.createInstance(Og,e,t):e instanceof E0?e.item.isSelection?s.createInstance(f2,e):e.item.rememberDefaultAction?s.createInstance(g2,e,{...t,persistLastActionId:!0}):s.createInstance(h2,e,t):void 0}class Ir extends j{constructor(e,t={}){var i,n,o,r,a,l;super(),this._actionRunnerDisposables=this._register(new ie),this.viewItemDisposables=this._register(new NA),this.triggerKeyDown=!1,this.focusable=!0,this._onDidBlur=this._register(new W),this.onDidBlur=this._onDidBlur.event,this._onDidCancel=this._register(new W({onWillAddFirstListener:()=>this.cancelHasListener=!0})),this.onDidCancel=this._onDidCancel.event,this.cancelHasListener=!1,this._onDidRun=this._register(new W),this.onDidRun=this._onDidRun.event,this._onWillRun=this._register(new W),this.onWillRun=this._onWillRun.event,this.options=t,this._context=(i=t.context)!==null&&i!==void 0?i:null,this._orientation=(n=this.options.orientation)!==null&&n!==void 0?n:0,this._triggerKeys={keyDown:(r=(o=this.options.triggerKeys)===null||o===void 0?void 0:o.keyDown)!==null&&r!==void 0?r:!1,keys:(l=(a=this.options.triggerKeys)===null||a===void 0?void 0:a.keys)!==null&&l!==void 0?l:[3,10]},this.options.actionRunner?this._actionRunner=this.options.actionRunner:(this._actionRunner=new Eg,this._actionRunnerDisposables.add(this._actionRunner)),this._actionRunnerDisposables.add(this._actionRunner.onDidRun(u=>this._onDidRun.fire(u))),this._actionRunnerDisposables.add(this._actionRunner.onWillRun(u=>this._onWillRun.fire(u))),this.viewItems=[],this.focusedItem=void 0,this.domNode=document.createElement("div"),this.domNode.className="monaco-action-bar",t.animated!==!1&&this.domNode.classList.add("animated");let d,c;switch(this._orientation){case 0:d=[15],c=[17];break;case 1:d=[16],c=[18],this.domNode.className+=" vertical";break}this._register(Y(this.domNode,he.KEY_DOWN,u=>{const h=new ri(u);let g=!0;const f=typeof this.focusedItem=="number"?this.viewItems[this.focusedItem]:void 0;d&&(h.equals(d[0])||h.equals(d[1]))?g=this.focusPrevious():c&&(h.equals(c[0])||h.equals(c[1]))?g=this.focusNext():h.equals(9)&&this.cancelHasListener?this._onDidCancel.fire():h.equals(14)?g=this.focusFirst():h.equals(13)?g=this.focusLast():h.equals(2)&&f instanceof wa&&f.trapsArrowNavigation?g=this.focusNext():this.isTriggerKeyEvent(h)?this._triggerKeys.keyDown?this.doTrigger(h):this.triggerKeyDown=!0:g=!1,g&&(h.preventDefault(),h.stopPropagation())})),this._register(Y(this.domNode,he.KEY_UP,u=>{const h=new ri(u);this.isTriggerKeyEvent(h)?(!this._triggerKeys.keyDown&&this.triggerKeyDown&&(this.triggerKeyDown=!1,this.doTrigger(h)),h.preventDefault(),h.stopPropagation()):(h.equals(2)||h.equals(1026)||h.equals(16)||h.equals(18)||h.equals(15)||h.equals(17))&&this.updateFocusedItem()})),this.focusTracker=this._register(ql(this.domNode)),this._register(this.focusTracker.onDidBlur(()=>{(Jo()===this.domNode||!Yn(Jo(),this.domNode))&&(this._onDidBlur.fire(),this.previouslyFocusedItem=this.focusedItem,this.focusedItem=void 0,this.triggerKeyDown=!1)})),this._register(this.focusTracker.onDidFocus(()=>this.updateFocusedItem())),this.actionsList=document.createElement("ul"),this.actionsList.className="actions-container",this.options.highlightToggledItems&&this.actionsList.classList.add("highlight-toggled"),this.actionsList.setAttribute("role",this.options.ariaRole||"toolbar"),this.options.ariaLabel&&this.actionsList.setAttribute("aria-label",this.options.ariaLabel),this.domNode.appendChild(this.actionsList),e.appendChild(this.domNode)}refreshRole(){this.length()>=1?this.actionsList.setAttribute("role",this.options.ariaRole||"toolbar"):this.actionsList.setAttribute("role","presentation")}setFocusable(e){if(this.focusable=e,this.focusable){const t=this.viewItems.find(i=>i instanceof wa&&i.isEnabled());t instanceof wa&&t.setFocusable(!0)}else this.viewItems.forEach(t=>{t instanceof wa&&t.setFocusable(!1)})}isTriggerKeyEvent(e){let t=!1;return this._triggerKeys.keys.forEach(i=>{t=t||e.equals(i)}),t}updateFocusedItem(){var e,t;for(let i=0;i<this.actionsList.children.length;i++){const n=this.actionsList.children[i];if(Yn(Jo(),n)){this.focusedItem=i,(t=(e=this.viewItems[this.focusedItem])===null||e===void 0?void 0:e.showHover)===null||t===void 0||t.call(e);break}}}get context(){return this._context}set context(e){this._context=e,this.viewItems.forEach(t=>t.setActionContext(e))}get actionRunner(){return this._actionRunner}set actionRunner(e){this._actionRunner=e,this._actionRunnerDisposables.clear(),this._actionRunnerDisposables.add(this._actionRunner.onDidRun(t=>this._onDidRun.fire(t))),this._actionRunnerDisposables.add(this._actionRunner.onWillRun(t=>this._onWillRun.fire(t))),this.viewItems.forEach(t=>t.actionRunner=e)}getContainer(){return this.domNode}getAction(e){var t;if(typeof e=="number")return(t=this.viewItems[e])===null||t===void 0?void 0:t.action;if(e instanceof HTMLElement){for(;e.parentElement!==this.actionsList;){if(!e.parentElement)return;e=e.parentElement}for(let i=0;i<this.actionsList.childNodes.length;i++)if(this.actionsList.childNodes[i]===e)return this.viewItems[i].action}}push(e,t={}){const i=Array.isArray(e)?e:[e];let n=xu(t.index)?t.index:null;i.forEach(o=>{const r=document.createElement("li");r.className="action-item",r.setAttribute("role","presentation");let a;const l={hoverDelegate:this.options.hoverDelegate,...t};this.options.actionViewItemProvider&&(a=this.options.actionViewItemProvider(o,l)),a||(a=new Em(this.context,o,l)),this.options.allowContextMenu||this.viewItemDisposables.set(a,Y(r,he.CONTEXT_MENU,d=>{ot.stop(d,!0)})),a.actionRunner=this._actionRunner,a.setActionContext(this.context),a.render(r),this.focusable&&a instanceof wa&&this.viewItems.length===0&&a.setFocusable(!0),n===null||n<0||n>=this.actionsList.children.length?(this.actionsList.appendChild(r),this.viewItems.push(a)):(this.actionsList.insertBefore(r,this.actionsList.children[n]),this.viewItems.splice(n,0,a),n++)}),typeof this.focusedItem=="number"&&this.focus(this.focusedItem),this.refreshRole()}clear(){this.isEmpty()||(this.viewItems=Bt(this.viewItems),this.viewItemDisposables.clearAndDisposeAll(),Vn(this.actionsList),this.refreshRole())}length(){return this.viewItems.length}isEmpty(){return this.viewItems.length===0}focus(e){let t=!1,i;if(e===void 0?t=!0:typeof e=="number"?i=e:typeof e=="boolean"&&(t=e),t&&typeof this.focusedItem>"u"){const n=this.viewItems.findIndex(o=>o.isEnabled());this.focusedItem=n===-1?void 0:n,this.updateFocus(void 0,void 0,!0)}else i!==void 0&&(this.focusedItem=i),this.updateFocus(void 0,void 0,!0)}focusFirst(){return this.focusedItem=this.length()-1,this.focusNext(!0)}focusLast(){return this.focusedItem=0,this.focusPrevious(!0)}focusNext(e){if(typeof this.focusedItem>"u")this.focusedItem=this.viewItems.length-1;else if(this.viewItems.length<=1)return!1;const t=this.focusedItem;let i;do{if(!e&&this.options.preventLoopNavigation&&this.focusedItem+1>=this.viewItems.length)return this.focusedItem=t,!1;this.focusedItem=(this.focusedItem+1)%this.viewItems.length,i=this.viewItems[this.focusedItem]}while(this.focusedItem!==t&&(this.options.focusOnlyEnabledItems&&!i.isEnabled()||i.action.id===In.ID));return this.updateFocus(),!0}focusPrevious(e){if(typeof this.focusedItem>"u")this.focusedItem=0;else if(this.viewItems.length<=1)return!1;const t=this.focusedItem;let i;do{if(this.focusedItem=this.focusedItem-1,this.focusedItem<0){if(!e&&this.options.preventLoopNavigation)return this.focusedItem=t,!1;this.focusedItem=this.viewItems.length-1}i=this.viewItems[this.focusedItem]}while(this.focusedItem!==t&&(this.options.focusOnlyEnabledItems&&!i.isEnabled()||i.action.id===In.ID));return this.updateFocus(!0),!0}updateFocus(e,t,i=!1){var n,o;typeof this.focusedItem>"u"&&this.actionsList.focus({preventScroll:t}),this.previouslyFocusedItem!==void 0&&this.previouslyFocusedItem!==this.focusedItem&&((n=this.viewItems[this.previouslyFocusedItem])===null||n===void 0||n.blur());const r=this.focusedItem!==void 0?this.viewItems[this.focusedItem]:void 0;if(r){let a=!0;C0(r.focus)||(a=!1),this.options.focusOnlyEnabledItems&&C0(r.isEnabled)&&!r.isEnabled()&&(a=!1),r.action.id===In.ID&&(a=!1),a&&((o=r.showHover)===null||o===void 0||o.call(r)),a?(i||this.previouslyFocusedItem!==this.focusedItem)&&(r.focus(e),this.previouslyFocusedItem=this.focusedItem):(this.actionsList.focus({preventScroll:t}),this.previouslyFocusedItem=void 0)}}doTrigger(e){if(typeof this.focusedItem>"u")return;const t=this.viewItems[this.focusedItem];if(t instanceof wa){const i=t._context===null||t._context===void 0?e:t._context;this.run(t._action,i)}}async run(e,t){await this._actionRunner.run(e,t)}dispose(){this._context=void 0,this.viewItems=Bt(this.viewItems),this.getContainer().remove(),super.dispose()}}const p2=/\(&([^\s&])\)|(^|[^&])&([^\s&])/,HI=/(&amp;)?(&amp;)([^\s&])/g;var ky;(function(s){s[s.Right=0]="Right",s[s.Left=1]="Left"})(ky||(ky={}));class Xp extends Ir{constructor(e,t,i,n){e.classList.add("monaco-menu-container"),e.setAttribute("role","presentation");const o=document.createElement("div");o.classList.add("monaco-menu"),o.setAttribute("role","presentation"),super(o,{orientation:1,actionViewItemProvider:d=>this.doGetActionViewItem(d,i,r),context:i.context,actionRunner:i.actionRunner,ariaLabel:i.ariaLabel,ariaRole:"menu",focusOnlyEnabledItems:!0,triggerKeys:{keys:[3,...bt||Ss?[10]:[]],keyDown:!0}}),this.menuStyles=n,this.menuElement=o,this.actionsList.tabIndex=0,this.initializeOrUpdateStyleSheet(e,n),this._register(Xt.addTarget(o)),this._register(Y(o,he.KEY_DOWN,d=>{new ri(d).equals(2)&&d.preventDefault()})),i.enableMnemonics&&this._register(Y(o,he.KEY_DOWN,d=>{const c=d.key.toLocaleLowerCase();if(this.mnemonics.has(c)){ot.stop(d,!0);const u=this.mnemonics.get(c);if(u.length===1&&(u[0]instanceof c9&&u[0].container&&this.focusItemByElement(u[0].container),u[0].onClick(d)),u.length>1){const h=u.shift();h&&h.container&&(this.focusItemByElement(h.container),u.push(h)),this.mnemonics.set(c,u)}}})),Ss&&this._register(Y(o,he.KEY_DOWN,d=>{const c=new ri(d);c.equals(14)||c.equals(11)?(this.focusedItem=this.viewItems.length-1,this.focusNext(),ot.stop(d,!0)):(c.equals(13)||c.equals(12))&&(this.focusedItem=0,this.focusPrevious(),ot.stop(d,!0))})),this._register(Y(this.domNode,he.MOUSE_OUT,d=>{const c=d.relatedTarget;Yn(c,this.domNode)||(this.focusedItem=void 0,this.updateFocus(),d.stopPropagation())})),this._register(Y(this.actionsList,he.MOUSE_OVER,d=>{let c=d.target;if(!(!c||!Yn(c,this.actionsList)||c===this.actionsList)){for(;c.parentElement!==this.actionsList&&c.parentElement!==null;)c=c.parentElement;if(c.classList.contains("action-item")){const u=this.focusedItem;this.setFocusedItem(c),u!==this.focusedItem&&this.updateFocus()}}})),this._register(Xt.addTarget(this.actionsList)),this._register(Y(this.actionsList,Qt.Tap,d=>{let c=d.initialTarget;if(!(!c||!Yn(c,this.actionsList)||c===this.actionsList)){for(;c.parentElement!==this.actionsList&&c.parentElement!==null;)c=c.parentElement;if(c.classList.contains("action-item")){const u=this.focusedItem;this.setFocusedItem(c),u!==this.focusedItem&&this.updateFocus()}}}));const r={parent:this};this.mnemonics=new Map,this.scrollableElement=this._register(new hC(o,{alwaysConsumeMouseWheel:!0,horizontal:2,vertical:3,verticalScrollbarSize:7,handleMouseWheel:!0,useShadows:!0}));const a=this.scrollableElement.getDomNode();a.style.position="",this.styleScrollElement(a,n),this._register(Y(o,Qt.Change,d=>{ot.stop(d,!0);const c=this.scrollableElement.getScrollPosition().scrollTop;this.scrollableElement.setScrollPosition({scrollTop:c-d.translationY})})),this._register(Y(a,he.MOUSE_UP,d=>{d.preventDefault()}));const l=Xe(e);o.style.maxHeight=`${Math.max(10,l.innerHeight-e.getBoundingClientRect().top-35)}px`,t=t.filter(d=>{var c;return!((c=i.submenuIds)===null||c===void 0)&&c.has(d.id)?(console.warn(`Found submenu cycle: ${d.id}`),!1):!0}),this.push(t,{icon:!0,label:!0,isMenu:!0}),e.appendChild(this.scrollableElement.getDomNode()),this.scrollableElement.scanDomNode(),this.viewItems.filter(d=>!(d instanceof u9)).forEach((d,c,u)=>{d.updatePositionInSet(c+1,u.length)})}initializeOrUpdateStyleSheet(e,t){this.styleSheet||(FS(e)?this.styleSheet=Lr(e):(Xp.globalStyleSheet||(Xp.globalStyleSheet=Lr()),this.styleSheet=Xp.globalStyleSheet)),this.styleSheet.textContent=Gge(t,FS(e))}styleScrollElement(e,t){var i,n;const o=(i=t.foregroundColor)!==null&&i!==void 0?i:"",r=(n=t.backgroundColor)!==null&&n!==void 0?n:"",a=t.borderColor?`1px solid ${t.borderColor}`:"",l="5px",d=t.shadowColor?`0 2px 8px ${t.shadowColor}`:"";e.style.outline=a,e.style.borderRadius=l,e.style.color=o,e.style.backgroundColor=r,e.style.boxShadow=d}getContainer(){return this.scrollableElement.getDomNode()}get onScroll(){return this.scrollableElement.onScroll}focusItemByElement(e){const t=this.focusedItem;this.setFocusedItem(e),t!==this.focusedItem&&this.updateFocus()}setFocusedItem(e){for(let t=0;t<this.actionsList.children.length;t++){const i=this.actionsList.children[t];if(e===i){this.focusedItem=t;break}}}updateFocus(e){super.updateFocus(e,!0,!0),typeof this.focusedItem<"u"&&this.scrollableElement.setScrollPosition({scrollTop:Math.round(this.menuElement.scrollTop)})}doGetActionViewItem(e,t,i){if(e instanceof In)return new u9(t.context,e,{icon:!0},this.menuStyles);if(e instanceof cm){const n=new c9(e,e.actions,i,{...t,submenuIds:new Set([...t.submenuIds||[],e.id])},this.menuStyles);if(t.enableMnemonics){const o=n.getMnemonic();if(o&&n.isEnabled()){let r=[];this.mnemonics.has(o)&&(r=this.mnemonics.get(o)),r.push(n),this.mnemonics.set(o,r)}}return n}else{const n={enableMnemonics:t.enableMnemonics,useEventAsContext:t.useEventAsContext};if(t.getKeyBinding){const r=t.getKeyBinding(e);if(r){const a=r.getLabel();a&&(n.keybinding=a)}}const o=new Jz(t.context,e,n,this.menuStyles);if(t.enableMnemonics){const r=o.getMnemonic();if(r&&o.isEnabled()){let a=[];this.mnemonics.has(r)&&(a=this.mnemonics.get(r)),a.push(o),this.mnemonics.set(r,a)}}return o}}}class Jz extends wa{constructor(e,t,i,n){if(i.isMenu=!0,super(t,t,i),this.menuStyle=n,this.options=i,this.options.icon=i.icon!==void 0?i.icon:!1,this.options.label=i.label!==void 0?i.label:!0,this.cssClass="",this.options.label&&i.enableMnemonics){const o=this.action.label;if(o){const r=p2.exec(o);r&&(this.mnemonic=(r[1]?r[1]:r[3]).toLocaleLowerCase())}}this.runOnceToEnableMouseUp=new jt(()=>{this.element&&(this._register(Y(this.element,he.MOUSE_UP,o=>{if(ot.stop(o,!0),yr){if(new zr(Xe(this.element),o).rightButton)return;this.onClick(o)}else setTimeout(()=>{this.onClick(o)},0)})),this._register(Y(this.element,he.CONTEXT_MENU,o=>{ot.stop(o,!0)})))},100),this._register(this.runOnceToEnableMouseUp)}render(e){super.render(e),this.element&&(this.container=e,this.item=te(this.element,se("a.action-menu-item")),this._action.id===In.ID?this.item.setAttribute("role","presentation"):(this.item.setAttribute("role","menuitem"),this.mnemonic&&this.item.setAttribute("aria-keyshortcuts",`${this.mnemonic}`)),this.check=te(this.item,se("span.menu-item-check"+Oe.asCSSSelector(le.menuSelection))),this.check.setAttribute("role","none"),this.label=te(this.item,se("span.action-label")),this.options.label&&this.options.keybinding&&(te(this.item,se("span.keybinding")).textContent=this.options.keybinding),this.runOnceToEnableMouseUp.schedule(),this.updateClass(),this.updateLabel(),this.updateTooltip(),this.updateEnabled(),this.updateChecked(),this.applyStyle())}blur(){super.blur(),this.applyStyle()}focus(){var e;super.focus(),(e=this.item)===null||e===void 0||e.focus(),this.applyStyle()}updatePositionInSet(e,t){this.item&&(this.item.setAttribute("aria-posinset",`${e}`),this.item.setAttribute("aria-setsize",`${t}`))}updateLabel(){var e;if(this.label&&this.options.label){Vn(this.label);let t=lO(this.action.label);if(t){const i=qge(t);this.options.enableMnemonics||(t=i),this.label.setAttribute("aria-label",i.replace(/&&/g,"&"));const n=p2.exec(t);if(n){t=MS(t),HI.lastIndex=0;let o=HI.exec(t);for(;o&&o[1];)o=HI.exec(t);const r=a=>a.replace(/&amp;&amp;/g,"&amp;");o?this.label.append(iC(r(t.substr(0,o.index))," "),se("u",{"aria-hidden":"true"},o[3]),HW(r(t.substr(o.index+o[0].length))," ")):this.label.innerText=r(t).trim(),(e=this.item)===null||e===void 0||e.setAttribute("aria-keyshortcuts",(n[1]?n[1]:n[3]).toLocaleLowerCase())}else this.label.innerText=t.replace(/&&/g,"&").trim()}}}updateTooltip(){}updateClass(){this.cssClass&&this.item&&this.item.classList.remove(...this.cssClass.split(" ")),this.options.icon&&this.label?(this.cssClass=this.action.class||"",this.label.classList.add("icon"),this.cssClass&&this.label.classList.add(...this.cssClass.split(" ")),this.updateEnabled()):this.label&&this.label.classList.remove("icon")}updateEnabled(){this.action.enabled?(this.element&&(this.element.classList.remove("disabled"),this.element.removeAttribute("aria-disabled")),this.item&&(this.item.classList.remove("disabled"),this.item.removeAttribute("aria-disabled"),this.item.tabIndex=0)):(this.element&&(this.element.classList.add("disabled"),this.element.setAttribute("aria-disabled","true")),this.item&&(this.item.classList.add("disabled"),this.item.setAttribute("aria-disabled","true")))}updateChecked(){if(!this.item)return;const e=this.action.checked;this.item.classList.toggle("checked",!!e),e!==void 0?(this.item.setAttribute("role","menuitemcheckbox"),this.item.setAttribute("aria-checked",e?"true":"false")):(this.item.setAttribute("role","menuitem"),this.item.setAttribute("aria-checked",""))}getMnemonic(){return this.mnemonic}applyStyle(){const e=this.element&&this.element.classList.contains("focused"),t=e&&this.menuStyle.selectionForegroundColor?this.menuStyle.selectionForegroundColor:this.menuStyle.foregroundColor,i=e&&this.menuStyle.selectionBackgroundColor?this.menuStyle.selectionBackgroundColor:void 0,n=e&&this.menuStyle.selectionBorderColor?`1px solid ${this.menuStyle.selectionBorderColor}`:"",o=e&&this.menuStyle.selectionBorderColor?"-1px":"";this.item&&(this.item.style.color=t??"",this.item.style.backgroundColor=i??"",this.item.style.outline=n,this.item.style.outlineOffset=o),this.check&&(this.check.style.color=t??"")}}class c9 extends Jz{constructor(e,t,i,n,o){super(e,e,n,o),this.submenuActions=t,this.parentData=i,this.submenuOptions=n,this.mysubmenu=null,this.submenuDisposables=this._register(new ie),this.mouseOver=!1,this.expandDirection=n&&n.expandDirection!==void 0?n.expandDirection:ky.Right,this.showScheduler=new jt(()=>{this.mouseOver&&(this.cleanupExistingSubmenu(!1),this.createSubmenu(!1))},250),this.hideScheduler=new jt(()=>{this.element&&!Yn(Jo(),this.element)&&this.parentData.submenu===this.mysubmenu&&(this.parentData.parent.focus(!1),this.cleanupExistingSubmenu(!0))},750)}render(e){super.render(e),this.element&&(this.item&&(this.item.classList.add("monaco-submenu-item"),this.item.tabIndex=0,this.item.setAttribute("aria-haspopup","true"),this.updateAriaExpanded("false"),this.submenuIndicator=te(this.item,se("span.submenu-indicator"+Oe.asCSSSelector(le.menuSubmenu))),this.submenuIndicator.setAttribute("aria-hidden","true")),this._register(Y(this.element,he.KEY_UP,t=>{const i=new ri(t);(i.equals(17)||i.equals(3))&&(ot.stop(t,!0),this.createSubmenu(!0))})),this._register(Y(this.element,he.KEY_DOWN,t=>{const i=new ri(t);Jo()===this.item&&(i.equals(17)||i.equals(3))&&ot.stop(t,!0)})),this._register(Y(this.element,he.MOUSE_OVER,t=>{this.mouseOver||(this.mouseOver=!0,this.showScheduler.schedule())})),this._register(Y(this.element,he.MOUSE_LEAVE,t=>{this.mouseOver=!1})),this._register(Y(this.element,he.FOCUS_OUT,t=>{this.element&&!Yn(Jo(),this.element)&&this.hideScheduler.schedule()})),this._register(this.parentData.parent.onScroll(()=>{this.parentData.submenu===this.mysubmenu&&(this.parentData.parent.focus(!1),this.cleanupExistingSubmenu(!0))})))}updateEnabled(){}onClick(e){ot.stop(e,!0),this.cleanupExistingSubmenu(!1),this.createSubmenu(!0)}cleanupExistingSubmenu(e){if(this.parentData.submenu&&(e||this.parentData.submenu!==this.mysubmenu)){try{this.parentData.submenu.dispose()}catch{}this.parentData.submenu=void 0,this.updateAriaExpanded("false"),this.submenuContainer&&(this.submenuDisposables.clear(),this.submenuContainer=void 0)}}calculateSubmenuMenuLayout(e,t,i,n){const o={top:0,left:0};return o.left=vp(e.width,t.width,{position:n===ky.Right?0:1,offset:i.left,size:i.width}),o.left>=i.left&&o.left<i.left+i.width&&(i.left+10+t.width<=e.width&&(o.left=i.left+10),i.top+=10,i.height=0),o.top=vp(e.height,t.height,{position:0,offset:i.top,size:0}),o.top+t.height===i.top&&o.top+i.height+t.height<=e.height&&(o.top+=i.height),o}createSubmenu(e=!0){if(this.element)if(this.parentData.submenu)this.parentData.submenu.focus(!1);else{this.updateAriaExpanded("true"),this.submenuContainer=te(this.element,se("div.monaco-submenu")),this.submenuContainer.classList.add("menubar-menu-items-holder","context-view");const t=Xe(this.parentData.parent.domNode).getComputedStyle(this.parentData.parent.domNode),i=parseFloat(t.paddingTop||"0")||0;this.submenuContainer.style.zIndex="1",this.submenuContainer.style.position="fixed",this.submenuContainer.style.top="0",this.submenuContainer.style.left="0",this.parentData.submenu=new Xp(this.submenuContainer,this.submenuActions.length?this.submenuActions:[new GL],this.submenuOptions,this.menuStyle);const n=this.element.getBoundingClientRect(),o={top:n.top-i,left:n.left,height:n.height+2*i,width:n.width},r=this.submenuContainer.getBoundingClientRect(),a=Xe(this.element),{top:l,left:d}=this.calculateSubmenuMenuLayout(new Dt(a.innerWidth,a.innerHeight),Dt.lift(r),o,this.expandDirection);this.submenuContainer.style.left=`${d-r.left}px`,this.submenuContainer.style.top=`${l-r.top}px`,this.submenuDisposables.add(Y(this.submenuContainer,he.KEY_UP,c=>{new ri(c).equals(15)&&(ot.stop(c,!0),this.parentData.parent.focus(),this.cleanupExistingSubmenu(!0))})),this.submenuDisposables.add(Y(this.submenuContainer,he.KEY_DOWN,c=>{new ri(c).equals(15)&&ot.stop(c,!0)})),this.submenuDisposables.add(this.parentData.submenu.onDidCancel(()=>{this.parentData.parent.focus(),this.cleanupExistingSubmenu(!0)})),this.parentData.submenu.focus(e),this.mysubmenu=this.parentData.submenu}}updateAriaExpanded(e){var t;this.item&&((t=this.item)===null||t===void 0||t.setAttribute("aria-expanded",e))}applyStyle(){super.applyStyle();const t=this.element&&this.element.classList.contains("focused")&&this.menuStyle.selectionForegroundColor?this.menuStyle.selectionForegroundColor:this.menuStyle.foregroundColor;this.submenuIndicator&&(this.submenuIndicator.style.color=t??"")}dispose(){super.dispose(),this.hideScheduler.dispose(),this.mysubmenu&&(this.mysubmenu.dispose(),this.mysubmenu=null),this.submenuContainer&&(this.submenuContainer=void 0)}}class u9 extends Em{constructor(e,t,i,n){super(e,t,i),this.menuStyles=n}render(e){super.render(e),this.label&&(this.label.style.borderBottomColor=this.menuStyles.separatorColor?`${this.menuStyles.separatorColor}`:"")}}function qge(s){const e=p2,t=e.exec(s);if(!t)return s;const i=!t[1];return s.replace(e,i?"$2$3":"").trim()}function h9(s){const e=FW()[s.id];return`.codicon-${s.id}:before { content: '\\${e.toString(16)}'; }`}function Gge(s,e){let t=`
.monaco-menu {
	font-size: 13px;
	border-radius: 5px;
	min-width: 160px;
}

${h9(le.menuSelection)}
${h9(le.menuSubmenu)}

.monaco-menu .monaco-action-bar {
	text-align: right;
	overflow: hidden;
	white-space: nowrap;
}

.monaco-menu .monaco-action-bar .actions-container {
	display: flex;
	margin: 0 auto;
	padding: 0;
	width: 100%;
	justify-content: flex-end;
}

.monaco-menu .monaco-action-bar.vertical .actions-container {
	display: inline-block;
}

.monaco-menu .monaco-action-bar.reverse .actions-container {
	flex-direction: row-reverse;
}

.monaco-menu .monaco-action-bar .action-item {
	cursor: pointer;
	display: inline-block;
	transition: transform 50ms ease;
	position: relative;  /* DO NOT REMOVE - this is the key to preventing the ghosting icon bug in Chrome 42 */
}

.monaco-menu .monaco-action-bar .action-item.disabled {
	cursor: default;
}

.monaco-menu .monaco-action-bar.animated .action-item.active {
	transform: scale(1.272019649, 1.272019649); /* 1.272019649 = √φ */
}

.monaco-menu .monaco-action-bar .action-item .icon,
.monaco-menu .monaco-action-bar .action-item .codicon {
	display: inline-block;
}

.monaco-menu .monaco-action-bar .action-item .codicon {
	display: flex;
	align-items: center;
}

.monaco-menu .monaco-action-bar .action-label {
	font-size: 11px;
	margin-right: 4px;
}

.monaco-menu .monaco-action-bar .action-item.disabled .action-label,
.monaco-menu .monaco-action-bar .action-item.disabled .action-label:hover {
	color: var(--vscode-disabledForeground);
}

/* Vertical actions */

.monaco-menu .monaco-action-bar.vertical {
	text-align: left;
}

.monaco-menu .monaco-action-bar.vertical .action-item {
	display: block;
}

.monaco-menu .monaco-action-bar.vertical .action-label.separator {
	display: block;
	border-bottom: 1px solid var(--vscode-menu-separatorBackground);
	padding-top: 1px;
	padding: 30px;
}

.monaco-menu .secondary-actions .monaco-action-bar .action-label {
	margin-left: 6px;
}

/* Action Items */
.monaco-menu .monaco-action-bar .action-item.select-container {
	overflow: hidden; /* somehow the dropdown overflows its container, we prevent it here to not push */
	flex: 1;
	max-width: 170px;
	min-width: 60px;
	display: flex;
	align-items: center;
	justify-content: center;
	margin-right: 10px;
}

.monaco-menu .monaco-action-bar.vertical {
	margin-left: 0;
	overflow: visible;
}

.monaco-menu .monaco-action-bar.vertical .actions-container {
	display: block;
}

.monaco-menu .monaco-action-bar.vertical .action-item {
	padding: 0;
	transform: none;
	display: flex;
}

.monaco-menu .monaco-action-bar.vertical .action-item.active {
	transform: none;
}

.monaco-menu .monaco-action-bar.vertical .action-menu-item {
	flex: 1 1 auto;
	display: flex;
	height: 2em;
	align-items: center;
	position: relative;
	margin: 0 4px;
	border-radius: 4px;
}

.monaco-menu .monaco-action-bar.vertical .action-menu-item:hover .keybinding,
.monaco-menu .monaco-action-bar.vertical .action-menu-item:focus .keybinding {
	opacity: unset;
}

.monaco-menu .monaco-action-bar.vertical .action-label {
	flex: 1 1 auto;
	text-decoration: none;
	padding: 0 1em;
	background: none;
	font-size: 12px;
	line-height: 1;
}

.monaco-menu .monaco-action-bar.vertical .keybinding,
.monaco-menu .monaco-action-bar.vertical .submenu-indicator {
	display: inline-block;
	flex: 2 1 auto;
	padding: 0 1em;
	text-align: right;
	font-size: 12px;
	line-height: 1;
}

.monaco-menu .monaco-action-bar.vertical .submenu-indicator {
	height: 100%;
}

.monaco-menu .monaco-action-bar.vertical .submenu-indicator.codicon {
	font-size: 16px !important;
	display: flex;
	align-items: center;
}

.monaco-menu .monaco-action-bar.vertical .submenu-indicator.codicon::before {
	margin-left: auto;
	margin-right: -20px;
}

.monaco-menu .monaco-action-bar.vertical .action-item.disabled .keybinding,
.monaco-menu .monaco-action-bar.vertical .action-item.disabled .submenu-indicator {
	opacity: 0.4;
}

.monaco-menu .monaco-action-bar.vertical .action-label:not(.separator) {
	display: inline-block;
	box-sizing: border-box;
	margin: 0;
}

.monaco-menu .monaco-action-bar.vertical .action-item {
	position: static;
	overflow: visible;
}

.monaco-menu .monaco-action-bar.vertical .action-item .monaco-submenu {
	position: absolute;
}

.monaco-menu .monaco-action-bar.vertical .action-label.separator {
	width: 100%;
	height: 0px !important;
	opacity: 1;
}

.monaco-menu .monaco-action-bar.vertical .action-label.separator.text {
	padding: 0.7em 1em 0.1em 1em;
	font-weight: bold;
	opacity: 1;
}

.monaco-menu .monaco-action-bar.vertical .action-label:hover {
	color: inherit;
}

.monaco-menu .monaco-action-bar.vertical .menu-item-check {
	position: absolute;
	visibility: hidden;
	width: 1em;
	height: 100%;
}

.monaco-menu .monaco-action-bar.vertical .action-menu-item.checked .menu-item-check {
	visibility: visible;
	display: flex;
	align-items: center;
	justify-content: center;
}

/* Context Menu */

.context-view.monaco-menu-container {
	outline: 0;
	border: none;
	animation: fadeIn 0.083s linear;
	-webkit-app-region: no-drag;
}

.context-view.monaco-menu-container :focus,
.context-view.monaco-menu-container .monaco-action-bar.vertical:focus,
.context-view.monaco-menu-container .monaco-action-bar.vertical :focus {
	outline: 0;
}

.hc-black .context-view.monaco-menu-container,
.hc-light .context-view.monaco-menu-container,
:host-context(.hc-black) .context-view.monaco-menu-container,
:host-context(.hc-light) .context-view.monaco-menu-container {
	box-shadow: none;
}

.hc-black .monaco-menu .monaco-action-bar.vertical .action-item.focused,
.hc-light .monaco-menu .monaco-action-bar.vertical .action-item.focused,
:host-context(.hc-black) .monaco-menu .monaco-action-bar.vertical .action-item.focused,
:host-context(.hc-light) .monaco-menu .monaco-action-bar.vertical .action-item.focused {
	background: none;
}

/* Vertical Action Bar Styles */

.monaco-menu .monaco-action-bar.vertical {
	padding: 4px 0;
}

.monaco-menu .monaco-action-bar.vertical .action-menu-item {
	height: 2em;
}

.monaco-menu .monaco-action-bar.vertical .action-label:not(.separator),
.monaco-menu .monaco-action-bar.vertical .keybinding {
	font-size: inherit;
	padding: 0 2em;
}

.monaco-menu .monaco-action-bar.vertical .menu-item-check {
	font-size: inherit;
	width: 2em;
}

.monaco-menu .monaco-action-bar.vertical .action-label.separator {
	font-size: inherit;
	margin: 5px 0 !important;
	padding: 0;
	border-radius: 0;
}

.linux .monaco-menu .monaco-action-bar.vertical .action-label.separator,
:host-context(.linux) .monaco-menu .monaco-action-bar.vertical .action-label.separator {
	margin-left: 0;
	margin-right: 0;
}

.monaco-menu .monaco-action-bar.vertical .submenu-indicator {
	font-size: 60%;
	padding: 0 1.8em;
}

.linux .monaco-menu .monaco-action-bar.vertical .submenu-indicator,
:host-context(.linux) .monaco-menu .monaco-action-bar.vertical .submenu-indicator {
	height: 100%;
	mask-size: 10px 10px;
	-webkit-mask-size: 10px 10px;
}

.monaco-menu .action-item {
	cursor: default;
}`;if(e){t+=`
			/* Arrows */
			.monaco-scrollable-element > .scrollbar > .scra {
				cursor: pointer;
				font-size: 11px !important;
			}

			.monaco-scrollable-element > .visible {
				opacity: 1;

				/* Background rule added for IE9 - to allow clicks on dom node */
				background:rgba(0,0,0,0);

				transition: opacity 100ms linear;
			}
			.monaco-scrollable-element > .invisible {
				opacity: 0;
				pointer-events: none;
			}
			.monaco-scrollable-element > .invisible.fade {
				transition: opacity 800ms linear;
			}

			/* Scrollable Content Inset Shadow */
			.monaco-scrollable-element > .shadow {
				position: absolute;
				display: none;
			}
			.monaco-scrollable-element > .shadow.top {
				display: block;
				top: 0;
				left: 3px;
				height: 3px;
				width: 100%;
			}
			.monaco-scrollable-element > .shadow.left {
				display: block;
				top: 3px;
				left: 0;
				height: 100%;
				width: 3px;
			}
			.monaco-scrollable-element > .shadow.top-left-corner {
				display: block;
				top: 0;
				left: 0;
				height: 3px;
				width: 3px;
			}
		`;const i=s.scrollbarShadow;i&&(t+=`
				.monaco-scrollable-element > .shadow.top {
					box-shadow: ${i} 0 6px 6px -6px inset;
				}

				.monaco-scrollable-element > .shadow.left {
					box-shadow: ${i} 6px 0 6px -6px inset;
				}

				.monaco-scrollable-element > .shadow.top.left {
					box-shadow: ${i} 6px 6px 6px -6px inset;
				}
			`);const n=s.scrollbarSliderBackground;n&&(t+=`
				.monaco-scrollable-element > .scrollbar > .slider {
					background: ${n};
				}
			`);const o=s.scrollbarSliderHoverBackground;o&&(t+=`
				.monaco-scrollable-element > .scrollbar > .slider:hover {
					background: ${o};
				}
			`);const r=s.scrollbarSliderActiveBackground;r&&(t+=`
				.monaco-scrollable-element > .scrollbar > .slider.active {
					background: ${r};
				}
			`)}return t}class Zge{constructor(e,t,i,n){this.contextViewService=e,this.telemetryService=t,this.notificationService=i,this.keybindingService=n,this.focusToReturn=null,this.lastContainer=null,this.block=null,this.blockDisposable=null,this.options={blockMouse:!0}}configure(e){this.options=e}showContextMenu(e){const t=e.getActions();if(!t.length)return;this.focusToReturn=Jo();let i;const n=e.domForShadowRoot instanceof HTMLElement?e.domForShadowRoot:void 0;this.contextViewService.showContextView({getAnchor:()=>e.getAnchor(),canRelayout:!1,anchorAlignment:e.anchorAlignment,anchorAxisAlignment:e.anchorAxisAlignment,render:o=>{var r;this.lastContainer=o;const a=e.getMenuClassName?e.getMenuClassName():"";a&&(o.className+=" "+a),this.options.blockMouse&&(this.block=o.appendChild(se(".context-view-block")),this.block.style.position="fixed",this.block.style.cursor="initial",this.block.style.left="0",this.block.style.top="0",this.block.style.width="100%",this.block.style.height="100%",this.block.style.zIndex="-1",(r=this.blockDisposable)===null||r===void 0||r.dispose(),this.blockDisposable=Y(this.block,he.MOUSE_DOWN,u=>u.stopPropagation()));const l=new ie,d=e.actionRunner||new Eg;d.onWillRun(u=>this.onActionRun(u,!e.skipTelemetry),this,l),d.onDidRun(this.onDidActionRun,this,l),i=new Xp(o,t,{actionViewItemProvider:e.getActionViewItem,context:e.getActionsContext?e.getActionsContext():null,actionRunner:d,getKeyBinding:e.getKeyBinding?e.getKeyBinding:u=>this.keybindingService.lookupKeybinding(u.id)},$ge),i.onDidCancel(()=>this.contextViewService.hideContextView(!0),null,l),i.onDidBlur(()=>this.contextViewService.hideContextView(!0),null,l);const c=Xe(o);return l.add(Y(c,he.BLUR,()=>this.contextViewService.hideContextView(!0))),l.add(Y(c,he.MOUSE_DOWN,u=>{if(u.defaultPrevented)return;const h=new zr(c,u);let g=h.target;if(!h.rightButton){for(;g;){if(g===o)return;g=g.parentElement}this.contextViewService.hideContextView(!0)}})),Gr(l,i)},focus:()=>{i==null||i.focus(!!e.autoSelectFirstItem)},onHide:o=>{var r,a,l;(r=e.onHide)===null||r===void 0||r.call(e,!!o),this.block&&(this.block.remove(),this.block=null),(a=this.blockDisposable)===null||a===void 0||a.dispose(),this.blockDisposable=null,this.lastContainer&&(Jo()===this.lastContainer||Yn(Jo(),this.lastContainer))&&((l=this.focusToReturn)===null||l===void 0||l.focus()),this.lastContainer=null}},n,!!n)}onActionRun(e,t){t&&this.telemetryService.publicLog2("workbenchActionExecuted",{id:e.action.id,from:"contextMenu"}),this.contextViewService.hideContextView(!1)}onDidActionRun(e){e.error&&!Ka(e.error)&&this.notificationService.error(e.error)}}var Yge=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Rf=function(s,e){return function(t,i){e(t,i,s)}};let m2=class extends j{get contextMenuHandler(){return this._contextMenuHandler||(this._contextMenuHandler=new Zge(this.contextViewService,this.telemetryService,this.notificationService,this.keybindingService)),this._contextMenuHandler}constructor(e,t,i,n,o,r){super(),this.telemetryService=e,this.notificationService=t,this.contextViewService=i,this.keybindingService=n,this.menuService=o,this.contextKeyService=r,this._contextMenuHandler=void 0,this._onDidShowContextMenu=this._store.add(new W),this._onDidHideContextMenu=this._store.add(new W)}configure(e){this.contextMenuHandler.configure(e)}showContextMenu(e){e=_2.transform(e,this.menuService,this.contextKeyService),this.contextMenuHandler.showContextMenu({...e,onHide:t=>{var i;(i=e.onHide)===null||i===void 0||i.call(e,t),this._onDidHideContextMenu.fire()}}),Pd.getInstance().resetKeyStatus(),this._onDidShowContextMenu.fire()}};m2=Yge([Rf(0,Do),Rf(1,Qi),Rf(2,rc),Rf(3,qt),Rf(4,qa),Rf(5,je)],m2);var _2;(function(s){function e(i){return i&&i.menuId instanceof N}function t(i,n,o){if(!e(i))return i;const{menuId:r,menuActionOptions:a,contextKeyService:l}=i;return{...i,getActions:()=>{const d=[];if(r){const c=n.createMenu(r,l??o);jge(c,a,d),c.dispose()}return i.getActions?In.join(i.getActions(),d):d}}}s.transform=t})(_2||(_2={}));var Iy;(function(s){s[s.API=0]="API",s[s.USER=1]="USER"})(Iy||(Iy={}));const No=ut("openerService");function Xge(s){let e;const t=/^L?(\d+)(?:,(\d+))?(-L?(\d+)(?:,(\d+))?)?/.exec(s.fragment);return t&&(e={startLineNumber:parseInt(t[1]),startColumn:t[2]?parseInt(t[2]):1,endLineNumber:t[4]?parseInt(t[4]):void 0,endColumn:t[4]?t[5]?parseInt(t[5]):1:void 0},s=s.with({fragment:""})),{selection:e,uri:s}}var gO=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Ey=function(s,e){return function(t,i){e(t,i,s)}};let v2=class{constructor(e){this._commandService=e}async open(e,t){if(!YA(e,it.command))return!1;if(!(t!=null&&t.allowCommands)||(typeof e=="string"&&(e=Pe.parse(e)),Array.isArray(t.allowCommands)&&!t.allowCommands.includes(e.path)))return!0;let i=[];try{i=a2(decodeURIComponent(e.query))}catch{try{i=a2(e.query)}catch{}}return Array.isArray(i)||(i=[i]),await this._commandService.executeCommand(e.path,...i),!0}};v2=gO([Ey(0,Ei)],v2);let b2=class{constructor(e){this._editorService=e}async open(e,t){typeof e=="string"&&(e=Pe.parse(e));const{selection:i,uri:n}=Xge(e);return e=n,e.scheme===it.file&&(e=Fle(e)),await this._editorService.openCodeEditor({resource:e,options:{selection:i,source:t!=null&&t.fromUserGesture?Iy.USER:Iy.API,...t==null?void 0:t.editorOptions}},this._editorService.getFocusedCodeEditor(),t==null?void 0:t.openToSide),!0}};b2=gO([Ey(0,It)],b2);let C2=class{constructor(e,t){this._openers=new Ms,this._validators=new Ms,this._resolvers=new Ms,this._resolvedUriTargets=new zi(i=>i.with({path:null,fragment:null,query:null}).toString()),this._externalOpeners=new Ms,this._defaultExternalOpener={openExternal:async i=>(S5(i,it.http,it.https)?xV(i):Ci.location.href=i,!0)},this._openers.push({open:async(i,n)=>n!=null&&n.openExternal||S5(i,it.mailto,it.http,it.https,it.vsls)?(await this._doOpenExternal(i,n),!0):!1}),this._openers.push(new v2(t)),this._openers.push(new b2(e))}registerOpener(e){return{dispose:this._openers.unshift(e)}}async open(e,t){var i;const n=typeof e=="string"?Pe.parse(e):e,o=(i=this._resolvedUriTargets.get(n))!==null&&i!==void 0?i:e;for(const r of this._validators)if(!await r.shouldOpen(o,t))return!1;for(const r of this._openers)if(await r.open(e,t))return!0;return!1}async resolveExternalUri(e,t){for(const i of this._resolvers)try{const n=await i.resolveExternalUri(e,t);if(n)return this._resolvedUriTargets.has(n.resolved)||this._resolvedUriTargets.set(n.resolved,e),n}catch{}throw new Error("Could not resolve external URI: "+e.toString())}async _doOpenExternal(e,t){const i=typeof e=="string"?Pe.parse(e):e;let n;try{n=(await this.resolveExternalUri(i,t)).resolved}catch{n=i}let o;if(typeof e=="string"&&i.toString()===n.toString()?o=e:o=encodeURI(n.toString(!0)),t!=null&&t.allowContributedOpeners){const r=typeof(t==null?void 0:t.allowContributedOpeners)=="string"?t==null?void 0:t.allowContributedOpeners:void 0;for(const a of this._externalOpeners)if(await a.openExternal(o,{sourceUri:i,preferredOpenerId:r},ct.None))return!0}return this._defaultExternalOpener.openExternal(o,{sourceUri:i},ct.None)}dispose(){this._validators.clear()}};C2=gO([Ey(0,It),Ey(1,Ei)],C2);const oa=ut("editorWorkerService");var Ii;(function(s){s[s.Hint=1]="Hint",s[s.Info=2]="Info",s[s.Warning=4]="Warning",s[s.Error=8]="Error"})(Ii||(Ii={}));(function(s){function e(r,a){return a-r}s.compare=e;const t=Object.create(null);t[s.Error]=p("sev.error","Error"),t[s.Warning]=p("sev.warning","Warning"),t[s.Info]=p("sev.info","Info");function i(r){return t[r]||""}s.toString=i;function n(r){switch(r){case Wi.Error:return s.Error;case Wi.Warning:return s.Warning;case Wi.Info:return s.Info;case Wi.Ignore:return s.Hint}}s.fromSeverity=n;function o(r){switch(r){case s.Error:return Wi.Error;case s.Warning:return Wi.Warning;case s.Info:return Wi.Info;case s.Hint:return Wi.Ignore}}s.toSeverity=o})(Ii||(Ii={}));var Ny;(function(s){const e="";function t(n){return i(n,!0)}s.makeKey=t;function i(n,o){const r=[e];return n.source?r.push(n.source.replace("¦","\\¦")):r.push(e),n.code?typeof n.code=="string"?r.push(n.code.replace("¦","\\¦")):r.push(n.code.value.replace("¦","\\¦")):r.push(e),n.severity!==void 0&&n.severity!==null?r.push(Ii.toString(n.severity)):r.push(e),n.message&&o?r.push(n.message.replace("¦","\\¦")):r.push(e),n.startLineNumber!==void 0&&n.startLineNumber!==null?r.push(n.startLineNumber.toString()):r.push(e),n.startColumn!==void 0&&n.startColumn!==null?r.push(n.startColumn.toString()):r.push(e),n.endLineNumber!==void 0&&n.endLineNumber!==null?r.push(n.endLineNumber.toString()):r.push(e),n.endColumn!==void 0&&n.endColumn!==null?r.push(n.endColumn.toString()):r.push(e),r.push(e),r.join("¦")}s.makeKeyOptionalMessage=i})(Ny||(Ny={}));const ld=ut("markerService");function Qge(s,e){const t=[],i=[];for(const n of s)e.has(n)||t.push(n);for(const n of e)s.has(n)||i.push(n);return{removed:t,added:i}}function Jge(s,e){const t=new Set;for(const i of e)s.has(i)&&t.add(i);return t}var efe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},g9=function(s,e){return function(t,i){e(t,i,s)}};let w2=class extends j{constructor(e,t){super(),this._markerService=t,this._onDidChangeMarker=this._register(new W),this._markerDecorations=new zi,e.getModels().forEach(i=>this._onModelAdded(i)),this._register(e.onModelAdded(this._onModelAdded,this)),this._register(e.onModelRemoved(this._onModelRemoved,this)),this._register(this._markerService.onMarkerChanged(this._handleMarkerChange,this))}dispose(){super.dispose(),this._markerDecorations.forEach(e=>e.dispose()),this._markerDecorations.clear()}getMarker(e,t){const i=this._markerDecorations.get(e);return i&&i.getMarker(t)||null}_handleMarkerChange(e){e.forEach(t=>{const i=this._markerDecorations.get(t);i&&this._updateDecorations(i)})}_onModelAdded(e){const t=new tfe(e);this._markerDecorations.set(e.uri,t),this._updateDecorations(t)}_onModelRemoved(e){var t;const i=this._markerDecorations.get(e.uri);i&&(i.dispose(),this._markerDecorations.delete(e.uri)),(e.uri.scheme===it.inMemory||e.uri.scheme===it.internal||e.uri.scheme===it.vscode)&&((t=this._markerService)===null||t===void 0||t.read({resource:e.uri}).map(n=>n.owner).forEach(n=>this._markerService.remove(n,[e.uri])))}_updateDecorations(e){const t=this._markerService.read({resource:e.model.uri,take:500});e.update(t)&&this._onDidChangeMarker.fire(e.model)}};w2=efe([g9(0,vi),g9(1,ld)],w2);class tfe extends j{constructor(e){super(),this.model=e,this._map=new Vie,this._register(Fe(()=>{this.model.deltaDecorations([...this._map.values()],[]),this._map.clear()}))}update(e){const{added:t,removed:i}=Qge(new Set(this._map.keys()),new Set(e));if(t.length===0&&i.length===0)return!1;const n=i.map(a=>this._map.get(a)),o=t.map(a=>({range:this._createDecorationRange(this.model,a),options:this._createDecorationOption(a)})),r=this.model.deltaDecorations(n,o);for(const a of i)this._map.delete(a);for(let a=0;a<r.length;a++)this._map.set(t[a],r[a]);return!0}getMarker(e){return this._map.getKey(e.id)}_createDecorationRange(e,t){let i=D.lift(t);if(t.severity===Ii.Hint&&!this._hasMarkerTag(t,1)&&!this._hasMarkerTag(t,2)&&(i=i.setEndPosition(i.startLineNumber,i.startColumn+2)),i=e.validateRange(i),i.isEmpty()){const n=e.getLineLastNonWhitespaceColumn(i.startLineNumber)||e.getLineMaxColumn(i.startLineNumber);if(n===1||i.endColumn>=n)return i;const o=e.getWordAtPosition(i.getStartPosition());o&&(i=new D(i.startLineNumber,o.startColumn,i.endLineNumber,o.endColumn))}else if(t.endColumn===Number.MAX_VALUE&&t.startColumn===1&&i.startLineNumber===i.endLineNumber){const n=e.getLineFirstNonWhitespaceColumn(t.startLineNumber);n<i.endColumn&&(i=new D(i.startLineNumber,n,i.endLineNumber,i.endColumn),t.startColumn=n)}return i}_createDecorationOption(e){let t,i,n,o,r;switch(e.severity){case Ii.Hint:this._hasMarkerTag(e,2)?t=void 0:this._hasMarkerTag(e,1)?t="squiggly-unnecessary":t="squiggly-hint",n=0;break;case Ii.Info:t="squiggly-info",i=Di(Mre),n=10,r={color:Di(_oe),position:bo.Inline};break;case Ii.Warning:t="squiggly-warning",i=Di(Tre),n=20,r={color:Di(voe),position:bo.Inline};break;case Ii.Error:default:t="squiggly-error",i=Di(Nre),n=30,r={color:Di(boe),position:bo.Inline};break}return e.tags&&(e.tags.indexOf(1)!==-1&&(o="squiggly-inline-unnecessary"),e.tags.indexOf(2)!==-1&&(o="squiggly-inline-deprecated")),{description:"marker-decoration",stickiness:1,className:t,showIfCollapsed:!0,overviewRuler:{color:i,position:nr.Right},minimap:r,zIndex:n,inlineClassName:o}}_hasMarkerTag(e,t){return e.tags?e.tags.indexOf(t)>=0:!1}}var ife=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},H_=function(s,e){return function(t,i){e(t,i,s)}},Gf;function Dh(s){return s.toString()}class nfe{constructor(e,t,i){this.model=e,this._modelEventListeners=new ie,this.model=e,this._modelEventListeners.add(e.onWillDispose(()=>t(e))),this._modelEventListeners.add(e.onDidChangeLanguage(n=>i(e,n)))}dispose(){this._modelEventListeners.dispose()}}const sfe=Ss||bt?1:2;class ofe{constructor(e,t,i,n,o,r,a,l){this.uri=e,this.initialUndoRedoSnapshot=t,this.time=i,this.sharesUndoRedoStack=n,this.heapSize=o,this.sha1=r,this.versionId=a,this.alternativeVersionId=l}}let Ty=Gf=class extends j{constructor(e,t,i,n,o){super(),this._configurationService=e,this._resourcePropertiesService=t,this._undoRedoService=i,this._languageService=n,this._languageConfigurationService=o,this._onModelAdded=this._register(new W),this.onModelAdded=this._onModelAdded.event,this._onModelRemoved=this._register(new W),this.onModelRemoved=this._onModelRemoved.event,this._onModelModeChanged=this._register(new W),this.onModelLanguageChanged=this._onModelModeChanged.event,this._modelCreationOptionsByLanguageAndResource=Object.create(null),this._models={},this._disposedModels=new Map,this._disposedModelsHeapSize=0,this._register(this._configurationService.onDidChangeConfiguration(r=>this._updateModelOptions(r))),this._updateModelOptions(void 0)}static _readModelOptions(e,t){var i;let n=os.tabSize;if(e.editor&&typeof e.editor.tabSize<"u"){const g=parseInt(e.editor.tabSize,10);isNaN(g)||(n=g),n<1&&(n=1)}let o="tabSize";if(e.editor&&typeof e.editor.indentSize<"u"&&e.editor.indentSize!=="tabSize"){const g=parseInt(e.editor.indentSize,10);isNaN(g)||(o=Math.max(g,1))}let r=os.insertSpaces;e.editor&&typeof e.editor.insertSpaces<"u"&&(r=e.editor.insertSpaces==="false"?!1:!!e.editor.insertSpaces);let a=sfe;const l=e.eol;l===`\r
`?a=2:l===`
`&&(a=1);let d=os.trimAutoWhitespace;e.editor&&typeof e.editor.trimAutoWhitespace<"u"&&(d=e.editor.trimAutoWhitespace==="false"?!1:!!e.editor.trimAutoWhitespace);let c=os.detectIndentation;e.editor&&typeof e.editor.detectIndentation<"u"&&(c=e.editor.detectIndentation==="false"?!1:!!e.editor.detectIndentation);let u=os.largeFileOptimizations;e.editor&&typeof e.editor.largeFileOptimizations<"u"&&(u=e.editor.largeFileOptimizations==="false"?!1:!!e.editor.largeFileOptimizations);let h=os.bracketPairColorizationOptions;return!((i=e.editor)===null||i===void 0)&&i.bracketPairColorization&&typeof e.editor.bracketPairColorization=="object"&&(h={enabled:!!e.editor.bracketPairColorization.enabled,independentColorPoolPerBracketType:!!e.editor.bracketPairColorization.independentColorPoolPerBracketType}),{isForSimpleWidget:t,tabSize:n,indentSize:o,insertSpaces:r,detectIndentation:c,defaultEOL:a,trimAutoWhitespace:d,largeFileOptimizations:u,bracketPairColorizationOptions:h}}_getEOL(e,t){if(e)return this._resourcePropertiesService.getEOL(e,t);const i=this._configurationService.getValue("files.eol",{overrideIdentifier:t});return i&&typeof i=="string"&&i!=="auto"?i:Go===3||Go===2?`
`:`\r
`}_shouldRestoreUndoStack(){const e=this._configurationService.getValue("files.restoreUndoStack");return typeof e=="boolean"?e:!0}getCreationOptions(e,t,i){const n=typeof e=="string"?e:e.languageId;let o=this._modelCreationOptionsByLanguageAndResource[n+t];if(!o){const r=this._configurationService.getValue("editor",{overrideIdentifier:n,resource:t}),a=this._getEOL(t,n);o=Gf._readModelOptions({editor:r,eol:a},i),this._modelCreationOptionsByLanguageAndResource[n+t]=o}return o}_updateModelOptions(e){const t=this._modelCreationOptionsByLanguageAndResource;this._modelCreationOptionsByLanguageAndResource=Object.create(null);const i=Object.keys(this._models);for(let n=0,o=i.length;n<o;n++){const r=i[n],a=this._models[r],l=a.model.getLanguageId(),d=a.model.uri;if(e&&!e.affectsConfiguration("editor",{overrideIdentifier:l,resource:d})&&!e.affectsConfiguration("files.eol",{overrideIdentifier:l,resource:d}))continue;const c=t[l+d],u=this.getCreationOptions(l,d,a.model.isForSimpleWidget);Gf._setModelOptionsForModel(a.model,u,c)}}static _setModelOptionsForModel(e,t,i){i&&i.defaultEOL!==t.defaultEOL&&e.getLineCount()===1&&e.setEOL(t.defaultEOL===1?0:1),!(i&&i.detectIndentation===t.detectIndentation&&i.insertSpaces===t.insertSpaces&&i.tabSize===t.tabSize&&i.indentSize===t.indentSize&&i.trimAutoWhitespace===t.trimAutoWhitespace&&Qo(i.bracketPairColorizationOptions,t.bracketPairColorizationOptions))&&(t.detectIndentation?(e.detectIndentation(t.insertSpaces,t.tabSize),e.updateOptions({trimAutoWhitespace:t.trimAutoWhitespace,bracketColorizationOptions:t.bracketPairColorizationOptions})):e.updateOptions({insertSpaces:t.insertSpaces,tabSize:t.tabSize,indentSize:t.indentSize,trimAutoWhitespace:t.trimAutoWhitespace,bracketColorizationOptions:t.bracketPairColorizationOptions}))}_insertDisposedModel(e){this._disposedModels.set(Dh(e.uri),e),this._disposedModelsHeapSize+=e.heapSize}_removeDisposedModel(e){const t=this._disposedModels.get(Dh(e));return t&&(this._disposedModelsHeapSize-=t.heapSize),this._disposedModels.delete(Dh(e)),t}_ensureDisposedModelsHeapSize(e){if(this._disposedModelsHeapSize>e){const t=[];for(this._disposedModels.forEach(i=>{i.sharesUndoRedoStack||t.push(i)}),t.sort((i,n)=>i.time-n.time);t.length>0&&this._disposedModelsHeapSize>e;){const i=t.shift();this._removeDisposedModel(i.uri),i.initialUndoRedoSnapshot!==null&&this._undoRedoService.restoreSnapshot(i.initialUndoRedoSnapshot)}}}_createModelData(e,t,i,n){const o=this.getCreationOptions(t,i,n),r=new Xl(e,t,o,i,this._undoRedoService,this._languageService,this._languageConfigurationService);if(i&&this._disposedModels.has(Dh(i))){const d=this._removeDisposedModel(i),c=this._undoRedoService.getElements(i),u=this._getSHA1Computer(),h=u.canComputeSHA1(r)?u.computeSHA1(r)===d.sha1:!1;if(h||d.sharesUndoRedoStack){for(const g of c.past)xd(g)&&g.matchesResource(i)&&g.setModel(r);for(const g of c.future)xd(g)&&g.matchesResource(i)&&g.setModel(r);this._undoRedoService.setElementsValidFlag(i,!0,g=>xd(g)&&g.matchesResource(i)),h&&(r._overwriteVersionId(d.versionId),r._overwriteAlternativeVersionId(d.alternativeVersionId),r._overwriteInitialUndoRedoSnapshot(d.initialUndoRedoSnapshot))}else d.initialUndoRedoSnapshot!==null&&this._undoRedoService.restoreSnapshot(d.initialUndoRedoSnapshot)}const a=Dh(r.uri);if(this._models[a])throw new Error("ModelService: Cannot add model because it already exists!");const l=new nfe(r,d=>this._onWillDispose(d),(d,c)=>this._onDidChangeLanguage(d,c));return this._models[a]=l,l}createModel(e,t,i,n=!1){let o;return t?o=this._createModelData(e,t,i,n):o=this._createModelData(e,er,i,n),this._onModelAdded.fire(o.model),o.model}getModels(){const e=[],t=Object.keys(this._models);for(let i=0,n=t.length;i<n;i++){const o=t[i];e.push(this._models[o].model)}return e}getModel(e){const t=Dh(e),i=this._models[t];return i?i.model:null}_schemaShouldMaintainUndoRedoElements(e){return e.scheme===it.file||e.scheme===it.vscodeRemote||e.scheme===it.vscodeUserData||e.scheme===it.vscodeNotebookCell||e.scheme==="fake-fs"}_onWillDispose(e){const t=Dh(e.uri),i=this._models[t],n=this._undoRedoService.getUriComparisonKey(e.uri)!==e.uri.toString();let o=!1,r=0;if(n||this._shouldRestoreUndoStack()&&this._schemaShouldMaintainUndoRedoElements(e.uri)){const d=this._undoRedoService.getElements(e.uri);if(d.past.length>0||d.future.length>0){for(const c of d.past)xd(c)&&c.matchesResource(e.uri)&&(o=!0,r+=c.heapSize(e.uri),c.setModel(e.uri));for(const c of d.future)xd(c)&&c.matchesResource(e.uri)&&(o=!0,r+=c.heapSize(e.uri),c.setModel(e.uri))}}const a=Gf.MAX_MEMORY_FOR_CLOSED_FILES_UNDO_STACK,l=this._getSHA1Computer();if(o)if(!n&&(r>a||!l.canComputeSHA1(e))){const d=i.model.getInitialUndoRedoSnapshot();d!==null&&this._undoRedoService.restoreSnapshot(d)}else this._ensureDisposedModelsHeapSize(a-r),this._undoRedoService.setElementsValidFlag(e.uri,!1,d=>xd(d)&&d.matchesResource(e.uri)),this._insertDisposedModel(new ofe(e.uri,i.model.getInitialUndoRedoSnapshot(),Date.now(),n,r,l.computeSHA1(e),e.getVersionId(),e.getAlternativeVersionId()));else if(!n){const d=i.model.getInitialUndoRedoSnapshot();d!==null&&this._undoRedoService.restoreSnapshot(d)}delete this._models[t],i.dispose(),delete this._modelCreationOptionsByLanguageAndResource[e.getLanguageId()+e.uri],this._onModelRemoved.fire(e)}_onDidChangeLanguage(e,t){const i=t.oldLanguage,n=e.getLanguageId(),o=this.getCreationOptions(i,e.uri,e.isForSimpleWidget),r=this.getCreationOptions(n,e.uri,e.isForSimpleWidget);Gf._setModelOptionsForModel(e,r,o),this._onModelModeChanged.fire({model:e,oldLanguageId:i})}_getSHA1Computer(){return new Ux}};Ty.MAX_MEMORY_FOR_CLOSED_FILES_UNDO_STACK=20*1024*1024;Ty=Gf=ife([H_(0,mt),H_(1,YV),H_(2,Mx),H_(3,fi),H_(4,Jt)],Ty);class Ux{canComputeSHA1(e){return e.getValueLength()<=Ux.MAX_MODEL_SIZE}computeSHA1(e){const t=new ax,i=e.createSnapshot();let n;for(;n=i.read();)t.update(n);return t.digest()}}Ux.MAX_MODEL_SIZE=10*1024*1024;class rfe{get templateId(){return this.renderer.templateId}constructor(e,t){this.renderer=e,this.modelProvider=t}renderTemplate(e){return{data:this.renderer.renderTemplate(e),disposable:j.None}}renderElement(e,t,i,n){var o;if((o=i.disposable)===null||o===void 0||o.dispose(),!i.data)return;const r=this.modelProvider();if(r.isResolved(e))return this.renderer.renderElement(r.get(e),e,i.data,n);const a=new Yi,l=r.resolve(e,a.token);i.disposable={dispose:()=>a.cancel()},this.renderer.renderPlaceholder(e,i.data),l.then(d=>this.renderer.renderElement(d,e,i.data,n))}disposeTemplate(e){e.disposable&&(e.disposable.dispose(),e.disposable=void 0),e.data&&(this.renderer.disposeTemplate(e.data),e.data=void 0)}}class afe{constructor(e,t){this.modelProvider=e,this.accessibilityProvider=t}getWidgetAriaLabel(){return this.accessibilityProvider.getWidgetAriaLabel()}getAriaLabel(e){const t=this.modelProvider();return t.isResolved(e)?this.accessibilityProvider.getAriaLabel(t.get(e)):null}}function lfe(s,e){return{...e,accessibilityProvider:e.accessibilityProvider&&new afe(s,e.accessibilityProvider)}}class dfe{constructor(e,t,i,n,o={}){const r=()=>this.model,a=n.map(l=>new rfe(l,r));this.list=new na(e,t,i,a,lfe(r,o))}updateOptions(e){this.list.updateOptions(e)}getHTMLElement(){return this.list.getHTMLElement()}get onDidFocus(){return this.list.onDidFocus}get widget(){return this.list}get onDidDispose(){return this.list.onDidDispose}get onMouseDblClick(){return ge.map(this.list.onMouseDblClick,({element:e,index:t,browserEvent:i})=>({element:e===void 0?void 0:this._model.get(e),index:t,browserEvent:i}))}get onPointer(){return ge.map(this.list.onPointer,({element:e,index:t,browserEvent:i})=>({element:e===void 0?void 0:this._model.get(e),index:t,browserEvent:i}))}get onDidChangeSelection(){return ge.map(this.list.onDidChangeSelection,({elements:e,indexes:t,browserEvent:i})=>({elements:e.map(n=>this._model.get(n)),indexes:t,browserEvent:i}))}get model(){return this._model}set model(e){this._model=e,this.list.splice(0,this.list.length,Ls(e.length))}getFocus(){return this.list.getFocus()}getSelection(){return this.list.getSelection()}getSelectedElements(){return this.getSelection().map(e=>this.model.get(e))}style(e){this.list.style(e)}dispose(){this.list.dispose()}}var u_=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o};const cfe=!1;var My;(function(s){s.North="north",s.South="south",s.East="east",s.West="west"})(My||(My={}));let ufe=4;const hfe=new W;let gfe=300;const ffe=new W;class fO{constructor(e){this.el=e,this.disposables=new ie}get onPointerMove(){return this.disposables.add(new gt(Xe(this.el),"mousemove")).event}get onPointerUp(){return this.disposables.add(new gt(Xe(this.el),"mouseup")).event}dispose(){this.disposables.dispose()}}u_([Xi],fO.prototype,"onPointerMove",null);u_([Xi],fO.prototype,"onPointerUp",null);class pO{get onPointerMove(){return this.disposables.add(new gt(this.el,Qt.Change)).event}get onPointerUp(){return this.disposables.add(new gt(this.el,Qt.End)).event}constructor(e){this.el=e,this.disposables=new ie}dispose(){this.disposables.dispose()}}u_([Xi],pO.prototype,"onPointerMove",null);u_([Xi],pO.prototype,"onPointerUp",null);class Ry{get onPointerMove(){return this.factory.onPointerMove}get onPointerUp(){return this.factory.onPointerUp}constructor(e){this.factory=e}dispose(){}}u_([Xi],Ry.prototype,"onPointerMove",null);u_([Xi],Ry.prototype,"onPointerUp",null);const f9="pointer-events-disabled";class ns extends j{get state(){return this._state}get orthogonalStartSash(){return this._orthogonalStartSash}get orthogonalEndSash(){return this._orthogonalEndSash}set state(e){this._state!==e&&(this.el.classList.toggle("disabled",e===0),this.el.classList.toggle("minimum",e===1),this.el.classList.toggle("maximum",e===2),this._state=e,this.onDidEnablementChange.fire(e))}set orthogonalStartSash(e){if(this._orthogonalStartSash!==e){if(this.orthogonalStartDragHandleDisposables.clear(),this.orthogonalStartSashDisposables.clear(),e){const t=i=>{this.orthogonalStartDragHandleDisposables.clear(),i!==0&&(this._orthogonalStartDragHandle=te(this.el,se(".orthogonal-drag-handle.start")),this.orthogonalStartDragHandleDisposables.add(Fe(()=>this._orthogonalStartDragHandle.remove())),this.orthogonalStartDragHandleDisposables.add(new gt(this._orthogonalStartDragHandle,"mouseenter")).event(()=>ns.onMouseEnter(e),void 0,this.orthogonalStartDragHandleDisposables),this.orthogonalStartDragHandleDisposables.add(new gt(this._orthogonalStartDragHandle,"mouseleave")).event(()=>ns.onMouseLeave(e),void 0,this.orthogonalStartDragHandleDisposables))};this.orthogonalStartSashDisposables.add(e.onDidEnablementChange.event(t,this)),t(e.state)}this._orthogonalStartSash=e}}set orthogonalEndSash(e){if(this._orthogonalEndSash!==e){if(this.orthogonalEndDragHandleDisposables.clear(),this.orthogonalEndSashDisposables.clear(),e){const t=i=>{this.orthogonalEndDragHandleDisposables.clear(),i!==0&&(this._orthogonalEndDragHandle=te(this.el,se(".orthogonal-drag-handle.end")),this.orthogonalEndDragHandleDisposables.add(Fe(()=>this._orthogonalEndDragHandle.remove())),this.orthogonalEndDragHandleDisposables.add(new gt(this._orthogonalEndDragHandle,"mouseenter")).event(()=>ns.onMouseEnter(e),void 0,this.orthogonalEndDragHandleDisposables),this.orthogonalEndDragHandleDisposables.add(new gt(this._orthogonalEndDragHandle,"mouseleave")).event(()=>ns.onMouseLeave(e),void 0,this.orthogonalEndDragHandleDisposables))};this.orthogonalEndSashDisposables.add(e.onDidEnablementChange.event(t,this)),t(e.state)}this._orthogonalEndSash=e}}constructor(e,t,i){super(),this.hoverDelay=gfe,this.hoverDelayer=this._register(new Qr(this.hoverDelay)),this._state=3,this.onDidEnablementChange=this._register(new W),this._onDidStart=this._register(new W),this._onDidChange=this._register(new W),this._onDidReset=this._register(new W),this._onDidEnd=this._register(new W),this.orthogonalStartSashDisposables=this._register(new ie),this.orthogonalStartDragHandleDisposables=this._register(new ie),this.orthogonalEndSashDisposables=this._register(new ie),this.orthogonalEndDragHandleDisposables=this._register(new ie),this.onDidStart=this._onDidStart.event,this.onDidChange=this._onDidChange.event,this.onDidReset=this._onDidReset.event,this.onDidEnd=this._onDidEnd.event,this.linkedSash=void 0,this.el=te(e,se(".monaco-sash")),i.orthogonalEdge&&this.el.classList.add(`orthogonal-edge-${i.orthogonalEdge}`),bt&&this.el.classList.add("mac");const n=this._register(new gt(this.el,"mousedown")).event;this._register(n(u=>this.onPointerStart(u,new fO(e)),this));const o=this._register(new gt(this.el,"dblclick")).event;this._register(o(this.onPointerDoublePress,this));const r=this._register(new gt(this.el,"mouseenter")).event;this._register(r(()=>ns.onMouseEnter(this)));const a=this._register(new gt(this.el,"mouseleave")).event;this._register(a(()=>ns.onMouseLeave(this))),this._register(Xt.addTarget(this.el));const l=this._register(new gt(this.el,Qt.Start)).event;this._register(l(u=>this.onPointerStart(u,new pO(this.el)),this));const d=this._register(new gt(this.el,Qt.Tap)).event;let c;this._register(d(u=>{if(c){clearTimeout(c),c=void 0,this.onPointerDoublePress(u);return}clearTimeout(c),c=setTimeout(()=>c=void 0,250)},this)),typeof i.size=="number"?(this.size=i.size,i.orientation===0?this.el.style.width=`${this.size}px`:this.el.style.height=`${this.size}px`):(this.size=ufe,this._register(hfe.event(u=>{this.size=u,this.layout()}))),this._register(ffe.event(u=>this.hoverDelay=u)),this.layoutProvider=t,this.orthogonalStartSash=i.orthogonalStartSash,this.orthogonalEndSash=i.orthogonalEndSash,this.orientation=i.orientation||0,this.orientation===1?(this.el.classList.add("horizontal"),this.el.classList.remove("vertical")):(this.el.classList.remove("horizontal"),this.el.classList.add("vertical")),this.el.classList.toggle("debug",cfe),this.layout()}onPointerStart(e,t){ot.stop(e);let i=!1;if(!e.__orthogonalSashEvent){const f=this.getOrthogonalSash(e);f&&(i=!0,e.__orthogonalSashEvent=!0,f.onPointerStart(e,new Ry(t)))}if(this.linkedSash&&!e.__linkedSashEvent&&(e.__linkedSashEvent=!0,this.linkedSash.onPointerStart(e,new Ry(t))),!this.state)return;const n=this.el.ownerDocument.getElementsByTagName("iframe");for(const f of n)f.classList.add(f9);const o=e.pageX,r=e.pageY,a=e.altKey,l={startX:o,currentX:o,startY:r,currentY:r,altKey:a};this.el.classList.add("active"),this._onDidStart.fire(l);const d=Lr(this.el),c=()=>{let f="";i?f="all-scroll":this.orientation===1?this.state===1?f="s-resize":this.state===2?f="n-resize":f=bt?"row-resize":"ns-resize":this.state===1?f="e-resize":this.state===2?f="w-resize":f=bt?"col-resize":"ew-resize",d.textContent=`* { cursor: ${f} !important; }`},u=new ie;c(),i||this.onDidEnablementChange.event(c,null,u);const h=f=>{ot.stop(f,!1);const m={startX:o,currentX:f.pageX,startY:r,currentY:f.pageY,altKey:a};this._onDidChange.fire(m)},g=f=>{ot.stop(f,!1),this.el.removeChild(d),this.el.classList.remove("active"),this._onDidEnd.fire(),u.dispose();for(const m of n)m.classList.remove(f9)};t.onPointerMove(h,null,u),t.onPointerUp(g,null,u),u.add(t)}onPointerDoublePress(e){const t=this.getOrthogonalSash(e);t&&t._onDidReset.fire(),this.linkedSash&&this.linkedSash._onDidReset.fire(),this._onDidReset.fire()}static onMouseEnter(e,t=!1){e.el.classList.contains("active")?(e.hoverDelayer.cancel(),e.el.classList.add("hover")):e.hoverDelayer.trigger(()=>e.el.classList.add("hover"),e.hoverDelay).then(void 0,()=>{}),!t&&e.linkedSash&&ns.onMouseEnter(e.linkedSash,!0)}static onMouseLeave(e,t=!1){e.hoverDelayer.cancel(),e.el.classList.remove("hover"),!t&&e.linkedSash&&ns.onMouseLeave(e.linkedSash,!0)}clearSashHoverState(){ns.onMouseLeave(this)}layout(){if(this.orientation===0){const e=this.layoutProvider;this.el.style.left=e.getVerticalSashLeft(this)-this.size/2+"px",e.getVerticalSashTop&&(this.el.style.top=e.getVerticalSashTop(this)+"px"),e.getVerticalSashHeight&&(this.el.style.height=e.getVerticalSashHeight(this)+"px")}else{const e=this.layoutProvider;this.el.style.top=e.getHorizontalSashTop(this)-this.size/2+"px",e.getHorizontalSashLeft&&(this.el.style.left=e.getHorizontalSashLeft(this)+"px"),e.getHorizontalSashWidth&&(this.el.style.width=e.getHorizontalSashWidth(this)+"px")}}getOrthogonalSash(e){var t;const i=(t=e.initialTarget)!==null&&t!==void 0?t:e.target;if(!(!i||!(i instanceof HTMLElement))&&i.classList.contains("orthogonal-drag-handle"))return i.classList.contains("start")?this.orthogonalStartSash:this.orthogonalEndSash}dispose(){super.dispose(),this.el.remove()}}const pfe={separatorBorder:G.transparent};class eU{set size(e){this._size=e}get size(){return this._size}get visible(){return typeof this._cachedVisibleSize>"u"}setVisible(e,t){var i,n;if(e!==this.visible){e?(this.size=co(this._cachedVisibleSize,this.viewMinimumSize,this.viewMaximumSize),this._cachedVisibleSize=void 0):(this._cachedVisibleSize=typeof t=="number"?t:this.size,this.size=0),this.container.classList.toggle("visible",e);try{(n=(i=this.view).setVisible)===null||n===void 0||n.call(i,e)}catch(o){console.error("Splitview: Failed to set visible view"),console.error(o)}}}get minimumSize(){return this.visible?this.view.minimumSize:0}get viewMinimumSize(){return this.view.minimumSize}get maximumSize(){return this.visible?this.view.maximumSize:0}get viewMaximumSize(){return this.view.maximumSize}get priority(){return this.view.priority}get proportionalLayout(){var e;return(e=this.view.proportionalLayout)!==null&&e!==void 0?e:!0}get snap(){return!!this.view.snap}set enabled(e){this.container.style.pointerEvents=e?"":"none"}constructor(e,t,i,n){this.container=e,this.view=t,this.disposable=n,this._cachedVisibleSize=void 0,typeof i=="number"?(this._size=i,this._cachedVisibleSize=void 0,e.classList.add("visible")):(this._size=0,this._cachedVisibleSize=i.cachedVisibleSize)}layout(e,t){this.layoutContainer(e);try{this.view.layout(this.size,e,t)}catch(i){console.error("Splitview: Failed to layout view"),console.error(i)}}dispose(){this.disposable.dispose()}}class mfe extends eU{layoutContainer(e){this.container.style.top=`${e}px`,this.container.style.height=`${this.size}px`}}class _fe extends eU{layoutContainer(e){this.container.style.left=`${e}px`,this.container.style.width=`${this.size}px`}}var wd;(function(s){s[s.Idle=0]="Idle",s[s.Busy=1]="Busy"})(wd||(wd={}));var Ay;(function(s){s.Distribute={type:"distribute"};function e(n){return{type:"split",index:n}}s.Split=e;function t(n){return{type:"auto",index:n}}s.Auto=t;function i(n){return{type:"invisible",cachedVisibleSize:n}}s.Invisible=i})(Ay||(Ay={}));class tU extends j{get orthogonalStartSash(){return this._orthogonalStartSash}get orthogonalEndSash(){return this._orthogonalEndSash}get startSnappingEnabled(){return this._startSnappingEnabled}get endSnappingEnabled(){return this._endSnappingEnabled}set orthogonalStartSash(e){for(const t of this.sashItems)t.sash.orthogonalStartSash=e;this._orthogonalStartSash=e}set orthogonalEndSash(e){for(const t of this.sashItems)t.sash.orthogonalEndSash=e;this._orthogonalEndSash=e}set startSnappingEnabled(e){this._startSnappingEnabled!==e&&(this._startSnappingEnabled=e,this.updateSashEnablement())}set endSnappingEnabled(e){this._endSnappingEnabled!==e&&(this._endSnappingEnabled=e,this.updateSashEnablement())}constructor(e,t={}){var i,n,o,r,a;super(),this.size=0,this._contentSize=0,this.proportions=void 0,this.viewItems=[],this.sashItems=[],this.state=wd.Idle,this._onDidSashChange=this._register(new W),this._onDidSashReset=this._register(new W),this._startSnappingEnabled=!0,this._endSnappingEnabled=!0,this.onDidSashChange=this._onDidSashChange.event,this.onDidSashReset=this._onDidSashReset.event,this.orientation=(i=t.orientation)!==null&&i!==void 0?i:0,this.inverseAltBehavior=(n=t.inverseAltBehavior)!==null&&n!==void 0?n:!1,this.proportionalLayout=(o=t.proportionalLayout)!==null&&o!==void 0?o:!0,this.getSashOrthogonalSize=t.getSashOrthogonalSize,this.el=document.createElement("div"),this.el.classList.add("monaco-split-view2"),this.el.classList.add(this.orientation===0?"vertical":"horizontal"),e.appendChild(this.el),this.sashContainer=te(this.el,se(".sash-container")),this.viewContainer=se(".split-view-container"),this.scrollable=this._register(new a_({forceIntegerValues:!0,smoothScrollDuration:125,scheduleAtNextAnimationFrame:d=>yo(Xe(this.el),d)})),this.scrollableElement=this._register(new Lx(this.viewContainer,{vertical:this.orientation===0?(r=t.scrollbarVisibility)!==null&&r!==void 0?r:1:2,horizontal:this.orientation===1?(a=t.scrollbarVisibility)!==null&&a!==void 0?a:1:2},this.scrollable));const l=this._register(new gt(this.viewContainer,"scroll")).event;this._register(l(d=>{const c=this.scrollableElement.getScrollPosition(),u=Math.abs(this.viewContainer.scrollLeft-c.scrollLeft)<=1?void 0:this.viewContainer.scrollLeft,h=Math.abs(this.viewContainer.scrollTop-c.scrollTop)<=1?void 0:this.viewContainer.scrollTop;(u!==void 0||h!==void 0)&&this.scrollableElement.setScrollPosition({scrollLeft:u,scrollTop:h})})),this.onDidScroll=this.scrollableElement.onScroll,this._register(this.onDidScroll(d=>{d.scrollTopChanged&&(this.viewContainer.scrollTop=d.scrollTop),d.scrollLeftChanged&&(this.viewContainer.scrollLeft=d.scrollLeft)})),te(this.el,this.scrollableElement.getDomNode()),this.style(t.styles||pfe),t.descriptor&&(this.size=t.descriptor.size,t.descriptor.views.forEach((d,c)=>{const u=fo(d.visible)||d.visible?d.size:{type:"invisible",cachedVisibleSize:d.size},h=d.view;this.doAddView(h,u,c,!0)}),this._contentSize=this.viewItems.reduce((d,c)=>d+c.size,0),this.saveProportions())}style(e){e.separatorBorder.isTransparent()?(this.el.classList.remove("separator-border"),this.el.style.removeProperty("--separator-border")):(this.el.classList.add("separator-border"),this.el.style.setProperty("--separator-border",e.separatorBorder.toString()))}addView(e,t,i=this.viewItems.length,n){this.doAddView(e,t,i,n)}layout(e,t){const i=Math.max(this.size,this._contentSize);if(this.size=e,this.layoutContext=t,this.proportions){let n=0;for(let o=0;o<this.viewItems.length;o++){const r=this.viewItems[o],a=this.proportions[o];typeof a=="number"?n+=a:e-=r.size}for(let o=0;o<this.viewItems.length;o++){const r=this.viewItems[o],a=this.proportions[o];typeof a=="number"&&n>0&&(r.size=co(Math.round(a*e/n),r.minimumSize,r.maximumSize))}}else{const n=Ls(this.viewItems.length),o=n.filter(a=>this.viewItems[a].priority===1),r=n.filter(a=>this.viewItems[a].priority===2);this.resize(this.viewItems.length-1,e-i,void 0,o,r)}this.distributeEmptySpace(),this.layoutViews()}saveProportions(){this.proportionalLayout&&this._contentSize>0&&(this.proportions=this.viewItems.map(e=>e.proportionalLayout&&e.visible?e.size/this._contentSize:void 0))}onSashStart({sash:e,start:t,alt:i}){for(const a of this.viewItems)a.enabled=!1;const n=this.sashItems.findIndex(a=>a.sash===e),o=Gr(Y(this.el.ownerDocument.body,"keydown",a=>r(this.sashDragState.current,a.altKey)),Y(this.el.ownerDocument.body,"keyup",()=>r(this.sashDragState.current,!1))),r=(a,l)=>{const d=this.viewItems.map(f=>f.size);let c=Number.NEGATIVE_INFINITY,u=Number.POSITIVE_INFINITY;if(this.inverseAltBehavior&&(l=!l),l)if(n===this.sashItems.length-1){const m=this.viewItems[n];c=(m.minimumSize-m.size)/2,u=(m.maximumSize-m.size)/2}else{const m=this.viewItems[n+1];c=(m.size-m.maximumSize)/2,u=(m.size-m.minimumSize)/2}let h,g;if(!l){const f=Ls(n,-1),m=Ls(n+1,this.viewItems.length),_=f.reduce((k,I)=>k+(this.viewItems[I].minimumSize-d[I]),0),v=f.reduce((k,I)=>k+(this.viewItems[I].viewMaximumSize-d[I]),0),b=m.length===0?Number.POSITIVE_INFINITY:m.reduce((k,I)=>k+(d[I]-this.viewItems[I].minimumSize),0),C=m.length===0?Number.NEGATIVE_INFINITY:m.reduce((k,I)=>k+(d[I]-this.viewItems[I].viewMaximumSize),0),w=Math.max(_,C),S=Math.min(b,v),x=this.findFirstSnapIndex(f),L=this.findFirstSnapIndex(m);if(typeof x=="number"){const k=this.viewItems[x],I=Math.floor(k.viewMinimumSize/2);h={index:x,limitDelta:k.visible?w-I:w+I,size:k.size}}if(typeof L=="number"){const k=this.viewItems[L],I=Math.floor(k.viewMinimumSize/2);g={index:L,limitDelta:k.visible?S+I:S-I,size:k.size}}}this.sashDragState={start:a,current:a,index:n,sizes:d,minDelta:c,maxDelta:u,alt:l,snapBefore:h,snapAfter:g,disposable:o}};r(t,i)}onSashChange({current:e}){const{index:t,start:i,sizes:n,alt:o,minDelta:r,maxDelta:a,snapBefore:l,snapAfter:d}=this.sashDragState;this.sashDragState.current=e;const c=e-i,u=this.resize(t,c,n,void 0,void 0,r,a,l,d);if(o){const h=t===this.sashItems.length-1,g=this.viewItems.map(C=>C.size),f=h?t:t+1,m=this.viewItems[f],_=m.size-m.maximumSize,v=m.size-m.minimumSize,b=h?t-1:t+1;this.resize(b,-u,g,void 0,void 0,_,v)}this.distributeEmptySpace(),this.layoutViews()}onSashEnd(e){this._onDidSashChange.fire(e),this.sashDragState.disposable.dispose(),this.saveProportions();for(const t of this.viewItems)t.enabled=!0}onViewChange(e,t){const i=this.viewItems.indexOf(e);i<0||i>=this.viewItems.length||(t=typeof t=="number"?t:e.size,t=co(t,e.minimumSize,e.maximumSize),this.inverseAltBehavior&&i>0?(this.resize(i-1,Math.floor((e.size-t)/2)),this.distributeEmptySpace(),this.layoutViews()):(e.size=t,this.relayout([i],void 0)))}resizeView(e,t){if(!(e<0||e>=this.viewItems.length)){if(this.state!==wd.Idle)throw new Error("Cant modify splitview");this.state=wd.Busy;try{const i=Ls(this.viewItems.length).filter(a=>a!==e),n=[...i.filter(a=>this.viewItems[a].priority===1),e],o=i.filter(a=>this.viewItems[a].priority===2),r=this.viewItems[e];t=Math.round(t),t=co(t,r.minimumSize,Math.min(r.maximumSize,this.size)),r.size=t,this.relayout(n,o)}finally{this.state=wd.Idle}}}distributeViewSizes(){const e=[];let t=0;for(const a of this.viewItems)a.maximumSize-a.minimumSize>0&&(e.push(a),t+=a.size);const i=Math.floor(t/e.length);for(const a of e)a.size=co(i,a.minimumSize,a.maximumSize);const n=Ls(this.viewItems.length),o=n.filter(a=>this.viewItems[a].priority===1),r=n.filter(a=>this.viewItems[a].priority===2);this.relayout(o,r)}getViewSize(e){return e<0||e>=this.viewItems.length?-1:this.viewItems[e].size}doAddView(e,t,i=this.viewItems.length,n){if(this.state!==wd.Idle)throw new Error("Cant modify splitview");this.state=wd.Busy;try{const o=se(".split-view-view");i===this.viewItems.length?this.viewContainer.appendChild(o):this.viewContainer.insertBefore(o,this.viewContainer.children.item(i));const r=e.onDidChange(h=>this.onViewChange(c,h)),a=Fe(()=>this.viewContainer.removeChild(o)),l=Gr(r,a);let d;typeof t=="number"?d=t:(t.type==="auto"&&(this.areViewsDistributed()?t={type:"distribute"}:t={type:"split",index:t.index}),t.type==="split"?d=this.getViewSize(t.index)/2:t.type==="invisible"?d={cachedVisibleSize:t.cachedVisibleSize}:d=e.minimumSize);const c=this.orientation===0?new mfe(o,e,d,l):new _fe(o,e,d,l);if(this.viewItems.splice(i,0,c),this.viewItems.length>1){const h={orthogonalStartSash:this.orthogonalStartSash,orthogonalEndSash:this.orthogonalEndSash},g=this.orientation===0?new ns(this.sashContainer,{getHorizontalSashTop:k=>this.getSashPosition(k),getHorizontalSashWidth:this.getSashOrthogonalSize},{...h,orientation:1}):new ns(this.sashContainer,{getVerticalSashLeft:k=>this.getSashPosition(k),getVerticalSashHeight:this.getSashOrthogonalSize},{...h,orientation:0}),f=this.orientation===0?k=>({sash:g,start:k.startY,current:k.currentY,alt:k.altKey}):k=>({sash:g,start:k.startX,current:k.currentX,alt:k.altKey}),_=ge.map(g.onDidStart,f)(this.onSashStart,this),b=ge.map(g.onDidChange,f)(this.onSashChange,this),w=ge.map(g.onDidEnd,()=>this.sashItems.findIndex(k=>k.sash===g))(this.onSashEnd,this),S=g.onDidReset(()=>{const k=this.sashItems.findIndex(z=>z.sash===g),I=Ls(k,-1),P=Ls(k+1,this.viewItems.length),$=this.findFirstSnapIndex(I),A=this.findFirstSnapIndex(P);typeof $=="number"&&!this.viewItems[$].visible||typeof A=="number"&&!this.viewItems[A].visible||this._onDidSashReset.fire(k)}),x=Gr(_,b,w,S,g),L={sash:g,disposable:x};this.sashItems.splice(i-1,0,L)}o.appendChild(e.element);let u;typeof t!="number"&&t.type==="split"&&(u=[t.index]),n||this.relayout([i],u),!n&&typeof t!="number"&&t.type==="distribute"&&this.distributeViewSizes()}finally{this.state=wd.Idle}}relayout(e,t){const i=this.viewItems.reduce((n,o)=>n+o.size,0);this.resize(this.viewItems.length-1,this.size-i,void 0,e,t),this.distributeEmptySpace(),this.layoutViews(),this.saveProportions()}resize(e,t,i=this.viewItems.map(c=>c.size),n,o,r=Number.NEGATIVE_INFINITY,a=Number.POSITIVE_INFINITY,l,d){if(e<0||e>=this.viewItems.length)return 0;const c=Ls(e,-1),u=Ls(e+1,this.viewItems.length);if(o)for(const L of o)Lk(c,L),Lk(u,L);if(n)for(const L of n)t1(c,L),t1(u,L);const h=c.map(L=>this.viewItems[L]),g=c.map(L=>i[L]),f=u.map(L=>this.viewItems[L]),m=u.map(L=>i[L]),_=c.reduce((L,k)=>L+(this.viewItems[k].minimumSize-i[k]),0),v=c.reduce((L,k)=>L+(this.viewItems[k].maximumSize-i[k]),0),b=u.length===0?Number.POSITIVE_INFINITY:u.reduce((L,k)=>L+(i[k]-this.viewItems[k].minimumSize),0),C=u.length===0?Number.NEGATIVE_INFINITY:u.reduce((L,k)=>L+(i[k]-this.viewItems[k].maximumSize),0),w=Math.max(_,C,r),S=Math.min(b,v,a);let x=!1;if(l){const L=this.viewItems[l.index],k=t>=l.limitDelta;x=k!==L.visible,L.setVisible(k,l.size)}if(!x&&d){const L=this.viewItems[d.index],k=t<d.limitDelta;x=k!==L.visible,L.setVisible(k,d.size)}if(x)return this.resize(e,t,i,n,o,r,a);t=co(t,w,S);for(let L=0,k=t;L<h.length;L++){const I=h[L],P=co(g[L]+k,I.minimumSize,I.maximumSize),$=P-g[L];k-=$,I.size=P}for(let L=0,k=t;L<f.length;L++){const I=f[L],P=co(m[L]-k,I.minimumSize,I.maximumSize),$=P-m[L];k+=$,I.size=P}return t}distributeEmptySpace(e){const t=this.viewItems.reduce((a,l)=>a+l.size,0);let i=this.size-t;const n=Ls(this.viewItems.length-1,-1),o=n.filter(a=>this.viewItems[a].priority===1),r=n.filter(a=>this.viewItems[a].priority===2);for(const a of r)Lk(n,a);for(const a of o)t1(n,a);typeof e=="number"&&t1(n,e);for(let a=0;i!==0&&a<n.length;a++){const l=this.viewItems[n[a]],d=co(l.size+i,l.minimumSize,l.maximumSize),c=d-l.size;i-=c,l.size=d}}layoutViews(){this._contentSize=this.viewItems.reduce((t,i)=>t+i.size,0);let e=0;for(const t of this.viewItems)t.layout(e,this.layoutContext),e+=t.size;this.sashItems.forEach(t=>t.sash.layout()),this.updateSashEnablement(),this.updateScrollableElement()}updateScrollableElement(){this.orientation===0?this.scrollableElement.setScrollDimensions({height:this.size,scrollHeight:this._contentSize}):this.scrollableElement.setScrollDimensions({width:this.size,scrollWidth:this._contentSize})}updateSashEnablement(){let e=!1;const t=this.viewItems.map(l=>e=l.size-l.minimumSize>0||e);e=!1;const i=this.viewItems.map(l=>e=l.maximumSize-l.size>0||e),n=[...this.viewItems].reverse();e=!1;const o=n.map(l=>e=l.size-l.minimumSize>0||e).reverse();e=!1;const r=n.map(l=>e=l.maximumSize-l.size>0||e).reverse();let a=0;for(let l=0;l<this.sashItems.length;l++){const{sash:d}=this.sashItems[l],c=this.viewItems[l];a+=c.size;const u=!(t[l]&&r[l+1]),h=!(i[l]&&o[l+1]);if(u&&h){const g=Ls(l,-1),f=Ls(l+1,this.viewItems.length),m=this.findFirstSnapIndex(g),_=this.findFirstSnapIndex(f),v=typeof m=="number"&&!this.viewItems[m].visible,b=typeof _=="number"&&!this.viewItems[_].visible;v&&o[l]&&(a>0||this.startSnappingEnabled)?d.state=1:b&&t[l]&&(a<this._contentSize||this.endSnappingEnabled)?d.state=2:d.state=0}else u&&!h?d.state=1:!u&&h?d.state=2:d.state=3}}getSashPosition(e){let t=0;for(let i=0;i<this.sashItems.length;i++)if(t+=this.viewItems[i].size,this.sashItems[i].sash===e)return t;return 0}findFirstSnapIndex(e){for(const t of e){const i=this.viewItems[t];if(i.visible&&i.snap)return t}for(const t of e){const i=this.viewItems[t];if(i.visible&&i.maximumSize-i.minimumSize>0)return;if(!i.visible&&i.snap)return t}}areViewsDistributed(){let e,t;for(const i of this.viewItems)if(e=e===void 0?i.size:Math.min(e,i.size),t=t===void 0?i.size:Math.max(t,i.size),t-e>2)return!1;return!0}dispose(){var e;(e=this.sashDragState)===null||e===void 0||e.disposable.dispose(),Bt(this.viewItems),this.viewItems=[],this.sashItems.forEach(t=>t.disposable.dispose()),this.sashItems=[],super.dispose()}}class yC{constructor(e,t,i){this.columns=e,this.getColumnSize=i,this.templateId=yC.TemplateId,this.renderedTemplates=new Set;const n=new Map(t.map(o=>[o.templateId,o]));this.renderers=[];for(const o of e){const r=n.get(o.templateId);if(!r)throw new Error(`Table cell renderer for template id ${o.templateId} not found.`);this.renderers.push(r)}}renderTemplate(e){const t=te(e,se(".monaco-table-tr")),i=[],n=[];for(let r=0;r<this.columns.length;r++){const a=this.renderers[r],l=te(t,se(".monaco-table-td",{"data-col-index":r}));l.style.width=`${this.getColumnSize(r)}px`,i.push(l),n.push(a.renderTemplate(l))}const o={container:e,cellContainers:i,cellTemplateData:n};return this.renderedTemplates.add(o),o}renderElement(e,t,i,n){for(let o=0;o<this.columns.length;o++){const a=this.columns[o].project(e);this.renderers[o].renderElement(a,t,i.cellTemplateData[o],n)}}disposeElement(e,t,i,n){for(let o=0;o<this.columns.length;o++){const r=this.renderers[o];if(r.disposeElement){const l=this.columns[o].project(e);r.disposeElement(l,t,i.cellTemplateData[o],n)}}}disposeTemplate(e){for(let t=0;t<this.columns.length;t++)this.renderers[t].disposeTemplate(e.cellTemplateData[t]);Vn(e.container),this.renderedTemplates.delete(e)}layoutColumn(e,t){for(const{cellContainers:i}of this.renderedTemplates)i[e].style.width=`${t}px`}}yC.TemplateId="row";function vfe(s){return{getHeight(e){return s.getHeight(e)},getTemplateId(){return yC.TemplateId}}}class bfe{get minimumSize(){var e;return(e=this.column.minimumWidth)!==null&&e!==void 0?e:120}get maximumSize(){var e;return(e=this.column.maximumWidth)!==null&&e!==void 0?e:Number.POSITIVE_INFINITY}get onDidChange(){var e;return(e=this.column.onDidChangeWidthConstraints)!==null&&e!==void 0?e:ge.None}constructor(e,t){this.column=e,this.index=t,this._onDidLayout=new W,this.onDidLayout=this._onDidLayout.event,this.element=se(".monaco-table-th",{"data-col-index":t,title:e.tooltip},e.label)}layout(e){this._onDidLayout.fire([this.index,e])}}class $x{get onDidChangeFocus(){return this.list.onDidChangeFocus}get onDidChangeSelection(){return this.list.onDidChangeSelection}get onDidScroll(){return this.list.onDidScroll}get onMouseDblClick(){return this.list.onMouseDblClick}get onPointer(){return this.list.onPointer}get onDidFocus(){return this.list.onDidFocus}get scrollTop(){return this.list.scrollTop}set scrollTop(e){this.list.scrollTop=e}get scrollHeight(){return this.list.scrollHeight}get renderHeight(){return this.list.renderHeight}get onDidDispose(){return this.list.onDidDispose}constructor(e,t,i,n,o,r){this.virtualDelegate=i,this.domId=`table_id_${++$x.InstanceCount}`,this.disposables=new ie,this.cachedWidth=0,this.cachedHeight=0,this.domNode=te(t,se(`.monaco-table.${this.domId}`));const a=n.map((c,u)=>new bfe(c,u)),l={size:a.reduce((c,u)=>c+u.column.weight,0),views:a.map(c=>({size:c.column.weight,view:c}))};this.splitview=this.disposables.add(new tU(this.domNode,{orientation:1,scrollbarVisibility:2,getSashOrthogonalSize:()=>this.cachedHeight,descriptor:l})),this.splitview.el.style.height=`${i.headerRowHeight}px`,this.splitview.el.style.lineHeight=`${i.headerRowHeight}px`;const d=new yC(n,o,c=>this.splitview.getViewSize(c));this.list=this.disposables.add(new na(e,this.domNode,vfe(i),[d],r)),ge.any(...a.map(c=>c.onDidLayout))(([c,u])=>d.layoutColumn(c,u),null,this.disposables),this.splitview.onDidSashReset(c=>{const u=n.reduce((g,f)=>g+f.weight,0),h=n[c].weight/u*this.cachedWidth;this.splitview.resizeView(c,h)},null,this.disposables),this.styleElement=Lr(this.domNode),this.style(Sge)}updateOptions(e){this.list.updateOptions(e)}splice(e,t,i=[]){this.list.splice(e,t,i)}getHTMLElement(){return this.domNode}style(e){const t=[];t.push(`.monaco-table.${this.domId} > .monaco-split-view2 .monaco-sash.vertical::before {
			top: ${this.virtualDelegate.headerRowHeight+1}px;
			height: calc(100% - ${this.virtualDelegate.headerRowHeight}px);
		}`),this.styleElement.textContent=t.join(`
`),this.list.style(e)}getSelectedElements(){return this.list.getSelectedElements()}getSelection(){return this.list.getSelection()}getFocus(){return this.list.getFocus()}dispose(){this.disposables.dispose()}}$x.InstanceCount=0;class h_ extends ta{constructor(e){super(),this._onChange=this._register(new W),this.onChange=this._onChange.event,this._onKeyDown=this._register(new W),this.onKeyDown=this._onKeyDown.event,this._opts=e,this._checked=this._opts.isChecked;const t=["monaco-custom-toggle"];this._opts.icon&&(this._icon=this._opts.icon,t.push(...Oe.asClassNameArray(this._icon))),this._opts.actionClassName&&t.push(...this._opts.actionClassName.split(" ")),this._checked&&t.push("checked"),this.domNode=document.createElement("div"),this.domNode.title=this._opts.title,this.domNode.classList.add(...t),this._opts.notFocusable||(this.domNode.tabIndex=0),this.domNode.setAttribute("role","checkbox"),this.domNode.setAttribute("aria-checked",String(this._checked)),this.domNode.setAttribute("aria-label",this._opts.title),this.applyStyles(),this.onclick(this.domNode,i=>{this.enabled&&(this.checked=!this._checked,this._onChange.fire(!1),i.preventDefault())}),this._register(this.ignoreGesture(this.domNode)),this.onkeydown(this.domNode,i=>{if(i.keyCode===10||i.keyCode===3){this.checked=!this._checked,this._onChange.fire(!0),i.preventDefault(),i.stopPropagation();return}this._onKeyDown.fire(i)})}get enabled(){return this.domNode.getAttribute("aria-disabled")!=="true"}focus(){this.domNode.focus()}get checked(){return this._checked}set checked(e){this._checked=e,this.domNode.setAttribute("aria-checked",String(this._checked)),this.domNode.classList.toggle("checked",this._checked),this.applyStyles()}width(){return 22}applyStyles(){this.domNode&&(this.domNode.style.borderColor=this._checked&&this._opts.inputActiveOptionBorder||"",this.domNode.style.color=this._checked&&this._opts.inputActiveOptionForeground||"inherit",this.domNode.style.backgroundColor=this._checked&&this._opts.inputActiveOptionBackground||"")}enable(){this.domNode.setAttribute("aria-disabled",String(!1))}disable(){this.domNode.setAttribute("aria-disabled",String(!0))}}const Cfe=p("caseDescription","Match Case"),wfe=p("wordsDescription","Match Whole Word"),Sfe=p("regexDescription","Use Regular Expression");class iU extends h_{constructor(e){super({icon:le.caseSensitive,title:Cfe+e.appendTitle,isChecked:e.isChecked,inputActiveOptionBorder:e.inputActiveOptionBorder,inputActiveOptionForeground:e.inputActiveOptionForeground,inputActiveOptionBackground:e.inputActiveOptionBackground})}}class nU extends h_{constructor(e){super({icon:le.wholeWord,title:wfe+e.appendTitle,isChecked:e.isChecked,inputActiveOptionBorder:e.inputActiveOptionBorder,inputActiveOptionForeground:e.inputActiveOptionForeground,inputActiveOptionBackground:e.inputActiveOptionBackground})}}class sU extends h_{constructor(e){super({icon:le.regex,title:Sfe+e.appendTitle,isChecked:e.isChecked,inputActiveOptionBorder:e.inputActiveOptionBorder,inputActiveOptionForeground:e.inputActiveOptionForeground,inputActiveOptionBackground:e.inputActiveOptionBackground})}}class yfe{constructor(e,t=0,i=e.length,n=t-1){this.items=e,this.start=t,this.end=i,this.index=n}current(){return this.index===this.start-1||this.index===this.end?null:this.items[this.index]}next(){return this.index=Math.min(this.index+1,this.end),this.current()}previous(){return this.index=Math.max(this.index-1,this.start-1),this.current()}first(){return this.index=this.start,this.current()}last(){return this.index=this.end-1,this.current()}}class Lfe{constructor(e=[],t=10){this._initialize(e),this._limit=t,this._onChange()}getHistory(){return this._elements}add(e){this._history.delete(e),this._history.add(e),this._onChange()}next(){return this._navigator.next()}previous(){return this._currentPosition()!==0?this._navigator.previous():null}current(){return this._navigator.current()}first(){return this._navigator.first()}last(){return this._navigator.last()}isLast(){return this._currentPosition()>=this._elements.length-1}isNowhere(){return this._navigator.current()===null}has(e){return this._history.has(e)}_onChange(){this._reduceToLimit();const e=this._elements;this._navigator=new yfe(e,0,e.length,e.length)}_reduceToLimit(){const e=this._elements;e.length>this._limit&&this._initialize(e.slice(e.length-this._limit))}_currentPosition(){const e=this._navigator.current();return e?this._elements.indexOf(e):-1}_initialize(e){this._history=new Set;for(const t of e)this._history.add(t)}get _elements(){const e=[];return this._history.forEach(t=>e.push(t)),e}}const z_=se;let xfe=class extends ta{constructor(e,t,i){var n;super(),this.state="idle",this.maxHeight=Number.POSITIVE_INFINITY,this._onDidChange=this._register(new W),this.onDidChange=this._onDidChange.event,this._onDidHeightChange=this._register(new W),this.onDidHeightChange=this._onDidHeightChange.event,this.contextViewProvider=t,this.options=i,this.message=null,this.placeholder=this.options.placeholder||"",this.tooltip=(n=this.options.tooltip)!==null&&n!==void 0?n:this.placeholder||"",this.ariaLabel=this.options.ariaLabel||"",this.options.validationOptions&&(this.validation=this.options.validationOptions.validation),this.element=te(e,z_(".monaco-inputbox.idle"));const o=this.options.flexibleHeight?"textarea":"input",r=te(this.element,z_(".ibwrapper"));if(this.input=te(r,z_(o+".input.empty")),this.input.setAttribute("autocorrect","off"),this.input.setAttribute("autocapitalize","off"),this.input.setAttribute("spellcheck","false"),this.onfocus(this.input,()=>this.element.classList.add("synthetic-focus")),this.onblur(this.input,()=>this.element.classList.remove("synthetic-focus")),this.options.flexibleHeight){this.maxHeight=typeof this.options.flexibleMaxHeight=="number"?this.options.flexibleMaxHeight:Number.POSITIVE_INFINITY,this.mirror=te(r,z_("div.mirror")),this.mirror.innerText=" ",this.scrollableElement=new CH(this.element,{vertical:1}),this.options.flexibleWidth&&(this.input.setAttribute("wrap","off"),this.mirror.style.whiteSpace="pre",this.mirror.style.wordWrap="initial"),te(e,this.scrollableElement.getDomNode()),this._register(this.scrollableElement),this._register(this.scrollableElement.onScroll(d=>this.input.scrollTop=d.scrollTop));const a=this._register(new gt(e.ownerDocument,"selectionchange")),l=ge.filter(a.event,()=>{const d=e.ownerDocument.getSelection();return(d==null?void 0:d.anchorNode)===r});this._register(l(this.updateScrollDimensions,this)),this._register(this.onDidHeightChange(this.updateScrollDimensions,this))}else this.input.type=this.options.type||"text",this.input.setAttribute("wrap","off");this.ariaLabel&&this.input.setAttribute("aria-label",this.ariaLabel),this.placeholder&&!this.options.showPlaceholderOnFocus&&this.setPlaceHolder(this.placeholder),this.tooltip&&this.setTooltip(this.tooltip),this.oninput(this.input,()=>this.onValueChange()),this.onblur(this.input,()=>this.onBlur()),this.onfocus(this.input,()=>this.onFocus()),this._register(this.ignoreGesture(this.input)),setTimeout(()=>this.updateMirror(),0),this.options.actions&&(this.actionbar=this._register(new Ir(this.element)),this.actionbar.push(this.options.actions,{icon:!0,label:!1})),this.applyStyles()}onBlur(){this._hideMessage(),this.options.showPlaceholderOnFocus&&this.input.setAttribute("placeholder","")}onFocus(){this._showMessage(),this.options.showPlaceholderOnFocus&&this.input.setAttribute("placeholder",this.placeholder||"")}setPlaceHolder(e){this.placeholder=e,this.input.setAttribute("placeholder",e)}setTooltip(e){this.tooltip=e,this.input.title=e}get inputElement(){return this.input}get value(){return this.input.value}set value(e){this.input.value!==e&&(this.input.value=e,this.onValueChange())}get height(){return typeof this.cachedHeight=="number"?this.cachedHeight:Qh(this.element)}focus(){this.input.focus()}blur(){this.input.blur()}hasFocus(){return dx(this.input)}select(e=null){this.input.select(),e&&(this.input.setSelectionRange(e.start,e.end),e.end===this.input.value.length&&(this.input.scrollLeft=this.input.scrollWidth))}isSelectionAtEnd(){return this.input.selectionEnd===this.input.value.length&&this.input.selectionStart===this.input.selectionEnd}enable(){this.input.removeAttribute("disabled")}disable(){this.blur(),this.input.disabled=!0,this._hideMessage()}set paddingRight(e){this.input.style.width=`calc(100% - ${e}px)`,this.mirror&&(this.mirror.style.paddingRight=e+"px")}updateScrollDimensions(){if(typeof this.cachedContentHeight!="number"||typeof this.cachedHeight!="number"||!this.scrollableElement)return;const e=this.cachedContentHeight,t=this.cachedHeight,i=this.input.scrollTop;this.scrollableElement.setScrollDimensions({scrollHeight:e,height:t}),this.scrollableElement.setScrollPosition({scrollTop:i})}showMessage(e,t){if(this.state==="open"&&Qo(this.message,e))return;this.message=e,this.element.classList.remove("idle"),this.element.classList.remove("info"),this.element.classList.remove("warning"),this.element.classList.remove("error"),this.element.classList.add(this.classForType(e.type));const i=this.stylesForType(this.message.type);this.element.style.border=`1px solid ${gg(i.border,"transparent")}`,this.message.content&&(this.hasFocus()||t)&&this._showMessage()}hideMessage(){this.message=null,this.element.classList.remove("info"),this.element.classList.remove("warning"),this.element.classList.remove("error"),this.element.classList.add("idle"),this._hideMessage(),this.applyStyles()}validate(){let e=null;return this.validation&&(e=this.validation(this.value),e?(this.inputElement.setAttribute("aria-invalid","true"),this.showMessage(e)):this.inputElement.hasAttribute("aria-invalid")&&(this.inputElement.removeAttribute("aria-invalid"),this.hideMessage())),e==null?void 0:e.type}stylesForType(e){const t=this.options.inputBoxStyles;switch(e){case 1:return{border:t.inputValidationInfoBorder,background:t.inputValidationInfoBackground,foreground:t.inputValidationInfoForeground};case 2:return{border:t.inputValidationWarningBorder,background:t.inputValidationWarningBackground,foreground:t.inputValidationWarningForeground};default:return{border:t.inputValidationErrorBorder,background:t.inputValidationErrorBackground,foreground:t.inputValidationErrorForeground}}}classForType(e){switch(e){case 1:return"info";case 2:return"warning";default:return"error"}}_showMessage(){if(!this.contextViewProvider||!this.message)return;let e;const t=()=>e.style.width=js(this.element)+"px";this.contextViewProvider.showContextView({getAnchor:()=>this.element,anchorAlignment:1,render:n=>{var o,r;if(!this.message)return null;e=te(n,z_(".monaco-inputbox-container")),t();const a={inline:!0,className:"monaco-inputbox-message"},l=this.message.formatContent?Ahe(this.message.content,a):Rhe(this.message.content,a);l.classList.add(this.classForType(this.message.type));const d=this.stylesForType(this.message.type);return l.style.backgroundColor=(o=d.background)!==null&&o!==void 0?o:"",l.style.color=(r=d.foreground)!==null&&r!==void 0?r:"",l.style.border=d.border?`1px solid ${d.border}`:"",te(e,l),null},onHide:()=>{this.state="closed"},layout:t});let i;this.message.type===3?i=p("alertErrorMessage","Error: {0}",this.message.content):this.message.type===2?i=p("alertWarningMessage","Warning: {0}",this.message.content):i=p("alertInfoMessage","Info: {0}",this.message.content),Lo(i),this.state="open"}_hideMessage(){this.contextViewProvider&&(this.state==="open"&&this.contextViewProvider.hideContextView(),this.state="idle")}onValueChange(){this._onDidChange.fire(this.value),this.validate(),this.updateMirror(),this.input.classList.toggle("empty",!this.value),this.state==="open"&&this.contextViewProvider&&this.contextViewProvider.layout()}updateMirror(){if(!this.mirror)return;const e=this.value,i=e.charCodeAt(e.length-1)===10?" ":"";(e+i).replace(/\u000c/g,"")?this.mirror.textContent=e+i:this.mirror.innerText=" ",this.layout()}applyStyles(){var e,t,i;const n=this.options.inputBoxStyles,o=(e=n.inputBackground)!==null&&e!==void 0?e:"",r=(t=n.inputForeground)!==null&&t!==void 0?t:"",a=(i=n.inputBorder)!==null&&i!==void 0?i:"";this.element.style.backgroundColor=o,this.element.style.color=r,this.input.style.backgroundColor="inherit",this.input.style.color=r,this.element.style.border=`1px solid ${gg(a,"transparent")}`}layout(){if(!this.mirror)return;const e=this.cachedContentHeight;this.cachedContentHeight=Qh(this.mirror),e!==this.cachedContentHeight&&(this.cachedHeight=Math.min(this.cachedContentHeight,this.maxHeight),this.input.style.height=this.cachedHeight+"px",this._onDidHeightChange.fire(this.cachedContentHeight))}insertAtCursor(e){const t=this.inputElement,i=t.selectionStart,n=t.selectionEnd,o=t.value;i!==null&&n!==null&&(this.value=o.substr(0,i)+e+o.substr(n),t.setSelectionRange(i+1,i+1),this.layout())}dispose(){var e;this._hideMessage(),this.message=null,(e=this.actionbar)===null||e===void 0||e.dispose(),super.dispose()}};class oU extends xfe{constructor(e,t,i){const n=p({key:"history.inputbox.hint.suffix.noparens",comment:['Text is the suffix of an input field placeholder coming after the action the input field performs, this will be used when the input field ends in a closing parenthesis ")", for example "Filter (e.g. text, !exclude)". The character inserted into the final string is ⇅ to represent the up and down arrow keys.']}," or {0} for history","⇅"),o=p({key:"history.inputbox.hint.suffix.inparens",comment:['Text is the suffix of an input field placeholder coming after the action the input field performs, this will be used when the input field does NOT end in a closing parenthesis (eg. "Find"). The character inserted into the final string is ⇅ to represent the up and down arrow keys.']}," ({0} for history)","⇅");super(e,t,i),this._onDidFocus=this._register(new W),this.onDidFocus=this._onDidFocus.event,this._onDidBlur=this._register(new W),this.onDidBlur=this._onDidBlur.event,this.history=new Lfe(i.history,100);const r=()=>{if(i.showHistoryHint&&i.showHistoryHint()&&!this.placeholder.endsWith(n)&&!this.placeholder.endsWith(o)&&this.history.getHistory().length){const a=this.placeholder.endsWith(")")?n:o,l=this.placeholder+a;i.showPlaceholderOnFocus&&!dx(this.input)?this.placeholder=l:this.setPlaceHolder(l)}};this.observer=new MutationObserver((a,l)=>{a.forEach(d=>{d.target.textContent||r()})}),this.observer.observe(this.input,{attributeFilter:["class"]}),this.onfocus(this.input,()=>r()),this.onblur(this.input,()=>{const a=l=>{if(this.placeholder.endsWith(l)){const d=this.placeholder.slice(0,this.placeholder.length-l.length);return i.showPlaceholderOnFocus?this.placeholder=d:this.setPlaceHolder(d),!0}else return!1};a(o)||a(n)})}dispose(){super.dispose(),this.observer&&(this.observer.disconnect(),this.observer=void 0)}addToHistory(e){this.value&&(e||this.value!==this.getCurrentValue())&&this.history.add(this.value)}isAtLastInHistory(){return this.history.isLast()}isNowhereInHistory(){return this.history.isNowhere()}showNextValue(){this.history.has(this.value)||this.addToHistory();let e=this.getNextValue();e&&(e=e===this.value?this.getNextValue():e),this.value=e??"",Au(this.value?this.value:p("clearedInput","Cleared Input"))}showPreviousValue(){this.history.has(this.value)||this.addToHistory();let e=this.getPreviousValue();e&&(e=e===this.value?this.getPreviousValue():e),e&&(this.value=e,Au(this.value))}setPlaceHolder(e){super.setPlaceHolder(e),this.setTooltip(e)}onBlur(){super.onBlur(),this._onDidBlur.fire()}onFocus(){super.onFocus(),this._onDidFocus.fire()}getCurrentValue(){let e=this.history.current();return e||(e=this.history.last(),this.history.next()),e}getPreviousValue(){return this.history.previous()||this.history.first()}getNextValue(){return this.history.next()}}const Dfe=p("defaultLabel","input");class rU extends ta{constructor(e,t,i){super(),this.fixFocusOnOptionClickEnabled=!0,this.imeSessionInProgress=!1,this.additionalTogglesDisposables=this._register(new En),this.additionalToggles=[],this._onDidOptionChange=this._register(new W),this.onDidOptionChange=this._onDidOptionChange.event,this._onKeyDown=this._register(new W),this.onKeyDown=this._onKeyDown.event,this._onMouseDown=this._register(new W),this.onMouseDown=this._onMouseDown.event,this._onInput=this._register(new W),this._onKeyUp=this._register(new W),this._onCaseSensitiveKeyDown=this._register(new W),this.onCaseSensitiveKeyDown=this._onCaseSensitiveKeyDown.event,this._onRegexKeyDown=this._register(new W),this.onRegexKeyDown=this._onRegexKeyDown.event,this._lastHighlightFindOptions=0,this.placeholder=i.placeholder||"",this.validation=i.validation,this.label=i.label||Dfe,this.showCommonFindToggles=!!i.showCommonFindToggles;const n=i.appendCaseSensitiveLabel||"",o=i.appendWholeWordsLabel||"",r=i.appendRegexLabel||"",a=i.history||[],l=!!i.flexibleHeight,d=!!i.flexibleWidth,c=i.flexibleMaxHeight;if(this.domNode=document.createElement("div"),this.domNode.classList.add("monaco-findInput"),this.inputBox=this._register(new oU(this.domNode,t,{placeholder:this.placeholder||"",ariaLabel:this.label||"",validationOptions:{validation:this.validation},history:a,showHistoryHint:i.showHistoryHint,flexibleHeight:l,flexibleWidth:d,flexibleMaxHeight:c,inputBoxStyles:i.inputBoxStyles})),this.showCommonFindToggles){this.regex=this._register(new sU({appendTitle:r,isChecked:!1,...i.toggleStyles})),this._register(this.regex.onChange(h=>{this._onDidOptionChange.fire(h),!h&&this.fixFocusOnOptionClickEnabled&&this.inputBox.focus(),this.validate()})),this._register(this.regex.onKeyDown(h=>{this._onRegexKeyDown.fire(h)})),this.wholeWords=this._register(new nU({appendTitle:o,isChecked:!1,...i.toggleStyles})),this._register(this.wholeWords.onChange(h=>{this._onDidOptionChange.fire(h),!h&&this.fixFocusOnOptionClickEnabled&&this.inputBox.focus(),this.validate()})),this.caseSensitive=this._register(new iU({appendTitle:n,isChecked:!1,...i.toggleStyles})),this._register(this.caseSensitive.onChange(h=>{this._onDidOptionChange.fire(h),!h&&this.fixFocusOnOptionClickEnabled&&this.inputBox.focus(),this.validate()})),this._register(this.caseSensitive.onKeyDown(h=>{this._onCaseSensitiveKeyDown.fire(h)}));const u=[this.caseSensitive.domNode,this.wholeWords.domNode,this.regex.domNode];this.onkeydown(this.domNode,h=>{if(h.equals(15)||h.equals(17)||h.equals(9)){const g=u.indexOf(this.domNode.ownerDocument.activeElement);if(g>=0){let f=-1;h.equals(17)?f=(g+1)%u.length:h.equals(15)&&(g===0?f=u.length-1:f=g-1),h.equals(9)?(u[g].blur(),this.inputBox.focus()):f>=0&&u[f].focus(),ot.stop(h,!0)}}})}this.controls=document.createElement("div"),this.controls.className="controls",this.controls.style.display=this.showCommonFindToggles?"":"none",this.caseSensitive&&this.controls.append(this.caseSensitive.domNode),this.wholeWords&&this.controls.appendChild(this.wholeWords.domNode),this.regex&&this.controls.appendChild(this.regex.domNode),this.setAdditionalToggles(i==null?void 0:i.additionalToggles),this.controls&&this.domNode.appendChild(this.controls),e==null||e.appendChild(this.domNode),this._register(Y(this.inputBox.inputElement,"compositionstart",u=>{this.imeSessionInProgress=!0})),this._register(Y(this.inputBox.inputElement,"compositionend",u=>{this.imeSessionInProgress=!1,this._onInput.fire()})),this.onkeydown(this.inputBox.inputElement,u=>this._onKeyDown.fire(u)),this.onkeyup(this.inputBox.inputElement,u=>this._onKeyUp.fire(u)),this.oninput(this.inputBox.inputElement,u=>this._onInput.fire()),this.onmousedown(this.inputBox.inputElement,u=>this._onMouseDown.fire(u))}get onDidChange(){return this.inputBox.onDidChange}layout(e){this.inputBox.layout(),this.updateInputBoxPadding(e.collapsedFindWidget)}enable(){var e,t,i;this.domNode.classList.remove("disabled"),this.inputBox.enable(),(e=this.regex)===null||e===void 0||e.enable(),(t=this.wholeWords)===null||t===void 0||t.enable(),(i=this.caseSensitive)===null||i===void 0||i.enable();for(const n of this.additionalToggles)n.enable()}disable(){var e,t,i;this.domNode.classList.add("disabled"),this.inputBox.disable(),(e=this.regex)===null||e===void 0||e.disable(),(t=this.wholeWords)===null||t===void 0||t.disable(),(i=this.caseSensitive)===null||i===void 0||i.disable();for(const n of this.additionalToggles)n.disable()}setFocusInputOnOptionClick(e){this.fixFocusOnOptionClickEnabled=e}setEnabled(e){e?this.enable():this.disable()}setAdditionalToggles(e){for(const t of this.additionalToggles)t.domNode.remove();this.additionalToggles=[],this.additionalTogglesDisposables.value=new ie;for(const t of e??[])this.additionalTogglesDisposables.value.add(t),this.controls.appendChild(t.domNode),this.additionalTogglesDisposables.value.add(t.onChange(i=>{this._onDidOptionChange.fire(i),!i&&this.fixFocusOnOptionClickEnabled&&this.inputBox.focus()})),this.additionalToggles.push(t);this.additionalToggles.length>0&&(this.controls.style.display=""),this.updateInputBoxPadding()}updateInputBoxPadding(e=!1){var t,i,n,o,r,a;e?this.inputBox.paddingRight=0:this.inputBox.paddingRight=((i=(t=this.caseSensitive)===null||t===void 0?void 0:t.width())!==null&&i!==void 0?i:0)+((o=(n=this.wholeWords)===null||n===void 0?void 0:n.width())!==null&&o!==void 0?o:0)+((a=(r=this.regex)===null||r===void 0?void 0:r.width())!==null&&a!==void 0?a:0)+this.additionalToggles.reduce((l,d)=>l+d.width(),0)}getValue(){return this.inputBox.value}setValue(e){this.inputBox.value!==e&&(this.inputBox.value=e)}select(){this.inputBox.select()}focus(){this.inputBox.focus()}getCaseSensitive(){var e,t;return(t=(e=this.caseSensitive)===null||e===void 0?void 0:e.checked)!==null&&t!==void 0?t:!1}setCaseSensitive(e){this.caseSensitive&&(this.caseSensitive.checked=e)}getWholeWords(){var e,t;return(t=(e=this.wholeWords)===null||e===void 0?void 0:e.checked)!==null&&t!==void 0?t:!1}setWholeWords(e){this.wholeWords&&(this.wholeWords.checked=e)}getRegex(){var e,t;return(t=(e=this.regex)===null||e===void 0?void 0:e.checked)!==null&&t!==void 0?t:!1}setRegex(e){this.regex&&(this.regex.checked=e,this.validate())}focusOnCaseSensitive(){var e;(e=this.caseSensitive)===null||e===void 0||e.focus()}highlightFindOptions(){this.domNode.classList.remove("highlight-"+this._lastHighlightFindOptions),this._lastHighlightFindOptions=1-this._lastHighlightFindOptions,this.domNode.classList.add("highlight-"+this._lastHighlightFindOptions)}validate(){this.inputBox.validate()}showMessage(e){this.inputBox.showMessage(e)}clearMessage(){this.inputBox.hideMessage()}}var Vo;(function(s){s[s.Expanded=0]="Expanded",s[s.Collapsed=1]="Collapsed",s[s.PreserveOrExpanded=2]="PreserveOrExpanded",s[s.PreserveOrCollapsed=3]="PreserveOrCollapsed"})(Vo||(Vo={}));var og;(function(s){s[s.Unknown=0]="Unknown",s[s.Twistie=1]="Twistie",s[s.Element=2]="Element",s[s.Filter=3]="Filter"})(og||(og={}));class jo extends Error{constructor(e,t){super(`TreeError [${e}] ${t}`)}}class mO{constructor(e){this.fn=e,this._map=new WeakMap}map(e){let t=this._map.get(e);return t||(t=this.fn(e),this._map.set(e,t)),t}}function _O(s){return typeof s=="object"&&"visibility"in s&&"data"in s}function cb(s){switch(s){case!0:return 1;case!1:return 0;default:return s}}function zI(s){return typeof s.collapsible=="boolean"}class kfe{constructor(e,t,i,n={}){this.user=e,this.list=t,this.rootRef=[],this.eventBufferer=new MA,this._onDidChangeCollapseState=new W,this.onDidChangeCollapseState=this.eventBufferer.wrapEvent(this._onDidChangeCollapseState.event),this._onDidChangeRenderNodeCount=new W,this.onDidChangeRenderNodeCount=this.eventBufferer.wrapEvent(this._onDidChangeRenderNodeCount.event),this._onDidSplice=new W,this.onDidSplice=this._onDidSplice.event,this.refilterDelayer=new Qr(nV),this.collapseByDefault=typeof n.collapseByDefault>"u"?!1:n.collapseByDefault,this.filter=n.filter,this.autoExpandSingleChildren=typeof n.autoExpandSingleChildren>"u"?!1:n.autoExpandSingleChildren,this.root={parent:void 0,element:i,children:[],depth:0,visibleChildrenCount:0,visibleChildIndex:-1,collapsible:!1,collapsed:!1,renderNodeCount:0,visibility:1,visible:!0,filterData:void 0}}splice(e,t,i=ht.empty(),n={}){if(e.length===0)throw new jo(this.user,"Invalid tree location");n.diffIdentityProvider?this.spliceSmart(n.diffIdentityProvider,e,t,i,n):this.spliceSimple(e,t,i,n)}spliceSmart(e,t,i,n,o,r){var a;n===void 0&&(n=ht.empty()),r===void 0&&(r=(a=o.diffDepth)!==null&&a!==void 0?a:0);const{parentNode:l}=this.getParentNodeWithListIndex(t);if(!l.lastDiffIds)return this.spliceSimple(t,i,n,o);const d=[...n],c=t[t.length-1],u=new vl({getElements:()=>l.lastDiffIds},{getElements:()=>[...l.children.slice(0,c),...d,...l.children.slice(c+i)].map(_=>e.getId(_.element).toString())}).ComputeDiff(!1);if(u.quitEarly)return l.lastDiffIds=void 0,this.spliceSimple(t,i,d,o);const h=t.slice(0,-1),g=(_,v,b)=>{if(r>0)for(let C=0;C<b;C++)_--,v--,this.spliceSmart(e,[...h,_,0],Number.MAX_SAFE_INTEGER,d[v].children,o,r-1)};let f=Math.min(l.children.length,c+i),m=d.length;for(const _ of u.changes.sort((v,b)=>b.originalStart-v.originalStart))g(f,m,f-(_.originalStart+_.originalLength)),f=_.originalStart,m=_.modifiedStart-c,this.spliceSimple([...h,f],_.originalLength,ht.slice(d,m,m+_.modifiedLength),o);g(f,m,f)}spliceSimple(e,t,i=ht.empty(),{onDidCreateNode:n,onDidDeleteNode:o,diffIdentityProvider:r}){const{parentNode:a,listIndex:l,revealed:d,visible:c}=this.getParentNodeWithListIndex(e),u=[],h=ht.map(i,L=>this.createTreeNode(L,a,a.visible?1:0,d,u,n)),g=e[e.length-1],f=a.children.length>0;let m=0;for(let L=g;L>=0&&L<a.children.length;L--){const k=a.children[L];if(k.visible){m=k.visibleChildIndex;break}}const _=[];let v=0,b=0;for(const L of h)_.push(L),b+=L.renderNodeCount,L.visible&&(L.visibleChildIndex=m+v++);const C=ZF(a.children,g,t,_);r?a.lastDiffIds?ZF(a.lastDiffIds,g,t,_.map(L=>r.getId(L.element).toString())):a.lastDiffIds=a.children.map(L=>r.getId(L.element).toString()):a.lastDiffIds=void 0;let w=0;for(const L of C)L.visible&&w++;if(w!==0)for(let L=g+_.length;L<a.children.length;L++){const k=a.children[L];k.visible&&(k.visibleChildIndex-=w)}if(a.visibleChildrenCount+=v-w,d&&c){const L=C.reduce((k,I)=>k+(I.visible?I.renderNodeCount:0),0);this._updateAncestorsRenderNodeCount(a,b-L),this.list.splice(l,L,u)}if(C.length>0&&o){const L=k=>{o(k),k.children.forEach(L)};C.forEach(L)}this._onDidSplice.fire({insertedNodes:_,deletedNodes:C});const S=a.children.length>0;f!==S&&this.setCollapsible(e.slice(0,-1),S);let x=a;for(;x;){if(x.visibility===2){this.refilterDelayer.trigger(()=>this.refilter());break}x=x.parent}}rerender(e){if(e.length===0)throw new jo(this.user,"Invalid tree location");const{node:t,listIndex:i,revealed:n}=this.getTreeNodeWithListIndex(e);t.visible&&n&&this.list.splice(i,1,[t])}has(e){return this.hasTreeNode(e)}getListIndex(e){const{listIndex:t,visible:i,revealed:n}=this.getTreeNodeWithListIndex(e);return i&&n?t:-1}getListRenderCount(e){return this.getTreeNode(e).renderNodeCount}isCollapsible(e){return this.getTreeNode(e).collapsible}setCollapsible(e,t){const i=this.getTreeNode(e);typeof t>"u"&&(t=!i.collapsible);const n={collapsible:t};return this.eventBufferer.bufferEvents(()=>this._setCollapseState(e,n))}isCollapsed(e){return this.getTreeNode(e).collapsed}setCollapsed(e,t,i){const n=this.getTreeNode(e);typeof t>"u"&&(t=!n.collapsed);const o={collapsed:t,recursive:i||!1};return this.eventBufferer.bufferEvents(()=>this._setCollapseState(e,o))}_setCollapseState(e,t){const{node:i,listIndex:n,revealed:o}=this.getTreeNodeWithListIndex(e),r=this._setListNodeCollapseState(i,n,o,t);if(i!==this.root&&this.autoExpandSingleChildren&&r&&!zI(t)&&i.collapsible&&!i.collapsed&&!t.recursive){let a=-1;for(let l=0;l<i.children.length;l++)if(i.children[l].visible)if(a>-1){a=-1;break}else a=l;a>-1&&this._setCollapseState([...e,a],t)}return r}_setListNodeCollapseState(e,t,i,n){const o=this._setNodeCollapseState(e,n,!1);if(!i||!e.visible||!o)return o;const r=e.renderNodeCount,a=this.updateNodeAfterCollapseChange(e),l=r-(t===-1?0:1);return this.list.splice(t+1,l,a.slice(1)),o}_setNodeCollapseState(e,t,i){let n;if(e===this.root?n=!1:(zI(t)?(n=e.collapsible!==t.collapsible,e.collapsible=t.collapsible):e.collapsible?(n=e.collapsed!==t.collapsed,e.collapsed=t.collapsed):n=!1,n&&this._onDidChangeCollapseState.fire({node:e,deep:i})),!zI(t)&&t.recursive)for(const o of e.children)n=this._setNodeCollapseState(o,t,!0)||n;return n}expandTo(e){this.eventBufferer.bufferEvents(()=>{let t=this.getTreeNode(e);for(;t.parent;)t=t.parent,e=e.slice(0,e.length-1),t.collapsed&&this._setCollapseState(e,{collapsed:!1,recursive:!1})})}refilter(){const e=this.root.renderNodeCount,t=this.updateNodeAfterFilterChange(this.root);this.list.splice(0,e,t),this.refilterDelayer.cancel()}createTreeNode(e,t,i,n,o,r){const a={parent:t,element:e.element,children:[],depth:t.depth+1,visibleChildrenCount:0,visibleChildIndex:-1,collapsible:typeof e.collapsible=="boolean"?e.collapsible:typeof e.collapsed<"u",collapsed:typeof e.collapsed>"u"?this.collapseByDefault:e.collapsed,renderNodeCount:1,visibility:1,visible:!0,filterData:void 0},l=this._filterNode(a,i);a.visibility=l,n&&o.push(a);const d=e.children||ht.empty(),c=n&&l!==0&&!a.collapsed;let u=0,h=1;for(const g of d){const f=this.createTreeNode(g,a,l,c,o,r);a.children.push(f),h+=f.renderNodeCount,f.visible&&(f.visibleChildIndex=u++)}return a.collapsible=a.collapsible||a.children.length>0,a.visibleChildrenCount=u,a.visible=l===2?u>0:l===1,a.visible?a.collapsed||(a.renderNodeCount=h):(a.renderNodeCount=0,n&&o.pop()),r==null||r(a),a}updateNodeAfterCollapseChange(e){const t=e.renderNodeCount,i=[];return this._updateNodeAfterCollapseChange(e,i),this._updateAncestorsRenderNodeCount(e.parent,i.length-t),i}_updateNodeAfterCollapseChange(e,t){if(e.visible===!1)return 0;if(t.push(e),e.renderNodeCount=1,!e.collapsed)for(const i of e.children)e.renderNodeCount+=this._updateNodeAfterCollapseChange(i,t);return this._onDidChangeRenderNodeCount.fire(e),e.renderNodeCount}updateNodeAfterFilterChange(e){const t=e.renderNodeCount,i=[];return this._updateNodeAfterFilterChange(e,e.visible?1:0,i),this._updateAncestorsRenderNodeCount(e.parent,i.length-t),i}_updateNodeAfterFilterChange(e,t,i,n=!0){let o;if(e!==this.root){if(o=this._filterNode(e,t),o===0)return e.visible=!1,e.renderNodeCount=0,!1;n&&i.push(e)}const r=i.length;e.renderNodeCount=e===this.root?0:1;let a=!1;if(!e.collapsed||o!==0){let l=0;for(const d of e.children)a=this._updateNodeAfterFilterChange(d,o,i,n&&!e.collapsed)||a,d.visible&&(d.visibleChildIndex=l++);e.visibleChildrenCount=l}else e.visibleChildrenCount=0;return e!==this.root&&(e.visible=o===2?a:o===1,e.visibility=o),e.visible?e.collapsed||(e.renderNodeCount+=i.length-r):(e.renderNodeCount=0,n&&i.pop()),this._onDidChangeRenderNodeCount.fire(e),e.visible}_updateAncestorsRenderNodeCount(e,t){if(t!==0)for(;e;)e.renderNodeCount+=t,this._onDidChangeRenderNodeCount.fire(e),e=e.parent}_filterNode(e,t){const i=this.filter?this.filter.filter(e.element,t):1;return typeof i=="boolean"?(e.filterData=void 0,i?1:0):_O(i)?(e.filterData=i.data,cb(i.visibility)):(e.filterData=void 0,cb(i))}hasTreeNode(e,t=this.root){if(!e||e.length===0)return!0;const[i,...n]=e;return i<0||i>t.children.length?!1:this.hasTreeNode(n,t.children[i])}getTreeNode(e,t=this.root){if(!e||e.length===0)return t;const[i,...n]=e;if(i<0||i>t.children.length)throw new jo(this.user,"Invalid tree location");return this.getTreeNode(n,t.children[i])}getTreeNodeWithListIndex(e){if(e.length===0)return{node:this.root,listIndex:-1,revealed:!0,visible:!1};const{parentNode:t,listIndex:i,revealed:n,visible:o}=this.getParentNodeWithListIndex(e),r=e[e.length-1];if(r<0||r>t.children.length)throw new jo(this.user,"Invalid tree location");const a=t.children[r];return{node:a,listIndex:i,revealed:n,visible:o&&a.visible}}getParentNodeWithListIndex(e,t=this.root,i=0,n=!0,o=!0){const[r,...a]=e;if(r<0||r>t.children.length)throw new jo(this.user,"Invalid tree location");for(let l=0;l<r;l++)i+=t.children[l].renderNodeCount;return n=n&&!t.collapsed,o=o&&t.visible,a.length===0?{parentNode:t,listIndex:i,revealed:n,visible:o}:this.getParentNodeWithListIndex(a,t.children[r],i+1,n,o)}getNode(e=[]){return this.getTreeNode(e)}getNodeLocation(e){const t=[];let i=e;for(;i.parent;)t.push(i.parent.children.indexOf(i)),i=i.parent;return t.reverse()}getParentNodeLocation(e){if(e.length!==0)return e.length===1?[]:XY(e)[0]}getFirstElementChild(e){const t=this.getTreeNode(e);if(t.children.length!==0)return t.children[0].element}}class Ife extends wC{constructor(e){super(e.elements.map(t=>t.element)),this.data=e}}function UI(s){return s instanceof wC?new Ife(s):s}class Efe{constructor(e,t){this.modelProvider=e,this.dnd=t,this.autoExpandDisposable=j.None,this.disposables=new ie}getDragURI(e){return this.dnd.getDragURI(e.element)}getDragLabel(e,t){if(this.dnd.getDragLabel)return this.dnd.getDragLabel(e.map(i=>i.element),t)}onDragStart(e,t){var i,n;(n=(i=this.dnd).onDragStart)===null||n===void 0||n.call(i,UI(e),t)}onDragOver(e,t,i,n,o=!0){const r=this.dnd.onDragOver(UI(e),t&&t.element,i,n),a=this.autoExpandNode!==t;if(a&&(this.autoExpandDisposable.dispose(),this.autoExpandNode=t),typeof t>"u")return r;if(a&&typeof r!="boolean"&&r.autoExpand&&(this.autoExpandDisposable=Eu(()=>{const h=this.modelProvider(),g=h.getNodeLocation(t);h.isCollapsed(g)&&h.setCollapsed(g,!1),this.autoExpandNode=void 0},500,this.disposables)),typeof r=="boolean"||!r.accept||typeof r.bubble>"u"||r.feedback){if(!o){const h=typeof r=="boolean"?r:r.accept,g=typeof r=="boolean"?void 0:r.effect;return{accept:h,effect:g,feedback:[i]}}return r}if(r.bubble===1){const h=this.modelProvider(),g=h.getNodeLocation(t),f=h.getParentNodeLocation(g),m=h.getNode(f),_=f&&h.getListIndex(f);return this.onDragOver(e,m,_,n,!1)}const l=this.modelProvider(),d=l.getNodeLocation(t),c=l.getListIndex(d),u=l.getListRenderCount(d);return{...r,feedback:Ls(c,c+u)}}drop(e,t,i,n){this.autoExpandDisposable.dispose(),this.autoExpandNode=void 0,this.dnd.drop(UI(e),t&&t.element,i,n)}onDragEnd(e){var t,i;(i=(t=this.dnd).onDragEnd)===null||i===void 0||i.call(t,e)}dispose(){this.disposables.dispose(),this.dnd.dispose()}}function Nfe(s,e){return e&&{...e,identityProvider:e.identityProvider&&{getId(t){return e.identityProvider.getId(t.element)}},dnd:e.dnd&&new Efe(s,e.dnd),multipleSelectionController:e.multipleSelectionController&&{isSelectionSingleChangeEvent(t){return e.multipleSelectionController.isSelectionSingleChangeEvent({...t,element:t.element})},isSelectionRangeChangeEvent(t){return e.multipleSelectionController.isSelectionRangeChangeEvent({...t,element:t.element})}},accessibilityProvider:e.accessibilityProvider&&{...e.accessibilityProvider,getSetSize(t){const i=s(),n=i.getNodeLocation(t),o=i.getParentNodeLocation(n);return i.getNode(o).visibleChildrenCount},getPosInSet(t){return t.visibleChildIndex+1},isChecked:e.accessibilityProvider&&e.accessibilityProvider.isChecked?t=>e.accessibilityProvider.isChecked(t.element):void 0,getRole:e.accessibilityProvider&&e.accessibilityProvider.getRole?t=>e.accessibilityProvider.getRole(t.element):()=>"treeitem",getAriaLabel(t){return e.accessibilityProvider.getAriaLabel(t.element)},getWidgetAriaLabel(){return e.accessibilityProvider.getWidgetAriaLabel()},getWidgetRole:e.accessibilityProvider&&e.accessibilityProvider.getWidgetRole?()=>e.accessibilityProvider.getWidgetRole():()=>"tree",getAriaLevel:e.accessibilityProvider&&e.accessibilityProvider.getAriaLevel?t=>e.accessibilityProvider.getAriaLevel(t.element):t=>t.depth,getActiveDescendantId:e.accessibilityProvider.getActiveDescendantId&&(t=>e.accessibilityProvider.getActiveDescendantId(t.element))},keyboardNavigationLabelProvider:e.keyboardNavigationLabelProvider&&{...e.keyboardNavigationLabelProvider,getKeyboardNavigationLabel(t){return e.keyboardNavigationLabelProvider.getKeyboardNavigationLabel(t.element)}}}}class vO{constructor(e){this.delegate=e}getHeight(e){return this.delegate.getHeight(e.element)}getTemplateId(e){return this.delegate.getTemplateId(e.element)}hasDynamicHeight(e){return!!this.delegate.hasDynamicHeight&&this.delegate.hasDynamicHeight(e.element)}setDynamicHeight(e,t){var i,n;(n=(i=this.delegate).setDynamicHeight)===null||n===void 0||n.call(i,e.element,t)}}var ub;(function(s){s.None="none",s.OnHover="onHover",s.Always="always"})(ub||(ub={}));class Tfe{get elements(){return this._elements}constructor(e,t=[]){this._elements=t,this.disposables=new ie,this.onDidChange=ge.forEach(e,i=>this._elements=i,this.disposables)}dispose(){this.disposables.dispose()}}class hb{constructor(e,t,i,n,o,r={}){var a;this.renderer=e,this.modelProvider=t,this.activeNodes=n,this.renderedIndentGuides=o,this.renderedElements=new Map,this.renderedNodes=new Map,this.indent=hb.DefaultIndent,this.hideTwistiesOfChildlessElements=!1,this.shouldRenderIndentGuides=!1,this.activeIndentNodes=new Set,this.indentGuidesDisposable=j.None,this.disposables=new ie,this.templateId=e.templateId,this.updateOptions(r),ge.map(i,l=>l.node)(this.onDidChangeNodeTwistieState,this,this.disposables),(a=e.onDidChangeTwistieState)===null||a===void 0||a.call(e,this.onDidChangeTwistieState,this,this.disposables)}updateOptions(e={}){if(typeof e.indent<"u"){const t=co(e.indent,0,40);if(t!==this.indent){this.indent=t;for(const[i,n]of this.renderedNodes)this.renderTreeElement(i,n)}}if(typeof e.renderIndentGuides<"u"){const t=e.renderIndentGuides!==ub.None;if(t!==this.shouldRenderIndentGuides){this.shouldRenderIndentGuides=t;for(const[i,n]of this.renderedNodes)this._renderIndentGuides(i,n);if(this.indentGuidesDisposable.dispose(),t){const i=new ie;this.activeNodes.onDidChange(this._onDidChangeActiveNodes,this,i),this.indentGuidesDisposable=i,this._onDidChangeActiveNodes(this.activeNodes.elements)}}}typeof e.hideTwistiesOfChildlessElements<"u"&&(this.hideTwistiesOfChildlessElements=e.hideTwistiesOfChildlessElements)}renderTemplate(e){const t=te(e,se(".monaco-tl-row")),i=te(t,se(".monaco-tl-indent")),n=te(t,se(".monaco-tl-twistie")),o=te(t,se(".monaco-tl-contents")),r=this.renderer.renderTemplate(o);return{container:e,indent:i,twistie:n,indentGuidesDisposable:j.None,templateData:r}}renderElement(e,t,i,n){this.renderedNodes.set(e,i),this.renderedElements.set(e.element,e),this.renderTreeElement(e,i),this.renderer.renderElement(e,t,i.templateData,n)}disposeElement(e,t,i,n){var o,r;i.indentGuidesDisposable.dispose(),(r=(o=this.renderer).disposeElement)===null||r===void 0||r.call(o,e,t,i.templateData,n),typeof n=="number"&&(this.renderedNodes.delete(e),this.renderedElements.delete(e.element))}disposeTemplate(e){this.renderer.disposeTemplate(e.templateData)}onDidChangeTwistieState(e){const t=this.renderedElements.get(e);t&&this.onDidChangeNodeTwistieState(t)}onDidChangeNodeTwistieState(e){const t=this.renderedNodes.get(e);t&&(this._onDidChangeActiveNodes(this.activeNodes.elements),this.renderTreeElement(e,t))}renderTreeElement(e,t){const i=hb.DefaultIndent+(e.depth-1)*this.indent;t.twistie.style.paddingLeft=`${i}px`,t.indent.style.width=`${i+this.indent-16}px`,e.collapsible?t.container.setAttribute("aria-expanded",String(!e.collapsed)):t.container.removeAttribute("aria-expanded"),t.twistie.classList.remove(...Oe.asClassNameArray(le.treeItemExpanded));let n=!1;this.renderer.renderTwistie&&(n=this.renderer.renderTwistie(e.element,t.twistie)),e.collapsible&&(!this.hideTwistiesOfChildlessElements||e.visibleChildrenCount>0)?(n||t.twistie.classList.add(...Oe.asClassNameArray(le.treeItemExpanded)),t.twistie.classList.add("collapsible"),t.twistie.classList.toggle("collapsed",e.collapsed)):t.twistie.classList.remove("collapsible","collapsed"),this._renderIndentGuides(e,t)}_renderIndentGuides(e,t){if(Vn(t.indent),t.indentGuidesDisposable.dispose(),!this.shouldRenderIndentGuides)return;const i=new ie,n=this.modelProvider();for(;;){const o=n.getNodeLocation(e),r=n.getParentNodeLocation(o);if(!r)break;const a=n.getNode(r),l=se(".indent-guide",{style:`width: ${this.indent}px`});this.activeIndentNodes.has(a)&&l.classList.add("active"),t.indent.childElementCount===0?t.indent.appendChild(l):t.indent.insertBefore(l,t.indent.firstElementChild),this.renderedIndentGuides.add(a,l),i.add(Fe(()=>this.renderedIndentGuides.delete(a,l))),e=a}t.indentGuidesDisposable=i}_onDidChangeActiveNodes(e){if(!this.shouldRenderIndentGuides)return;const t=new Set,i=this.modelProvider();e.forEach(n=>{const o=i.getNodeLocation(n);try{const r=i.getParentNodeLocation(o);n.collapsible&&n.children.length>0&&!n.collapsed?t.add(n):r&&t.add(i.getNode(r))}catch{}}),this.activeIndentNodes.forEach(n=>{t.has(n)||this.renderedIndentGuides.forEach(n,o=>o.classList.remove("active"))}),t.forEach(n=>{this.activeIndentNodes.has(n)||this.renderedIndentGuides.forEach(n,o=>o.classList.add("active"))}),this.activeIndentNodes=t}dispose(){this.renderedNodes.clear(),this.renderedElements.clear(),this.indentGuidesDisposable.dispose(),Bt(this.disposables)}}hb.DefaultIndent=8;class Mfe{get totalCount(){return this._totalCount}get matchCount(){return this._matchCount}constructor(e,t,i){this.tree=e,this.keyboardNavigationLabelProvider=t,this._filter=i,this._totalCount=0,this._matchCount=0,this._pattern="",this._lowercasePattern="",this.disposables=new ie,e.onWillRefilter(this.reset,this,this.disposables)}filter(e,t){let i=1;if(this._filter){const r=this._filter.filter(e,t);if(typeof r=="boolean"?i=r?1:0:_O(r)?i=cb(r.visibility):i=r,i===0)return!1}if(this._totalCount++,!this._pattern)return this._matchCount++,{data:Fa.Default,visibility:i};const n=this.keyboardNavigationLabelProvider.getKeyboardNavigationLabel(e),o=Array.isArray(n)?n:[n];for(const r of o){const a=r&&r.toString();if(typeof a>"u")return{data:Fa.Default,visibility:i};let l;if(this.tree.findMatchType===Fg.Contiguous){const d=a.toLowerCase().indexOf(this._lowercasePattern);if(d>-1){l=[Number.MAX_SAFE_INTEGER,0];for(let c=this._lowercasePattern.length;c>0;c--)l.push(d+c-1)}}else l=Pg(this._pattern,this._lowercasePattern,0,a,a.toLowerCase(),0,{firstMatchCanBeWeak:!0,boostFullMatch:!0});if(l)return this._matchCount++,o.length===1?{data:l,visibility:i}:{data:{label:a,score:l},visibility:i}}return this.tree.findMode===Pl.Filter?typeof this.tree.options.defaultFindVisibility=="number"?this.tree.options.defaultFindVisibility:this.tree.options.defaultFindVisibility?this.tree.options.defaultFindVisibility(e):2:{data:Fa.Default,visibility:i}}reset(){this._totalCount=0,this._matchCount=0}dispose(){Bt(this.disposables)}}var Pl;(function(s){s[s.Highlight=0]="Highlight",s[s.Filter=1]="Filter"})(Pl||(Pl={}));var Fg;(function(s){s[s.Fuzzy=0]="Fuzzy",s[s.Contiguous=1]="Contiguous"})(Fg||(Fg={}));let Rfe=class{get pattern(){return this._pattern}get mode(){return this._mode}set mode(e){e!==this._mode&&(this._mode=e,this.widget&&(this.widget.mode=this._mode),this.tree.refilter(),this.render(),this._onDidChangeMode.fire(e))}get matchType(){return this._matchType}set matchType(e){e!==this._matchType&&(this._matchType=e,this.widget&&(this.widget.matchType=this._matchType),this.tree.refilter(),this.render(),this._onDidChangeMatchType.fire(e))}constructor(e,t,i,n,o,r={}){var a,l;this.tree=e,this.view=i,this.filter=n,this.contextViewProvider=o,this.options=r,this._pattern="",this.width=0,this._onDidChangeMode=new W,this.onDidChangeMode=this._onDidChangeMode.event,this._onDidChangeMatchType=new W,this.onDidChangeMatchType=this._onDidChangeMatchType.event,this._onDidChangePattern=new W,this._onDidChangeOpenState=new W,this.onDidChangeOpenState=this._onDidChangeOpenState.event,this.enabledDisposables=new ie,this.disposables=new ie,this._mode=(a=e.options.defaultFindMode)!==null&&a!==void 0?a:Pl.Highlight,this._matchType=(l=e.options.defaultFindMatchType)!==null&&l!==void 0?l:Fg.Fuzzy,t.onDidSplice(this.onDidSpliceModel,this,this.disposables)}updateOptions(e={}){e.defaultFindMode!==void 0&&(this.mode=e.defaultFindMode),e.defaultFindMatchType!==void 0&&(this.matchType=e.defaultFindMatchType)}onDidSpliceModel(){!this.widget||this.pattern.length===0||(this.tree.refilter(),this.render())}render(){var e,t,i,n;const o=this.filter.totalCount>0&&this.filter.matchCount===0;this.pattern&&o?!((e=this.tree.options.showNotFoundMessage)!==null&&e!==void 0)||e?(t=this.widget)===null||t===void 0||t.showMessage({type:2,content:p("not found","No elements found.")}):(i=this.widget)===null||i===void 0||i.showMessage({type:2}):(n=this.widget)===null||n===void 0||n.clearMessage()}shouldAllowFocus(e){return!this.widget||!this.pattern||this._mode===Pl.Filter||this.filter.totalCount>0&&this.filter.matchCount<=1?!0:!Fa.isDefault(e.filterData)}layout(e){var t;this.width=e,(t=this.widget)===null||t===void 0||t.layout(e)}dispose(){this._history=void 0,this._onDidChangePattern.dispose(),this.enabledDisposables.dispose(),this.disposables.dispose()}};function Afe(s,e){return s.position===e.position&&s.node.element===e.node.element&&s.startIndex===e.startIndex&&s.height===e.height&&s.endIndex===e.endIndex}class Pfe extends j{constructor(e=[]){super(),this.stickyNodes=e}get count(){return this.stickyNodes.length}equal(e){return Ai(this.stickyNodes,e.stickyNodes,Afe)}addDisposable(e){this._register(e)}}let p9=class extends j{get firstVisibleNode(){const e=this.view.firstVisibleIndex;if(!(e<0||e>=this.view.length))return this.view.element(e)}constructor(e,t,i,n,o,r={}){super(),this.tree=e,this.model=t,this.view=i,this.treeDelegate=o,this.maxWidgetViewRatio=.4;const a=this.validateStickySettings(r);this.stickyScrollMaxItemCount=a.stickyScrollMaxItemCount,this._widget=this._register(new Ofe(i.getScrollableElement(),i,t,n,o)),this._register(i.onDidScroll(()=>this.update())),this._register(i.onDidChangeContentHeight(()=>this.update())),this._register(e.onDidChangeCollapseState(()=>this.update())),this.update()}update(){const e=this.firstVisibleNode;if(!e||this.tree.scrollTop===0){this._widget.setState(void 0);return}const t=this.findStickyState(e);this._widget.setState(t)}findStickyState(e){const t=[],i=this.view.renderHeight*this.maxWidgetViewRatio;let n=e,o=0,r=this.getNextStickyNode(n,void 0,o);for(;r&&o+r.height<i&&(t.push(r),o+=r.height,!(t.length>=this.stickyScrollMaxItemCount||(n=this.getNextVisibleNode(n),!n)));)r=this.getNextStickyNode(n,r.node,o);return t.length?new Pfe(t):void 0}getNextVisibleNode(e){const t=this.getNodeIndex(e);return t===-1||t===this.view.length-1?void 0:this.view.element(t+1)}getNextStickyNode(e,t,i){const n=this.getAncestorUnderPrevious(e,t);if(n&&!(n===e&&(!this.nodeIsUncollapsedParent(e)||this.nodeTopAlignsWithStickyNodesBottom(e,i))))return this.createStickyScrollNode(n,i)}nodeTopAlignsWithStickyNodesBottom(e,t){const i=this.getNodeIndex(e),n=this.view.getElementTop(i),o=t;return this.view.scrollTop===n-o}createStickyScrollNode(e,t){const i=this.treeDelegate.getHeight(e),{startIndex:n,endIndex:o}=this.getNodeRange(e),r=this.calculateStickyNodePosition(o,t);return{node:e,position:r,height:i,startIndex:n,endIndex:o}}getAncestorUnderPrevious(e,t=void 0){let i=e,n=this.getParentNode(i);for(;n;){if(n===t)return i;i=n,n=this.getParentNode(i)}if(t===void 0)return i}calculateStickyNodePosition(e,t){let i=this.view.getRelativeTop(e);if(i===null&&this.view.firstVisibleIndex===e&&e+1<this.view.length){const l=this.treeDelegate.getHeight(this.view.element(e)),d=this.view.getRelativeTop(e+1);i=d?d-l/this.view.renderHeight:null}if(i===null)return t;const n=this.view.element(e),o=this.treeDelegate.getHeight(n),r=i*this.view.renderHeight,a=r+o;return t>r&&t<=a?r:t}getParentNode(e){const t=this.model.getNodeLocation(e),i=this.model.getParentNodeLocation(t);return i?this.model.getNode(i):void 0}nodeIsUncollapsedParent(e){const t=this.model.getNodeLocation(e);return this.model.getListRenderCount(t)>1}getNodeIndex(e,t){return t===void 0&&(t=this.model.getNodeLocation(e)),this.model.getListIndex(t)}getNodeRange(e){const t=this.model.getNodeLocation(e),i=this.model.getListIndex(t);if(i<0)throw new Error("Node not found in tree");const n=this.model.getListRenderCount(t),o=i+n-1;return{startIndex:i,endIndex:o}}nodePositionTopBelowWidget(e){const t=[];let i=this.getParentNode(e);for(;i;)t.push(i),i=this.getParentNode(i);let n=0;for(let o=0;o<t.length&&o<this.stickyScrollMaxItemCount;o++)n+=this.treeDelegate.getHeight(t[o]);return n}updateOptions(e={}){const t=this.validateStickySettings(e);this.stickyScrollMaxItemCount!==t.stickyScrollMaxItemCount&&(this.stickyScrollMaxItemCount=t.stickyScrollMaxItemCount,this.update())}validateStickySettings(e){let t=5;return typeof e.stickyScrollMaxItemCount=="number"&&(t=Math.max(e.stickyScrollMaxItemCount,1)),{stickyScrollMaxItemCount:t}}},Ofe=class{constructor(e,t,i,n,o){this.view=t,this.model=i,this.treeRenderers=n,this.treeDelegate=o,this._rootDomNode=document.createElement("div"),this._rootDomNode.classList.add("monaco-tree-sticky-container"),e.appendChild(this._rootDomNode)}setState(e){var t;const i=!!this._previousState&&this._previousState.count>0,n=!!e&&e.count>0;if(!i&&!n||i&&n&&this._previousState.equal(e)||(i!==n&&this.setVisible(n),(t=this._previousState)===null||t===void 0||t.dispose(),this._previousState=e,!n))return;for(let a=e.count-1;a>=0;a--){const l=e.stickyNodes[a],d=a?e.stickyNodes[a-1]:void 0,c=d?d.position+d.height:0,{element:u,disposable:h}=this.createElement(l,c);this._rootDomNode.appendChild(u),e.addDisposable(h)}const o=se(".monaco-tree-sticky-container-shadow");this._rootDomNode.appendChild(o),e.addDisposable(Fe(()=>o.remove()));const r=e.stickyNodes[e.count-1];this._rootDomNode.style.height=`${r.position+r.height}px`}createElement(e,t){const i=this.model.getNodeLocation(e.node),n=this.model.getListIndex(i),o=document.createElement("div");o.style.top=`${e.position}px`,o.style.height=`${e.height}px`,o.style.lineHeight=`${e.height}px`,o.classList.add("monaco-tree-sticky-row"),o.classList.add("monaco-list-row"),o.setAttribute("data-index",`${n}`),o.setAttribute("data-parity",n%2===0?"even":"odd"),o.setAttribute("id",this.view.getElementID(n));const r=this.treeDelegate.getTemplateId(e.node),a=this.treeRenderers.find(u=>u.templateId===r);if(!a)throw new Error(`No renderer found for template id ${r}`);const l=new Proxy(e.node,{}),d=a.renderTemplate(o);a.renderElement(l,e.startIndex,d,e.height);const c=Fe(()=>{a.disposeElement(l,e.startIndex,d,e.height),a.disposeTemplate(d),o.remove()});return{element:o,disposable:c}}setVisible(e){this._rootDomNode.style.display=e?"block":"none"}dispose(){var e;(e=this._previousState)===null||e===void 0||e.dispose(),this._rootDomNode.remove()}};function m9(s){let e=og.Unknown;return zk(s.browserEvent.target,"monaco-tl-twistie","monaco-tl-row")?e=og.Twistie:zk(s.browserEvent.target,"monaco-tl-contents","monaco-tl-row")?e=og.Element:zk(s.browserEvent.target,"monaco-tree-type-filter","monaco-list")&&(e=og.Filter),{browserEvent:s.browserEvent,element:s.element?s.element.element:null,target:e}}function Gw(s,e){e(s),s.children.forEach(t=>Gw(t,e))}class $I{get nodeSet(){return this._nodeSet||(this._nodeSet=this.createNodeSet()),this._nodeSet}constructor(e,t){this.getFirstViewElementWithTrait=e,this.identityProvider=t,this.nodes=[],this._onDidChange=new W,this.onDidChange=this._onDidChange.event}set(e,t){!(t!=null&&t.__forceEvent)&&Ai(this.nodes,e)||this._set(e,!1,t)}_set(e,t,i){if(this.nodes=[...e],this.elements=void 0,this._nodeSet=void 0,!t){const n=this;this._onDidChange.fire({get elements(){return n.get()},browserEvent:i})}}get(){return this.elements||(this.elements=this.nodes.map(e=>e.element)),[...this.elements]}getNodes(){return this.nodes}has(e){return this.nodeSet.has(e)}onDidModelSplice({insertedNodes:e,deletedNodes:t}){if(!this.identityProvider){const l=this.createNodeSet(),d=c=>l.delete(c);t.forEach(c=>Gw(c,d)),this.set([...l.values()]);return}const i=new Set,n=l=>i.add(this.identityProvider.getId(l.element).toString());t.forEach(l=>Gw(l,n));const o=new Map,r=l=>o.set(this.identityProvider.getId(l.element).toString(),l);e.forEach(l=>Gw(l,r));const a=[];for(const l of this.nodes){const d=this.identityProvider.getId(l.element).toString();if(!i.has(d))a.push(l);else{const u=o.get(d);u&&u.visible&&a.push(u)}}if(this.nodes.length>0&&a.length===0){const l=this.getFirstViewElementWithTrait();l&&a.push(l)}this._set(a,!0)}createNodeSet(){const e=new Set;for(const t of this.nodes)e.add(t);return e}}class Ffe extends Gz{constructor(e,t,i){super(e),this.tree=t,this.stickyScrollProvider=i}onViewPointer(e){if($z(e.browserEvent.target)||gu(e.browserEvent.target)||bv(e.browserEvent.target)||e.browserEvent.isHandledByList)return;const t=e.element;if(!t)return super.onViewPointer(e);if(this.isSelectionRangeChangeEvent(e)||this.isSelectionSingleChangeEvent(e))return super.onViewPointer(e);const i=e.browserEvent.target,n=i.classList.contains("monaco-tl-twistie")||i.classList.contains("monaco-icon-label")&&i.classList.contains("folder-icon")&&e.browserEvent.offsetX<16,o=_ge(e.browserEvent.target);let r=!1;if(o?r=!0:typeof this.tree.expandOnlyOnTwistieClick=="function"?r=this.tree.expandOnlyOnTwistieClick(t.element):r=!!this.tree.expandOnlyOnTwistieClick,o)this.handleStickyScrollMouseEvent(e,t);else{if(r&&!n&&e.browserEvent.detail!==2)return super.onViewPointer(e);if(!this.tree.expandOnDoubleClick&&e.browserEvent.detail===2)return super.onViewPointer(e)}if(t.collapsible&&(!o||n)){const a=this.tree.getNodeLocation(t),l=e.browserEvent.altKey;if(this.tree.setFocus([a]),this.tree.toggleCollapsed(a,l),r&&n){e.browserEvent.isHandledByList=!0;return}}o||super.onViewPointer(e)}handleStickyScrollMouseEvent(e,t){if(pge(e.browserEvent.target)||mge(e.browserEvent.target))return;const i=this.stickyScrollProvider();if(!i)throw new Error("Sticky scroll controller not found");const n=this.list.indexOf(t),o=this.list.getElementTop(n),r=i.nodePositionTopBelowWidget(t);this.tree.scrollTop=o-r,this.list.setFocus([n]),this.list.setSelection([n])}onDoubleClick(e){e.browserEvent.target.classList.contains("monaco-tl-twistie")||!this.tree.expandOnDoubleClick||e.browserEvent.isHandledByList||super.onDoubleClick(e)}}class Bfe extends na{constructor(e,t,i,n,o,r,a,l){super(e,t,i,n,l),this.focusTrait=o,this.selectionTrait=r,this.anchorTrait=a}createMouseController(e){return new Ffe(this,e.tree,e.stickyScrollProvider)}splice(e,t,i=[]){if(super.splice(e,t,i),i.length===0)return;const n=[],o=[];let r;i.forEach((a,l)=>{this.focusTrait.has(a)&&n.push(e+l),this.selectionTrait.has(a)&&o.push(e+l),this.anchorTrait.has(a)&&(r=e+l)}),n.length>0&&super.setFocus(Lu([...super.getFocus(),...n])),o.length>0&&super.setSelection(Lu([...super.getSelection(),...o])),typeof r=="number"&&super.setAnchor(r)}setFocus(e,t,i=!1){super.setFocus(e,t),i||this.focusTrait.set(e.map(n=>this.element(n)),t)}setSelection(e,t,i=!1){super.setSelection(e,t),i||this.selectionTrait.set(e.map(n=>this.element(n)),t)}setAnchor(e,t=!1){super.setAnchor(e),t||(typeof e>"u"?this.anchorTrait.set([]):this.anchorTrait.set([this.element(e)]))}}class aU{get onDidScroll(){return this.view.onDidScroll}get onDidChangeFocus(){return this.eventBufferer.wrapEvent(this.focus.onDidChange)}get onDidChangeSelection(){return this.eventBufferer.wrapEvent(this.selection.onDidChange)}get onMouseDblClick(){return ge.filter(ge.map(this.view.onMouseDblClick,m9),e=>e.target!==og.Filter)}get onPointer(){return ge.map(this.view.onPointer,m9)}get onDidFocus(){return this.view.onDidFocus}get onDidChangeModel(){return ge.signal(this.model.onDidSplice)}get onDidChangeCollapseState(){return this.model.onDidChangeCollapseState}get findMode(){var e,t;return(t=(e=this.findController)===null||e===void 0?void 0:e.mode)!==null&&t!==void 0?t:Pl.Highlight}set findMode(e){this.findController&&(this.findController.mode=e)}get findMatchType(){var e,t;return(t=(e=this.findController)===null||e===void 0?void 0:e.matchType)!==null&&t!==void 0?t:Fg.Fuzzy}set findMatchType(e){this.findController&&(this.findController.matchType=e)}get expandOnDoubleClick(){return typeof this._options.expandOnDoubleClick>"u"?!0:this._options.expandOnDoubleClick}get expandOnlyOnTwistieClick(){return typeof this._options.expandOnlyOnTwistieClick>"u"?!0:this._options.expandOnlyOnTwistieClick}get onDidDispose(){return this.view.onDidDispose}constructor(e,t,i,n,o={}){var r;this._user=e,this._options=o,this.eventBufferer=new MA,this.onDidChangeFindOpenState=ge.None,this.disposables=new ie,this._onWillRefilter=new W,this.onWillRefilter=this._onWillRefilter.event,this._onDidUpdateOptions=new W,this.treeDelegate=new vO(i);const a=new i5,l=new i5,d=this.disposables.add(new Tfe(l.event)),c=new lP;this.renderers=n.map(m=>new hb(m,()=>this.model,a.event,d,c,o));for(const m of this.renderers)this.disposables.add(m);let u;o.keyboardNavigationLabelProvider&&(u=new Mfe(this,o.keyboardNavigationLabelProvider,o.filter),o={...o,filter:u},this.disposables.add(u)),this.focus=new $I(()=>this.view.getFocusedElements()[0],o.identityProvider),this.selection=new $I(()=>this.view.getSelectedElements()[0],o.identityProvider),this.anchor=new $I(()=>this.view.getAnchorElement(),o.identityProvider),this.view=new Bfe(e,t,this.treeDelegate,this.renderers,this.focus,this.selection,this.anchor,{...Nfe(()=>this.model,o),tree:this,stickyScrollProvider:()=>this.stickyScrollController}),this.model=this.createModel(e,this.view,o),a.input=this.model.onDidChangeCollapseState;const h=ge.forEach(this.model.onDidSplice,m=>{this.eventBufferer.bufferEvents(()=>{this.focus.onDidModelSplice(m),this.selection.onDidModelSplice(m)})},this.disposables);h(()=>null,null,this.disposables);const g=this.disposables.add(new W),f=this.disposables.add(new Qr(0));if(this.disposables.add(ge.any(h,this.focus.onDidChange,this.selection.onDidChange)(()=>{f.trigger(()=>{const m=new Set;for(const _ of this.focus.getNodes())m.add(_);for(const _ of this.selection.getNodes())m.add(_);g.fire([...m.values()])})})),l.input=g.event,o.keyboardSupport!==!1){const m=ge.chain(this.view.onKeyDown,_=>_.filter(v=>!gu(v.target)).map(v=>new ri(v)));ge.chain(m,_=>_.filter(v=>v.keyCode===15))(this.onLeftArrow,this,this.disposables),ge.chain(m,_=>_.filter(v=>v.keyCode===17))(this.onRightArrow,this,this.disposables),ge.chain(m,_=>_.filter(v=>v.keyCode===10))(this.onSpace,this,this.disposables)}if((!((r=o.findWidgetEnabled)!==null&&r!==void 0)||r)&&o.keyboardNavigationLabelProvider&&o.contextViewProvider){const m=this.options.findWidgetStyles?{styles:this.options.findWidgetStyles}:void 0;this.findController=new Rfe(this,this.model,this.view,u,o.contextViewProvider,m),this.focusNavigationFilter=_=>this.findController.shouldAllowFocus(_),this.onDidChangeFindOpenState=this.findController.onDidChangeOpenState,this.disposables.add(this.findController),this.onDidChangeFindMode=this.findController.onDidChangeMode,this.onDidChangeFindMatchType=this.findController.onDidChangeMatchType}else this.onDidChangeFindMode=ge.None,this.onDidChangeFindMatchType=ge.None;o.enableStickyScroll&&(this.stickyScrollController=new p9(this,this.model,this.view,this.renderers,this.treeDelegate,o)),this.styleElement=Lr(this.view.getHTMLElement()),this.getHTMLElement().classList.toggle("always",this._options.renderIndentGuides===ub.Always)}updateOptions(e={}){var t;this._options={...this._options,...e};for(const i of this.renderers)i.updateOptions(e);this.view.updateOptions(this._options),(t=this.findController)===null||t===void 0||t.updateOptions(e),this.updateStickyScroll(e),this._onDidUpdateOptions.fire(this._options),this.getHTMLElement().classList.toggle("always",this._options.renderIndentGuides===ub.Always)}get options(){return this._options}updateStickyScroll(e){var t;!this.stickyScrollController&&this._options.enableStickyScroll?this.stickyScrollController=new p9(this,this.model,this.view,this.renderers,this.treeDelegate,this._options):this.stickyScrollController&&!this._options.enableStickyScroll&&(this.stickyScrollController.dispose(),this.stickyScrollController=void 0),(t=this.stickyScrollController)===null||t===void 0||t.updateOptions(e)}getHTMLElement(){return this.view.getHTMLElement()}get scrollTop(){return this.view.scrollTop}set scrollTop(e){this.view.scrollTop=e}get scrollHeight(){return this.view.scrollHeight}get renderHeight(){return this.view.renderHeight}domFocus(){this.view.domFocus()}layout(e,t){var i;this.view.layout(e,t),xu(t)&&((i=this.findController)===null||i===void 0||i.layout(t))}style(e){const t=`.${this.view.domId}`,i=[];e.treeIndentGuidesStroke&&(i.push(`.monaco-list${t}:hover .monaco-tl-indent > .indent-guide, .monaco-list${t}.always .monaco-tl-indent > .indent-guide  { border-color: ${e.treeInactiveIndentGuidesStroke}; }`),i.push(`.monaco-list${t} .monaco-tl-indent > .indent-guide.active { border-color: ${e.treeIndentGuidesStroke}; }`)),e.listBackground&&(i.push(`.monaco-list${t} .monaco-scrollable-element .monaco-tree-sticky-container { background-color: ${e.listBackground}; }`),i.push(`.monaco-list${t} .monaco-scrollable-element .monaco-tree-sticky-container .monaco-tree-sticky-row { background-color: ${e.listBackground}; }`)),this.styleElement.textContent=i.join(`
`),this.view.style(e)}getParentElement(e){const t=this.model.getParentNodeLocation(e);return this.model.getNode(t).element}getFirstElementChild(e){return this.model.getFirstElementChild(e)}getNode(e){return this.model.getNode(e)}getNodeLocation(e){return this.model.getNodeLocation(e)}collapse(e,t=!1){return this.model.setCollapsed(e,!0,t)}expand(e,t=!1){return this.model.setCollapsed(e,!1,t)}toggleCollapsed(e,t=!1){return this.model.setCollapsed(e,void 0,t)}isCollapsible(e){return this.model.isCollapsible(e)}setCollapsible(e,t){return this.model.setCollapsible(e,t)}isCollapsed(e){return this.model.isCollapsed(e)}refilter(){this._onWillRefilter.fire(void 0),this.model.refilter()}setSelection(e,t){const i=e.map(o=>this.model.getNode(o));this.selection.set(i,t);const n=e.map(o=>this.model.getListIndex(o)).filter(o=>o>-1);this.view.setSelection(n,t,!0)}getSelection(){return this.selection.get()}setFocus(e,t){const i=e.map(o=>this.model.getNode(o));this.focus.set(i,t);const n=e.map(o=>this.model.getListIndex(o)).filter(o=>o>-1);this.view.setFocus(n,t,!0)}getFocus(){return this.focus.get()}reveal(e,t){this.model.expandTo(e);const i=this.model.getListIndex(e);if(i!==-1)if(!this.stickyScrollController)this.view.reveal(i,t);else{const n=this.stickyScrollController.nodePositionTopBelowWidget(this.getNode(e));this.view.reveal(i,t,n)}}onLeftArrow(e){e.preventDefault(),e.stopPropagation();const t=this.view.getFocusedElements();if(t.length===0)return;const i=t[0],n=this.model.getNodeLocation(i);if(!this.model.setCollapsed(n,!0)){const r=this.model.getParentNodeLocation(n);if(!r)return;const a=this.model.getListIndex(r);this.view.reveal(a),this.view.setFocus([a])}}onRightArrow(e){e.preventDefault(),e.stopPropagation();const t=this.view.getFocusedElements();if(t.length===0)return;const i=t[0],n=this.model.getNodeLocation(i);if(!this.model.setCollapsed(n,!1)){if(!i.children.some(l=>l.visible))return;const[r]=this.view.getFocus(),a=r+1;this.view.reveal(a),this.view.setFocus([a])}}onSpace(e){e.preventDefault(),e.stopPropagation();const t=this.view.getFocusedElements();if(t.length===0)return;const i=t[0],n=this.model.getNodeLocation(i),o=e.browserEvent.altKey;this.model.setCollapsed(n,void 0,o)}dispose(){var e;Bt(this.disposables),(e=this.stickyScrollController)===null||e===void 0||e.dispose(),this.view.dispose()}}class bO{constructor(e,t,i={}){this.user=e,this.rootRef=null,this.nodes=new Map,this.nodesByIdentity=new Map,this.model=new kfe(e,t,null,i),this.onDidSplice=this.model.onDidSplice,this.onDidChangeCollapseState=this.model.onDidChangeCollapseState,this.onDidChangeRenderNodeCount=this.model.onDidChangeRenderNodeCount,i.sorter&&(this.sorter={compare(n,o){return i.sorter.compare(n.element,o.element)}}),this.identityProvider=i.identityProvider}setChildren(e,t=ht.empty(),i={}){const n=this.getElementLocation(e);this._setChildren(n,this.preserveCollapseState(t),i)}_setChildren(e,t=ht.empty(),i){const n=new Set,o=new Set,r=l=>{var d;if(l.element===null)return;const c=l;if(n.add(c.element),this.nodes.set(c.element,c),this.identityProvider){const u=this.identityProvider.getId(c.element).toString();o.add(u),this.nodesByIdentity.set(u,c)}(d=i.onDidCreateNode)===null||d===void 0||d.call(i,c)},a=l=>{var d;if(l.element===null)return;const c=l;if(n.has(c.element)||this.nodes.delete(c.element),this.identityProvider){const u=this.identityProvider.getId(c.element).toString();o.has(u)||this.nodesByIdentity.delete(u)}(d=i.onDidDeleteNode)===null||d===void 0||d.call(i,c)};this.model.splice([...e,0],Number.MAX_VALUE,t,{...i,onDidCreateNode:r,onDidDeleteNode:a})}preserveCollapseState(e=ht.empty()){return this.sorter&&(e=[...e].sort(this.sorter.compare.bind(this.sorter))),ht.map(e,t=>{let i=this.nodes.get(t.element);if(!i&&this.identityProvider){const r=this.identityProvider.getId(t.element).toString();i=this.nodesByIdentity.get(r)}if(!i){let r;return typeof t.collapsed>"u"?r=void 0:t.collapsed===Vo.Collapsed||t.collapsed===Vo.PreserveOrCollapsed?r=!0:t.collapsed===Vo.Expanded||t.collapsed===Vo.PreserveOrExpanded?r=!1:r=!!t.collapsed,{...t,children:this.preserveCollapseState(t.children),collapsed:r}}const n=typeof t.collapsible=="boolean"?t.collapsible:i.collapsible;let o;return typeof t.collapsed>"u"||t.collapsed===Vo.PreserveOrCollapsed||t.collapsed===Vo.PreserveOrExpanded?o=i.collapsed:t.collapsed===Vo.Collapsed?o=!0:t.collapsed===Vo.Expanded?o=!1:o=!!t.collapsed,{...t,collapsible:n,collapsed:o,children:this.preserveCollapseState(t.children)}})}rerender(e){const t=this.getElementLocation(e);this.model.rerender(t)}getFirstElementChild(e=null){const t=this.getElementLocation(e);return this.model.getFirstElementChild(t)}has(e){return this.nodes.has(e)}getListIndex(e){const t=this.getElementLocation(e);return this.model.getListIndex(t)}getListRenderCount(e){const t=this.getElementLocation(e);return this.model.getListRenderCount(t)}isCollapsible(e){const t=this.getElementLocation(e);return this.model.isCollapsible(t)}setCollapsible(e,t){const i=this.getElementLocation(e);return this.model.setCollapsible(i,t)}isCollapsed(e){const t=this.getElementLocation(e);return this.model.isCollapsed(t)}setCollapsed(e,t,i){const n=this.getElementLocation(e);return this.model.setCollapsed(n,t,i)}expandTo(e){const t=this.getElementLocation(e);this.model.expandTo(t)}refilter(){this.model.refilter()}getNode(e=null){if(e===null)return this.model.getNode(this.model.rootRef);const t=this.nodes.get(e);if(!t)throw new jo(this.user,`Tree element not found: ${e}`);return t}getNodeLocation(e){return e.element}getParentNodeLocation(e){if(e===null)throw new jo(this.user,"Invalid getParentNodeLocation call");const t=this.nodes.get(e);if(!t)throw new jo(this.user,`Tree element not found: ${e}`);const i=this.model.getNodeLocation(t),n=this.model.getParentNodeLocation(i);return this.model.getNode(n).element}getElementLocation(e){if(e===null)return[];const t=this.nodes.get(e);if(!t)throw new jo(this.user,`Tree element not found: ${e}`);return this.model.getNodeLocation(t)}}function Zw(s){const e=[s.element],t=s.incompressible||!1;return{element:{elements:e,incompressible:t},children:ht.map(ht.from(s.children),Zw),collapsible:s.collapsible,collapsed:s.collapsed}}function Yw(s){const e=[s.element],t=s.incompressible||!1;let i,n;for(;[n,i]=ht.consume(ht.from(s.children),2),!(n.length!==1||n[0].incompressible);)s=n[0],e.push(s.element);return{element:{elements:e,incompressible:t},children:ht.map(ht.concat(n,i),Yw),collapsible:s.collapsible,collapsed:s.collapsed}}function S2(s,e=0){let t;return e<s.element.elements.length-1?t=[S2(s,e+1)]:t=ht.map(ht.from(s.children),i=>S2(i,0)),e===0&&s.element.incompressible?{element:s.element.elements[e],children:t,incompressible:!0,collapsible:s.collapsible,collapsed:s.collapsed}:{element:s.element.elements[e],children:t,collapsible:s.collapsible,collapsed:s.collapsed}}function _9(s){return S2(s,0)}function lU(s,e,t){return s.element===e?{...s,children:t}:{...s,children:ht.map(ht.from(s.children),i=>lU(i,e,t))}}const Wfe=s=>({getId(e){return e.elements.map(t=>s.getId(t).toString()).join("\0")}});class Vfe{get onDidSplice(){return this.model.onDidSplice}get onDidChangeCollapseState(){return this.model.onDidChangeCollapseState}get onDidChangeRenderNodeCount(){return this.model.onDidChangeRenderNodeCount}constructor(e,t,i={}){this.user=e,this.rootRef=null,this.nodes=new Map,this.model=new bO(e,t,i),this.enabled=typeof i.compressionEnabled>"u"?!0:i.compressionEnabled,this.identityProvider=i.identityProvider}setChildren(e,t=ht.empty(),i){const n=i.diffIdentityProvider&&Wfe(i.diffIdentityProvider);if(e===null){const f=ht.map(t,this.enabled?Yw:Zw);this._setChildren(null,f,{diffIdentityProvider:n,diffDepth:1/0});return}const o=this.nodes.get(e);if(!o)throw new jo(this.user,"Unknown compressed tree node");const r=this.model.getNode(o),a=this.model.getParentNodeLocation(o),l=this.model.getNode(a),d=_9(r),c=lU(d,e,t),u=(this.enabled?Yw:Zw)(c),h=i.diffIdentityProvider?(f,m)=>i.diffIdentityProvider.getId(f)===i.diffIdentityProvider.getId(m):void 0;if(Ai(u.element.elements,r.element.elements,h)){this._setChildren(o,u.children||ht.empty(),{diffIdentityProvider:n,diffDepth:1});return}const g=l.children.map(f=>f===r?u:f);this._setChildren(l.element,g,{diffIdentityProvider:n,diffDepth:r.depth-l.depth})}setCompressionEnabled(e){if(e===this.enabled)return;this.enabled=e;const i=this.model.getNode().children,n=ht.map(i,_9),o=ht.map(n,e?Yw:Zw);this._setChildren(null,o,{diffIdentityProvider:this.identityProvider,diffDepth:1/0})}_setChildren(e,t,i){const n=new Set,o=a=>{for(const l of a.element.elements)n.add(l),this.nodes.set(l,a.element)},r=a=>{for(const l of a.element.elements)n.has(l)||this.nodes.delete(l)};this.model.setChildren(e,t,{...i,onDidCreateNode:o,onDidDeleteNode:r})}has(e){return this.nodes.has(e)}getListIndex(e){const t=this.getCompressedNode(e);return this.model.getListIndex(t)}getListRenderCount(e){const t=this.getCompressedNode(e);return this.model.getListRenderCount(t)}getNode(e){if(typeof e>"u")return this.model.getNode();const t=this.getCompressedNode(e);return this.model.getNode(t)}getNodeLocation(e){const t=this.model.getNodeLocation(e);return t===null?null:t.elements[t.elements.length-1]}getParentNodeLocation(e){const t=this.getCompressedNode(e),i=this.model.getParentNodeLocation(t);return i===null?null:i.elements[i.elements.length-1]}getFirstElementChild(e){const t=this.getCompressedNode(e);return this.model.getFirstElementChild(t)}isCollapsible(e){const t=this.getCompressedNode(e);return this.model.isCollapsible(t)}setCollapsible(e,t){const i=this.getCompressedNode(e);return this.model.setCollapsible(i,t)}isCollapsed(e){const t=this.getCompressedNode(e);return this.model.isCollapsed(t)}setCollapsed(e,t,i){const n=this.getCompressedNode(e);return this.model.setCollapsed(n,t,i)}expandTo(e){const t=this.getCompressedNode(e);this.model.expandTo(t)}rerender(e){const t=this.getCompressedNode(e);this.model.rerender(t)}refilter(){this.model.refilter()}getCompressedNode(e){if(e===null)return null;const t=this.nodes.get(e);if(!t)throw new jo(this.user,`Tree element not found: ${e}`);return t}}const Hfe=s=>s[s.length-1];class CO{get element(){return this.node.element===null?null:this.unwrapper(this.node.element)}get children(){return this.node.children.map(e=>new CO(this.unwrapper,e))}get depth(){return this.node.depth}get visibleChildrenCount(){return this.node.visibleChildrenCount}get visibleChildIndex(){return this.node.visibleChildIndex}get collapsible(){return this.node.collapsible}get collapsed(){return this.node.collapsed}get visible(){return this.node.visible}get filterData(){return this.node.filterData}constructor(e,t){this.unwrapper=e,this.node=t}}function zfe(s,e){return{splice(t,i,n){e.splice(t,i,n.map(o=>s.map(o)))},updateElementHeight(t,i){e.updateElementHeight(t,i)}}}function Ufe(s,e){return{...e,identityProvider:e.identityProvider&&{getId(t){return e.identityProvider.getId(s(t))}},sorter:e.sorter&&{compare(t,i){return e.sorter.compare(t.elements[0],i.elements[0])}},filter:e.filter&&{filter(t,i){return e.filter.filter(s(t),i)}}}}class $fe{get onDidSplice(){return ge.map(this.model.onDidSplice,({insertedNodes:e,deletedNodes:t})=>({insertedNodes:e.map(i=>this.nodeMapper.map(i)),deletedNodes:t.map(i=>this.nodeMapper.map(i))}))}get onDidChangeCollapseState(){return ge.map(this.model.onDidChangeCollapseState,({node:e,deep:t})=>({node:this.nodeMapper.map(e),deep:t}))}get onDidChangeRenderNodeCount(){return ge.map(this.model.onDidChangeRenderNodeCount,e=>this.nodeMapper.map(e))}constructor(e,t,i={}){this.rootRef=null,this.elementMapper=i.elementMapper||Hfe;const n=o=>this.elementMapper(o.elements);this.nodeMapper=new mO(o=>new CO(n,o)),this.model=new Vfe(e,zfe(this.nodeMapper,t),Ufe(n,i))}setChildren(e,t=ht.empty(),i={}){this.model.setChildren(e,t,i)}setCompressionEnabled(e){this.model.setCompressionEnabled(e)}has(e){return this.model.has(e)}getListIndex(e){return this.model.getListIndex(e)}getListRenderCount(e){return this.model.getListRenderCount(e)}getNode(e){return this.nodeMapper.map(this.model.getNode(e))}getNodeLocation(e){return e.element}getParentNodeLocation(e){return this.model.getParentNodeLocation(e)}getFirstElementChild(e){const t=this.model.getFirstElementChild(e);return t===null||typeof t>"u"?t:this.elementMapper(t.elements)}isCollapsible(e){return this.model.isCollapsible(e)}setCollapsible(e,t){return this.model.setCollapsible(e,t)}isCollapsed(e){return this.model.isCollapsed(e)}setCollapsed(e,t,i){return this.model.setCollapsed(e,t,i)}expandTo(e){return this.model.expandTo(e)}rerender(e){return this.model.rerender(e)}refilter(){return this.model.refilter()}getCompressedTreeNode(e=null){return this.model.getNode(e)}}var jfe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o};class wO extends aU{get onDidChangeCollapseState(){return this.model.onDidChangeCollapseState}constructor(e,t,i,n,o={}){super(e,t,i,n,o),this.user=e}setChildren(e,t=ht.empty(),i){this.model.setChildren(e,t,i)}rerender(e){if(e===void 0){this.view.rerender();return}this.model.rerender(e)}hasElement(e){return this.model.has(e)}createModel(e,t,i){return new bO(e,t,i)}}class dU{get compressedTreeNodeProvider(){return this._compressedTreeNodeProvider()}constructor(e,t){this._compressedTreeNodeProvider=e,this.renderer=t,this.templateId=t.templateId,t.onDidChangeTwistieState&&(this.onDidChangeTwistieState=t.onDidChangeTwistieState)}renderTemplate(e){return{compressedTreeNode:void 0,data:this.renderer.renderTemplate(e)}}renderElement(e,t,i,n){const o=this.compressedTreeNodeProvider.getCompressedTreeNode(e.element);o.element.elements.length===1?(i.compressedTreeNode=void 0,this.renderer.renderElement(e,t,i.data,n)):(i.compressedTreeNode=o,this.renderer.renderCompressedElements(o,t,i.data,n))}disposeElement(e,t,i,n){var o,r,a,l;i.compressedTreeNode?(r=(o=this.renderer).disposeCompressedElements)===null||r===void 0||r.call(o,i.compressedTreeNode,t,i.data,n):(l=(a=this.renderer).disposeElement)===null||l===void 0||l.call(a,e,t,i.data,n)}disposeTemplate(e){this.renderer.disposeTemplate(e.data)}renderTwistie(e,t){return this.renderer.renderTwistie?this.renderer.renderTwistie(e,t):!1}}jfe([Xi],dU.prototype,"compressedTreeNodeProvider",null);function Kfe(s,e){return e&&{...e,keyboardNavigationLabelProvider:e.keyboardNavigationLabelProvider&&{getKeyboardNavigationLabel(t){let i;try{i=s().getCompressedTreeNode(t)}catch{return e.keyboardNavigationLabelProvider.getKeyboardNavigationLabel(t)}return i.element.elements.length===1?e.keyboardNavigationLabelProvider.getKeyboardNavigationLabel(t):e.keyboardNavigationLabelProvider.getCompressedNodeKeyboardNavigationLabel(i.element.elements)}}}}class cU extends wO{constructor(e,t,i,n,o={}){const r=()=>this,a=n.map(l=>new dU(r,l));super(e,t,i,a,Kfe(r,o))}setChildren(e,t=ht.empty(),i){this.model.setChildren(e,t,i)}createModel(e,t,i){return new $fe(e,t,i)}updateOptions(e={}){super.updateOptions(e),typeof e.compressionEnabled<"u"&&this.model.setCompressionEnabled(e.compressionEnabled)}getCompressedTreeNode(e=null){return this.model.getCompressedTreeNode(e)}}function jI(s){return{...s,children:[],refreshPromise:void 0,stale:!0,slow:!1,forceExpanded:!1}}function y2(s,e){return e.parent?e.parent===s?!0:y2(s,e.parent):!1}function qfe(s,e){return s===e||y2(s,e)||y2(e,s)}class SO{get element(){return this.node.element.element}get children(){return this.node.children.map(e=>new SO(e))}get depth(){return this.node.depth}get visibleChildrenCount(){return this.node.visibleChildrenCount}get visibleChildIndex(){return this.node.visibleChildIndex}get collapsible(){return this.node.collapsible}get collapsed(){return this.node.collapsed}get visible(){return this.node.visible}get filterData(){return this.node.filterData}constructor(e){this.node=e}}class Gfe{constructor(e,t,i){this.renderer=e,this.nodeMapper=t,this.onDidChangeTwistieState=i,this.renderedNodes=new Map,this.templateId=e.templateId}renderTemplate(e){return{templateData:this.renderer.renderTemplate(e)}}renderElement(e,t,i,n){this.renderer.renderElement(this.nodeMapper.map(e),t,i.templateData,n)}renderTwistie(e,t){return e.slow?(t.classList.add(...Oe.asClassNameArray(le.treeItemLoading)),!0):(t.classList.remove(...Oe.asClassNameArray(le.treeItemLoading)),!1)}disposeElement(e,t,i,n){var o,r;(r=(o=this.renderer).disposeElement)===null||r===void 0||r.call(o,this.nodeMapper.map(e),t,i.templateData,n)}disposeTemplate(e){this.renderer.disposeTemplate(e.templateData)}dispose(){this.renderedNodes.clear()}}function v9(s){return{browserEvent:s.browserEvent,elements:s.elements.map(e=>e.element)}}function b9(s){return{browserEvent:s.browserEvent,element:s.element&&s.element.element,target:s.target}}class Zfe extends wC{constructor(e){super(e.elements.map(t=>t.element)),this.data=e}}function KI(s){return s instanceof wC?new Zfe(s):s}class Yfe{constructor(e){this.dnd=e}getDragURI(e){return this.dnd.getDragURI(e.element)}getDragLabel(e,t){if(this.dnd.getDragLabel)return this.dnd.getDragLabel(e.map(i=>i.element),t)}onDragStart(e,t){var i,n;(n=(i=this.dnd).onDragStart)===null||n===void 0||n.call(i,KI(e),t)}onDragOver(e,t,i,n,o=!0){return this.dnd.onDragOver(KI(e),t&&t.element,i,n)}drop(e,t,i,n){this.dnd.drop(KI(e),t&&t.element,i,n)}onDragEnd(e){var t,i;(i=(t=this.dnd).onDragEnd)===null||i===void 0||i.call(t,e)}dispose(){this.dnd.dispose()}}function uU(s){return s&&{...s,collapseByDefault:!0,identityProvider:s.identityProvider&&{getId(e){return s.identityProvider.getId(e.element)}},dnd:s.dnd&&new Yfe(s.dnd),multipleSelectionController:s.multipleSelectionController&&{isSelectionSingleChangeEvent(e){return s.multipleSelectionController.isSelectionSingleChangeEvent({...e,element:e.element})},isSelectionRangeChangeEvent(e){return s.multipleSelectionController.isSelectionRangeChangeEvent({...e,element:e.element})}},accessibilityProvider:s.accessibilityProvider&&{...s.accessibilityProvider,getPosInSet:void 0,getSetSize:void 0,getRole:s.accessibilityProvider.getRole?e=>s.accessibilityProvider.getRole(e.element):()=>"treeitem",isChecked:s.accessibilityProvider.isChecked?e=>{var t;return!!(!((t=s.accessibilityProvider)===null||t===void 0)&&t.isChecked(e.element))}:void 0,getAriaLabel(e){return s.accessibilityProvider.getAriaLabel(e.element)},getWidgetAriaLabel(){return s.accessibilityProvider.getWidgetAriaLabel()},getWidgetRole:s.accessibilityProvider.getWidgetRole?()=>s.accessibilityProvider.getWidgetRole():()=>"tree",getAriaLevel:s.accessibilityProvider.getAriaLevel&&(e=>s.accessibilityProvider.getAriaLevel(e.element)),getActiveDescendantId:s.accessibilityProvider.getActiveDescendantId&&(e=>s.accessibilityProvider.getActiveDescendantId(e.element))},filter:s.filter&&{filter(e,t){return s.filter.filter(e.element,t)}},keyboardNavigationLabelProvider:s.keyboardNavigationLabelProvider&&{...s.keyboardNavigationLabelProvider,getKeyboardNavigationLabel(e){return s.keyboardNavigationLabelProvider.getKeyboardNavigationLabel(e.element)}},sorter:void 0,expandOnlyOnTwistieClick:typeof s.expandOnlyOnTwistieClick>"u"?void 0:typeof s.expandOnlyOnTwistieClick!="function"?s.expandOnlyOnTwistieClick:e=>s.expandOnlyOnTwistieClick(e.element),defaultFindVisibility:e=>e.hasChildren&&e.stale?1:typeof s.defaultFindVisibility=="number"?s.defaultFindVisibility:typeof s.defaultFindVisibility>"u"?2:s.defaultFindVisibility(e.element)}}function L2(s,e){e(s),s.children.forEach(t=>L2(t,e))}class hU{get onDidScroll(){return this.tree.onDidScroll}get onDidChangeFocus(){return ge.map(this.tree.onDidChangeFocus,v9)}get onDidChangeSelection(){return ge.map(this.tree.onDidChangeSelection,v9)}get onMouseDblClick(){return ge.map(this.tree.onMouseDblClick,b9)}get onPointer(){return ge.map(this.tree.onPointer,b9)}get onDidFocus(){return this.tree.onDidFocus}get onDidChangeModel(){return this.tree.onDidChangeModel}get onDidChangeCollapseState(){return this.tree.onDidChangeCollapseState}get onDidChangeFindOpenState(){return this.tree.onDidChangeFindOpenState}get onDidDispose(){return this.tree.onDidDispose}constructor(e,t,i,n,o,r={}){this.user=e,this.dataSource=o,this.nodes=new Map,this.subTreeRefreshPromises=new Map,this.refreshPromises=new Map,this._onDidRender=new W,this._onDidChangeNodeSlowState=new W,this.nodeMapper=new mO(a=>new SO(a)),this.disposables=new ie,this.identityProvider=r.identityProvider,this.autoExpandSingleChildren=typeof r.autoExpandSingleChildren>"u"?!1:r.autoExpandSingleChildren,this.sorter=r.sorter,this.getDefaultCollapseState=a=>r.collapseByDefault?r.collapseByDefault(a)?Vo.PreserveOrCollapsed:Vo.PreserveOrExpanded:void 0,this.tree=this.createTree(e,t,i,n,r),this.onDidChangeFindMode=this.tree.onDidChangeFindMode,this.root=jI({element:void 0,parent:null,hasChildren:!0,defaultCollapseState:void 0}),this.identityProvider&&(this.root={...this.root,id:null}),this.nodes.set(null,this.root),this.tree.onDidChangeCollapseState(this._onDidChangeCollapseState,this,this.disposables)}createTree(e,t,i,n,o){const r=new vO(i),a=n.map(d=>new Gfe(d,this.nodeMapper,this._onDidChangeNodeSlowState.event)),l=uU(o)||{};return new wO(e,t,r,a,l)}updateOptions(e={}){this.tree.updateOptions(e)}getHTMLElement(){return this.tree.getHTMLElement()}get scrollTop(){return this.tree.scrollTop}set scrollTop(e){this.tree.scrollTop=e}get scrollHeight(){return this.tree.scrollHeight}get renderHeight(){return this.tree.renderHeight}domFocus(){this.tree.domFocus()}layout(e,t){this.tree.layout(e,t)}style(e){this.tree.style(e)}getInput(){return this.root.element}async setInput(e,t){this.refreshPromises.forEach(n=>n.cancel()),this.refreshPromises.clear(),this.root.element=e;const i=t&&{viewState:t,focus:[],selection:[]};await this._updateChildren(e,!0,!1,i),i&&(this.tree.setFocus(i.focus),this.tree.setSelection(i.selection)),t&&typeof t.scrollTop=="number"&&(this.scrollTop=t.scrollTop)}async _updateChildren(e=this.root.element,t=!0,i=!1,n,o){if(typeof this.root.element>"u")throw new jo(this.user,"Tree input not set");this.root.refreshPromise&&(await this.root.refreshPromise,await ge.toPromise(this._onDidRender.event));const r=this.getDataNode(e);if(await this.refreshAndRenderNode(r,t,n,o),i)try{this.tree.rerender(r)}catch{}}rerender(e){if(e===void 0||e===this.root.element){this.tree.rerender();return}const t=this.getDataNode(e);this.tree.rerender(t)}getNode(e=this.root.element){const t=this.getDataNode(e),i=this.tree.getNode(t===this.root?null:t);return this.nodeMapper.map(i)}collapse(e,t=!1){const i=this.getDataNode(e);return this.tree.collapse(i===this.root?null:i,t)}async expand(e,t=!1){if(typeof this.root.element>"u")throw new jo(this.user,"Tree input not set");this.root.refreshPromise&&(await this.root.refreshPromise,await ge.toPromise(this._onDidRender.event));const i=this.getDataNode(e);if(this.tree.hasElement(i)&&!this.tree.isCollapsible(i)||(i.refreshPromise&&(await this.root.refreshPromise,await ge.toPromise(this._onDidRender.event)),i!==this.root&&!i.refreshPromise&&!this.tree.isCollapsed(i)))return!1;const n=this.tree.expand(i===this.root?null:i,t);return i.refreshPromise&&(await this.root.refreshPromise,await ge.toPromise(this._onDidRender.event)),n}setSelection(e,t){const i=e.map(n=>this.getDataNode(n));this.tree.setSelection(i,t)}getSelection(){return this.tree.getSelection().map(t=>t.element)}setFocus(e,t){const i=e.map(n=>this.getDataNode(n));this.tree.setFocus(i,t)}getFocus(){return this.tree.getFocus().map(t=>t.element)}reveal(e,t){this.tree.reveal(this.getDataNode(e),t)}getParentElement(e){const t=this.tree.getParentElement(this.getDataNode(e));return t&&t.element}getFirstElementChild(e=this.root.element){const t=this.getDataNode(e),i=this.tree.getFirstElementChild(t===this.root?null:t);return i&&i.element}getDataNode(e){const t=this.nodes.get(e===this.root.element?null:e);if(!t)throw new jo(this.user,`Data tree node not found: ${e}`);return t}async refreshAndRenderNode(e,t,i,n){await this.refreshNode(e,t,i),this.render(e,i,n)}async refreshNode(e,t,i){let n;if(this.subTreeRefreshPromises.forEach((o,r)=>{!n&&qfe(r,e)&&(n=o.then(()=>this.refreshNode(e,t,i)))}),n)return n;if(e!==this.root&&this.tree.getNode(e).collapsed){e.hasChildren=!!this.dataSource.hasChildren(e.element),e.stale=!0;return}return this.doRefreshSubTree(e,t,i)}async doRefreshSubTree(e,t,i){let n;e.refreshPromise=new Promise(o=>n=o),this.subTreeRefreshPromises.set(e,e.refreshPromise),e.refreshPromise.finally(()=>{e.refreshPromise=void 0,this.subTreeRefreshPromises.delete(e)});try{const o=await this.doRefreshNode(e,t,i);e.stale=!1,await GN.settled(o.map(r=>this.doRefreshSubTree(r,t,i)))}finally{n()}}async doRefreshNode(e,t,i){e.hasChildren=!!this.dataSource.hasChildren(e.element);let n;if(!e.hasChildren)n=Promise.resolve(ht.empty());else{const o=this.doGetChildren(e);if(YF(o))n=Promise.resolve(o);else{const r=Iu(800);r.then(()=>{e.slow=!0,this._onDidChangeNodeSlowState.fire(e)},a=>null),n=o.finally(()=>r.cancel())}}try{const o=await n;return this.setChildren(e,o,t,i)}catch(o){if(e!==this.root&&this.tree.hasElement(e)&&this.tree.collapse(e),Ka(o))return[];throw o}finally{e.slow&&(e.slow=!1,this._onDidChangeNodeSlowState.fire(e))}}doGetChildren(e){let t=this.refreshPromises.get(e);if(t)return t;const i=this.dataSource.getChildren(e.element);return YF(i)?this.processChildren(i):(t=gn(async()=>this.processChildren(await i)),this.refreshPromises.set(e,t),t.finally(()=>{this.refreshPromises.delete(e)}))}_onDidChangeCollapseState({node:e,deep:t}){e.element!==null&&!e.collapsed&&e.element.stale&&(t?this.collapse(e.element.element):this.refreshAndRenderNode(e.element,!1).catch(et))}setChildren(e,t,i,n){const o=[...t];if(e.children.length===0&&o.length===0)return[];const r=new Map,a=new Map;for(const c of e.children)r.set(c.element,c),this.identityProvider&&a.set(c.id,{node:c,collapsed:this.tree.hasElement(c)&&this.tree.isCollapsed(c)});const l=[],d=o.map(c=>{const u=!!this.dataSource.hasChildren(c);if(!this.identityProvider){const m=jI({element:c,parent:e,hasChildren:u,defaultCollapseState:this.getDefaultCollapseState(c)});return u&&m.defaultCollapseState===Vo.PreserveOrExpanded&&l.push(m),m}const h=this.identityProvider.getId(c).toString(),g=a.get(h);if(g){const m=g.node;return r.delete(m.element),this.nodes.delete(m.element),this.nodes.set(c,m),m.element=c,m.hasChildren=u,i?g.collapsed?(m.children.forEach(_=>L2(_,v=>this.nodes.delete(v.element))),m.children.splice(0,m.children.length),m.stale=!0):l.push(m):u&&!g.collapsed&&l.push(m),m}const f=jI({element:c,parent:e,id:h,hasChildren:u,defaultCollapseState:this.getDefaultCollapseState(c)});return n&&n.viewState.focus&&n.viewState.focus.indexOf(h)>-1&&n.focus.push(f),n&&n.viewState.selection&&n.viewState.selection.indexOf(h)>-1&&n.selection.push(f),(n&&n.viewState.expanded&&n.viewState.expanded.indexOf(h)>-1||u&&f.defaultCollapseState===Vo.PreserveOrExpanded)&&l.push(f),f});for(const c of r.values())L2(c,u=>this.nodes.delete(u.element));for(const c of d)this.nodes.set(c.element,c);return e.children.splice(0,e.children.length,...d),e!==this.root&&this.autoExpandSingleChildren&&d.length===1&&l.length===0&&(d[0].forceExpanded=!0,l.push(d[0])),l}render(e,t,i){const n=e.children.map(r=>this.asTreeElement(r,t)),o=i&&{...i,diffIdentityProvider:i.diffIdentityProvider&&{getId(r){return i.diffIdentityProvider.getId(r.element)}}};this.tree.setChildren(e===this.root?null:e,n,o),e!==this.root&&this.tree.setCollapsible(e,e.hasChildren),this._onDidRender.fire()}asTreeElement(e,t){if(e.stale)return{element:e,collapsible:e.hasChildren,collapsed:!0};let i;return t&&t.viewState.expanded&&e.id&&t.viewState.expanded.indexOf(e.id)>-1?i=!1:e.forceExpanded?(i=!1,e.forceExpanded=!1):i=e.defaultCollapseState,{element:e,children:e.hasChildren?ht.map(e.children,n=>this.asTreeElement(n,t)):[],collapsible:e.hasChildren,collapsed:i}}processChildren(e){return this.sorter&&(e=[...e].sort(this.sorter.compare.bind(this.sorter))),e}dispose(){this.disposables.dispose(),this.tree.dispose()}}class yO{get element(){return{elements:this.node.element.elements.map(e=>e.element),incompressible:this.node.element.incompressible}}get children(){return this.node.children.map(e=>new yO(e))}get depth(){return this.node.depth}get visibleChildrenCount(){return this.node.visibleChildrenCount}get visibleChildIndex(){return this.node.visibleChildIndex}get collapsible(){return this.node.collapsible}get collapsed(){return this.node.collapsed}get visible(){return this.node.visible}get filterData(){return this.node.filterData}constructor(e){this.node=e}}class Xfe{constructor(e,t,i,n){this.renderer=e,this.nodeMapper=t,this.compressibleNodeMapperProvider=i,this.onDidChangeTwistieState=n,this.renderedNodes=new Map,this.disposables=[],this.templateId=e.templateId}renderTemplate(e){return{templateData:this.renderer.renderTemplate(e)}}renderElement(e,t,i,n){this.renderer.renderElement(this.nodeMapper.map(e),t,i.templateData,n)}renderCompressedElements(e,t,i,n){this.renderer.renderCompressedElements(this.compressibleNodeMapperProvider().map(e),t,i.templateData,n)}renderTwistie(e,t){return e.slow?(t.classList.add(...Oe.asClassNameArray(le.treeItemLoading)),!0):(t.classList.remove(...Oe.asClassNameArray(le.treeItemLoading)),!1)}disposeElement(e,t,i,n){var o,r;(r=(o=this.renderer).disposeElement)===null||r===void 0||r.call(o,this.nodeMapper.map(e),t,i.templateData,n)}disposeCompressedElements(e,t,i,n){var o,r;(r=(o=this.renderer).disposeCompressedElements)===null||r===void 0||r.call(o,this.compressibleNodeMapperProvider().map(e),t,i.templateData,n)}disposeTemplate(e){this.renderer.disposeTemplate(e.templateData)}dispose(){this.renderedNodes.clear(),this.disposables=Bt(this.disposables)}}function Qfe(s){const e=s&&uU(s);return e&&{...e,keyboardNavigationLabelProvider:e.keyboardNavigationLabelProvider&&{...e.keyboardNavigationLabelProvider,getCompressedNodeKeyboardNavigationLabel(t){return s.keyboardNavigationLabelProvider.getCompressedNodeKeyboardNavigationLabel(t.map(i=>i.element))}}}}class Jfe extends hU{constructor(e,t,i,n,o,r,a={}){super(e,t,i,o,r,a),this.compressionDelegate=n,this.compressibleNodeMapper=new mO(l=>new yO(l)),this.filter=a.filter}createTree(e,t,i,n,o){const r=new vO(i),a=n.map(d=>new Xfe(d,this.nodeMapper,()=>this.compressibleNodeMapper,this._onDidChangeNodeSlowState.event)),l=Qfe(o)||{};return new cU(e,t,r,a,l)}asTreeElement(e,t){return{incompressible:this.compressionDelegate.isIncompressible(e.element),...super.asTreeElement(e,t)}}updateOptions(e={}){this.tree.updateOptions(e)}render(e,t){if(!this.identityProvider)return super.render(e,t);const i=h=>this.identityProvider.getId(h).toString(),n=h=>{const g=new Set;for(const f of h){const m=this.tree.getCompressedTreeNode(f===this.root?null:f);if(m.element)for(const _ of m.element.elements)g.add(i(_.element))}return g},o=n(this.tree.getSelection()),r=n(this.tree.getFocus());super.render(e,t);const a=this.getSelection();let l=!1;const d=this.getFocus();let c=!1;const u=h=>{const g=h.element;if(g)for(let f=0;f<g.elements.length;f++){const m=i(g.elements[f].element),_=g.elements[g.elements.length-1].element;o.has(m)&&a.indexOf(_)===-1&&(a.push(_),l=!0),r.has(m)&&d.indexOf(_)===-1&&(d.push(_),c=!0)}h.children.forEach(u)};u(this.tree.getCompressedTreeNode(e===this.root?null:e)),l&&this.setSelection(a),c&&this.setFocus(d)}processChildren(e){return this.filter&&(e=ht.filter(e,t=>{const i=this.filter.filter(t,1),n=epe(i);if(n===2)throw new Error("Recursive tree visibility not supported in async data compressed trees");return n===1})),super.processChildren(e)}}function epe(s){return typeof s=="boolean"?s?1:0:_O(s)?cb(s.visibility):cb(s)}class tpe extends aU{constructor(e,t,i,n,o,r={}){super(e,t,i,n,r),this.user=e,this.dataSource=o,this.identityProvider=r.identityProvider}createModel(e,t,i){return new bO(e,t,i)}}new me("isMac",bt,p("isMac","Whether the operating system is macOS"));new me("isLinux",Ss,p("isLinux","Whether the operating system is Linux"));const jx=new me("isWindows",es,p("isWindows","Whether the operating system is Windows")),gU=new me("isWeb",Ju,p("isWeb","Whether the platform is a web browser"));new me("isMacNative",bt&&!Ju,p("isMacNative","Whether the operating system is macOS on a non-browser platform"));new me("isIOS",Wa,p("isIOS","Whether the operating system is iOS"));new me("isMobile",_X,p("isMobile","Whether the platform is a mobile web browser"));new me("isDevelopment",!1,!0);new me("productQualityType","",p("productQualityType","Quality type of VS Code"));const fU="inputFocus";new me(fU,!1,p("inputFocus","Whether keyboard focus is inside an input box"));let Ao;const qI=globalThis.vscode;if(typeof qI<"u"&&typeof qI.context<"u"){const s=qI.context.configuration();if(s)Ao=s.product;else throw new Error("Sandbox: unable to resolve product configuration from preload script.")}else if(globalThis._VSCODE_PRODUCT_JSON&&globalThis._VSCODE_PACKAGE_JSON){if(Ao=globalThis._VSCODE_PRODUCT_JSON,kS.VSCODE_DEV&&Object.assign(Ao,{nameShort:`${Ao.nameShort} Dev`,nameLong:`${Ao.nameLong} Dev`,dataFolderName:`${Ao.dataFolderName}-dev`,serverDataFolderName:Ao.serverDataFolderName?`${Ao.serverDataFolderName}-dev`:void 0}),!Ao.version){const s=globalThis._VSCODE_PACKAGE_JSON;Object.assign(Ao,{version:s.version})}}else Ao={},Object.keys(Ao).length===0&&Object.assign(Ao,{version:"1.82.0-dev",nameShort:"Code - OSS Dev",nameLong:"Code - OSS Dev",applicationName:"code-oss",dataFolderName:".vscode-oss",urlProtocol:"code-oss",reportIssueUrl:"https://github.com/microsoft/vscode/issues/new",licenseName:"MIT",licenseUrl:"https://github.com/microsoft/vscode/blob/main/LICENSE.txt",serverLicenseUrl:"https://github.com/microsoft/vscode/blob/main/LICENSE.txt"});const C9=Ao;var lc=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},ii=function(s,e){return function(t,i){e(t,i,s)}};const Mr=ut("listService");class ipe{get lastFocusedList(){return this._lastFocusedWidget}constructor(){this.disposables=new ie,this.lists=[],this._lastFocusedWidget=void 0,this._hasCreatedStyleController=!1}setLastFocusedList(e){var t,i;e!==this._lastFocusedWidget&&((t=this._lastFocusedWidget)===null||t===void 0||t.getHTMLElement().classList.remove("last-focused"),this._lastFocusedWidget=e,(i=this._lastFocusedWidget)===null||i===void 0||i.getHTMLElement().classList.add("last-focused"))}register(e,t){if(this._hasCreatedStyleController||(this._hasCreatedStyleController=!0,new Zz(Lr(),"").style(gf)),this.lists.some(n=>n.widget===e))throw new Error("Cannot register the same widget multiple times");const i={widget:e,extraContextKeys:t};return this.lists.push(i),dx(e.getHTMLElement())&&this.setLastFocusedList(e),Gr(e.onDidFocus(()=>this.setLastFocusedList(e)),Fe(()=>this.lists.splice(this.lists.indexOf(i),1)),e.onDidDispose(()=>{this.lists=this.lists.filter(n=>n!==i),this._lastFocusedWidget===e&&this.setLastFocusedList(void 0)}))}dispose(){this.disposables.dispose()}}const gb=new me("listScrollAtBoundary","none");ee.or(gb.isEqualTo("top"),gb.isEqualTo("both"));ee.or(gb.isEqualTo("bottom"),gb.isEqualTo("both"));const pU=new me("listFocus",!0),Kx=new me("listSupportsMultiselect",!0),mU=ee.and(pU,ee.not(fU)),LO=new me("listHasSelectionOrFocus",!1),xO=new me("listDoubleSelection",!1),DO=new me("listMultiSelection",!1),qx=new me("listSelectionNavigation",!1),npe=new me("listSupportsFind",!0),kO=new me("treeElementCanCollapse",!1),spe=new me("treeElementHasParent",!1),IO=new me("treeElementCanExpand",!1),ope=new me("treeElementHasChild",!1),rpe=new me("treeFindOpen",!1),_U="listTypeNavigationMode",vU="listAutomaticKeyboardNavigation";function Gx(s,e){const t=s.createScoped(e.getHTMLElement());return pU.bindTo(t),t}function Zx(s,e){const t=gb.bindTo(s),i=()=>{const n=e.scrollTop===0,o=e.scrollHeight-e.renderHeight-e.scrollTop<1;n&&o?t.set("both"):n?t.set("top"):o?t.set("bottom"):t.set("none")};return i(),e.onDidScroll(i)}const ff="workbench.list.multiSelectModifier",Xw="workbench.list.openMode",Sr="workbench.list.horizontalScrolling",EO="workbench.list.defaultFindMode",NO="workbench.list.typeNavigationMode",Py="workbench.list.keyboardNavigation",za="workbench.list.scrollByPage",TO="workbench.list.defaultFindMatchType",fb="workbench.tree.indent",Oy="workbench.tree.renderIndentGuides",Ua="workbench.list.smoothScrolling",Ql="workbench.list.mouseWheelScrollSensitivity",Jl="workbench.list.fastScrollSensitivity",Fy="workbench.tree.expandMode",By="workbench.tree.enableStickyScroll",Wy="workbench.tree.stickyScrollMaxItemCount";function ed(s){return s.getValue(ff)==="alt"}class ape extends j{constructor(e){super(),this.configurationService=e,this.useAltAsMultipleSelectionModifier=ed(e),this.registerListeners()}registerListeners(){this._register(this.configurationService.onDidChangeConfiguration(e=>{e.affectsConfiguration(ff)&&(this.useAltAsMultipleSelectionModifier=ed(this.configurationService))}))}isSelectionSingleChangeEvent(e){return this.useAltAsMultipleSelectionModifier?e.browserEvent.altKey:Kz(e)}isSelectionRangeChangeEvent(e){return qz(e)}}function Yx(s,e){var t;const i=s.get(mt),n=s.get(qt),o=new ie;return[{...e,keyboardNavigationDelegate:{mightProducePrintableCharacter(a){return n.mightProducePrintableCharacter(a)}},smoothScrolling:!!i.getValue(Ua),mouseWheelScrollSensitivity:i.getValue(Ql),fastScrollSensitivity:i.getValue(Jl),multipleSelectionController:(t=e.multipleSelectionController)!==null&&t!==void 0?t:o.add(new ape(i)),keyboardNavigationEventFilter:cpe(n),scrollByPage:!!i.getValue(za)},o]}let x2=class extends na{constructor(e,t,i,n,o,r,a,l,d){const c=typeof o.horizontalScrolling<"u"?o.horizontalScrolling:!!l.getValue(Sr),[u,h]=d.invokeFunction(Yx,o);super(e,t,i,n,{keyboardSupport:!1,...u,horizontalScrolling:c}),this.disposables.add(h),this.contextKeyService=Gx(r,this),this.disposables.add(Zx(this.contextKeyService,this)),this.listSupportsMultiSelect=Kx.bindTo(this.contextKeyService),this.listSupportsMultiSelect.set(o.multipleSelectionSupport!==!1),qx.bindTo(this.contextKeyService).set(!!o.selectionNavigation),this.listHasSelectionOrFocus=LO.bindTo(this.contextKeyService),this.listDoubleSelection=xO.bindTo(this.contextKeyService),this.listMultiSelection=DO.bindTo(this.contextKeyService),this.horizontalScrolling=o.horizontalScrolling,this._useAltAsMultipleSelectionModifier=ed(l),this.disposables.add(this.contextKeyService),this.disposables.add(a.register(this)),this.updateStyles(o.overrideStyles),this.disposables.add(this.onDidChangeSelection(()=>{const f=this.getSelection(),m=this.getFocus();this.contextKeyService.bufferChangeEvents(()=>{this.listHasSelectionOrFocus.set(f.length>0||m.length>0),this.listMultiSelection.set(f.length>1),this.listDoubleSelection.set(f.length===2)})})),this.disposables.add(this.onDidChangeFocus(()=>{const f=this.getSelection(),m=this.getFocus();this.listHasSelectionOrFocus.set(f.length>0||m.length>0)})),this.disposables.add(l.onDidChangeConfiguration(f=>{f.affectsConfiguration(ff)&&(this._useAltAsMultipleSelectionModifier=ed(l));let m={};if(f.affectsConfiguration(Sr)&&this.horizontalScrolling===void 0){const _=!!l.getValue(Sr);m={...m,horizontalScrolling:_}}if(f.affectsConfiguration(za)){const _=!!l.getValue(za);m={...m,scrollByPage:_}}if(f.affectsConfiguration(Ua)){const _=!!l.getValue(Ua);m={...m,smoothScrolling:_}}if(f.affectsConfiguration(Ql)){const _=l.getValue(Ql);m={...m,mouseWheelScrollSensitivity:_}}if(f.affectsConfiguration(Jl)){const _=l.getValue(Jl);m={...m,fastScrollSensitivity:_}}Object.keys(m).length>0&&this.updateOptions(m)})),this.navigator=new bU(this,{configurationService:l,...o}),this.disposables.add(this.navigator)}updateOptions(e){super.updateOptions(e),e.overrideStyles!==void 0&&this.updateStyles(e.overrideStyles),e.multipleSelectionSupport!==void 0&&this.listSupportsMultiSelect.set(!!e.multipleSelectionSupport)}updateStyles(e){this.style(e?c_(e):gf)}};x2=lc([ii(5,je),ii(6,Mr),ii(7,mt),ii(8,We)],x2);let w9=class extends dfe{constructor(e,t,i,n,o,r,a,l,d){const c=typeof o.horizontalScrolling<"u"?o.horizontalScrolling:!!l.getValue(Sr),[u,h]=d.invokeFunction(Yx,o);super(e,t,i,n,{keyboardSupport:!1,...u,horizontalScrolling:c}),this.disposables=new ie,this.disposables.add(h),this.contextKeyService=Gx(r,this),this.disposables.add(Zx(this.contextKeyService,this.widget)),this.horizontalScrolling=o.horizontalScrolling,this.listSupportsMultiSelect=Kx.bindTo(this.contextKeyService),this.listSupportsMultiSelect.set(o.multipleSelectionSupport!==!1),qx.bindTo(this.contextKeyService).set(!!o.selectionNavigation),this._useAltAsMultipleSelectionModifier=ed(l),this.disposables.add(this.contextKeyService),this.disposables.add(a.register(this)),this.updateStyles(o.overrideStyles),this.disposables.add(l.onDidChangeConfiguration(f=>{f.affectsConfiguration(ff)&&(this._useAltAsMultipleSelectionModifier=ed(l));let m={};if(f.affectsConfiguration(Sr)&&this.horizontalScrolling===void 0){const _=!!l.getValue(Sr);m={...m,horizontalScrolling:_}}if(f.affectsConfiguration(za)){const _=!!l.getValue(za);m={...m,scrollByPage:_}}if(f.affectsConfiguration(Ua)){const _=!!l.getValue(Ua);m={...m,smoothScrolling:_}}if(f.affectsConfiguration(Ql)){const _=l.getValue(Ql);m={...m,mouseWheelScrollSensitivity:_}}if(f.affectsConfiguration(Jl)){const _=l.getValue(Jl);m={...m,fastScrollSensitivity:_}}Object.keys(m).length>0&&this.updateOptions(m)})),this.navigator=new bU(this,{configurationService:l,...o}),this.disposables.add(this.navigator)}updateOptions(e){super.updateOptions(e),e.overrideStyles!==void 0&&this.updateStyles(e.overrideStyles),e.multipleSelectionSupport!==void 0&&this.listSupportsMultiSelect.set(!!e.multipleSelectionSupport)}updateStyles(e){this.style(e?c_(e):gf)}dispose(){this.disposables.dispose(),super.dispose()}};w9=lc([ii(5,je),ii(6,Mr),ii(7,mt),ii(8,We)],w9);let S9=class extends $x{constructor(e,t,i,n,o,r,a,l,d,c){const u=typeof r.horizontalScrolling<"u"?r.horizontalScrolling:!!d.getValue(Sr),[h,g]=c.invokeFunction(Yx,r);super(e,t,i,n,o,{keyboardSupport:!1,...h,horizontalScrolling:u}),this.disposables.add(g),this.contextKeyService=Gx(a,this),this.disposables.add(Zx(this.contextKeyService,this)),this.listSupportsMultiSelect=Kx.bindTo(this.contextKeyService),this.listSupportsMultiSelect.set(r.multipleSelectionSupport!==!1),qx.bindTo(this.contextKeyService).set(!!r.selectionNavigation),this.listHasSelectionOrFocus=LO.bindTo(this.contextKeyService),this.listDoubleSelection=xO.bindTo(this.contextKeyService),this.listMultiSelection=DO.bindTo(this.contextKeyService),this.horizontalScrolling=r.horizontalScrolling,this._useAltAsMultipleSelectionModifier=ed(d),this.disposables.add(this.contextKeyService),this.disposables.add(l.register(this)),this.updateStyles(r.overrideStyles),this.disposables.add(this.onDidChangeSelection(()=>{const m=this.getSelection(),_=this.getFocus();this.contextKeyService.bufferChangeEvents(()=>{this.listHasSelectionOrFocus.set(m.length>0||_.length>0),this.listMultiSelection.set(m.length>1),this.listDoubleSelection.set(m.length===2)})})),this.disposables.add(this.onDidChangeFocus(()=>{const m=this.getSelection(),_=this.getFocus();this.listHasSelectionOrFocus.set(m.length>0||_.length>0)})),this.disposables.add(d.onDidChangeConfiguration(m=>{m.affectsConfiguration(ff)&&(this._useAltAsMultipleSelectionModifier=ed(d));let _={};if(m.affectsConfiguration(Sr)&&this.horizontalScrolling===void 0){const v=!!d.getValue(Sr);_={..._,horizontalScrolling:v}}if(m.affectsConfiguration(za)){const v=!!d.getValue(za);_={..._,scrollByPage:v}}if(m.affectsConfiguration(Ua)){const v=!!d.getValue(Ua);_={..._,smoothScrolling:v}}if(m.affectsConfiguration(Ql)){const v=d.getValue(Ql);_={..._,mouseWheelScrollSensitivity:v}}if(m.affectsConfiguration(Jl)){const v=d.getValue(Jl);_={..._,fastScrollSensitivity:v}}Object.keys(_).length>0&&this.updateOptions(_)})),this.navigator=new lpe(this,{configurationService:d,...r}),this.disposables.add(this.navigator)}updateOptions(e){super.updateOptions(e),e.overrideStyles!==void 0&&this.updateStyles(e.overrideStyles),e.multipleSelectionSupport!==void 0&&this.listSupportsMultiSelect.set(!!e.multipleSelectionSupport)}updateStyles(e){this.style(e?c_(e):gf)}dispose(){this.disposables.dispose(),super.dispose()}};S9=lc([ii(6,je),ii(7,Mr),ii(8,mt),ii(9,We)],S9);class MO extends j{constructor(e,t){var i;super(),this.widget=e,this._onDidOpen=this._register(new W),this.onDidOpen=this._onDidOpen.event,this._register(ge.filter(this.widget.onDidChangeSelection,n=>SV(n.browserEvent))(n=>this.onSelectionFromKeyboard(n))),this._register(this.widget.onPointer(n=>this.onPointer(n.element,n.browserEvent))),this._register(this.widget.onMouseDblClick(n=>this.onMouseDblClick(n.element,n.browserEvent))),typeof(t==null?void 0:t.openOnSingleClick)!="boolean"&&(t!=null&&t.configurationService)?(this.openOnSingleClick=(t==null?void 0:t.configurationService.getValue(Xw))!=="doubleClick",this._register(t==null?void 0:t.configurationService.onDidChangeConfiguration(n=>{n.affectsConfiguration(Xw)&&(this.openOnSingleClick=(t==null?void 0:t.configurationService.getValue(Xw))!=="doubleClick")}))):this.openOnSingleClick=(i=t==null?void 0:t.openOnSingleClick)!==null&&i!==void 0?i:!0}onSelectionFromKeyboard(e){if(e.elements.length!==1)return;const t=e.browserEvent,i=typeof t.preserveFocus=="boolean"?t.preserveFocus:!0,n=typeof t.pinned=="boolean"?t.pinned:!i;this._open(this.getSelectedElement(),i,n,!1,e.browserEvent)}onPointer(e,t){if(!this.openOnSingleClick||t.detail===2)return;const n=t.button===1,o=!0,r=n,a=t.ctrlKey||t.metaKey||t.altKey;this._open(e,o,r,a,t)}onMouseDblClick(e,t){if(!t)return;const i=t.target;if(i.classList.contains("monaco-tl-twistie")||i.classList.contains("monaco-icon-label")&&i.classList.contains("folder-icon")&&t.offsetX<16)return;const o=!1,r=!0,a=t.ctrlKey||t.metaKey||t.altKey;this._open(e,o,r,a,t)}_open(e,t,i,n,o){e&&this._onDidOpen.fire({editorOptions:{preserveFocus:t,pinned:i,revealIfVisible:!0},sideBySide:n,element:e,browserEvent:o})}}class bU extends MO{constructor(e,t){super(e,t),this.widget=e}getSelectedElement(){return this.widget.getSelectedElements()[0]}}class lpe extends MO{constructor(e,t){super(e,t)}getSelectedElement(){return this.widget.getSelectedElements()[0]}}class dpe extends MO{constructor(e,t){super(e,t)}getSelectedElement(){var e;return(e=this.widget.getSelection()[0])!==null&&e!==void 0?e:void 0}}function cpe(s){let e=!1;return t=>{if(t.toKeyCodeChord().isModifierKey())return!1;if(e)return e=!1,!1;const i=s.softDispatch(t,t.target);return i.kind===1?(e=!0,!1):(e=!1,i.kind===0)}}let y9=class extends wO{constructor(e,t,i,n,o,r,a,l,d){const{options:c,getTypeNavigationMode:u,disposable:h}=r.invokeFunction(LC,o);super(e,t,i,n,c),this.disposables.add(h),this.internals=new Bg(this,o,u,o.overrideStyles,a,l,d),this.disposables.add(this.internals)}updateOptions(e){super.updateOptions(e),this.internals.updateOptions(e)}};y9=lc([ii(5,We),ii(6,je),ii(7,Mr),ii(8,mt)],y9);let L9=class extends cU{constructor(e,t,i,n,o,r,a,l,d){const{options:c,getTypeNavigationMode:u,disposable:h}=r.invokeFunction(LC,o);super(e,t,i,n,c),this.disposables.add(h),this.internals=new Bg(this,o,u,o.overrideStyles,a,l,d),this.disposables.add(this.internals)}updateOptions(e={}){super.updateOptions(e),e.overrideStyles&&this.internals.updateStyleOverrides(e.overrideStyles),this.internals.updateOptions(e)}};L9=lc([ii(5,We),ii(6,je),ii(7,Mr),ii(8,mt)],L9);let x9=class extends tpe{constructor(e,t,i,n,o,r,a,l,d,c){const{options:u,getTypeNavigationMode:h,disposable:g}=a.invokeFunction(LC,r);super(e,t,i,n,o,u),this.disposables.add(g),this.internals=new Bg(this,r,h,r.overrideStyles,l,d,c),this.disposables.add(this.internals)}updateOptions(e={}){super.updateOptions(e),e.overrideStyles!==void 0&&this.internals.updateStyleOverrides(e.overrideStyles),this.internals.updateOptions(e)}};x9=lc([ii(6,We),ii(7,je),ii(8,Mr),ii(9,mt)],x9);let D2=class extends hU{get onDidOpen(){return this.internals.onDidOpen}constructor(e,t,i,n,o,r,a,l,d,c){const{options:u,getTypeNavigationMode:h,disposable:g}=a.invokeFunction(LC,r);super(e,t,i,n,o,u),this.disposables.add(g),this.internals=new Bg(this,r,h,r.overrideStyles,l,d,c),this.disposables.add(this.internals)}updateOptions(e={}){super.updateOptions(e),e.overrideStyles&&this.internals.updateStyleOverrides(e.overrideStyles),this.internals.updateOptions(e)}};D2=lc([ii(6,We),ii(7,je),ii(8,Mr),ii(9,mt)],D2);let D9=class extends Jfe{constructor(e,t,i,n,o,r,a,l,d,c,u){const{options:h,getTypeNavigationMode:g,disposable:f}=l.invokeFunction(LC,a);super(e,t,i,n,o,r,h),this.disposables.add(f),this.internals=new Bg(this,a,g,a.overrideStyles,d,c,u),this.disposables.add(this.internals)}updateOptions(e){super.updateOptions(e),this.internals.updateOptions(e)}};D9=lc([ii(7,We),ii(8,je),ii(9,Mr),ii(10,mt)],D9);function CU(s){const e=s.getValue(EO);if(e==="highlight")return Pl.Highlight;if(e==="filter")return Pl.Filter;const t=s.getValue(Py);if(t==="simple"||t==="highlight")return Pl.Highlight;if(t==="filter")return Pl.Filter}function wU(s){const e=s.getValue(TO);if(e==="fuzzy")return Fg.Fuzzy;if(e==="contiguous")return Fg.Contiguous}function LC(s,e){var t;const i=s.get(mt),n=s.get(rc),o=s.get(je),r=s.get(We),a=()=>{const g=o.getContextKeyValue(_U);if(g==="automatic")return Sl.Automatic;if(g==="trigger"||o.getContextKeyValue(vU)===!1)return Sl.Trigger;const m=i.getValue(NO);if(m==="automatic")return Sl.Automatic;if(m==="trigger")return Sl.Trigger},l=e.horizontalScrolling!==void 0?e.horizontalScrolling:!!i.getValue(Sr),[d,c]=r.invokeFunction(Yx,e),u=e.paddingBottom,h=e.renderIndentGuides!==void 0?e.renderIndentGuides:i.getValue(Oy);return{getTypeNavigationMode:a,disposable:c,options:{keyboardSupport:!1,...d,indent:typeof i.getValue(fb)=="number"?i.getValue(fb):void 0,renderIndentGuides:h,smoothScrolling:!!i.getValue(Ua),defaultFindMode:CU(i),defaultFindMatchType:wU(i),horizontalScrolling:l,scrollByPage:!!i.getValue(za),paddingBottom:u,hideTwistiesOfChildlessElements:e.hideTwistiesOfChildlessElements,expandOnlyOnTwistieClick:(t=e.expandOnlyOnTwistieClick)!==null&&t!==void 0?t:i.getValue(Fy)==="doubleClick",contextViewProvider:n,findWidgetStyles:zge,enableStickyScroll:!!i.getValue(By),stickyScrollMaxItemCount:Number(i.getValue(Wy))}}}let Bg=class{get onDidOpen(){return this.navigator.onDidOpen}constructor(e,t,i,n,o,r,a){var l;this.tree=e,this.disposables=[],this.contextKeyService=Gx(o,e),this.disposables.push(Zx(this.contextKeyService,e)),this.listSupportsMultiSelect=Kx.bindTo(this.contextKeyService),this.listSupportsMultiSelect.set(t.multipleSelectionSupport!==!1),qx.bindTo(this.contextKeyService).set(!!t.selectionNavigation),this.listSupportFindWidget=npe.bindTo(this.contextKeyService),this.listSupportFindWidget.set((l=t.findWidgetEnabled)!==null&&l!==void 0?l:!0),this.hasSelectionOrFocus=LO.bindTo(this.contextKeyService),this.hasDoubleSelection=xO.bindTo(this.contextKeyService),this.hasMultiSelection=DO.bindTo(this.contextKeyService),this.treeElementCanCollapse=kO.bindTo(this.contextKeyService),this.treeElementHasParent=spe.bindTo(this.contextKeyService),this.treeElementCanExpand=IO.bindTo(this.contextKeyService),this.treeElementHasChild=ope.bindTo(this.contextKeyService),this.treeFindOpen=rpe.bindTo(this.contextKeyService),this._useAltAsMultipleSelectionModifier=ed(a),this.updateStyleOverrides(n);const c=()=>{const h=e.getFocus()[0];if(!h)return;const g=e.getNode(h);this.treeElementCanCollapse.set(g.collapsible&&!g.collapsed),this.treeElementHasParent.set(!!e.getParentElement(h)),this.treeElementCanExpand.set(g.collapsible&&g.collapsed),this.treeElementHasChild.set(!!e.getFirstElementChild(h))},u=new Set;u.add(_U),u.add(vU),this.disposables.push(this.contextKeyService,r.register(e),e.onDidChangeSelection(()=>{const h=e.getSelection(),g=e.getFocus();this.contextKeyService.bufferChangeEvents(()=>{this.hasSelectionOrFocus.set(h.length>0||g.length>0),this.hasMultiSelection.set(h.length>1),this.hasDoubleSelection.set(h.length===2)})}),e.onDidChangeFocus(()=>{const h=e.getSelection(),g=e.getFocus();this.hasSelectionOrFocus.set(h.length>0||g.length>0),c()}),e.onDidChangeCollapseState(c),e.onDidChangeModel(c),e.onDidChangeFindOpenState(h=>this.treeFindOpen.set(h)),a.onDidChangeConfiguration(h=>{let g={};if(h.affectsConfiguration(ff)&&(this._useAltAsMultipleSelectionModifier=ed(a)),h.affectsConfiguration(fb)){const f=a.getValue(fb);g={...g,indent:f}}if(h.affectsConfiguration(Oy)&&t.renderIndentGuides===void 0){const f=a.getValue(Oy);g={...g,renderIndentGuides:f}}if(h.affectsConfiguration(Ua)){const f=!!a.getValue(Ua);g={...g,smoothScrolling:f}}if(h.affectsConfiguration(EO)||h.affectsConfiguration(Py)){const f=CU(a);g={...g,defaultFindMode:f}}if(h.affectsConfiguration(NO)||h.affectsConfiguration(Py)){const f=i();g={...g,typeNavigationMode:f}}if(h.affectsConfiguration(TO)){const f=wU(a);g={...g,defaultFindMatchType:f}}if(h.affectsConfiguration(Sr)&&t.horizontalScrolling===void 0){const f=!!a.getValue(Sr);g={...g,horizontalScrolling:f}}if(h.affectsConfiguration(za)){const f=!!a.getValue(za);g={...g,scrollByPage:f}}if(h.affectsConfiguration(Fy)&&t.expandOnlyOnTwistieClick===void 0&&(g={...g,expandOnlyOnTwistieClick:a.getValue(Fy)==="doubleClick"}),h.affectsConfiguration(By)){const f=a.getValue(By);g={...g,enableStickyScroll:f}}if(h.affectsConfiguration(Wy)){const f=Math.max(1,a.getValue(Wy));g={...g,stickyScrollMaxItemCount:f}}if(h.affectsConfiguration(Ql)){const f=a.getValue(Ql);g={...g,mouseWheelScrollSensitivity:f}}if(h.affectsConfiguration(Jl)){const f=a.getValue(Jl);g={...g,fastScrollSensitivity:f}}Object.keys(g).length>0&&e.updateOptions(g)}),this.contextKeyService.onDidChangeContext(h=>{h.affectsSome(u)&&e.updateOptions({typeNavigationMode:i()})})),this.navigator=new dpe(e,{configurationService:a,...t}),this.disposables.push(this.navigator)}updateOptions(e){e.multipleSelectionSupport!==void 0&&this.listSupportsMultiSelect.set(!!e.multipleSelectionSupport)}updateStyleOverrides(e){this.tree.style(e?c_(e):gf)}dispose(){this.disposables=Bt(this.disposables)}};Bg=lc([ii(4,je),ii(5,Mr),ii(6,mt)],Bg);const upe=Si.as(Za.Configuration);upe.registerConfiguration({id:"workbench",order:7,title:p("workbenchConfigurationTitle","Workbench"),type:"object",properties:{[ff]:{type:"string",enum:["ctrlCmd","alt"],markdownEnumDescriptions:[p("multiSelectModifier.ctrlCmd","Maps to `Control` on Windows and Linux and to `Command` on macOS."),p("multiSelectModifier.alt","Maps to `Alt` on Windows and Linux and to `Option` on macOS.")],default:"ctrlCmd",description:p({key:"multiSelectModifier",comment:["- `ctrlCmd` refers to a value the setting can take and should not be localized.","- `Control` and `Command` refer to the modifier keys Ctrl or Cmd on the keyboard and can be localized."]},"The modifier to be used to add an item in trees and lists to a multi-selection with the mouse (for example in the explorer, open editors and scm view). The 'Open to Side' mouse gestures - if supported - will adapt such that they do not conflict with the multiselect modifier.")},[Xw]:{type:"string",enum:["singleClick","doubleClick"],default:"singleClick",description:p({key:"openModeModifier",comment:["`singleClick` and `doubleClick` refers to a value the setting can take and should not be localized."]},"Controls how to open items in trees and lists using the mouse (if supported). Note that some trees and lists might choose to ignore this setting if it is not applicable.")},[Sr]:{type:"boolean",default:!1,description:p("horizontalScrolling setting","Controls whether lists and trees support horizontal scrolling in the workbench. Warning: turning on this setting has a performance implication.")},[za]:{type:"boolean",default:!1,description:p("list.scrollByPage","Controls whether clicks in the scrollbar scroll page by page.")},[fb]:{type:"number",default:8,minimum:4,maximum:40,description:p("tree indent setting","Controls tree indentation in pixels.")},[Oy]:{type:"string",enum:["none","onHover","always"],default:"onHover",description:p("render tree indent guides","Controls whether the tree should render indent guides.")},[Ua]:{type:"boolean",default:!1,description:p("list smoothScrolling setting","Controls whether lists and trees have smooth scrolling.")},[Ql]:{type:"number",default:1,markdownDescription:p("Mouse Wheel Scroll Sensitivity","A multiplier to be used on the `deltaX` and `deltaY` of mouse wheel scroll events.")},[Jl]:{type:"number",default:5,markdownDescription:p("Fast Scroll Sensitivity","Scrolling speed multiplier when pressing `Alt`.")},[EO]:{type:"string",enum:["highlight","filter"],enumDescriptions:[p("defaultFindModeSettingKey.highlight","Highlight elements when searching. Further up and down navigation will traverse only the highlighted elements."),p("defaultFindModeSettingKey.filter","Filter elements when searching.")],default:"highlight",description:p("defaultFindModeSettingKey","Controls the default find mode for lists and trees in the workbench.")},[Py]:{type:"string",enum:["simple","highlight","filter"],enumDescriptions:[p("keyboardNavigationSettingKey.simple","Simple keyboard navigation focuses elements which match the keyboard input. Matching is done only on prefixes."),p("keyboardNavigationSettingKey.highlight","Highlight keyboard navigation highlights elements which match the keyboard input. Further up and down navigation will traverse only the highlighted elements."),p("keyboardNavigationSettingKey.filter","Filter keyboard navigation will filter out and hide all the elements which do not match the keyboard input.")],default:"highlight",description:p("keyboardNavigationSettingKey","Controls the keyboard navigation style for lists and trees in the workbench. Can be simple, highlight and filter."),deprecated:!0,deprecationMessage:p("keyboardNavigationSettingKeyDeprecated","Please use 'workbench.list.defaultFindMode' and	'workbench.list.typeNavigationMode' instead.")},[TO]:{type:"string",enum:["fuzzy","contiguous"],enumDescriptions:[p("defaultFindMatchTypeSettingKey.fuzzy","Use fuzzy matching when searching."),p("defaultFindMatchTypeSettingKey.contiguous","Use contiguous matching when searching.")],default:"fuzzy",description:p("defaultFindMatchTypeSettingKey","Controls the type of matching used when searching lists and trees in the workbench.")},[Fy]:{type:"string",enum:["singleClick","doubleClick"],default:"singleClick",description:p("expand mode","Controls how tree folders are expanded when clicking the folder names. Note that some trees and lists might choose to ignore this setting if it is not applicable.")},[By]:{type:"boolean",default:typeof C9.quality=="string"&&C9.quality!=="stable",description:p("sticky scroll","Controls whether sticky scrolling is enabled in trees.")},[Wy]:{type:"number",minimum:1,default:7,markdownDescription:p("sticky scroll maximum items","Controls the number of sticky elements displayed in the tree when `#workbench.tree.enableStickyScroll#` is enabled.")},[NO]:{type:"string",enum:["automatic","trigger"],default:"automatic",markdownDescription:p("typeNavigationMode2","Controls how type navigation works in lists and trees in the workbench. When set to `trigger`, type navigation begins once the `list.triggerTypeNavigation` command is run.")}}});var k2;(function(s){s[s.PRESERVE=0]="PRESERVE",s[s.LAST=1]="LAST"})(k2||(k2={}));const pf={Quickaccess:"workbench.contributions.quickaccess"};class hpe{constructor(){this.providers=[],this.defaultProvider=void 0}registerQuickAccessProvider(e){return e.prefix.length===0?this.defaultProvider=e:this.providers.push(e),this.providers.sort((t,i)=>i.prefix.length-t.prefix.length),Fe(()=>{this.providers.splice(this.providers.indexOf(e),1),this.defaultProvider===e&&(this.defaultProvider=void 0)})}getQuickAccessProviders(){return Ba([this.defaultProvider,...this.providers])}getQuickAccessProvider(e){return e&&this.providers.find(i=>e.startsWith(i.prefix))||void 0||this.defaultProvider}}Si.add(pf.Quickaccess,new hpe);const gpe={ctrlCmd:!1,alt:!1};var pb;(function(s){s[s.Blur=1]="Blur",s[s.Gesture=2]="Gesture",s[s.Other=3]="Other"})(pb||(pb={}));var ma;(function(s){s[s.NONE=0]="NONE",s[s.FIRST=1]="FIRST",s[s.SECOND=2]="SECOND",s[s.LAST=3]="LAST"})(ma||(ma={}));const Ya=ut("quickInputService");var fpe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},k9=function(s,e){return function(t,i){e(t,i,s)}};let I2=class extends j{constructor(e,t){super(),this.quickInputService=e,this.instantiationService=t,this.registry=Si.as(pf.Quickaccess),this.mapProviderToDescriptor=new Map,this.lastAcceptedPickerValues=new Map,this.visibleQuickAccess=void 0}show(e="",t){this.doShowOrPick(e,!1,t)}doShowOrPick(e,t,i){var n;const[o,r]=this.getOrInstantiateProvider(e),a=this.visibleQuickAccess,l=a==null?void 0:a.descriptor;if(a&&r&&l===r){e!==r.prefix&&!(i!=null&&i.preserveValue)&&(a.picker.value=e),this.adjustValueSelection(a.picker,r,i);return}if(r&&!(i!=null&&i.preserveValue)){let g;if(a&&l&&l!==r){const f=a.value.substr(l.prefix.length);f&&(g=`${r.prefix}${f}`)}if(!g){const f=o==null?void 0:o.defaultFilterValue;f===k2.LAST?g=this.lastAcceptedPickerValues.get(r):typeof f=="string"&&(g=`${r.prefix}${f}`)}typeof g=="string"&&(e=g)}const d=new ie,c=d.add(this.quickInputService.createQuickPick());c.value=e,this.adjustValueSelection(c,r,i),c.placeholder=r==null?void 0:r.placeholder,c.quickNavigate=i==null?void 0:i.quickNavigateConfiguration,c.hideInput=!!c.quickNavigate&&!a,(typeof(i==null?void 0:i.itemActivation)=="number"||i!=null&&i.quickNavigateConfiguration)&&(c.itemActivation=(n=i==null?void 0:i.itemActivation)!==null&&n!==void 0?n:ma.SECOND),c.contextKey=r==null?void 0:r.contextKey,c.filterValue=g=>g.substring(r?r.prefix.length:0);let u;t&&(u=new ox,d.add(ge.once(c.onWillAccept)(g=>{g.veto(),c.hide()}))),d.add(this.registerPickerListeners(c,o,r,e,i==null?void 0:i.providerOptions));const h=d.add(new Yi);if(o&&d.add(o.provide(c,h.token,i==null?void 0:i.providerOptions)),ge.once(c.onDidHide)(()=>{c.selectedItems.length===0&&h.cancel(),d.dispose(),u==null||u.complete(c.selectedItems.slice(0))}),c.show(),t)return u==null?void 0:u.p}adjustValueSelection(e,t,i){var n;let o;i!=null&&i.preserveValue?o=[e.value.length,e.value.length]:o=[(n=t==null?void 0:t.prefix.length)!==null&&n!==void 0?n:0,e.value.length],e.valueSelection=o}registerPickerListeners(e,t,i,n,o){const r=new ie,a=this.visibleQuickAccess={picker:e,descriptor:i,value:n};return r.add(Fe(()=>{a===this.visibleQuickAccess&&(this.visibleQuickAccess=void 0)})),r.add(e.onDidChangeValue(l=>{const[d]=this.getOrInstantiateProvider(l);d!==t?this.show(l,{preserveValue:!0,providerOptions:o}):a.value=l})),i&&r.add(e.onDidAccept(()=>{this.lastAcceptedPickerValues.set(i,e.value)})),r}getOrInstantiateProvider(e){const t=this.registry.getQuickAccessProvider(e);if(!t)return[void 0,void 0];let i=this.mapProviderToDescriptor.get(t);return i||(i=this.instantiationService.createInstance(t.ctor),this.mapProviderToDescriptor.set(t,i)),[i,t]}};I2=fpe([k9(0,Ya),k9(1,We)],I2);G.white.toString(),G.white.toString();class Vy extends j{get onDidClick(){return this._onDidClick.event}constructor(e,t){super(),this._label="",this._onDidClick=this._register(new W),this.options=t,this._element=document.createElement("a"),this._element.classList.add("monaco-button"),this._element.tabIndex=0,this._element.setAttribute("role","button"),this._element.classList.toggle("secondary",!!t.secondary);const i=t.secondary?t.buttonSecondaryBackground:t.buttonBackground,n=t.secondary?t.buttonSecondaryForeground:t.buttonForeground;this._element.style.color=n||"",this._element.style.backgroundColor=i||"",t.supportShortLabel&&(this._labelShortElement=document.createElement("div"),this._labelShortElement.classList.add("monaco-button-label-short"),this._element.appendChild(this._labelShortElement),this._labelElement=document.createElement("div"),this._labelElement.classList.add("monaco-button-label"),this._element.appendChild(this._labelElement),this._element.classList.add("monaco-text-button-with-short-label")),e.appendChild(this._element),this._register(Xt.addTarget(this._element)),[he.CLICK,Qt.Tap].forEach(o=>{this._register(Y(this._element,o,r=>{if(!this.enabled){ot.stop(r);return}this._onDidClick.fire(r)}))}),this._register(Y(this._element,he.KEY_DOWN,o=>{const r=new ri(o);let a=!1;this.enabled&&(r.equals(3)||r.equals(10))?(this._onDidClick.fire(o),a=!0):r.equals(9)&&(this._element.blur(),a=!0),a&&ot.stop(r,!0)})),this._register(Y(this._element,he.MOUSE_OVER,o=>{this._element.classList.contains("disabled")||this.updateBackground(!0)})),this._register(Y(this._element,he.MOUSE_OUT,o=>{this.updateBackground(!1)})),this.focusTracker=this._register(ql(this._element)),this._register(this.focusTracker.onDidFocus(()=>{this.enabled&&this.updateBackground(!0)})),this._register(this.focusTracker.onDidBlur(()=>{this.enabled&&this.updateBackground(!1)}))}dispose(){super.dispose(),this._element.remove()}getContentElements(e){const t=[];for(let i of hu(e))if(typeof i=="string"){if(i=i.trim(),i==="")continue;const n=document.createElement("span");n.textContent=i,t.push(n)}else t.push(i);return t}updateBackground(e){let t;this.options.secondary?t=e?this.options.buttonSecondaryHoverBackground:this.options.buttonSecondaryBackground:t=e?this.options.buttonHoverBackground:this.options.buttonBackground,t&&(this._element.style.backgroundColor=t)}get element(){return this._element}set label(e){var t;if(this._label===e||uu(this._label)&&uu(e)&&Ihe(this._label,e))return;this._element.classList.add("monaco-text-button");const i=this.options.supportShortLabel?this._labelElement:this._element;if(uu(e)){const n=Vx(e,{inline:!0});n.dispose();const o=(t=n.element.querySelector("p"))===null||t===void 0?void 0:t.innerHTML;if(o){const r=uV(o,{ADD_TAGS:["b","i","u","code","span"],ALLOWED_ATTR:["class"],RETURN_TRUSTED_TYPE:!0});i.innerHTML=r}else Qn(i)}else this.options.supportIcons?Qn(i,...this.getContentElements(e)):i.textContent=e;typeof this.options.title=="string"?this._element.title=this.options.title:this.options.title&&(this._element.title=Uhe(e)),this._label=e}get label(){return this._label}set icon(e){this._element.classList.add(...Oe.asClassNameArray(e))}set enabled(e){e?(this._element.classList.remove("disabled"),this._element.setAttribute("aria-disabled",String(!1)),this._element.tabIndex=0):(this._element.classList.add("disabled"),this._element.setAttribute("aria-disabled",String(!0)))}get enabled(){return!this._element.classList.contains("disabled")}}class E2{constructor(e,t,i){this.options=t,this.styles=i,this.count=0,this.element=te(e,se(".monaco-count-badge")),this.countFormat=this.options.countFormat||"{0}",this.titleFormat=this.options.titleFormat||"",this.setCount(this.options.count||0)}setCount(e){this.count=e,this.render()}setTitleFormat(e){this.titleFormat=e,this.render()}render(){var e,t;this.element.textContent=xg(this.countFormat,this.count),this.element.title=xg(this.titleFormat,this.count),this.element.style.backgroundColor=(e=this.styles.badgeBackground)!==null&&e!==void 0?e:"",this.element.style.color=(t=this.styles.badgeForeground)!==null&&t!==void 0?t:"",this.styles.badgeBorder&&(this.element.style.border=`1px solid ${this.styles.badgeBorder}`)}}const I9="done",E9="active",GI="infinite",ZI="infinite-long-running",N9="discrete";class Xx extends j{constructor(e,t){super(),this.workedVal=0,this.showDelayedScheduler=this._register(new jt(()=>go(this.element),0)),this.longRunningScheduler=this._register(new jt(()=>this.infiniteLongRunning(),Xx.LONG_RUNNING_INFINITE_THRESHOLD)),this.create(e,t)}create(e,t){this.element=document.createElement("div"),this.element.classList.add("monaco-progress-container"),this.element.setAttribute("role","progressbar"),this.element.setAttribute("aria-valuemin","0"),e.appendChild(this.element),this.bit=document.createElement("div"),this.bit.classList.add("progress-bit"),this.bit.style.backgroundColor=(t==null?void 0:t.progressBarBackground)||"#0E70C0",this.element.appendChild(this.bit)}off(){this.bit.style.width="inherit",this.bit.style.opacity="1",this.element.classList.remove(E9,GI,ZI,N9),this.workedVal=0,this.totalWork=void 0,this.longRunningScheduler.cancel()}stop(){return this.doDone(!1)}doDone(e){return this.element.classList.add(I9),this.element.classList.contains(GI)?(this.bit.style.opacity="0",e?setTimeout(()=>this.off(),200):this.off()):(this.bit.style.width="inherit",e?setTimeout(()=>this.off(),200):this.off()),this}infinite(){return this.bit.style.width="2%",this.bit.style.opacity="1",this.element.classList.remove(N9,I9,ZI),this.element.classList.add(E9,GI),this.longRunningScheduler.schedule(),this}infiniteLongRunning(){this.element.classList.add(ZI)}getContainer(){return this.element}}Xx.LONG_RUNNING_INFINITE_THRESHOLD=1e4;const ppe=se;class mpe extends j{constructor(e,t,i){super(),this.parent=e,this.onKeyDown=o=>Pi(this.findInput.inputBox.inputElement,he.KEY_DOWN,o),this.onMouseDown=o=>Pi(this.findInput.inputBox.inputElement,he.MOUSE_DOWN,o),this.onDidChange=o=>this.findInput.onDidChange(o),this.container=te(this.parent,ppe(".quick-input-box")),this.findInput=this._register(new rU(this.container,void 0,{label:"",inputBoxStyles:t,toggleStyles:i}));const n=this.findInput.inputBox.inputElement;n.role="combobox",n.ariaHasPopup="menu",n.ariaAutoComplete="list",n.ariaExpanded="true"}get value(){return this.findInput.getValue()}set value(e){this.findInput.setValue(e)}select(e=null){this.findInput.inputBox.select(e)}isSelectionAtEnd(){return this.findInput.inputBox.isSelectionAtEnd()}get placeholder(){return this.findInput.inputBox.inputElement.getAttribute("placeholder")||""}set placeholder(e){this.findInput.inputBox.setPlaceHolder(e)}get password(){return this.findInput.inputBox.inputElement.type==="password"}set password(e){this.findInput.inputBox.inputElement.type=e?"password":"text"}set enabled(e){this.findInput.inputBox.inputElement.toggleAttribute("readonly",!e)}set toggles(e){this.findInput.setAdditionalToggles(e)}setAttribute(e,t){this.findInput.inputBox.inputElement.setAttribute(e,t)}showDecoration(e){e===Wi.Ignore?this.findInput.clearMessage():this.findInput.showMessage({type:e===Wi.Info?1:e===Wi.Warning?2:3,content:""})}stylesForType(e){return this.findInput.inputBox.stylesForType(e===Wi.Info?1:e===Wi.Warning?2:3)}setFocus(){this.findInput.focus()}layout(){this.findInput.inputBox.layout()}}class fu{constructor(e,t){var i;this.text="",this.title="",this.highlights=[],this.didEverRender=!1,this.supportIcons=(i=t==null?void 0:t.supportIcons)!==null&&i!==void 0?i:!1,this.domNode=te(e,se("span.monaco-highlighted-label"))}get element(){return this.domNode}set(e,t=[],i="",n){e||(e=""),n&&(e=fu.escapeNewLines(e,t)),!(this.didEverRender&&this.text===e&&this.title===i&&Qo(this.highlights,t))&&(this.text=e,this.title=i,this.highlights=t,this.render())}render(){const e=[];let t=0;for(const i of this.highlights){if(i.end===i.start)continue;if(t<i.start){const r=this.text.substring(t,i.start);this.supportIcons?e.push(...hu(r)):e.push(r),t=i.start}const n=this.text.substring(t,i.end),o=se("span.highlight",void 0,...this.supportIcons?hu(n):[n]);i.extraClasses&&o.classList.add(...i.extraClasses),e.push(o),t=i.end}if(t<this.text.length){const i=this.text.substring(t);this.supportIcons?e.push(...hu(i)):e.push(i)}Qn(this.domNode,...e),this.title?this.domNode.title=this.title:this.domNode.removeAttribute("title"),this.didEverRender=!0}static escapeNewLines(e,t){let i=0,n=0;return e.replace(/\r\n|\r|\n/g,(o,r)=>{n=o===`\r
`?-1:0,r+=i;for(const a of t)a.end<=r||(a.start>=r&&(a.start+=n),a.end>=r&&(a.end+=n));return i+=n,"⏎"})}}class U_{constructor(e){this._element=e}get element(){return this._element}set textContent(e){this.disposed||e===this._textContent||(this._textContent=e,this._element.textContent=e)}set className(e){this.disposed||e===this._className||(this._className=e,this._element.className=e)}set empty(e){this.disposed||e===this._empty||(this._empty=e,this._element.style.marginLeft=e?"0":"")}dispose(){this.disposed=!0}}class Hy extends j{constructor(e,t){super(),this.customHovers=new Map,this.creationOptions=t,this.domNode=this._register(new U_(te(e,se(".monaco-icon-label")))),this.labelContainer=te(this.domNode.element,se(".monaco-icon-label-container")),this.nameContainer=te(this.labelContainer,se("span.monaco-icon-name-container")),t!=null&&t.supportHighlights||t!=null&&t.supportIcons?this.nameNode=new bpe(this.nameContainer,!!t.supportIcons):this.nameNode=new _pe(this.nameContainer),this.hoverDelegate=t==null?void 0:t.hoverDelegate}get element(){return this.domNode.element}setLabel(e,t,i){var n;const o=["monaco-icon-label"],r=["monaco-icon-label-container"];let a="";if(i&&(i.extraClasses&&o.push(...i.extraClasses),i.italic&&o.push("italic"),i.strikethrough&&o.push("strikethrough"),i.disabledCommand&&r.push("disabled"),i.title&&(typeof i.title=="string"?a+=i.title:a+=e)),this.domNode.className=o.join(" "),this.domNode.element.setAttribute("aria-label",a),this.labelContainer.className=r.join(" "),this.setupHover(i!=null&&i.descriptionTitle?this.labelContainer:this.element,i==null?void 0:i.title),this.nameNode.setLabel(e,i),t||this.descriptionNode){const l=this.getOrCreateDescriptionNode();l instanceof fu?(l.set(t||"",i?i.descriptionMatches:void 0,void 0,i==null?void 0:i.labelEscapeNewLines),this.setupHover(l.element,i==null?void 0:i.descriptionTitle)):(l.textContent=t&&(i!=null&&i.labelEscapeNewLines)?fu.escapeNewLines(t,[]):t||"",this.setupHover(l.element,(i==null?void 0:i.descriptionTitle)||""),l.empty=!t)}if(i!=null&&i.suffix||this.suffixNode){const l=this.getOrCreateSuffixNode();l.textContent=(n=i==null?void 0:i.suffix)!==null&&n!==void 0?n:""}}setupHover(e,t){const i=this.customHovers.get(e);if(i&&(i.dispose(),this.customHovers.delete(e)),!t){e.removeAttribute("title");return}if(!this.hoverDelegate)The(e,t);else{const n=zz(this.hoverDelegate,e,t);n&&this.customHovers.set(e,n)}}dispose(){super.dispose();for(const e of this.customHovers.values())e.dispose();this.customHovers.clear()}getOrCreateSuffixNode(){if(!this.suffixNode){const e=this._register(new U_(Qee(this.nameContainer,se("span.monaco-icon-suffix-container"))));this.suffixNode=this._register(new U_(te(e.element,se("span.label-suffix"))))}return this.suffixNode}getOrCreateDescriptionNode(){var e;if(!this.descriptionNode){const t=this._register(new U_(te(this.labelContainer,se("span.monaco-icon-description-container"))));!((e=this.creationOptions)===null||e===void 0)&&e.supportDescriptionHighlights?this.descriptionNode=new fu(te(t.element,se("span.label-description")),{supportIcons:!!this.creationOptions.supportIcons}):this.descriptionNode=this._register(new U_(te(t.element,se("span.label-description"))))}return this.descriptionNode}}class _pe{constructor(e){this.container=e,this.label=void 0,this.singleLabel=void 0}setLabel(e,t){if(!(this.label===e&&Qo(this.options,t)))if(this.label=e,this.options=t,typeof e=="string")this.singleLabel||(this.container.innerText="",this.container.classList.remove("multiple"),this.singleLabel=te(this.container,se("a.label-name",{id:t==null?void 0:t.domId}))),this.singleLabel.textContent=e;else{this.container.innerText="",this.container.classList.add("multiple"),this.singleLabel=void 0;for(let i=0;i<e.length;i++){const n=e[i],o=(t==null?void 0:t.domId)&&`${t==null?void 0:t.domId}_${i}`;te(this.container,se("a.label-name",{id:o,"data-icon-label-count":e.length,"data-icon-label-index":i,role:"treeitem"},n)),i<e.length-1&&te(this.container,se("span.label-separator",void 0,(t==null?void 0:t.separator)||"/"))}}}}function vpe(s,e,t){if(!t)return;let i=0;return s.map(n=>{const o={start:i,end:i+n.length},r=t.map(a=>is.intersect(o,a)).filter(a=>!is.isEmpty(a)).map(({start:a,end:l})=>({start:a-i,end:l-i}));return i=o.end+e.length,r})}class bpe{constructor(e,t){this.container=e,this.supportIcons=t,this.label=void 0,this.singleLabel=void 0}setLabel(e,t){if(!(this.label===e&&Qo(this.options,t)))if(this.label=e,this.options=t,typeof e=="string")this.singleLabel||(this.container.innerText="",this.container.classList.remove("multiple"),this.singleLabel=new fu(te(this.container,se("a.label-name",{id:t==null?void 0:t.domId})),{supportIcons:this.supportIcons})),this.singleLabel.set(e,t==null?void 0:t.matches,void 0,t==null?void 0:t.labelEscapeNewLines);else{this.container.innerText="",this.container.classList.add("multiple"),this.singleLabel=void 0;const i=(t==null?void 0:t.separator)||"/",n=vpe(e,i,t==null?void 0:t.matches);for(let o=0;o<e.length;o++){const r=e[o],a=n?n[o]:void 0,l=(t==null?void 0:t.domId)&&`${t==null?void 0:t.domId}_${o}`,d=se("a.label-name",{id:l,"data-icon-label-count":e.length,"data-icon-label-index":o,role:"treeitem"});new fu(te(this.container,d),{supportIcons:this.supportIcons}).set(r,a,void 0,t==null?void 0:t.labelEscapeNewLines),o<e.length-1&&te(d,se("span.label-separator",void 0,i))}}}}const V1=se,Cpe={keybindingLabelBackground:void 0,keybindingLabelForeground:void 0,keybindingLabelBorder:void 0,keybindingLabelBottomBorder:void 0,keybindingLabelShadow:void 0};class xC{constructor(e,t,i){this.os=t,this.keyElements=new Set,this.options=i||Object.create(null);const n=this.options.keybindingLabelForeground;this.domNode=te(e,V1(".monaco-keybinding")),n&&(this.domNode.style.color=n),this.didEverRender=!1,e.appendChild(this.domNode)}get element(){return this.domNode}set(e,t){this.didEverRender&&this.keybinding===e&&xC.areSame(this.matches,t)||(this.keybinding=e,this.matches=t,this.render())}render(){var e;if(this.clear(),this.keybinding){const t=this.keybinding.getChords();t[0]&&this.renderChord(this.domNode,t[0],this.matches?this.matches.firstPart:null);for(let n=1;n<t.length;n++)te(this.domNode,V1("span.monaco-keybinding-key-chord-separator",void 0," ")),this.renderChord(this.domNode,t[n],this.matches?this.matches.chordPart:null);const i=(e=this.options.disableTitle)!==null&&e!==void 0&&e?void 0:this.keybinding.getAriaLabel()||void 0;i!==void 0?this.domNode.title=i:this.domNode.removeAttribute("title")}else this.options&&this.options.renderUnboundKeybindings&&this.renderUnbound(this.domNode);this.didEverRender=!0}clear(){Vn(this.domNode),this.keyElements.clear()}renderChord(e,t,i){const n=eO.modifierLabels[this.os];t.ctrlKey&&this.renderKey(e,n.ctrlKey,!!(i!=null&&i.ctrlKey),n.separator),t.shiftKey&&this.renderKey(e,n.shiftKey,!!(i!=null&&i.shiftKey),n.separator),t.altKey&&this.renderKey(e,n.altKey,!!(i!=null&&i.altKey),n.separator),t.metaKey&&this.renderKey(e,n.metaKey,!!(i!=null&&i.metaKey),n.separator);const o=t.keyLabel;o&&this.renderKey(e,o,!!(i!=null&&i.keyCode),"")}renderKey(e,t,i,n){te(e,this.createKeyElement(t,i?".highlight":"")),n&&te(e,V1("span.monaco-keybinding-key-separator",void 0,n))}renderUnbound(e){te(e,this.createKeyElement(p("unbound","Unbound")))}createKeyElement(e,t=""){const i=V1("span.monaco-keybinding-key"+t,void 0,e);return this.keyElements.add(i),this.options.keybindingLabelBackground&&(i.style.backgroundColor=this.options.keybindingLabelBackground),this.options.keybindingLabelBorder&&(i.style.borderColor=this.options.keybindingLabelBorder),this.options.keybindingLabelBottomBorder&&(i.style.borderBottomColor=this.options.keybindingLabelBottomBorder),this.options.keybindingLabelShadow&&(i.style.boxShadow=`inset 0 -1px 0 ${this.options.keybindingLabelShadow}`),i}static areSame(e,t){return e===t||!e&&!t?!0:!!e&&!!t&&Qo(e.firstPart,t.firstPart)&&Qo(e.chordPart,t.chordPart)}}const T9=new ih(()=>{const s=new Intl.Collator(void 0,{numeric:!0,sensitivity:"base"});return{collator:s,collatorIsNumeric:s.resolvedOptions().numeric}});function wpe(s,e,t=!1){const i=s||"",n=e||"",o=T9.value.collator.compare(i,n);return T9.value.collatorIsNumeric&&o===0&&i!==n?i<n?-1:1:o}function Spe(s,e,t){const i=s.toLowerCase(),n=e.toLowerCase(),o=ype(s,e,t);if(o)return o;const r=i.endsWith(t),a=n.endsWith(t);if(r!==a)return r?-1:1;const l=wpe(i,n);return l!==0?l:i.localeCompare(n)}function ype(s,e,t){const i=s.toLowerCase(),n=e.toLowerCase(),o=i.startsWith(t),r=n.startsWith(t);if(o!==r)return o?-1:1;if(o&&r){if(i.length<n.length)return-1;if(i.length>n.length)return 1}return 0}var Lpe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o};class SU{constructor(e){this.nodes=e}toString(){return this.nodes.map(e=>typeof e=="string"?e:e.label).join("")}}Lpe([Xi],SU.prototype,"toString",null);const xpe=/\[([^\]]+)\]\(((?:https?:\/\/|command:|file:)[^\)\s]+)(?: (["'])(.+?)(\3))?\)/gi;function Dpe(s){const e=[];let t=0,i;for(;i=xpe.exec(s);){i.index-t>0&&e.push(s.substring(t,i.index));const[,n,o,,r]=i;r?e.push({label:n,href:o,title:r}):e.push({label:n,href:o}),t=i.index+i[0].length}return t<s.length&&e.push(s.substring(t)),new SU(e)}const YI={},kpe=new cO("quick-input-button-icon-");function N2(s){if(!s)return;let e;const t=s.dark.toString();return YI[t]?e=YI[t]:(e=kpe.nextId(),BS(`.${e}, .hc-light .${e}`,`background-image: ${Tu(s.light||s.dark)}`),BS(`.vs-dark .${e}, .hc-black .${e}`,`background-image: ${Tu(s.dark)}`),YI[t]=e),e}function Ipe(s,e,t){Qn(e);const i=Dpe(s);let n=0;for(const o of i.nodes)if(typeof o=="string")e.append(...hu(o));else{let r=o.title;!r&&o.href.startsWith("command:")?r=p("executeCommand","Click to execute command '{0}'",o.href.substring(8)):r||(r=o.href);const a=se("a",{href:o.href,title:r,tabIndex:n++},o.label);a.style.textDecoration="underline";const l=g=>{Zee(g)&&ot.stop(g,!0),t.callback(o.href)},d=t.disposables.add(new gt(a,he.CLICK)).event,c=t.disposables.add(new gt(a,he.KEY_DOWN)).event,u=ge.chain(c,g=>g.filter(f=>{const m=new ri(f);return m.equals(10)||m.equals(3)}));t.disposables.add(Xt.addTarget(a));const h=t.disposables.add(new gt(a,Qt.Tap)).event;ge.any(d,h,u)(l,null,t.disposables),e.appendChild(a)}}var yU=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o};const ua=se;class Epe{constructor(e,t,i,n,o,r,a){var l,d,c;this._checked=!1,this._hidden=!1,this.hasCheckbox=n,this.index=i,this.fireButtonTriggered=o,this.fireSeparatorButtonTriggered=r,this._onChecked=a,this.onChecked=n?ge.map(ge.filter(this._onChecked.event,u=>u.listElement===this),u=>u.checked):ge.None,e.type==="separator"?this._separator=e:(this.item=e,t&&t.type==="separator"&&!t.buttons&&(this._separator=t),this.saneDescription=this.item.description,this.saneDetail=this.item.detail,this._labelHighlights=(l=this.item.highlights)===null||l===void 0?void 0:l.label,this._descriptionHighlights=(d=this.item.highlights)===null||d===void 0?void 0:d.description,this._detailHighlights=(c=this.item.highlights)===null||c===void 0?void 0:c.detail,this.saneTooltip=this.item.tooltip),this._init=new ih(()=>{var u;const h=(u=e.label)!==null&&u!==void 0?u:"",g=vv(h).text.trim(),f=e.ariaLabel||[h,this.saneDescription,this.saneDetail].map(m=>khe(m)).filter(m=>!!m).join(", ");return{saneLabel:h,saneSortLabel:g,saneAriaLabel:f}})}get saneLabel(){return this._init.value.saneLabel}get saneSortLabel(){return this._init.value.saneSortLabel}get saneAriaLabel(){return this._init.value.saneAriaLabel}get element(){return this._element}set element(e){this._element=e}get hidden(){return this._hidden}set hidden(e){this._hidden=e}get checked(){return this._checked}set checked(e){e!==this._checked&&(this._checked=e,this._onChecked.fire({listElement:this,checked:e}))}get separator(){return this._separator}set separator(e){this._separator=e}get labelHighlights(){return this._labelHighlights}set labelHighlights(e){this._labelHighlights=e}get descriptionHighlights(){return this._descriptionHighlights}set descriptionHighlights(e){this._descriptionHighlights=e}get detailHighlights(){return this._detailHighlights}set detailHighlights(e){this._detailHighlights=e}}class DC{constructor(e){this.themeService=e}get templateId(){return DC.ID}renderTemplate(e){const t=Object.create(null);t.toDisposeElement=[],t.toDisposeTemplate=[],t.entry=te(e,ua(".quick-input-list-entry"));const i=te(t.entry,ua("label.quick-input-list-label"));t.toDisposeTemplate.push(Pi(i,he.CLICK,d=>{t.checkbox.offsetParent||d.preventDefault()})),t.checkbox=te(i,ua("input.quick-input-list-checkbox")),t.checkbox.type="checkbox",t.toDisposeTemplate.push(Pi(t.checkbox,he.CHANGE,d=>{t.element.checked=t.checkbox.checked}));const n=te(i,ua(".quick-input-list-rows")),o=te(n,ua(".quick-input-list-row")),r=te(n,ua(".quick-input-list-row"));t.label=new Hy(o,{supportHighlights:!0,supportDescriptionHighlights:!0,supportIcons:!0}),t.toDisposeTemplate.push(t.label),t.icon=yV(t.label.element,ua(".quick-input-list-icon"));const a=te(o,ua(".quick-input-list-entry-keybinding"));t.keybinding=new xC(a,Go);const l=te(r,ua(".quick-input-list-label-meta"));return t.detail=new Hy(l,{supportHighlights:!0,supportIcons:!0}),t.toDisposeTemplate.push(t.detail),t.separator=te(t.entry,ua(".quick-input-list-separator")),t.actionBar=new Ir(t.entry),t.actionBar.domNode.classList.add("quick-input-list-entry-action-bar"),t.toDisposeTemplate.push(t.actionBar),t}renderElement(e,t,i){var n,o,r,a;i.element=e,e.element=(n=i.entry)!==null&&n!==void 0?n:void 0;const l=e.item?e.item:e.separator;i.checkbox.checked=e.checked,i.toDisposeElement.push(e.onChecked(f=>i.checkbox.checked=f));const{labelHighlights:d,descriptionHighlights:c,detailHighlights:u}=e;if(!((o=e.item)===null||o===void 0)&&o.iconPath){const f=bm(this.themeService.getColorTheme().type)?e.item.iconPath.dark:(r=e.item.iconPath.light)!==null&&r!==void 0?r:e.item.iconPath.dark,m=Pe.revive(f);i.icon.className="quick-input-list-icon",i.icon.style.backgroundImage=Tu(m)}else i.icon.style.backgroundImage="",i.icon.className=!((a=e.item)===null||a===void 0)&&a.iconClass?`quick-input-list-icon ${e.item.iconClass}`:"";const h={matches:d||[],descriptionTitle:e.saneDescription,descriptionMatches:c||[],labelEscapeNewLines:!0};l.type!=="separator"?(h.extraClasses=l.iconClasses,h.italic=l.italic,h.strikethrough=l.strikethrough,i.entry.classList.remove("quick-input-list-separator-as-item")):i.entry.classList.add("quick-input-list-separator-as-item"),i.label.setLabel(e.saneLabel,e.saneDescription,h),i.keybinding.set(l.type==="separator"?void 0:l.keybinding),e.saneDetail?(i.detail.element.style.display="",i.detail.setLabel(e.saneDetail,void 0,{matches:u,title:e.saneDetail,labelEscapeNewLines:!0})):i.detail.element.style.display="none",e.item&&e.separator&&e.separator.label?(i.separator.textContent=e.separator.label,i.separator.style.display=""):i.separator.style.display="none",i.entry.classList.toggle("quick-input-list-separator-border",!!e.separator);const g=l.buttons;g&&g.length?(i.actionBar.push(g.map((f,m)=>{let _=f.iconClass||(f.iconPath?N2(f.iconPath):void 0);return f.alwaysVisible&&(_=_?`${_} always-visible`:"always-visible"),{id:`id-${m}`,class:_,enabled:!0,label:"",tooltip:f.tooltip||"",run:()=>{l.type!=="separator"?e.fireButtonTriggered({button:f,item:l}):e.fireSeparatorButtonTriggered({button:f,separator:l})}}}),{icon:!0,label:!1}),i.entry.classList.add("has-actions")):i.entry.classList.remove("has-actions")}disposeElement(e,t,i){i.toDisposeElement=Bt(i.toDisposeElement),i.actionBar.clear()}disposeTemplate(e){e.toDisposeElement=Bt(e.toDisposeElement),e.toDisposeTemplate=Bt(e.toDisposeTemplate)}}DC.ID="listelement";class Npe{getHeight(e){return e.item?e.saneDetail?44:22:24}getTemplateId(e){return DC.ID}}var xn;(function(s){s[s.First=1]="First",s[s.Second=2]="Second",s[s.Last=3]="Last",s[s.Next=4]="Next",s[s.Previous=5]="Previous",s[s.NextPage=6]="NextPage",s[s.PreviousPage=7]="PreviousPage"})(xn||(xn={}));class RO{constructor(e,t,i,n){this.parent=e,this.options=i,this.inputElements=[],this.elements=[],this.elementsToIndexes=new Map,this.matchOnDescription=!1,this.matchOnDetail=!1,this.matchOnLabel=!0,this.matchOnLabelMode="fuzzy",this.sortByLabel=!0,this._onChangedAllVisibleChecked=new W,this.onChangedAllVisibleChecked=this._onChangedAllVisibleChecked.event,this._onChangedCheckedCount=new W,this.onChangedCheckedCount=this._onChangedCheckedCount.event,this._onChangedVisibleCount=new W,this.onChangedVisibleCount=this._onChangedVisibleCount.event,this._onChangedCheckedElements=new W,this.onChangedCheckedElements=this._onChangedCheckedElements.event,this._onButtonTriggered=new W,this.onButtonTriggered=this._onButtonTriggered.event,this._onSeparatorButtonTriggered=new W,this.onSeparatorButtonTriggered=this._onSeparatorButtonTriggered.event,this._onKeyDown=new W,this.onKeyDown=this._onKeyDown.event,this._onLeave=new W,this.onLeave=this._onLeave.event,this._listElementChecked=new W,this._fireCheckedEvents=!0,this.elementDisposables=[],this.disposables=[],this.id=t,this.container=te(this.parent,ua(".quick-input-list"));const o=new Npe,r=new Rpe;if(this.list=i.createList("QuickInput",this.container,o,[new DC(n)],{identityProvider:{getId:a=>{var l,d,c,u,h,g,f,m;return(m=(g=(u=(d=(l=a.item)===null||l===void 0?void 0:l.id)!==null&&d!==void 0?d:(c=a.item)===null||c===void 0?void 0:c.label)!==null&&u!==void 0?u:(h=a.separator)===null||h===void 0?void 0:h.id)!==null&&g!==void 0?g:(f=a.separator)===null||f===void 0?void 0:f.label)!==null&&m!==void 0?m:""}},setRowLineHeight:!1,multipleSelectionSupport:!1,horizontalScrolling:!1,accessibilityProvider:r}),this.list.getHTMLElement().id=t,this.disposables.push(this.list),this.disposables.push(this.list.onKeyDown(a=>{const l=new ri(a);switch(l.keyCode){case 10:this.toggleCheckbox();break;case 31:(bt?a.metaKey:a.ctrlKey)&&this.list.setFocus(Ls(this.list.length));break;case 16:{const d=this.list.getFocus();d.length===1&&d[0]===0&&this._onLeave.fire();break}case 18:{const d=this.list.getFocus();d.length===1&&d[0]===this.list.length-1&&this._onLeave.fire();break}}this._onKeyDown.fire(l)})),this.disposables.push(this.list.onMouseDown(a=>{a.browserEvent.button!==2&&a.browserEvent.preventDefault()})),this.disposables.push(Y(this.container,he.CLICK,a=>{(a.x||a.y)&&this._onLeave.fire()})),this.disposables.push(this.list.onMouseMiddleClick(a=>{this._onLeave.fire()})),this.disposables.push(this.list.onContextMenu(a=>{typeof a.index=="number"&&(a.browserEvent.preventDefault(),this.list.setSelection([a.index]))})),i.hoverDelegate){const a=new sV(i.hoverDelegate.delay);this.disposables.push(this.list.onMouseOver(async l=>{var d;if(l.browserEvent.target instanceof HTMLAnchorElement){a.cancel();return}if(!(!(l.browserEvent.relatedTarget instanceof HTMLAnchorElement)&&Yn(l.browserEvent.relatedTarget,(d=l.element)===null||d===void 0?void 0:d.element)))try{await a.trigger(async()=>{l.element&&this.showHover(l.element)})}catch(c){if(!Ka(c))throw c}})),this.disposables.push(this.list.onMouseOut(l=>{var d;Yn(l.browserEvent.relatedTarget,(d=l.element)===null||d===void 0?void 0:d.element)||a.cancel()})),this.disposables.push(a)}this.disposables.push(this._listElementChecked.event(a=>this.fireCheckedEvents())),this.disposables.push(this._onChangedAllVisibleChecked,this._onChangedCheckedCount,this._onChangedVisibleCount,this._onChangedCheckedElements,this._onButtonTriggered,this._onSeparatorButtonTriggered,this._onLeave,this._onKeyDown)}get onDidChangeFocus(){return ge.map(this.list.onDidChangeFocus,e=>e.elements.map(t=>t.item))}get onDidChangeSelection(){return ge.map(this.list.onDidChangeSelection,e=>({items:e.elements.map(t=>t.item),event:e.browserEvent}))}get scrollTop(){return this.list.scrollTop}set scrollTop(e){this.list.scrollTop=e}get ariaLabel(){return this.list.getHTMLElement().ariaLabel}set ariaLabel(e){this.list.getHTMLElement().ariaLabel=e}getAllVisibleChecked(){return this.allVisibleChecked(this.elements,!1)}allVisibleChecked(e,t=!0){for(let i=0,n=e.length;i<n;i++){const o=e[i];if(!o.hidden)if(o.checked)t=!0;else return!1}return t}getCheckedCount(){let e=0;const t=this.elements;for(let i=0,n=t.length;i<n;i++)t[i].checked&&e++;return e}getVisibleCount(){let e=0;const t=this.elements;for(let i=0,n=t.length;i<n;i++)t[i].hidden||e++;return e}setAllVisibleChecked(e){try{this._fireCheckedEvents=!1,this.elements.forEach(t=>{t.hidden||(t.checked=e)})}finally{this._fireCheckedEvents=!0,this.fireCheckedEvents()}}setElements(e){this.elementDisposables=Bt(this.elementDisposables);const t=r=>this.fireButtonTriggered(r),i=r=>this.fireSeparatorButtonTriggered(r);this.inputElements=e;const n=new Map,o=this.parent.classList.contains("show-checkboxes");this.elements=e.reduce((r,a,l)=>{var d;const c=l>0?e[l-1]:void 0;if(a.type==="separator"&&!a.buttons)return r;const u=new Epe(a,c,l,o,t,i,this._listElementChecked),h=r.length;return r.push(u),n.set((d=u.item)!==null&&d!==void 0?d:u.separator,h),r},[]),this.elementsToIndexes=n,this.list.splice(0,this.list.length),this.list.splice(0,this.list.length,this.elements),this._onChangedVisibleCount.fire(this.elements.length)}getFocusedElements(){return this.list.getFocusedElements().map(e=>e.item)}setFocusedElements(e){if(this.list.setFocus(e.filter(t=>this.elementsToIndexes.has(t)).map(t=>this.elementsToIndexes.get(t))),e.length>0){const t=this.list.getFocus()[0];typeof t=="number"&&this.list.reveal(t)}}getActiveDescendant(){return this.list.getHTMLElement().getAttribute("aria-activedescendant")}setSelectedElements(e){this.list.setSelection(e.filter(t=>this.elementsToIndexes.has(t)).map(t=>this.elementsToIndexes.get(t)))}getCheckedElements(){return this.elements.filter(e=>e.checked).map(e=>e.item).filter(e=>!!e)}setCheckedElements(e){try{this._fireCheckedEvents=!1;const t=new Set;for(const i of e)t.add(i);for(const i of this.elements)i.checked=t.has(i.item)}finally{this._fireCheckedEvents=!0,this.fireCheckedEvents()}}set enabled(e){this.list.getHTMLElement().style.pointerEvents=e?"":"none"}focus(e){if(!this.list.length)return;switch(e===xn.Second&&this.list.length<2&&(e=xn.First),e){case xn.First:this.list.scrollTop=0,this.list.focusFirst(void 0,i=>!!i.item);break;case xn.Second:this.list.scrollTop=0,this.list.focusNth(1,void 0,i=>!!i.item);break;case xn.Last:this.list.scrollTop=this.list.scrollHeight,this.list.focusLast(void 0,i=>!!i.item);break;case xn.Next:{this.list.focusNext(void 0,!0,void 0,n=>!!n.item);const i=this.list.getFocus()[0];i!==0&&!this.elements[i-1].item&&this.list.firstVisibleIndex>i-1&&this.list.reveal(i-1);break}case xn.Previous:{this.list.focusPrevious(void 0,!0,void 0,n=>!!n.item);const i=this.list.getFocus()[0];i!==0&&!this.elements[i-1].item&&this.list.firstVisibleIndex>i-1&&this.list.reveal(i-1);break}case xn.NextPage:this.list.focusNextPage(void 0,i=>!!i.item);break;case xn.PreviousPage:this.list.focusPreviousPage(void 0,i=>!!i.item);break}const t=this.list.getFocus()[0];typeof t=="number"&&this.list.reveal(t)}clearFocus(){this.list.setFocus([])}domFocus(){this.list.domFocus()}showHover(e){var t,i,n;this.options.hoverDelegate!==void 0&&(this._lastHover&&!this._lastHover.isDisposed&&((i=(t=this.options.hoverDelegate).onDidHideHover)===null||i===void 0||i.call(t),(n=this._lastHover)===null||n===void 0||n.dispose()),!(!e.element||!e.saneTooltip)&&(this._lastHover=this.options.hoverDelegate.showHover({content:e.saneTooltip,target:e.element,linkHandler:o=>{this.options.linkOpenerDelegate(o)},appearance:{showPointer:!0},container:this.container,position:{hoverPosition:1}},!1)))}layout(e){this.list.getHTMLElement().style.maxHeight=e?`${Math.floor(e/44)*44+6}px`:"",this.list.layout()}filter(e){if(!(this.sortByLabel||this.matchOnLabel||this.matchOnDescription||this.matchOnDetail))return this.list.layout(),!1;const t=e;if(e=e.trim(),!e||!(this.matchOnLabel||this.matchOnDescription||this.matchOnDetail))this.elements.forEach(n=>{n.labelHighlights=void 0,n.descriptionHighlights=void 0,n.detailHighlights=void 0,n.hidden=!1;const o=n.index&&this.inputElements[n.index-1];n.item&&(n.separator=o&&o.type==="separator"&&!o.buttons?o:void 0)});else{let n;this.elements.forEach(o=>{var r,a,l,d;let c;this.matchOnLabelMode==="fuzzy"?c=this.matchOnLabel&&(r=PI(e,vv(o.saneLabel)))!==null&&r!==void 0?r:void 0:c=this.matchOnLabel&&(a=Tpe(t,vv(o.saneLabel)))!==null&&a!==void 0?a:void 0;const u=this.matchOnDescription&&(l=PI(e,vv(o.saneDescription||"")))!==null&&l!==void 0?l:void 0,h=this.matchOnDetail&&(d=PI(e,vv(o.saneDetail||"")))!==null&&d!==void 0?d:void 0;if(c||u||h?(o.labelHighlights=c,o.descriptionHighlights=u,o.detailHighlights=h,o.hidden=!1):(o.labelHighlights=void 0,o.descriptionHighlights=void 0,o.detailHighlights=void 0,o.hidden=o.item?!o.item.alwaysShow:!0),o.item?o.separator=void 0:o.separator&&(o.hidden=!0),!this.sortByLabel){const g=o.index&&this.inputElements[o.index-1];n=g&&g.type==="separator"?g:n,n&&!o.hidden&&(o.separator=n,n=void 0)}})}const i=this.elements.filter(n=>!n.hidden);if(this.sortByLabel&&e){const n=e.toLowerCase();i.sort((o,r)=>Mpe(o,r,n))}return this.elementsToIndexes=i.reduce((n,o,r)=>{var a;return n.set((a=o.item)!==null&&a!==void 0?a:o.separator,r),n},new Map),this.list.splice(0,this.list.length,i),this.list.setFocus([]),this.list.layout(),this._onChangedAllVisibleChecked.fire(this.getAllVisibleChecked()),this._onChangedVisibleCount.fire(i.length),!0}toggleCheckbox(){try{this._fireCheckedEvents=!1;const e=this.list.getFocusedElements(),t=this.allVisibleChecked(e);for(const i of e)i.checked=!t}finally{this._fireCheckedEvents=!0,this.fireCheckedEvents()}}display(e){this.container.style.display=e?"":"none"}isDisplayed(){return this.container.style.display!=="none"}dispose(){this.elementDisposables=Bt(this.elementDisposables),this.disposables=Bt(this.disposables)}fireCheckedEvents(){this._fireCheckedEvents&&(this._onChangedAllVisibleChecked.fire(this.getAllVisibleChecked()),this._onChangedCheckedCount.fire(this.getCheckedCount()),this._onChangedCheckedElements.fire(this.getCheckedElements()))}fireButtonTriggered(e){this._onButtonTriggered.fire(e)}fireSeparatorButtonTriggered(e){this._onSeparatorButtonTriggered.fire(e)}style(e){this.list.style(e)}toggleHover(){const e=this.list.getFocusedElements()[0];if(!(e!=null&&e.saneTooltip))return;if(this._lastHover&&!this._lastHover.isDisposed){this._lastHover.dispose();return}const t=this.list.getFocusedElements()[0];if(!t)return;this.showHover(t);const i=new ie;i.add(this.list.onDidChangeFocus(n=>{n.indexes.length&&this.showHover(n.elements[0])})),this._lastHover&&i.add(this._lastHover),this._toggleHover=i,this.elementDisposables.push(this._toggleHover)}}yU([Xi],RO.prototype,"onDidChangeFocus",null);yU([Xi],RO.prototype,"onDidChangeSelection",null);function Tpe(s,e){const{text:t,iconOffsets:i}=e;if(!i||i.length===0)return M9(s,t);const n=iC(t," "),o=t.length-n.length,r=M9(s,n);if(r)for(const a of r){const l=i[a.start+o]+o;a.start+=l,a.end+=l}return r}function M9(s,e){const t=e.toLowerCase().indexOf(s.toLowerCase());return t!==-1?[{start:t,end:t+s.length}]:null}function Mpe(s,e,t){const i=s.labelHighlights||[],n=e.labelHighlights||[];return i.length&&!n.length?-1:!i.length&&n.length?1:i.length===0&&n.length===0?0:Spe(s.saneSortLabel,e.saneSortLabel,t)}class Rpe{getWidgetAriaLabel(){return p("quickInput","Quick Input")}getAriaLabel(e){var t;return!((t=e.separator)===null||t===void 0)&&t.label?`${e.saneAriaLabel}, ${e.separator.label}`:e.saneAriaLabel}getWidgetRole(){return"listbox"}getRole(e){return e.hasCheckbox?"checkbox":"option"}isChecked(e){if(e.hasCheckbox)return{value:e.checked,onDidChange:e.onChecked}}}const T2={iconClass:Oe.asClassName(le.quickInputBack),tooltip:p("quickInput.back","Back"),handle:-1};class kC extends j{constructor(e){super(),this.ui=e,this._widgetUpdated=!1,this.visible=!1,this._enabled=!0,this._busy=!1,this._ignoreFocusOut=!1,this._buttons=[],this.buttonsUpdated=!1,this._toggles=[],this.togglesUpdated=!1,this.noValidationMessage=kC.noPromptMessage,this._severity=Wi.Ignore,this.onDidTriggerButtonEmitter=this._register(new W),this.onDidHideEmitter=this._register(new W),this.onDisposeEmitter=this._register(new W),this.visibleDisposables=this._register(new ie),this.onDidHide=this.onDidHideEmitter.event}get title(){return this._title}set title(e){this._title=e,this.update()}get description(){return this._description}set description(e){this._description=e,this.update()}get step(){return this._steps}set step(e){this._steps=e,this.update()}get totalSteps(){return this._totalSteps}set totalSteps(e){this._totalSteps=e,this.update()}get enabled(){return this._enabled}set enabled(e){this._enabled=e,this.update()}get contextKey(){return this._contextKey}set contextKey(e){this._contextKey=e,this.update()}get busy(){return this._busy}set busy(e){this._busy=e,this.update()}get ignoreFocusOut(){return this._ignoreFocusOut}set ignoreFocusOut(e){const t=this._ignoreFocusOut!==e&&!Wa;this._ignoreFocusOut=e&&!Wa,t&&this.update()}get buttons(){return this._buttons}set buttons(e){this._buttons=e,this.buttonsUpdated=!0,this.update()}get toggles(){return this._toggles}set toggles(e){this._toggles=e??[],this.togglesUpdated=!0,this.update()}get validationMessage(){return this._validationMessage}set validationMessage(e){this._validationMessage=e,this.update()}get severity(){return this._severity}set severity(e){this._severity=e,this.update()}show(){this.visible||(this.visibleDisposables.add(this.ui.onDidTriggerButton(e=>{this.buttons.indexOf(e)!==-1&&this.onDidTriggerButtonEmitter.fire(e)})),this.ui.show(this),this.visible=!0,this._lastValidationMessage=void 0,this._lastSeverity=void 0,this.buttons.length&&(this.buttonsUpdated=!0),this.toggles.length&&(this.togglesUpdated=!0),this.update())}hide(){this.visible&&this.ui.hide()}didHide(e=pb.Other){this.visible=!1,this.visibleDisposables.clear(),this.onDidHideEmitter.fire({reason:e})}update(){var e,t;if(!this.visible)return;const i=this.getTitle();i&&this.ui.title.textContent!==i?this.ui.title.textContent=i:!i&&this.ui.title.innerHTML!=="&nbsp;"&&(this.ui.title.innerText=" ");const n=this.getDescription();if(this.ui.description1.textContent!==n&&(this.ui.description1.textContent=n),this.ui.description2.textContent!==n&&(this.ui.description2.textContent=n),this._widgetUpdated&&(this._widgetUpdated=!1,this._widget?Qn(this.ui.widget,this._widget):Qn(this.ui.widget)),this.busy&&!this.busyDelay&&(this.busyDelay=new ea,this.busyDelay.setIfNotSet(()=>{this.visible&&this.ui.progressBar.infinite()},800)),!this.busy&&this.busyDelay&&(this.ui.progressBar.stop(),this.busyDelay.cancel(),this.busyDelay=void 0),this.buttonsUpdated){this.buttonsUpdated=!1,this.ui.leftActionBar.clear();const r=this.buttons.filter(l=>l===T2);this.ui.leftActionBar.push(r.map((l,d)=>{const c=new Os(`id-${d}`,"",l.iconClass||N2(l.iconPath),!0,async()=>{this.onDidTriggerButtonEmitter.fire(l)});return c.tooltip=l.tooltip||"",c}),{icon:!0,label:!1}),this.ui.rightActionBar.clear();const a=this.buttons.filter(l=>l!==T2);this.ui.rightActionBar.push(a.map((l,d)=>{const c=new Os(`id-${d}`,"",l.iconClass||N2(l.iconPath),!0,async()=>{this.onDidTriggerButtonEmitter.fire(l)});return c.tooltip=l.tooltip||"",c}),{icon:!0,label:!1})}if(this.togglesUpdated){this.togglesUpdated=!1;const r=(t=(e=this.toggles)===null||e===void 0?void 0:e.filter(a=>a instanceof h_))!==null&&t!==void 0?t:[];this.ui.inputBox.toggles=r}this.ui.ignoreFocusOut=this.ignoreFocusOut,this.ui.setEnabled(this.enabled),this.ui.setContextKey(this.contextKey);const o=this.validationMessage||this.noValidationMessage;this._lastValidationMessage!==o&&(this._lastValidationMessage=o,Qn(this.ui.message),Ipe(o,this.ui.message,{callback:r=>{this.ui.linkOpenerDelegate(r)},disposables:this.visibleDisposables})),this._lastSeverity!==this.severity&&(this._lastSeverity=this.severity,this.showMessageDecoration(this.severity))}getTitle(){return this.title&&this.step?`${this.title} (${this.getSteps()})`:this.title?this.title:this.step?this.getSteps():""}getDescription(){return this.description||""}getSteps(){return this.step&&this.totalSteps?p("quickInput.steps","{0}/{1}",this.step,this.totalSteps):this.step?String(this.step):""}showMessageDecoration(e){if(this.ui.inputBox.showDecoration(e),e!==Wi.Ignore){const t=this.ui.inputBox.stylesForType(e);this.ui.message.style.color=t.foreground?`${t.foreground}`:"",this.ui.message.style.backgroundColor=t.background?`${t.background}`:"",this.ui.message.style.border=t.border?`1px solid ${t.border}`:"",this.ui.message.style.marginBottom="-2px"}else this.ui.message.style.color="",this.ui.message.style.backgroundColor="",this.ui.message.style.border="",this.ui.message.style.marginBottom=""}dispose(){this.hide(),this.onDisposeEmitter.fire(),super.dispose()}}kC.noPromptMessage=p("inputModeEntry","Press 'Enter' to confirm your input or 'Escape' to cancel");class mb extends kC{constructor(){super(...arguments),this._value="",this.onDidChangeValueEmitter=this._register(new W),this.onWillAcceptEmitter=this._register(new W),this.onDidAcceptEmitter=this._register(new W),this.onDidCustomEmitter=this._register(new W),this._items=[],this.itemsUpdated=!1,this._canSelectMany=!1,this._canAcceptInBackground=!1,this._matchOnDescription=!1,this._matchOnDetail=!1,this._matchOnLabel=!0,this._matchOnLabelMode="fuzzy",this._sortByLabel=!0,this._autoFocusOnList=!0,this._keepScrollPosition=!1,this._itemActivation=ma.FIRST,this._activeItems=[],this.activeItemsUpdated=!1,this.activeItemsToConfirm=[],this.onDidChangeActiveEmitter=this._register(new W),this._selectedItems=[],this.selectedItemsUpdated=!1,this.selectedItemsToConfirm=[],this.onDidChangeSelectionEmitter=this._register(new W),this.onDidTriggerItemButtonEmitter=this._register(new W),this.onDidTriggerSeparatorButtonEmitter=this._register(new W),this.valueSelectionUpdated=!0,this._ok="default",this._customButton=!1,this.filterValue=e=>e,this.onDidChangeValue=this.onDidChangeValueEmitter.event,this.onWillAccept=this.onWillAcceptEmitter.event,this.onDidAccept=this.onDidAcceptEmitter.event,this.onDidChangeActive=this.onDidChangeActiveEmitter.event,this.onDidChangeSelection=this.onDidChangeSelectionEmitter.event,this.onDidTriggerItemButton=this.onDidTriggerItemButtonEmitter.event,this.onDidTriggerSeparatorButton=this.onDidTriggerSeparatorButtonEmitter.event}get quickNavigate(){return this._quickNavigate}set quickNavigate(e){this._quickNavigate=e,this.update()}get value(){return this._value}set value(e){this.doSetValue(e)}doSetValue(e,t){this._value!==e&&(this._value=e,t||this.update(),this.visible&&this.ui.list.filter(this.filterValue(this._value))&&this.trySelectFirst(),this.onDidChangeValueEmitter.fire(this._value))}set ariaLabel(e){this._ariaLabel=e,this.update()}get ariaLabel(){return this._ariaLabel}get placeholder(){return this._placeholder}set placeholder(e){this._placeholder=e,this.update()}get items(){return this._items}get scrollTop(){return this.ui.list.scrollTop}set scrollTop(e){this.ui.list.scrollTop=e}set items(e){this._items=e,this.itemsUpdated=!0,this.update()}get canSelectMany(){return this._canSelectMany}set canSelectMany(e){this._canSelectMany=e,this.update()}get canAcceptInBackground(){return this._canAcceptInBackground}set canAcceptInBackground(e){this._canAcceptInBackground=e}get matchOnDescription(){return this._matchOnDescription}set matchOnDescription(e){this._matchOnDescription=e,this.update()}get matchOnDetail(){return this._matchOnDetail}set matchOnDetail(e){this._matchOnDetail=e,this.update()}get matchOnLabel(){return this._matchOnLabel}set matchOnLabel(e){this._matchOnLabel=e,this.update()}get matchOnLabelMode(){return this._matchOnLabelMode}set matchOnLabelMode(e){this._matchOnLabelMode=e,this.update()}get sortByLabel(){return this._sortByLabel}set sortByLabel(e){this._sortByLabel=e,this.update()}get autoFocusOnList(){return this._autoFocusOnList}set autoFocusOnList(e){this._autoFocusOnList=e,this.update()}get keepScrollPosition(){return this._keepScrollPosition}set keepScrollPosition(e){this._keepScrollPosition=e}get itemActivation(){return this._itemActivation}set itemActivation(e){this._itemActivation=e}get activeItems(){return this._activeItems}set activeItems(e){this._activeItems=e,this.activeItemsUpdated=!0,this.update()}get selectedItems(){return this._selectedItems}set selectedItems(e){this._selectedItems=e,this.selectedItemsUpdated=!0,this.update()}get keyMods(){return this._quickNavigate?gpe:this.ui.keyMods}set valueSelection(e){this._valueSelection=e,this.valueSelectionUpdated=!0,this.update()}get customButton(){return this._customButton}set customButton(e){this._customButton=e,this.update()}get customLabel(){return this._customButtonLabel}set customLabel(e){this._customButtonLabel=e,this.update()}get customHover(){return this._customButtonHover}set customHover(e){this._customButtonHover=e,this.update()}get ok(){return this._ok}set ok(e){this._ok=e,this.update()}get hideInput(){return!!this._hideInput}set hideInput(e){this._hideInput=e,this.update()}trySelectFirst(){this.autoFocusOnList&&(this.canSelectMany||this.ui.list.focus(xn.First))}show(){this.visible||(this.visibleDisposables.add(this.ui.inputBox.onDidChange(e=>{this.doSetValue(e,!0)})),this.visibleDisposables.add(this.ui.inputBox.onMouseDown(e=>{this.autoFocusOnList||this.ui.list.clearFocus()})),this.visibleDisposables.add((this._hideInput?this.ui.list:this.ui.inputBox).onKeyDown(e=>{switch(e.keyCode){case 18:this.ui.list.focus(xn.Next),this.canSelectMany&&this.ui.list.domFocus(),ot.stop(e,!0);break;case 16:this.ui.list.getFocusedElements().length?this.ui.list.focus(xn.Previous):this.ui.list.focus(xn.Last),this.canSelectMany&&this.ui.list.domFocus(),ot.stop(e,!0);break;case 12:this.ui.list.focus(xn.NextPage),this.canSelectMany&&this.ui.list.domFocus(),ot.stop(e,!0);break;case 11:this.ui.list.focus(xn.PreviousPage),this.canSelectMany&&this.ui.list.domFocus(),ot.stop(e,!0);break;case 17:if(!this._canAcceptInBackground||!this.ui.inputBox.isSelectionAtEnd())return;this.activeItems[0]&&(this._selectedItems=[this.activeItems[0]],this.onDidChangeSelectionEmitter.fire(this.selectedItems),this.handleAccept(!0));break;case 14:(e.ctrlKey||e.metaKey)&&!e.shiftKey&&!e.altKey&&(this.ui.list.focus(xn.First),ot.stop(e,!0));break;case 13:(e.ctrlKey||e.metaKey)&&!e.shiftKey&&!e.altKey&&(this.ui.list.focus(xn.Last),ot.stop(e,!0));break}})),this.visibleDisposables.add(this.ui.onDidAccept(()=>{this.canSelectMany?this.ui.list.getCheckedElements().length||(this._selectedItems=[],this.onDidChangeSelectionEmitter.fire(this.selectedItems)):this.activeItems[0]&&(this._selectedItems=[this.activeItems[0]],this.onDidChangeSelectionEmitter.fire(this.selectedItems)),this.handleAccept(!1)})),this.visibleDisposables.add(this.ui.onDidCustom(()=>{this.onDidCustomEmitter.fire()})),this.visibleDisposables.add(this.ui.list.onDidChangeFocus(e=>{this.activeItemsUpdated||this.activeItemsToConfirm!==this._activeItems&&Ai(e,this._activeItems,(t,i)=>t===i)||(this._activeItems=e,this.onDidChangeActiveEmitter.fire(e))})),this.visibleDisposables.add(this.ui.list.onDidChangeSelection(({items:e,event:t})=>{if(this.canSelectMany){e.length&&this.ui.list.setSelectedElements([]);return}this.selectedItemsToConfirm!==this._selectedItems&&Ai(e,this._selectedItems,(i,n)=>i===n)||(this._selectedItems=e,this.onDidChangeSelectionEmitter.fire(e),e.length&&this.handleAccept(iP(t)&&t.button===1))})),this.visibleDisposables.add(this.ui.list.onChangedCheckedElements(e=>{this.canSelectMany&&(this.selectedItemsToConfirm!==this._selectedItems&&Ai(e,this._selectedItems,(t,i)=>t===i)||(this._selectedItems=e,this.onDidChangeSelectionEmitter.fire(e)))})),this.visibleDisposables.add(this.ui.list.onButtonTriggered(e=>this.onDidTriggerItemButtonEmitter.fire(e))),this.visibleDisposables.add(this.ui.list.onSeparatorButtonTriggered(e=>this.onDidTriggerSeparatorButtonEmitter.fire(e))),this.visibleDisposables.add(this.registerQuickNavigation()),this.valueSelectionUpdated=!0),super.show()}handleAccept(e){let t=!1;this.onWillAcceptEmitter.fire({veto:()=>t=!0}),t||this.onDidAcceptEmitter.fire({inBackground:e})}registerQuickNavigation(){return Y(this.ui.container,he.KEY_UP,e=>{if(this.canSelectMany||!this._quickNavigate)return;const t=new ri(e),i=t.keyCode;this._quickNavigate.keybindings.some(r=>{const a=r.getChords();return a.length>1?!1:a[0].shiftKey&&i===4?!(t.ctrlKey||t.altKey||t.metaKey):!!(a[0].altKey&&i===6||a[0].ctrlKey&&i===5||a[0].metaKey&&i===57)})&&(this.activeItems[0]&&(this._selectedItems=[this.activeItems[0]],this.onDidChangeSelectionEmitter.fire(this.selectedItems),this.handleAccept(!1)),this._quickNavigate=void 0)})}update(){if(!this.visible)return;const e=this.keepScrollPosition?this.scrollTop:0,t=!!this.description,i={title:!!this.title||!!this.step||!!this.buttons.length,description:t,checkAll:this.canSelectMany&&!this._hideCheckAll,checkBox:this.canSelectMany,inputBox:!this._hideInput,progressBar:!this._hideInput||t,visibleCount:!0,count:this.canSelectMany&&!this._hideCountBadge,ok:this.ok==="default"?this.canSelectMany:this.ok,list:!0,message:!!this.validationMessage,customButton:this.customButton};this.ui.setVisibilities(i),super.update(),this.ui.inputBox.value!==this.value&&(this.ui.inputBox.value=this.value),this.valueSelectionUpdated&&(this.valueSelectionUpdated=!1,this.ui.inputBox.select(this._valueSelection&&{start:this._valueSelection[0],end:this._valueSelection[1]})),this.ui.inputBox.placeholder!==(this.placeholder||"")&&(this.ui.inputBox.placeholder=this.placeholder||"");let n=this.ariaLabel;if(!n&&i.inputBox&&(n=this.placeholder||mb.DEFAULT_ARIA_LABEL,this.title&&(n+=` - ${this.title}`)),this.ui.list.ariaLabel!==n&&(this.ui.list.ariaLabel=n??null),this.ui.list.matchOnDescription=this.matchOnDescription,this.ui.list.matchOnDetail=this.matchOnDetail,this.ui.list.matchOnLabel=this.matchOnLabel,this.ui.list.matchOnLabelMode=this.matchOnLabelMode,this.ui.list.sortByLabel=this.sortByLabel,this.itemsUpdated)switch(this.itemsUpdated=!1,this.ui.list.setElements(this.items),this.ui.list.filter(this.filterValue(this.ui.inputBox.value)),this.ui.checkAll.checked=this.ui.list.getAllVisibleChecked(),this.ui.visibleCount.setCount(this.ui.list.getVisibleCount()),this.ui.count.setCount(this.ui.list.getCheckedCount()),this._itemActivation){case ma.NONE:this._itemActivation=ma.FIRST;break;case ma.SECOND:this.ui.list.focus(xn.Second),this._itemActivation=ma.FIRST;break;case ma.LAST:this.ui.list.focus(xn.Last),this._itemActivation=ma.FIRST;break;default:this.trySelectFirst();break}this.ui.container.classList.contains("show-checkboxes")!==!!this.canSelectMany&&(this.canSelectMany?this.ui.list.clearFocus():this.trySelectFirst()),this.activeItemsUpdated&&(this.activeItemsUpdated=!1,this.activeItemsToConfirm=this._activeItems,this.ui.list.setFocusedElements(this.activeItems),this.activeItemsToConfirm===this._activeItems&&(this.activeItemsToConfirm=null)),this.selectedItemsUpdated&&(this.selectedItemsUpdated=!1,this.selectedItemsToConfirm=this._selectedItems,this.canSelectMany?this.ui.list.setCheckedElements(this.selectedItems):this.ui.list.setSelectedElements(this.selectedItems),this.selectedItemsToConfirm===this._selectedItems&&(this.selectedItemsToConfirm=null)),this.ui.customButton.label=this.customLabel||"",this.ui.customButton.element.title=this.customHover||"",i.inputBox||(this.ui.list.domFocus(),this.canSelectMany&&this.ui.list.focus(xn.First)),this.keepScrollPosition&&(this.scrollTop=e)}}mb.DEFAULT_ARIA_LABEL=p("quickInputBox.ariaLabel","Type to narrow down results.");class Ape extends kC{constructor(){super(...arguments),this._value="",this.valueSelectionUpdated=!0,this._password=!1,this.onDidValueChangeEmitter=this._register(new W),this.onDidAcceptEmitter=this._register(new W),this.onDidChangeValue=this.onDidValueChangeEmitter.event,this.onDidAccept=this.onDidAcceptEmitter.event}get value(){return this._value}set value(e){this._value=e||"",this.update()}get placeholder(){return this._placeholder}set placeholder(e){this._placeholder=e,this.update()}get password(){return this._password}set password(e){this._password=e,this.update()}show(){this.visible||(this.visibleDisposables.add(this.ui.inputBox.onDidChange(e=>{e!==this.value&&(this._value=e,this.onDidValueChangeEmitter.fire(e))})),this.visibleDisposables.add(this.ui.onDidAccept(()=>this.onDidAcceptEmitter.fire())),this.valueSelectionUpdated=!0),super.show()}update(){if(!this.visible)return;this.ui.container.classList.remove("hidden-input");const e={title:!!this.title||!!this.step||!!this.buttons.length,description:!!this.description||!!this.step,inputBox:!0,message:!0,progressBar:!0};this.ui.setVisibilities(e),super.update(),this.ui.inputBox.value!==this.value&&(this.ui.inputBox.value=this.value),this.valueSelectionUpdated&&(this.valueSelectionUpdated=!1,this.ui.inputBox.select(this._valueSelection&&{start:this._valueSelection[0],end:this._valueSelection[1]})),this.ui.inputBox.placeholder!==(this.placeholder||"")&&(this.ui.inputBox.placeholder=this.placeholder||""),this.ui.inputBox.password!==this.password&&(this.ui.inputBox.password=this.password)}}const ro=se;class Qx extends j{constructor(e,t,i){super(),this.options=e,this.themeService=t,this.layoutService=i,this.enabled=!0,this.onDidAcceptEmitter=this._register(new W),this.onDidCustomEmitter=this._register(new W),this.onDidTriggerButtonEmitter=this._register(new W),this.keyMods={ctrlCmd:!1,alt:!1},this.controller=null,this.onShowEmitter=this._register(new W),this.onShow=this.onShowEmitter.event,this.onHideEmitter=this._register(new W),this.onHide=this.onHideEmitter.event,this.idPrefix=e.idPrefix,this.parentElement=e.container,this.styles=e.styles,this._register(ge.runAndSubscribe(JA,({window:n,disposables:o})=>this.registerKeyModsListeners(n,o),{window:Ci,disposables:this._store})),this._register(Pee(n=>{this.ui&&Xe(this.ui.container)===n&&this.reparentUI(this.layoutService.mainContainer)}))}registerKeyModsListeners(e,t){const i=n=>{this.keyMods.ctrlCmd=n.ctrlKey||n.metaKey,this.keyMods.alt=n.altKey};for(const n of[he.KEY_DOWN,he.KEY_UP,he.MOUSE_DOWN])t.add(Y(e,n,i,!0))}getUI(e){if(this.ui)return e&&this.parentElement.ownerDocument!==this.layoutService.activeContainer.ownerDocument&&this.reparentUI(this.layoutService.activeContainer),this.ui;const t=te(this.parentElement,ro(".quick-input-widget.show-file-icons"));t.tabIndex=-1,t.style.display="none";const i=Lr(t),n=te(t,ro(".quick-input-titlebar")),o=this.options.hoverDelegate?{hoverDelegate:this.options.hoverDelegate}:void 0,r=this._register(new Ir(n,o));r.domNode.classList.add("quick-input-left-action-bar");const a=te(n,ro(".quick-input-title")),l=this._register(new Ir(n,o));l.domNode.classList.add("quick-input-right-action-bar");const d=te(t,ro(".quick-input-header")),c=te(d,ro("input.quick-input-check-all"));c.type="checkbox",c.setAttribute("aria-label",p("quickInput.checkAll","Toggle all checkboxes")),this._register(Pi(c,he.CHANGE,K=>{const Q=c.checked;A.setAllVisibleChecked(Q)})),this._register(Y(c,he.CLICK,K=>{(K.x||K.y)&&f.setFocus()}));const u=te(d,ro(".quick-input-description")),h=te(d,ro(".quick-input-and-message")),g=te(h,ro(".quick-input-filter")),f=this._register(new mpe(g,this.styles.inputBox,this.styles.toggle));f.setAttribute("aria-describedby",`${this.idPrefix}message`);const m=te(g,ro(".quick-input-visible-count"));m.setAttribute("aria-live","polite"),m.setAttribute("aria-atomic","true");const _=new E2(m,{countFormat:p({key:"quickInput.visibleCount",comment:["This tells the user how many items are shown in a list of items to select from. The items can be anything. Currently not visible, but read by screen readers."]},"{0} Results")},this.styles.countBadge),v=te(g,ro(".quick-input-count"));v.setAttribute("aria-live","polite");const b=new E2(v,{countFormat:p({key:"quickInput.countSelected",comment:["This tells the user how many items are selected in a list of items to select from. The items can be anything."]},"{0} Selected")},this.styles.countBadge),C=te(d,ro(".quick-input-action")),w=this._register(new Vy(C,this.styles.button));w.label=p("ok","OK"),this._register(w.onDidClick(K=>{this.onDidAcceptEmitter.fire()}));const S=te(d,ro(".quick-input-action")),x=this._register(new Vy(S,this.styles.button));x.label=p("custom","Custom"),this._register(x.onDidClick(K=>{this.onDidCustomEmitter.fire()}));const L=te(h,ro(`#${this.idPrefix}message.quick-input-message`)),k=this._register(new Xx(t,this.styles.progressBar));k.getContainer().classList.add("quick-input-progress");const I=te(t,ro(".quick-input-html-widget"));I.tabIndex=-1;const P=te(t,ro(".quick-input-description")),$=this.idPrefix+"list",A=this._register(new RO(t,$,this.options,this.themeService));f.setAttribute("aria-controls",$),this._register(A.onDidChangeFocus(()=>{var K;f.setAttribute("aria-activedescendant",(K=A.getActiveDescendant())!==null&&K!==void 0?K:"")})),this._register(A.onChangedAllVisibleChecked(K=>{c.checked=K})),this._register(A.onChangedVisibleCount(K=>{_.setCount(K)})),this._register(A.onChangedCheckedCount(K=>{b.setCount(K)})),this._register(A.onLeave(()=>{setTimeout(()=>{f.setFocus(),this.controller instanceof mb&&this.controller.canSelectMany&&A.clearFocus()},0)}));const z=ql(t);return this._register(z),this._register(Y(t,he.FOCUS,K=>{Yn(K.relatedTarget,t)||(this.previousFocusElement=K.relatedTarget instanceof HTMLElement?K.relatedTarget:void 0)},!0)),this._register(z.onDidBlur(()=>{!this.getUI().ignoreFocusOut&&!this.options.ignoreFocusOut()&&this.hide(pb.Blur),this.previousFocusElement=void 0})),this._register(Y(t,he.FOCUS,K=>{f.setFocus()})),this._register(Pi(t,he.KEY_DOWN,K=>{if(!Yn(K.target,I))switch(K.keyCode){case 3:ot.stop(K,!0),this.enabled&&this.onDidAcceptEmitter.fire();break;case 9:ot.stop(K,!0),this.hide(pb.Gesture);break;case 2:if(!K.altKey&&!K.ctrlKey&&!K.metaKey){const Q=[".quick-input-list .monaco-action-bar .always-visible",".quick-input-list-entry:hover .monaco-action-bar",".monaco-list-row.focused .monaco-action-bar"];if(t.classList.contains("show-checkboxes")?Q.push("input"):Q.push("input[type=text]"),this.getUI().list.isDisplayed()&&Q.push(".monaco-list"),this.getUI().message&&Q.push(".quick-input-message a"),this.getUI().widget){if(Yn(K.target,this.getUI().widget))break;Q.push(".quick-input-html-widget")}const ne=t.querySelectorAll(Q.join(", "));K.shiftKey&&K.target===ne[0]?(ot.stop(K,!0),A.clearFocus()):!K.shiftKey&&Yn(K.target,ne[ne.length-1])&&(ot.stop(K,!0),ne[0].focus())}break;case 10:K.ctrlKey&&(ot.stop(K,!0),this.getUI().list.toggleHover());break}})),this.ui={container:t,styleSheet:i,leftActionBar:r,titleBar:n,title:a,description1:P,description2:u,widget:I,rightActionBar:l,checkAll:c,inputContainer:h,filterContainer:g,inputBox:f,visibleCountContainer:m,visibleCount:_,countContainer:v,count:b,okContainer:C,ok:w,message:L,customButtonContainer:S,customButton:x,list:A,progressBar:k,onDidAccept:this.onDidAcceptEmitter.event,onDidCustom:this.onDidCustomEmitter.event,onDidTriggerButton:this.onDidTriggerButtonEmitter.event,ignoreFocusOut:!1,keyMods:this.keyMods,show:K=>this.show(K),hide:()=>this.hide(),setVisibilities:K=>this.setVisibilities(K),setEnabled:K=>this.setEnabled(K),setContextKey:K=>this.options.setContextKey(K),linkOpenerDelegate:K=>this.options.linkOpenerDelegate(K)},this.updateStyles(),this.ui}reparentUI(e){this.ui&&(this.parentElement=e,te(this.parentElement,this.ui.container))}pick(e,t={},i=ct.None){return new Promise((n,o)=>{let r=c=>{var u;r=n,(u=t.onKeyMods)===null||u===void 0||u.call(t,a.keyMods),n(c)};if(i.isCancellationRequested){r(void 0);return}const a=this.createQuickPick();let l;const d=[a,a.onDidAccept(()=>{if(a.canSelectMany)r(a.selectedItems.slice()),a.hide();else{const c=a.activeItems[0];c&&(r(c),a.hide())}}),a.onDidChangeActive(c=>{const u=c[0];u&&t.onDidFocus&&t.onDidFocus(u)}),a.onDidChangeSelection(c=>{if(!a.canSelectMany){const u=c[0];u&&(r(u),a.hide())}}),a.onDidTriggerItemButton(c=>t.onDidTriggerItemButton&&t.onDidTriggerItemButton({...c,removeItem:()=>{const u=a.items.indexOf(c.item);if(u!==-1){const h=a.items.slice(),g=h.splice(u,1),f=a.activeItems.filter(_=>_!==g[0]),m=a.keepScrollPosition;a.keepScrollPosition=!0,a.items=h,f&&(a.activeItems=f),a.keepScrollPosition=m}}})),a.onDidTriggerSeparatorButton(c=>{var u;return(u=t.onDidTriggerSeparatorButton)===null||u===void 0?void 0:u.call(t,c)}),a.onDidChangeValue(c=>{l&&!c&&(a.activeItems.length!==1||a.activeItems[0]!==l)&&(a.activeItems=[l])}),i.onCancellationRequested(()=>{a.hide()}),a.onDidHide(()=>{Bt(d),r(void 0)})];a.title=t.title,a.canSelectMany=!!t.canPickMany,a.placeholder=t.placeHolder,a.ignoreFocusOut=!!t.ignoreFocusLost,a.matchOnDescription=!!t.matchOnDescription,a.matchOnDetail=!!t.matchOnDetail,a.matchOnLabel=t.matchOnLabel===void 0||t.matchOnLabel,a.autoFocusOnList=t.autoFocusOnList===void 0||t.autoFocusOnList,a.quickNavigate=t.quickNavigate,a.hideInput=!!t.hideInput,a.contextKey=t.contextKey,a.busy=!0,Promise.all([e,t.activeItem]).then(([c,u])=>{l=u,a.busy=!1,a.items=c,a.canSelectMany&&(a.selectedItems=c.filter(h=>h.type!=="separator"&&h.picked)),l&&(a.activeItems=[l])}),a.show(),Promise.resolve(e).then(void 0,c=>{o(c),a.hide()})})}createQuickPick(){const e=this.getUI(!0);return new mb(e)}createInputBox(){const e=this.getUI(!0);return new Ape(e)}show(e){const t=this.getUI(!0);this.onShowEmitter.fire();const i=this.controller;this.controller=e,i==null||i.didHide(),this.setEnabled(!0),t.leftActionBar.clear(),t.title.textContent="",t.description1.textContent="",t.description2.textContent="",Qn(t.widget),t.rightActionBar.clear(),t.checkAll.checked=!1,t.inputBox.placeholder="",t.inputBox.password=!1,t.inputBox.showDecoration(Wi.Ignore),t.visibleCount.setCount(0),t.count.setCount(0),Qn(t.message),t.progressBar.stop(),t.list.setElements([]),t.list.matchOnDescription=!1,t.list.matchOnDetail=!1,t.list.matchOnLabel=!0,t.list.sortByLabel=!0,t.ignoreFocusOut=!1,t.inputBox.toggles=void 0;const n=this.options.backKeybindingLabel();T2.tooltip=n?p("quickInput.backWithKeybinding","Back ({0})",n):p("quickInput.back","Back"),t.container.style.display="",this.updateLayout(),t.inputBox.setFocus()}isVisible(){return!!this.ui&&this.ui.container.style.display!=="none"}setVisibilities(e){const t=this.getUI();t.title.style.display=e.title?"":"none",t.description1.style.display=e.description&&(e.inputBox||e.checkAll)?"":"none",t.description2.style.display=e.description&&!(e.inputBox||e.checkAll)?"":"none",t.checkAll.style.display=e.checkAll?"":"none",t.inputContainer.style.display=e.inputBox?"":"none",t.filterContainer.style.display=e.inputBox?"":"none",t.visibleCountContainer.style.display=e.visibleCount?"":"none",t.countContainer.style.display=e.count?"":"none",t.okContainer.style.display=e.ok?"":"none",t.customButtonContainer.style.display=e.customButton?"":"none",t.message.style.display=e.message?"":"none",t.progressBar.getContainer().style.display=e.progressBar?"":"none",t.list.display(!!e.list),t.container.classList.toggle("show-checkboxes",!!e.checkBox),t.container.classList.toggle("hidden-input",!e.inputBox&&!e.description),this.updateLayout()}setEnabled(e){if(e!==this.enabled){this.enabled=e;for(const t of this.getUI().leftActionBar.viewItems)t.action.enabled=e;for(const t of this.getUI().rightActionBar.viewItems)t.action.enabled=e;this.getUI().checkAll.disabled=!e,this.getUI().inputBox.enabled=e,this.getUI().ok.enabled=e,this.getUI().list.enabled=e}}hide(e){var t,i;const n=this.controller;if(!n)return;const o=(t=this.ui)===null||t===void 0?void 0:t.container,r=o&&!$ee(o);if(this.controller=null,this.onHideEmitter.fire(),o&&(o.style.display="none"),!r){let a=this.previousFocusElement;for(;a&&!a.offsetParent;)a=(i=a.parentElement)!==null&&i!==void 0?i:void 0;a!=null&&a.offsetParent?(a.focus(),this.previousFocusElement=void 0):this.options.returnFocus()}n.didHide(e)}layout(e,t){this.dimension=e,this.titleBarOffset=t,this.updateLayout()}updateLayout(){if(this.ui&&this.isVisible()){this.ui.container.style.top=`${this.titleBarOffset}px`;const e=this.ui.container.style,t=Math.min(this.dimension.width*.62,Qx.MAX_WIDTH);e.width=t+"px",e.marginLeft="-"+t/2+"px",this.ui.inputBox.layout(),this.ui.list.layout(this.dimension&&this.dimension.height*.4)}}applyStyles(e){this.styles=e,this.updateStyles()}updateStyles(){if(this.ui){const{quickInputTitleBackground:e,quickInputBackground:t,quickInputForeground:i,widgetBorder:n,widgetShadow:o}=this.styles.widget;this.ui.titleBar.style.backgroundColor=e??"",this.ui.container.style.backgroundColor=t??"",this.ui.container.style.color=i??"",this.ui.container.style.border=n?`1px solid ${n}`:"",this.ui.container.style.boxShadow=o?`0 0 8px 2px ${o}`:"",this.ui.list.style(this.styles.list);const r=[];this.styles.pickerGroup.pickerGroupBorder&&r.push(`.quick-input-list .quick-input-list-entry { border-top-color:  ${this.styles.pickerGroup.pickerGroupBorder}; }`),this.styles.pickerGroup.pickerGroupForeground&&r.push(`.quick-input-list .quick-input-list-separator { color:  ${this.styles.pickerGroup.pickerGroupForeground}; }`),this.styles.pickerGroup.pickerGroupForeground&&r.push(".quick-input-list .quick-input-list-separator-as-item { color: var(--vscode-descriptionForeground); }"),(this.styles.keybindingLabel.keybindingLabelBackground||this.styles.keybindingLabel.keybindingLabelBorder||this.styles.keybindingLabel.keybindingLabelBottomBorder||this.styles.keybindingLabel.keybindingLabelShadow||this.styles.keybindingLabel.keybindingLabelForeground)&&(r.push(".quick-input-list .monaco-keybinding > .monaco-keybinding-key {"),this.styles.keybindingLabel.keybindingLabelBackground&&r.push(`background-color: ${this.styles.keybindingLabel.keybindingLabelBackground};`),this.styles.keybindingLabel.keybindingLabelBorder&&r.push(`border-color: ${this.styles.keybindingLabel.keybindingLabelBorder};`),this.styles.keybindingLabel.keybindingLabelBottomBorder&&r.push(`border-bottom-color: ${this.styles.keybindingLabel.keybindingLabelBottomBorder};`),this.styles.keybindingLabel.keybindingLabelShadow&&r.push(`box-shadow: inset 0 -1px 0 ${this.styles.keybindingLabel.keybindingLabelShadow};`),this.styles.keybindingLabel.keybindingLabelForeground&&r.push(`color: ${this.styles.keybindingLabel.keybindingLabelForeground};`),r.push("}"));const a=r.join(`
`);a!==this.ui.styleSheet.textContent&&(this.ui.styleSheet.textContent=a)}}}Qx.MAX_WIDTH=600;var Ppe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},H1=function(s,e){return function(t,i){e(t,i,s)}};let M2=class extends gre{get controller(){return this._controller||(this._controller=this._register(this.createController())),this._controller}get hasController(){return!!this._controller}get quickAccess(){return this._quickAccess||(this._quickAccess=this._register(this.instantiationService.createInstance(I2))),this._quickAccess}constructor(e,t,i,n){super(i),this.instantiationService=e,this.contextKeyService=t,this.layoutService=n,this._onShow=this._register(new W),this._onHide=this._register(new W),this.contexts=new Map}createController(e=this.layoutService,t){const i={idPrefix:"quickInput_",container:e.activeContainer,ignoreFocusOut:()=>!1,backKeybindingLabel:()=>{},setContextKey:o=>this.setContextKey(o),linkOpenerDelegate:o=>{this.instantiationService.invokeFunction(r=>{r.get(No).open(o,{allowCommands:!0,fromUserGesture:!0})})},returnFocus:()=>e.focus(),createList:(o,r,a,l,d)=>this.instantiationService.createInstance(x2,o,r,a,l,d),styles:this.computeStyles()},n=this._register(new Qx({...i,...t},this.themeService,this.layoutService));return n.layout(e.activeContainerDimension,e.activeContainerOffset.quickPickTop),this._register(e.onDidLayoutActiveContainer(o=>n.layout(o,e.activeContainerOffset.quickPickTop))),this._register(e.onDidChangeActiveContainer(()=>{n.isVisible()||n.layout(e.activeContainerDimension,e.activeContainerOffset.quickPickTop)})),this._register(n.onShow(()=>{this.resetContextKeys(),this._onShow.fire()})),this._register(n.onHide(()=>{this.resetContextKeys(),this._onHide.fire()})),n}setContextKey(e){let t;e&&(t=this.contexts.get(e),t||(t=new me(e,!1).bindTo(this.contextKeyService),this.contexts.set(e,t))),!(t&&t.get())&&(this.resetContextKeys(),t==null||t.set(!0))}resetContextKeys(){this.contexts.forEach(e=>{e.get()&&e.reset()})}pick(e,t={},i=ct.None){return this.controller.pick(e,t,i)}createQuickPick(){return this.controller.createQuickPick()}createInputBox(){return this.controller.createInputBox()}updateStyles(){this.hasController&&this.controller.applyStyles(this.computeStyles())}computeStyles(){return{widget:{quickInputBackground:_e(w3),quickInputForeground:_e(bse),quickInputTitleBackground:_e(Cse),widgetBorder:_e(vP),widgetShadow:_e(Il)},inputBox:Dy,toggle:xy,countBadge:Xz,button:Vge,progressBar:Hge,keybindingLabel:Wge,list:c_({listBackground:w3,listFocusBackground:tg,listFocusForeground:eg,listInactiveFocusForeground:eg,listInactiveSelectionIconForeground:dp,listInactiveFocusBackground:tg,listFocusOutline:ai,listInactiveFocusOutline:ai}),pickerGroup:{pickerGroupBorder:_e(wse),pickerGroupForeground:_e(lH)}}}};M2=Ppe([H1(0,We),H1(1,je),H1(2,Cn),H1(3,d_)],M2);var LU=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},wp=function(s,e){return function(t,i){e(t,i,s)}};let R2=class extends M2{constructor(e,t,i,n,o){super(t,i,n,new zT(e.getContainerDomNode(),o)),this.host=void 0;const r=Nm.get(e);if(r){const a=r.widget;this.host={_serviceBrand:void 0,get mainContainer(){return a.getDomNode()},getContainer(){return a.getDomNode()},get containers(){return[a.getDomNode()]},get activeContainer(){return a.getDomNode()},get mainContainerDimension(){return e.getLayoutInfo()},get activeContainerDimension(){return e.getLayoutInfo()},get onDidLayoutMainContainer(){return e.onDidLayoutChange},get onDidLayoutActiveContainer(){return e.onDidLayoutChange},get onDidLayoutContainer(){return ge.map(e.onDidLayoutChange,l=>({container:a.getDomNode(),dimension:l}))},get onDidChangeActiveContainer(){return ge.None},get onDidAddContainer(){return ge.None},get mainContainerOffset(){return{top:0,quickPickTop:0}},get activeContainerOffset(){return{top:0,quickPickTop:0}},focus:()=>e.focus()}}else this.host=void 0}createController(){return super.createController(this.host)}};R2=LU([wp(1,We),wp(2,je),wp(3,Cn),wp(4,It)],R2);let A2=class{get activeService(){const e=this.codeEditorService.getFocusedCodeEditor();if(!e)throw new Error("Quick input service needs a focused editor to work.");let t=this.mapEditorToService.get(e);if(!t){const i=t=this.instantiationService.createInstance(R2,e);this.mapEditorToService.set(e,t),Du(e.onDidDispose)(()=>{i.dispose(),this.mapEditorToService.delete(e)})}return t}get quickAccess(){return this.activeService.quickAccess}constructor(e,t){this.instantiationService=e,this.codeEditorService=t,this.mapEditorToService=new Map}pick(e,t={},i=ct.None){return this.activeService.pick(e,t,i)}createQuickPick(){return this.activeService.createQuickPick()}createInputBox(){return this.activeService.createInputBox()}};A2=LU([wp(0,We),wp(1,It)],A2);class Nm{static get(e){return e.getContribution(Nm.ID)}constructor(e){this.editor=e,this.widget=new Jx(this.editor)}dispose(){this.widget.dispose()}}Nm.ID="editor.controller.quickInput";class Jx{constructor(e){this.codeEditor=e,this.domNode=document.createElement("div"),this.codeEditor.addOverlayWidget(this)}getId(){return Jx.ID}getDomNode(){return this.domNode}getPosition(){return{preference:2}}dispose(){this.codeEditor.removeOverlayWidget(this)}}Jx.ID="editor.contrib.quickInputWidget";Lt(Nm.ID,Nm,4);class Ope{constructor(e,t,i,n,o){this._parsedThemeRuleBrand=void 0,this.token=e,this.index=t,this.fontStyle=i,this.foreground=n,this.background=o}}function Fpe(s){if(!s||!Array.isArray(s))return[];const e=[];let t=0;for(let i=0,n=s.length;i<n;i++){const o=s[i];let r=-1;if(typeof o.fontStyle=="string"){r=0;const d=o.fontStyle.split(" ");for(let c=0,u=d.length;c<u;c++)switch(d[c]){case"italic":r=r|1;break;case"bold":r=r|2;break;case"underline":r=r|4;break;case"strikethrough":r=r|8;break}}let a=null;typeof o.foreground=="string"&&(a=o.foreground);let l=null;typeof o.background=="string"&&(l=o.background),e[t++]=new Ope(o.token||"",i,r,a,l)}return e}function Bpe(s,e){s.sort((c,u)=>{const h=Upe(c.token,u.token);return h!==0?h:c.index-u.index});let t=0,i="000000",n="ffffff";for(;s.length>=1&&s[0].token==="";){const c=s.shift();c.fontStyle!==-1&&(t=c.fontStyle),c.foreground!==null&&(i=c.foreground),c.background!==null&&(n=c.background)}const o=new Vpe;for(const c of e)o.getId(c);const r=o.getId(i),a=o.getId(n),l=new AO(t,r,a),d=new PO(l);for(let c=0,u=s.length;c<u;c++){const h=s[c];d.insert(h.token,h.fontStyle,o.getId(h.foreground),o.getId(h.background))}return new xU(o,d)}const Wpe=/^#?([0-9A-Fa-f]{6})([0-9A-Fa-f]{2})?$/;class Vpe{constructor(){this._lastColorId=0,this._id2color=[],this._color2id=new Map}getId(e){if(e===null)return 0;const t=e.match(Wpe);if(!t)throw new Error("Illegal value for token color: "+e);e=t[1].toUpperCase();let i=this._color2id.get(e);return i||(i=++this._lastColorId,this._color2id.set(e,i),this._id2color[i]=G.fromHex("#"+e),i)}getColorMap(){return this._id2color.slice(0)}}class xU{static createFromRawTokenTheme(e,t){return this.createFromParsedTokenTheme(Fpe(e),t)}static createFromParsedTokenTheme(e,t){return Bpe(e,t)}constructor(e,t){this._colorMap=e,this._root=t,this._cache=new Map}getColorMap(){return this._colorMap.getColorMap()}_match(e){return this._root.match(e)}match(e,t){let i=this._cache.get(t);if(typeof i>"u"){const n=this._match(t),o=zpe(t);i=(n.metadata|o<<8)>>>0,this._cache.set(t,i)}return(i|e<<0)>>>0}}const Hpe=/\b(comment|string|regex|regexp)\b/;function zpe(s){const e=s.match(Hpe);if(!e)return 0;switch(e[1]){case"comment":return 1;case"string":return 2;case"regex":return 3;case"regexp":return 3}throw new Error("Unexpected match for standard token type!")}function Upe(s,e){return s<e?-1:s>e?1:0}class AO{constructor(e,t,i){this._themeTrieElementRuleBrand=void 0,this._fontStyle=e,this._foreground=t,this._background=i,this.metadata=(this._fontStyle<<11|this._foreground<<15|this._background<<24)>>>0}clone(){return new AO(this._fontStyle,this._foreground,this._background)}acceptOverwrite(e,t,i){e!==-1&&(this._fontStyle=e),t!==0&&(this._foreground=t),i!==0&&(this._background=i),this.metadata=(this._fontStyle<<11|this._foreground<<15|this._background<<24)>>>0}}class PO{constructor(e){this._themeTrieElementBrand=void 0,this._mainRule=e,this._children=new Map}match(e){if(e==="")return this._mainRule;const t=e.indexOf(".");let i,n;t===-1?(i=e,n=""):(i=e.substring(0,t),n=e.substring(t+1));const o=this._children.get(i);return typeof o<"u"?o.match(n):this._mainRule}insert(e,t,i,n){if(e===""){this._mainRule.acceptOverwrite(t,i,n);return}const o=e.indexOf(".");let r,a;o===-1?(r=e,a=""):(r=e.substring(0,o),a=e.substring(o+1));let l=this._children.get(r);typeof l>"u"&&(l=new PO(this._mainRule.clone()),this._children.set(r,l)),l.insert(a,t,i,n)}}function $pe(s){const e=[];for(let t=1,i=s.length;t<i;t++){const n=s[t];e[t]=`.mtk${t} { color: ${n}; }`}return e.push(".mtki { font-style: italic; }"),e.push(".mtkb { font-weight: bold; }"),e.push(".mtku { text-decoration: underline; text-underline-position: under; }"),e.push(".mtks { text-decoration: line-through; }"),e.push(".mtks.mtku { text-decoration: underline line-through; text-underline-position: under; }"),e.join(`
`)}const jpe={base:"vs",inherit:!1,rules:[{token:"",foreground:"000000",background:"fffffe"},{token:"invalid",foreground:"cd3131"},{token:"emphasis",fontStyle:"italic"},{token:"strong",fontStyle:"bold"},{token:"variable",foreground:"001188"},{token:"variable.predefined",foreground:"4864AA"},{token:"constant",foreground:"dd0000"},{token:"comment",foreground:"008000"},{token:"number",foreground:"098658"},{token:"number.hex",foreground:"3030c0"},{token:"regexp",foreground:"800000"},{token:"annotation",foreground:"808080"},{token:"type",foreground:"008080"},{token:"delimiter",foreground:"000000"},{token:"delimiter.html",foreground:"383838"},{token:"delimiter.xml",foreground:"0000FF"},{token:"tag",foreground:"800000"},{token:"tag.id.pug",foreground:"4F76AC"},{token:"tag.class.pug",foreground:"4F76AC"},{token:"meta.scss",foreground:"800000"},{token:"metatag",foreground:"e00000"},{token:"metatag.content.html",foreground:"FF0000"},{token:"metatag.html",foreground:"808080"},{token:"metatag.xml",foreground:"808080"},{token:"metatag.php",fontStyle:"bold"},{token:"key",foreground:"863B00"},{token:"string.key.json",foreground:"A31515"},{token:"string.value.json",foreground:"0451A5"},{token:"attribute.name",foreground:"FF0000"},{token:"attribute.value",foreground:"0451A5"},{token:"attribute.value.number",foreground:"098658"},{token:"attribute.value.unit",foreground:"098658"},{token:"attribute.value.html",foreground:"0000FF"},{token:"attribute.value.xml",foreground:"0000FF"},{token:"string",foreground:"A31515"},{token:"string.html",foreground:"0000FF"},{token:"string.sql",foreground:"FF0000"},{token:"string.yaml",foreground:"0451A5"},{token:"keyword",foreground:"0000FF"},{token:"keyword.json",foreground:"0451A5"},{token:"keyword.flow",foreground:"AF00DB"},{token:"keyword.flow.scss",foreground:"0000FF"},{token:"operator.scss",foreground:"666666"},{token:"operator.sql",foreground:"778899"},{token:"operator.swift",foreground:"666666"},{token:"predefined.sql",foreground:"C700C7"}],colors:{[bn]:"#FFFFFE",[$r]:"#000000",[dH]:"#E5EBF1",[gC]:"#D3D3D3",[fC]:"#939393",[wP]:"#ADD6FF4D"}},Kpe={base:"vs-dark",inherit:!1,rules:[{token:"",foreground:"D4D4D4",background:"1E1E1E"},{token:"invalid",foreground:"f44747"},{token:"emphasis",fontStyle:"italic"},{token:"strong",fontStyle:"bold"},{token:"variable",foreground:"74B0DF"},{token:"variable.predefined",foreground:"4864AA"},{token:"variable.parameter",foreground:"9CDCFE"},{token:"constant",foreground:"569CD6"},{token:"comment",foreground:"608B4E"},{token:"number",foreground:"B5CEA8"},{token:"number.hex",foreground:"5BB498"},{token:"regexp",foreground:"B46695"},{token:"annotation",foreground:"cc6666"},{token:"type",foreground:"3DC9B0"},{token:"delimiter",foreground:"DCDCDC"},{token:"delimiter.html",foreground:"808080"},{token:"delimiter.xml",foreground:"808080"},{token:"tag",foreground:"569CD6"},{token:"tag.id.pug",foreground:"4F76AC"},{token:"tag.class.pug",foreground:"4F76AC"},{token:"meta.scss",foreground:"A79873"},{token:"meta.tag",foreground:"CE9178"},{token:"metatag",foreground:"DD6A6F"},{token:"metatag.content.html",foreground:"9CDCFE"},{token:"metatag.html",foreground:"569CD6"},{token:"metatag.xml",foreground:"569CD6"},{token:"metatag.php",fontStyle:"bold"},{token:"key",foreground:"9CDCFE"},{token:"string.key.json",foreground:"9CDCFE"},{token:"string.value.json",foreground:"CE9178"},{token:"attribute.name",foreground:"9CDCFE"},{token:"attribute.value",foreground:"CE9178"},{token:"attribute.value.number.css",foreground:"B5CEA8"},{token:"attribute.value.unit.css",foreground:"B5CEA8"},{token:"attribute.value.hex.css",foreground:"D4D4D4"},{token:"string",foreground:"CE9178"},{token:"string.sql",foreground:"FF0000"},{token:"keyword",foreground:"569CD6"},{token:"keyword.flow",foreground:"C586C0"},{token:"keyword.json",foreground:"CE9178"},{token:"keyword.flow.scss",foreground:"569CD6"},{token:"operator.scss",foreground:"909090"},{token:"operator.sql",foreground:"778899"},{token:"operator.swift",foreground:"909090"},{token:"predefined.sql",foreground:"FF00FF"}],colors:{[bn]:"#1E1E1E",[$r]:"#D4D4D4",[dH]:"#3A3D41",[gC]:"#404040",[fC]:"#707070",[wP]:"#ADD6FF26"}},qpe={base:"hc-black",inherit:!1,rules:[{token:"",foreground:"FFFFFF",background:"000000"},{token:"invalid",foreground:"f44747"},{token:"emphasis",fontStyle:"italic"},{token:"strong",fontStyle:"bold"},{token:"variable",foreground:"1AEBFF"},{token:"variable.parameter",foreground:"9CDCFE"},{token:"constant",foreground:"569CD6"},{token:"comment",foreground:"608B4E"},{token:"number",foreground:"FFFFFF"},{token:"regexp",foreground:"C0C0C0"},{token:"annotation",foreground:"569CD6"},{token:"type",foreground:"3DC9B0"},{token:"delimiter",foreground:"FFFF00"},{token:"delimiter.html",foreground:"FFFF00"},{token:"tag",foreground:"569CD6"},{token:"tag.id.pug",foreground:"4F76AC"},{token:"tag.class.pug",foreground:"4F76AC"},{token:"meta",foreground:"D4D4D4"},{token:"meta.tag",foreground:"CE9178"},{token:"metatag",foreground:"569CD6"},{token:"metatag.content.html",foreground:"1AEBFF"},{token:"metatag.html",foreground:"569CD6"},{token:"metatag.xml",foreground:"569CD6"},{token:"metatag.php",fontStyle:"bold"},{token:"key",foreground:"9CDCFE"},{token:"string.key",foreground:"9CDCFE"},{token:"string.value",foreground:"CE9178"},{token:"attribute.name",foreground:"569CD6"},{token:"attribute.value",foreground:"3FF23F"},{token:"string",foreground:"CE9178"},{token:"string.sql",foreground:"FF0000"},{token:"keyword",foreground:"569CD6"},{token:"keyword.flow",foreground:"C586C0"},{token:"operator.sql",foreground:"778899"},{token:"operator.swift",foreground:"909090"},{token:"predefined.sql",foreground:"FF00FF"}],colors:{[bn]:"#000000",[$r]:"#FFFFFF",[gC]:"#FFFFFF",[fC]:"#FFFFFF"}},Gpe={base:"hc-light",inherit:!1,rules:[{token:"",foreground:"292929",background:"FFFFFF"},{token:"invalid",foreground:"B5200D"},{token:"emphasis",fontStyle:"italic"},{token:"strong",fontStyle:"bold"},{token:"variable",foreground:"264F70"},{token:"variable.predefined",foreground:"4864AA"},{token:"constant",foreground:"dd0000"},{token:"comment",foreground:"008000"},{token:"number",foreground:"098658"},{token:"number.hex",foreground:"3030c0"},{token:"regexp",foreground:"800000"},{token:"annotation",foreground:"808080"},{token:"type",foreground:"008080"},{token:"delimiter",foreground:"000000"},{token:"delimiter.html",foreground:"383838"},{token:"tag",foreground:"800000"},{token:"tag.id.pug",foreground:"4F76AC"},{token:"tag.class.pug",foreground:"4F76AC"},{token:"meta.scss",foreground:"800000"},{token:"metatag",foreground:"e00000"},{token:"metatag.content.html",foreground:"B5200D"},{token:"metatag.html",foreground:"808080"},{token:"metatag.xml",foreground:"808080"},{token:"metatag.php",fontStyle:"bold"},{token:"key",foreground:"863B00"},{token:"string.key.json",foreground:"A31515"},{token:"string.value.json",foreground:"0451A5"},{token:"attribute.name",foreground:"264F78"},{token:"attribute.value",foreground:"0451A5"},{token:"string",foreground:"A31515"},{token:"string.sql",foreground:"B5200D"},{token:"keyword",foreground:"0000FF"},{token:"keyword.flow",foreground:"AF00DB"},{token:"operator.sql",foreground:"778899"},{token:"operator.swift",foreground:"666666"},{token:"predefined.sql",foreground:"C700C7"}],colors:{[bn]:"#FFFFFF",[$r]:"#292929",[gC]:"#292929",[fC]:"#292929"}},Zpe={IconContribution:"base.contributions.icons"};var R9;(function(s){function e(t,i){let n=t.defaults;for(;Oe.isThemeIcon(n);){const o=mf.getIcon(n.id);if(!o)return;n=o.defaults}return n}s.getDefinition=e})(R9||(R9={}));var A9;(function(s){function e(i){return{weight:i.weight,style:i.style,src:i.src.map(n=>({format:n.format,location:n.location.toString()}))}}s.toJSONObject=e;function t(i){const n=o=>Ps(o)?o:void 0;if(i&&Array.isArray(i.src)&&i.src.every(o=>Ps(o.format)&&Ps(o.location)))return{weight:n(i.weight),style:n(i.style),src:i.src.map(o=>({format:o.format,location:Pe.parse(o.location)}))}}s.fromJSONObject=t})(A9||(A9={}));class Ype{constructor(){this._onDidChange=new W,this.onDidChange=this._onDidChange.event,this.iconSchema={definitions:{icons:{type:"object",properties:{fontId:{type:"string",description:p("iconDefinition.fontId","The id of the font to use. If not set, the font that is defined first is used.")},fontCharacter:{type:"string",description:p("iconDefinition.fontCharacter","The font character associated with the icon definition.")}},additionalProperties:!1,defaultSnippets:[{body:{fontCharacter:"\\\\e030"}}]}},type:"object",properties:{}},this.iconReferenceSchema={type:"string",pattern:`^${Oe.iconNameExpression}$`,enum:[],enumDescriptions:[]},this.iconsById={},this.iconFontsById={}}registerIcon(e,t,i,n){const o=this.iconsById[e];if(o){if(i&&!o.description){o.description=i,this.iconSchema.properties[e].markdownDescription=`${i} $(${e})`;const l=this.iconReferenceSchema.enum.indexOf(e);l!==-1&&(this.iconReferenceSchema.enumDescriptions[l]=i),this._onDidChange.fire()}return o}const r={id:e,description:i,defaults:t,deprecationMessage:n};this.iconsById[e]=r;const a={$ref:"#/definitions/icons"};return n&&(a.deprecationMessage=n),i&&(a.markdownDescription=`${i}: $(${e})`),this.iconSchema.properties[e]=a,this.iconReferenceSchema.enum.push(e),this.iconReferenceSchema.enumDescriptions.push(i||""),this._onDidChange.fire(),{id:e}}getIcons(){return Object.keys(this.iconsById).map(e=>this.iconsById[e])}getIcon(e){return this.iconsById[e]}getIconSchema(){return this.iconSchema}toString(){const e=(o,r)=>o.id.localeCompare(r.id),t=o=>{for(;Oe.isThemeIcon(o.defaults);)o=this.iconsById[o.defaults.id];return`codicon codicon-${o?o.id:""}`},i=[];i.push("| preview     | identifier                        | default codicon ID                | description"),i.push("| ----------- | --------------------------------- | --------------------------------- | --------------------------------- |");const n=Object.keys(this.iconsById).map(o=>this.iconsById[o]);for(const o of n.filter(r=>!!r.description).sort(e))i.push(`|<i class="${t(o)}"></i>|${o.id}|${Oe.isThemeIcon(o.defaults)?o.defaults.id:o.id}|${o.description||""}|`);i.push("| preview     | identifier                        "),i.push("| ----------- | --------------------------------- |");for(const o of n.filter(r=>!Oe.isThemeIcon(r.defaults)).sort(e))i.push(`|<i class="${t(o)}"></i>|${o.id}|`);return i.join(`
`)}}const mf=new Ype;Si.add(Zpe.IconContribution,mf);function Ui(s,e,t,i){return mf.registerIcon(s,e,t,i)}function DU(){return mf}function Xpe(){const s=FW();for(const e in s){const t="\\"+s[e].toString(16);mf.registerIcon(e,{fontCharacter:t})}}Xpe();const kU="vscode://schemas/icons",IU=Si.as(mx.JSONContribution);IU.registerSchema(kU,mf.getIconSchema());const P9=new jt(()=>IU.notifySchemaChanged(kU),200);mf.onDidChange(()=>{P9.isScheduled()||P9.schedule()});const EU=Ui("widget-close",le.close,p("widgetClose","Icon for the close action in widgets."));Ui("goto-previous-location",le.arrowUp,p("previousChangeIcon","Icon for goto previous editor location."));Ui("goto-next-location",le.arrowDown,p("nextChangeIcon","Icon for goto next editor location."));Oe.modify(le.sync,"spin");Oe.modify(le.loading,"spin");function Qpe(s){const e=new ie,t=e.add(new W),i=DU();return e.add(i.onDidChange(()=>t.fire())),s&&e.add(s.onDidProductIconThemeChange(()=>t.fire())),{dispose:()=>e.dispose(),onDidChange:t.event,getCSS(){const n=s?s.getProductIconTheme():new NU,o={},r=l=>{const d=n.getIcon(l);if(!d)return;const c=d.font;return c?(o[c.id]=c.definition,`.codicon-${l.id}:before { content: '${d.fontCharacter}'; font-family: ${k5(c.id)}; }`):`.codicon-${l.id}:before { content: '${d.fontCharacter}'; }`},a=[];for(const l of i.getIcons()){const d=r(l);d&&a.push(d)}for(const l in o){const d=o[l],c=d.weight?`font-weight: ${d.weight};`:"",u=d.style?`font-style: ${d.style};`:"",h=d.src.map(g=>`${Tu(g.location)} format('${g.format}')`).join(", ");a.push(`@font-face { src: ${h}; font-family: ${k5(l)};${c}${u} font-display: block; }`)}return a.join(`
`)}}}class NU{getIcon(e){const t=DU();let i=e.defaults;for(;Oe.isThemeIcon(i);){const n=t.getIcon(i.id);if(!n)return;i=n.defaults}return i}}const Rd="vs",Qp="vs-dark",bg="hc-black",Cg="hc-light",TU=Si.as(sH.ColorContribution),Jpe=Si.as(wH.ThemingContribution);class MU{constructor(e,t){this.semanticHighlighting=!1,this.themeData=t;const i=t.base;e.length>0?(Qw(e)?this.id=e:this.id=i+" "+e,this.themeName=e):(this.id=i,this.themeName=i),this.colors=null,this.defaultColors=Object.create(null),this._tokenTheme=null}get base(){return this.themeData.base}notifyBaseUpdated(){this.themeData.inherit&&(this.colors=null,this._tokenTheme=null)}getColors(){if(!this.colors){const e=new Map;for(const t in this.themeData.colors)e.set(t,G.fromHex(this.themeData.colors[t]));if(this.themeData.inherit){const t=P2(this.themeData.base);for(const i in t.colors)e.has(i)||e.set(i,G.fromHex(t.colors[i]))}this.colors=e}return this.colors}getColor(e,t){const i=this.getColors().get(e);if(i)return i;if(t!==!1)return this.getDefault(e)}getDefault(e){let t=this.defaultColors[e];return t||(t=TU.resolveDefaultColor(e,this),this.defaultColors[e]=t,t)}defines(e){return this.getColors().has(e)}get type(){switch(this.base){case Rd:return _r.LIGHT;case bg:return _r.HIGH_CONTRAST_DARK;case Cg:return _r.HIGH_CONTRAST_LIGHT;default:return _r.DARK}}get tokenTheme(){if(!this._tokenTheme){let e=[],t=[];if(this.themeData.inherit){const o=P2(this.themeData.base);e=o.rules,o.encodedTokensColors&&(t=o.encodedTokensColors)}const i=this.themeData.colors["editor.foreground"],n=this.themeData.colors["editor.background"];if(i||n){const o={token:""};i&&(o.foreground=i),n&&(o.background=n),e.push(o)}e=e.concat(this.themeData.rules),this.themeData.encodedTokensColors&&(t=this.themeData.encodedTokensColors),this._tokenTheme=xU.createFromRawTokenTheme(e,t)}return this._tokenTheme}getTokenStyleMetadata(e,t,i){const o=this.tokenTheme._match([e].concat(t).join(".")).metadata,r=Zn.getForeground(o),a=Zn.getFontStyle(o);return{foreground:r,italic:!!(a&1),bold:!!(a&2),underline:!!(a&4),strikethrough:!!(a&8)}}}function Qw(s){return s===Rd||s===Qp||s===bg||s===Cg}function P2(s){switch(s){case Rd:return jpe;case Qp:return Kpe;case bg:return qpe;case Cg:return Gpe}}function z1(s){const e=P2(s);return new MU(s,e)}class eme extends j{constructor(){super(),this._onColorThemeChange=this._register(new W),this.onDidColorThemeChange=this._onColorThemeChange.event,this._onProductIconThemeChange=this._register(new W),this.onDidProductIconThemeChange=this._onProductIconThemeChange.event,this._environment=Object.create(null),this._builtInProductIconTheme=new NU,this._autoDetectHighContrast=!0,this._knownThemes=new Map,this._knownThemes.set(Rd,z1(Rd)),this._knownThemes.set(Qp,z1(Qp)),this._knownThemes.set(bg,z1(bg)),this._knownThemes.set(Cg,z1(Cg));const e=this._register(Qpe(this));this._codiconCSS=e.getCSS(),this._themeCSS="",this._allCSS=`${this._codiconCSS}
${this._themeCSS}`,this._globalStyleElement=null,this._styleElements=[],this._colorMapOverride=null,this.setTheme(Rd),this._onOSSchemeChanged(),this._register(e.onDidChange(()=>{this._codiconCSS=e.getCSS(),this._updateCSS()})),GW("(forced-colors: active)",()=>{this._onOSSchemeChanged()})}registerEditorContainer(e){return FS(e)?this._registerShadowDomContainer(e):this._registerRegularEditorContainer()}_registerRegularEditorContainer(){return this._globalStyleElement||(this._globalStyleElement=Lr(void 0,e=>{e.className="monaco-colors",e.textContent=this._allCSS}),this._styleElements.push(this._globalStyleElement)),j.None}_registerShadowDomContainer(e){const t=Lr(e,i=>{i.className="monaco-colors",i.textContent=this._allCSS});return this._styleElements.push(t),{dispose:()=>{for(let i=0;i<this._styleElements.length;i++)if(this._styleElements[i]===t){this._styleElements.splice(i,1);return}}}}defineTheme(e,t){if(!/^[a-z0-9\-]+$/i.test(e))throw new Error("Illegal theme name!");if(!Qw(t.base)&&!Qw(e))throw new Error("Illegal theme base!");this._knownThemes.set(e,new MU(e,t)),Qw(e)&&this._knownThemes.forEach(i=>{i.base===e&&i.notifyBaseUpdated()}),this._theme.themeName===e&&this.setTheme(e)}getColorTheme(){return this._theme}setColorMapOverride(e){this._colorMapOverride=e,this._updateThemeOrColorMap()}setTheme(e){let t;this._knownThemes.has(e)?t=this._knownThemes.get(e):t=this._knownThemes.get(Rd),this._updateActualTheme(t)}_updateActualTheme(e){!e||this._theme===e||(this._theme=e,this._updateThemeOrColorMap())}_onOSSchemeChanged(){if(this._autoDetectHighContrast){const e=Ci.matchMedia("(forced-colors: active)").matches;if(e!==Oa(this._theme.type)){let t;bm(this._theme.type)?t=e?bg:Qp:t=e?Cg:Rd,this._updateActualTheme(this._knownThemes.get(t))}}}setAutoDetectHighContrast(e){this._autoDetectHighContrast=e,this._onOSSchemeChanged()}_updateThemeOrColorMap(){const e=[],t={},i={addRule:r=>{t[r]||(e.push(r),t[r]=!0)}};Jpe.getThemingParticipants().forEach(r=>r(this._theme,i,this._environment));const n=[];for(const r of TU.getColors()){const a=this._theme.getColor(r.id,!0);a&&n.push(`${_P(r.id)}: ${a.toString()};`)}i.addRule(`.monaco-editor, .monaco-diff-editor, .monaco-component { ${n.join(`
`)} }`);const o=this._colorMapOverride||this._theme.tokenTheme.getColorMap();i.addRule($pe(o)),this._themeCSS=e.join(`
`),this._updateCSS(),xi.setColorMap(o),this._onColorThemeChange.fire(this._theme)}_updateCSS(){this._allCSS=`${this._codiconCSS}
${this._themeCSS}`,this._styleElements.forEach(e=>e.textContent=this._allCSS)}getFileIconTheme(){return{hasFileIcons:!1,hasFolderIcons:!1,hidesExplorerArrows:!1}}getProductIconTheme(){return this._builtInProductIconTheme}}const lr=ut("themeService");var tme=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},XI=function(s,e){return function(t,i){e(t,i,s)}};let O2=class extends j{constructor(e,t,i){super(),this._contextKeyService=e,this._layoutService=t,this._configurationService=i,this._accessibilitySupport=0,this._onDidChangeScreenReaderOptimized=new W,this._onDidChangeReducedMotion=new W,this._accessibilityModeEnabledContext=dC.bindTo(this._contextKeyService);const n=()=>this._accessibilityModeEnabledContext.set(this.isScreenReaderOptimized());this._register(this._configurationService.onDidChangeConfiguration(r=>{r.affectsConfiguration("editor.accessibilitySupport")&&(n(),this._onDidChangeScreenReaderOptimized.fire()),r.affectsConfiguration("workbench.reduceMotion")&&(this._configMotionReduced=this._configurationService.getValue("workbench.reduceMotion"),this._onDidChangeReducedMotion.fire())})),n(),this._register(this.onDidChangeScreenReaderOptimized(()=>n()));const o=Ci.matchMedia("(prefers-reduced-motion: reduce)");this._systemMotionReduced=o.matches,this._configMotionReduced=this._configurationService.getValue("workbench.reduceMotion"),this.initReducedMotionListeners(o)}initReducedMotionListeners(e){this._register(Y(e,"change",()=>{this._systemMotionReduced=e.matches,this._configMotionReduced==="auto"&&this._onDidChangeReducedMotion.fire()}));const t=()=>{const i=this.isMotionReduced();this._layoutService.mainContainer.classList.toggle("reduce-motion",i),this._layoutService.mainContainer.classList.toggle("enable-motion",!i)};t(),this._register(this.onDidChangeReducedMotion(()=>t()))}get onDidChangeScreenReaderOptimized(){return this._onDidChangeScreenReaderOptimized.event}isScreenReaderOptimized(){const e=this._configurationService.getValue("editor.accessibilitySupport");return e==="on"||e==="auto"&&this._accessibilitySupport===2}get onDidChangeReducedMotion(){return this._onDidChangeReducedMotion.event}isMotionReduced(){const e=this._configMotionReduced;return e==="on"||e==="auto"&&this._systemMotionReduced}getAccessibilitySupport(){return this._accessibilitySupport}};O2=tme([XI(0,je),XI(1,d_),XI(2,mt)],O2);var eD=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Wg=function(s,e){return function(t,i){e(t,i,s)}},Zf,xc;let F2=class{constructor(e,t){this._commandService=e,this._hiddenStates=new zy(t)}createMenu(e,t,i){return new W2(e,this._hiddenStates,{emitEventsForSubmenuChanges:!1,eventDebounceDelay:50,...i},this._commandService,t)}resetHiddenStates(e){this._hiddenStates.reset(e)}};F2=eD([Wg(0,Ei),Wg(1,sa)],F2);let zy=Zf=class{constructor(e){this._storageService=e,this._disposables=new ie,this._onDidChange=new W,this.onDidChange=this._onDidChange.event,this._ignoreChangeEvent=!1,this._hiddenByDefaultCache=new Map;try{const t=e.get(Zf._key,0,"{}");this._data=JSON.parse(t)}catch{this._data=Object.create(null)}this._disposables.add(e.onDidChangeValue(0,Zf._key,this._disposables)(()=>{if(!this._ignoreChangeEvent)try{const t=e.get(Zf._key,0,"{}");this._data=JSON.parse(t)}catch(t){console.log("FAILED to read storage after UPDATE",t)}this._onDidChange.fire()}))}dispose(){this._onDidChange.dispose(),this._disposables.dispose()}_isHiddenByDefault(e,t){var i;return(i=this._hiddenByDefaultCache.get(`${e.id}/${t}`))!==null&&i!==void 0?i:!1}setDefaultState(e,t,i){this._hiddenByDefaultCache.set(`${e.id}/${t}`,i)}isHidden(e,t){var i,n;const o=this._isHiddenByDefault(e,t),r=(n=(i=this._data[e.id])===null||i===void 0?void 0:i.includes(t))!==null&&n!==void 0?n:!1;return o?!r:r}updateHidden(e,t,i){this._isHiddenByDefault(e,t)&&(i=!i);const o=this._data[e.id];if(i)o?o.indexOf(t)<0&&o.push(t):this._data[e.id]=[t];else if(o){const r=o.indexOf(t);r>=0&&QY(o,r),o.length===0&&delete this._data[e.id]}this._persist()}reset(e){if(e===void 0)this._data=Object.create(null),this._persist();else{for(const{id:t}of e)this._data[t]&&delete this._data[t];this._persist()}}_persist(){try{this._ignoreChangeEvent=!0;const e=JSON.stringify(this._data);this._storageService.store(Zf._key,e,0,0)}finally{this._ignoreChangeEvent=!1}}};zy._key="menu.hiddenCommands";zy=Zf=eD([Wg(0,sa)],zy);let B2=xc=class{constructor(e,t,i,n,o){this._id=e,this._hiddenStates=t,this._collectContextKeysForSubmenus=i,this._commandService=n,this._contextKeyService=o,this._menuGroups=[],this._structureContextKeys=new Set,this._preconditionContextKeys=new Set,this._toggledContextKeys=new Set,this.refresh()}get structureContextKeys(){return this._structureContextKeys}get preconditionContextKeys(){return this._preconditionContextKeys}get toggledContextKeys(){return this._toggledContextKeys}refresh(){this._menuGroups.length=0,this._structureContextKeys.clear(),this._preconditionContextKeys.clear(),this._toggledContextKeys.clear();const e=Wn.getMenuItems(this._id);let t;e.sort(xc._compareMenuItems);for(const i of e){const n=i.group||"";(!t||t[0]!==n)&&(t=[n,[]],this._menuGroups.push(t)),t[1].push(i),this._collectContextKeys(i)}}_collectContextKeys(e){if(xc._fillInKbExprKeys(e.when,this._structureContextKeys),sp(e)){if(e.command.precondition&&xc._fillInKbExprKeys(e.command.precondition,this._preconditionContextKeys),e.command.toggled){const t=e.command.toggled.condition||e.command.toggled;xc._fillInKbExprKeys(t,this._toggledContextKeys)}}else this._collectContextKeysForSubmenus&&Wn.getMenuItems(e.submenu).forEach(this._collectContextKeys,this)}createActionGroups(e){const t=[];for(const i of this._menuGroups){const[n,o]=i,r=[];for(const a of o)if(this._contextKeyService.contextMatchesRules(a.when)){const l=sp(a);l&&this._hiddenStates.setDefaultState(this._id,a.command.id,!!a.isHiddenByDefault);const d=ime(this._id,l?a.command:a,this._hiddenStates);if(l)r.push(new Xr(a.command,a.alt,e,d,this._contextKeyService,this._commandService));else{const c=new xc(a.submenu,this._hiddenStates,this._collectContextKeysForSubmenus,this._commandService,this._contextKeyService).createActionGroups(e),u=In.join(...c.map(h=>h[1]));u.length>0&&r.push(new E0(a,d,u))}}r.length>0&&t.push([n,r])}return t}static _fillInKbExprKeys(e,t){if(e)for(const i of e.keys())t.add(i)}static _compareMenuItems(e,t){const i=e.group,n=t.group;if(i!==n){if(i){if(!n)return-1}else return 1;if(i==="navigation")return-1;if(n==="navigation")return 1;const a=i.localeCompare(n);if(a!==0)return a}const o=e.order||0,r=t.order||0;return o<r?-1:o>r?1:xc._compareTitles(sp(e)?e.command.title:e.title,sp(t)?t.command.title:t.title)}static _compareTitles(e,t){const i=typeof e=="string"?e:e.original,n=typeof t=="string"?t:t.original;return i.localeCompare(n)}};B2=xc=eD([Wg(3,Ei),Wg(4,je)],B2);let W2=class{constructor(e,t,i,n,o){this._disposables=new ie,this._menuInfo=new B2(e,t,i.emitEventsForSubmenuChanges,n,o);const r=new jt(()=>{this._menuInfo.refresh(),this._onDidChange.fire({menu:this,isStructuralChange:!0,isEnablementChange:!0,isToggleChange:!0})},i.eventDebounceDelay);this._disposables.add(r),this._disposables.add(Wn.onDidChangeMenu(c=>{c.has(e)&&r.schedule()}));const a=this._disposables.add(new ie),l=c=>{let u=!1,h=!1,g=!1;for(const f of c)if(u=u||f.isStructuralChange,h=h||f.isEnablementChange,g=g||f.isToggleChange,u&&h&&g)break;return{menu:this,isStructuralChange:u,isEnablementChange:h,isToggleChange:g}},d=()=>{a.add(o.onDidChangeContext(c=>{const u=c.affectsSome(this._menuInfo.structureContextKeys),h=c.affectsSome(this._menuInfo.preconditionContextKeys),g=c.affectsSome(this._menuInfo.toggledContextKeys);(u||h||g)&&this._onDidChange.fire({menu:this,isStructuralChange:u,isEnablementChange:h,isToggleChange:g})})),a.add(t.onDidChange(c=>{this._onDidChange.fire({menu:this,isStructuralChange:!0,isEnablementChange:!1,isToggleChange:!1})}))};this._onDidChange=new kW({onWillAddFirstListener:d,onDidRemoveLastListener:a.clear.bind(a),delay:i.eventDebounceDelay,merge:l}),this.onDidChange=this._onDidChange.event}getActions(e){return this._menuInfo.createActionGroups(e)}dispose(){this._disposables.dispose(),this._onDidChange.dispose()}};W2=eD([Wg(3,Ei),Wg(4,je)],W2);function ime(s,e,t){const i=$J(e)?e.submenu.id:e.id,n=typeof e.title=="string"?e.title:e.title.value,o=Rp({id:`hide/${s.id}/${i}`,label:p("hide.label","Hide '{0}'",n),run(){t.updateHidden(s,i,!0)}}),r=Rp({id:`toggle/${s.id}/${i}`,label:n,get checked(){return!t.isHidden(s,i)},run(){t.updateHidden(s,i,!!this.checked)}});return{hide:o,toggle:r,get isHidden(){return!r.checked}}}var nme=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},O9=function(s,e){return function(t,i){e(t,i,s)}};let V2=class extends j{constructor(e,t){super(),this.layoutService=e,this.logService=t,this.mapTextToType=new Map,this.findText="",this.resources=[],(Jd||ZW)&&this.installWebKitWriteTextWorkaround()}installWebKitWriteTextWorkaround(){const e=()=>{const t=new ox;this.webKitPendingClipboardWritePromise&&!this.webKitPendingClipboardWritePromise.isSettled&&this.webKitPendingClipboardWritePromise.cancel(),this.webKitPendingClipboardWritePromise=t,navigator.clipboard.write([new ClipboardItem({"text/plain":t.p})]).catch(async i=>{(!(i instanceof Error)||i.name!=="NotAllowedError"||!t.isRejected)&&this.logService.error(i)})};this._register(ge.runAndSubscribe(this.layoutService.onDidAddContainer,({container:t,disposables:i})=>{i.add(Y(t,"click",e)),i.add(Y(t,"keydown",e))},{container:this.layoutService.mainContainer,disposables:this._store}))}async writeText(e,t){if(t){this.mapTextToType.set(t,e);return}if(this.webKitPendingClipboardWritePromise)return this.webKitPendingClipboardWritePromise.complete(e);try{return await navigator.clipboard.writeText(e)}catch(r){console.error(r)}const i=i_(),n=i.activeElement,o=i.body.appendChild(se("textarea",{"aria-hidden":!0}));o.style.height="1px",o.style.width="1px",o.style.position="absolute",o.value=e,o.focus(),o.select(),i.execCommand("copy"),n instanceof HTMLElement&&n.focus(),i.body.removeChild(o)}async readText(e){if(e)return this.mapTextToType.get(e)||"";try{return await navigator.clipboard.readText()}catch(t){return console.error(t),""}}async readFindText(){return this.findText}async writeFindText(e){this.findText=e}async writeResources(e){this.resources=e}async readResources(){return this.resources}};V2=nme([O9(0,d_),O9(1,ko)],V2);const dc=ut("clipboardService");var sme=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},ome=function(s,e){return function(t,i){e(t,i,s)}};const Qv="data-keybinding-context";let OO=class{constructor(e,t){this._id=e,this._parent=t,this._value=Object.create(null),this._value._contextId=e}get value(){return{...this._value}}setValue(e,t){return this._value[e]!==t?(this._value[e]=t,!0):!1}removeValue(e){return e in this._value?(delete this._value[e],!0):!1}getValue(e){const t=this._value[e];return typeof t>"u"&&this._parent?this._parent.getValue(e):t}};class Tm extends OO{constructor(){super(-1,null)}setValue(e,t){return!1}removeValue(e){return!1}getValue(e){}}Tm.INSTANCE=new Tm;class _b extends OO{constructor(e,t,i){super(e,null),this._configurationService=t,this._values=Gp.forConfigKeys(),this._listener=this._configurationService.onDidChangeConfiguration(n=>{if(n.source===7){const o=Array.from(this._values,([r])=>r);this._values.clear(),i.fire(new B9(o))}else{const o=[];for(const r of n.affectedKeys){const a=`config.${r}`,l=this._values.findSuperstr(a);l!==void 0&&(o.push(...ht.map(l,([d])=>d)),this._values.deleteSuperstr(a)),this._values.has(a)&&(o.push(a),this._values.delete(a))}i.fire(new B9(o))}})}dispose(){this._listener.dispose()}getValue(e){if(e.indexOf(_b._keyPrefix)!==0)return super.getValue(e);if(this._values.has(e))return this._values.get(e);const t=e.substr(_b._keyPrefix.length),i=this._configurationService.getValue(t);let n;switch(typeof i){case"number":case"boolean":case"string":n=i;break;default:Array.isArray(i)?n=JSON.stringify(i):n=i}return this._values.set(e,n),n}setValue(e,t){return super.setValue(e,t)}removeValue(e){return super.removeValue(e)}}_b._keyPrefix="config.";class rme{constructor(e,t,i){this._service=e,this._key=t,this._defaultValue=i,this.reset()}set(e){this._service.setContext(this._key,e)}reset(){typeof this._defaultValue>"u"?this._service.removeContext(this._key):this._service.setContext(this._key,this._defaultValue)}get(){return this._service.getContextKeyValue(this._key)}}class F9{constructor(e){this.key=e}affectsSome(e){return e.has(this.key)}allKeysContainedIn(e){return this.affectsSome(e)}}class B9{constructor(e){this.keys=e}affectsSome(e){for(const t of this.keys)if(e.has(t))return!0;return!1}allKeysContainedIn(e){return this.keys.every(t=>e.has(t))}}class ame{constructor(e){this.events=e}affectsSome(e){for(const t of this.events)if(t.affectsSome(e))return!0;return!1}allKeysContainedIn(e){return this.events.every(t=>t.allKeysContainedIn(e))}}function lme(s,e){return s.allKeysContainedIn(new Set(Object.keys(e)))}class RU extends j{constructor(e){super(),this._onDidChangeContext=this._register(new Lg({merge:t=>new ame(t)})),this.onDidChangeContext=this._onDidChangeContext.event,this._isDisposed=!1,this._myContextId=e}createKey(e,t){if(this._isDisposed)throw new Error("AbstractContextKeyService has been disposed");return new rme(this,e,t)}bufferChangeEvents(e){this._onDidChangeContext.pause();try{e()}finally{this._onDidChangeContext.resume()}}createScoped(e){if(this._isDisposed)throw new Error("AbstractContextKeyService has been disposed");return new dme(this,e)}contextMatchesRules(e){if(this._isDisposed)throw new Error("AbstractContextKeyService has been disposed");const t=this.getContextValuesContainer(this._myContextId);return e?e.evaluate(t):!0}getContextKeyValue(e){if(!this._isDisposed)return this.getContextValuesContainer(this._myContextId).getValue(e)}setContext(e,t){if(this._isDisposed)return;const i=this.getContextValuesContainer(this._myContextId);i&&i.setValue(e,t)&&this._onDidChangeContext.fire(new F9(e))}removeContext(e){this._isDisposed||this.getContextValuesContainer(this._myContextId).removeValue(e)&&this._onDidChangeContext.fire(new F9(e))}getContext(e){return this._isDisposed?Tm.INSTANCE:this.getContextValuesContainer(cme(e))}dispose(){super.dispose(),this._isDisposed=!0}}let H2=class extends RU{constructor(e){super(0),this._contexts=new Map,this._lastContextId=0;const t=this._register(new _b(this._myContextId,e,this._onDidChangeContext));this._contexts.set(this._myContextId,t)}getContextValuesContainer(e){return this._isDisposed?Tm.INSTANCE:this._contexts.get(e)||Tm.INSTANCE}createChildContext(e=this._myContextId){if(this._isDisposed)throw new Error("ContextKeyService has been disposed");const t=++this._lastContextId;return this._contexts.set(t,new OO(t,this.getContextValuesContainer(e))),t}disposeContext(e){this._isDisposed||this._contexts.delete(e)}};H2=sme([ome(0,mt)],H2);class dme extends RU{constructor(e,t){if(super(e.createChildContext()),this._parentChangeListener=this._register(new En),this._parent=e,this._updateParentChangeListener(),this._domNode=t,this._domNode.hasAttribute(Qv)){let i="";this._domNode.classList&&(i=Array.from(this._domNode.classList.values()).join(", ")),console.error(`Element already has context attribute${i?": "+i:""}`)}this._domNode.setAttribute(Qv,String(this._myContextId))}_updateParentChangeListener(){this._parentChangeListener.value=this._parent.onDidChangeContext(e=>{const i=this._parent.getContextValuesContainer(this._myContextId).value;lme(e,i)||this._onDidChangeContext.fire(e)})}dispose(){this._isDisposed||(this._parent.disposeContext(this._myContextId),this._domNode.removeAttribute(Qv),super.dispose())}getContextValuesContainer(e){return this._isDisposed?Tm.INSTANCE:this._parent.getContextValuesContainer(e)}createChildContext(e=this._myContextId){if(this._isDisposed)throw new Error("ScopedContextKeyService has been disposed");return this._parent.createChildContext(e)}disposeContext(e){this._isDisposed||this._parent.disposeContext(e)}}function cme(s){for(;s;){if(s.hasAttribute(Qv)){const e=s.getAttribute(Qv);return e?parseInt(e,10):NaN}s=s.parentElement}return 0}function ume(s,e,t){s.get(je).createKey(String(e),hme(t))}function hme(s){return fW(s,e=>{if(typeof e=="object"&&e.$mid===1)return Pe.revive(e).toString();if(e instanceof Pe)return e.toString()})}Ct.registerCommand("_setContext",ume);Ct.registerCommand({id:"getContextKeyInfo",handler(){return[...me.all()].sort((s,e)=>s.key.localeCompare(e.key))},metadata:{description:p("getContextKeyInfo","A command that returns information about context keys"),args:[]}});Ct.registerCommand("_generateContextKeyInfo",function(){const s=[],e=new Set;for(const t of me.all())e.has(t.key)||(e.add(t.key),s.push(t));s.sort((t,i)=>t.key.localeCompare(i.key)),console.log(JSON.stringify(s,void 0,2))});let gme=class{constructor(e,t){this.key=e,this.data=t,this.incoming=new Map,this.outgoing=new Map}};class W9{constructor(e){this._hashFn=e,this._nodes=new Map}roots(){const e=[];for(const t of this._nodes.values())t.outgoing.size===0&&e.push(t);return e}insertEdge(e,t){const i=this.lookupOrInsertNode(e),n=this.lookupOrInsertNode(t);i.outgoing.set(n.key,n),n.incoming.set(i.key,i)}removeNode(e){const t=this._hashFn(e);this._nodes.delete(t);for(const i of this._nodes.values())i.outgoing.delete(t),i.incoming.delete(t)}lookupOrInsertNode(e){const t=this._hashFn(e);let i=this._nodes.get(t);return i||(i=new gme(t,e),this._nodes.set(t,i)),i}isEmpty(){return this._nodes.size===0}toString(){const e=[];for(const[t,i]of this._nodes)e.push(`${t}
	(-> incoming)[${[...i.incoming.keys()].join(", ")}]
	(outgoing ->)[${[...i.outgoing.keys()].join(",")}]
`);return e.join(`
`)}findCycleSlow(){for(const[e,t]of this._nodes){const i=new Set([e]),n=this._findCycle(t,i);if(n)return n}}_findCycle(e,t){for(const[i,n]of e.outgoing){if(t.has(i))return[...t,i].join(" -> ");t.add(i);const o=this._findCycle(n,t);if(o)return o;t.delete(i)}}}const fme=!1;class V9 extends Error{constructor(e){var t;super("cyclic dependency between services"),this.message=(t=e.findCycleSlow())!==null&&t!==void 0?t:`UNABLE to detect cycle, dumping graph: 
${e.toString()}`}}class Uy{constructor(e=new _C,t=!1,i,n=fme){var o;this._services=e,this._strict=t,this._parent=i,this._enableTracing=n,this._activeInstantiations=new Set,this._services.set(We,this),this._globalGraph=n?(o=i==null?void 0:i._globalGraph)!==null&&o!==void 0?o:new W9(r=>r):void 0}createChild(e){return new Uy(e,this._strict,this,this._enableTracing)}invokeFunction(e,...t){const i=Ks.traceInvocation(this._enableTracing,e);let n=!1;try{return e({get:r=>{if(n)throw IA("service accessor is only valid during the invocation of its target method");const a=this._getOrCreateServiceInstance(r,i);if(!a)throw new Error(`[invokeFunction] unknown service '${r}'`);return a}},...t)}finally{n=!0,i.stop()}}createInstance(e,...t){let i,n;return e instanceof hl?(i=Ks.traceCreation(this._enableTracing,e.ctor),n=this._createInstance(e.ctor,e.staticArguments.concat(t),i)):(i=Ks.traceCreation(this._enableTracing,e),n=this._createInstance(e,t,i)),i.stop(),n}_createInstance(e,t=[],i){const n=Ea.getServiceDependencies(e).sort((a,l)=>a.index-l.index),o=[];for(const a of n){const l=this._getOrCreateServiceInstance(a.id,i);l||this._throwIfStrict(`[createInstance] ${e.name} depends on UNKNOWN service ${a.id}.`,!1),o.push(l)}const r=n.length>0?n[0].index:t.length;if(t.length!==r){console.trace(`[createInstance] First service dependency of ${e.name} at position ${r+1} conflicts with ${t.length} static arguments`);const a=r-t.length;a>0?t=t.concat(new Array(a)):t=t.slice(0,r)}return Reflect.construct(e,t.concat(o))}_setServiceInstance(e,t){if(this._services.get(e)instanceof hl)this._services.set(e,t);else if(this._parent)this._parent._setServiceInstance(e,t);else throw new Error("illegalState - setting UNKNOWN service instance")}_getServiceInstanceOrDescriptor(e){const t=this._services.get(e);return!t&&this._parent?this._parent._getServiceInstanceOrDescriptor(e):t}_getOrCreateServiceInstance(e,t){this._globalGraph&&this._globalGraphImplicitDependency&&this._globalGraph.insertEdge(this._globalGraphImplicitDependency,String(e));const i=this._getServiceInstanceOrDescriptor(e);return i instanceof hl?this._safeCreateAndCacheServiceInstance(e,i,t.branch(e,!0)):(t.branch(e,!1),i)}_safeCreateAndCacheServiceInstance(e,t,i){if(this._activeInstantiations.has(e))throw new Error(`illegal state - RECURSIVELY instantiating service '${e}'`);this._activeInstantiations.add(e);try{return this._createAndCacheServiceInstance(e,t,i)}finally{this._activeInstantiations.delete(e)}}_createAndCacheServiceInstance(e,t,i){var n;const o=new W9(l=>l.id.toString());let r=0;const a=[{id:e,desc:t,_trace:i}];for(;a.length;){const l=a.pop();if(o.lookupOrInsertNode(l),r++>1e3)throw new V9(o);for(const d of Ea.getServiceDependencies(l.desc.ctor)){const c=this._getServiceInstanceOrDescriptor(d.id);if(c||this._throwIfStrict(`[createInstance] ${e} depends on ${d.id} which is NOT registered.`,!0),(n=this._globalGraph)===null||n===void 0||n.insertEdge(String(l.id),String(d.id)),c instanceof hl){const u={id:d.id,desc:c,_trace:l._trace.branch(d.id,!0)};o.insertEdge(l,u),a.push(u)}}}for(;;){const l=o.roots();if(l.length===0){if(!o.isEmpty())throw new V9(o);break}for(const{data:d}of l){if(this._getServiceInstanceOrDescriptor(d.id)instanceof hl){const u=this._createServiceInstanceWithOwner(d.id,d.desc.ctor,d.desc.staticArguments,d.desc.supportsDelayedInstantiation,d._trace);this._setServiceInstance(d.id,u)}o.removeNode(d)}}return this._getServiceInstanceOrDescriptor(e)}_createServiceInstanceWithOwner(e,t,i=[],n,o){if(this._services.get(e)instanceof hl)return this._createServiceInstance(e,t,i,n,o);if(this._parent)return this._parent._createServiceInstanceWithOwner(e,t,i,n,o);throw new Error(`illegalState - creating UNKNOWN service instance ${t.name}`)}_createServiceInstance(e,t,i=[],n,o){if(n){const r=new Uy(void 0,this._strict,this,this._enableTracing);r._globalGraphImplicitDependency=String(e);const a=new Map,l=new see(()=>{const d=r._createInstance(t,i,o);for(const[c,u]of a){const h=d[c];if(typeof h=="function")for(const g of u)h.apply(d,g)}return a.clear(),d});return new Proxy(Object.create(null),{get(d,c){if(!l.isInitialized&&typeof c=="string"&&(c.startsWith("onDid")||c.startsWith("onWill"))){let g=a.get(c);return g||(g=new Ms,a.set(c,g)),(m,_,v)=>{const b=g.push([m,_,v]);return Fe(b)}}if(c in d)return d[c];const u=l.value;let h=u[c];return typeof h!="function"||(h=h.bind(u),d[c]=h),h},set(d,c,u){return l.value[c]=u,!0},getPrototypeOf(d){return t.prototype}})}else return this._createInstance(t,i,o)}_throwIfStrict(e,t){if(t&&console.warn(e),this._strict)throw new Error(e)}}class Ks{static traceInvocation(e,t){return e?new Ks(2,t.name||new Error().stack.split(`
`).slice(3,4).join(`
`)):Ks._None}static traceCreation(e,t){return e?new Ks(1,t.name):Ks._None}constructor(e,t){this.type=e,this.name=t,this._start=Date.now(),this._dep=[]}branch(e,t){const i=new Ks(3,e.toString());return this._dep.push([e,t,i]),i}stop(){const e=Date.now()-this._start;Ks._totals+=e;let t=!1;function i(o,r){const a=[],l=new Array(o+1).join("	");for(const[d,c,u]of r._dep)if(c&&u){t=!0,a.push(`${l}CREATES -> ${d}`);const h=i(o+1,u);h&&a.push(h)}else a.push(`${l}uses -> ${d}`);return a.join(`
`)}const n=[`${this.type===1?"CREATE":"CALL"} ${this.name}`,`${i(1,this)}`,`DONE, took ${e.toFixed(2)}ms (grand total ${Ks._totals.toFixed(2)}ms)`];(e>2||t)&&Ks.all.add(n.join(`
`))}}Ks.all=new Set;Ks._None=new class extends Ks{constructor(){super(0,null)}stop(){}branch(){return this}};Ks._totals=0;const pme=new Set([it.inMemory,it.vscodeSourceControl,it.walkThrough,it.walkThroughSnippet]);class mme{constructor(){this._byResource=new zi,this._byOwner=new Map}set(e,t,i){let n=this._byResource.get(e);n||(n=new Map,this._byResource.set(e,n)),n.set(t,i);let o=this._byOwner.get(t);o||(o=new zi,this._byOwner.set(t,o)),o.set(e,i)}get(e,t){const i=this._byResource.get(e);return i==null?void 0:i.get(t)}delete(e,t){let i=!1,n=!1;const o=this._byResource.get(e);o&&(i=o.delete(t));const r=this._byOwner.get(t);if(r&&(n=r.delete(e)),i!==n)throw new Error("illegal state");return i&&n}values(e){var t,i,n,o;return typeof e=="string"?(i=(t=this._byOwner.get(e))===null||t===void 0?void 0:t.values())!==null&&i!==void 0?i:ht.empty():Pe.isUri(e)?(o=(n=this._byResource.get(e))===null||n===void 0?void 0:n.values())!==null&&o!==void 0?o:ht.empty():ht.map(ht.concat(...this._byOwner.values()),r=>r[1])}}class _me{constructor(e){this.errors=0,this.infos=0,this.warnings=0,this.unknowns=0,this._data=new zi,this._service=e,this._subscription=e.onMarkerChanged(this._update,this)}dispose(){this._subscription.dispose()}_update(e){for(const t of e){const i=this._data.get(t);i&&this._substract(i);const n=this._resourceStats(t);this._add(n),this._data.set(t,n)}}_resourceStats(e){const t={errors:0,warnings:0,infos:0,unknowns:0};if(pme.has(e.scheme))return t;for(const{severity:i}of this._service.read({resource:e}))i===Ii.Error?t.errors+=1:i===Ii.Warning?t.warnings+=1:i===Ii.Info?t.infos+=1:t.unknowns+=1;return t}_substract(e){this.errors-=e.errors,this.warnings-=e.warnings,this.infos-=e.infos,this.unknowns-=e.unknowns}_add(e){this.errors+=e.errors,this.warnings+=e.warnings,this.infos+=e.infos,this.unknowns+=e.unknowns}}class Mc{constructor(){this._onMarkerChanged=new kW({delay:0,merge:Mc._merge}),this.onMarkerChanged=this._onMarkerChanged.event,this._data=new mme,this._stats=new _me(this)}dispose(){this._stats.dispose(),this._onMarkerChanged.dispose()}remove(e,t){for(const i of t||[])this.changeOne(e,i,[])}changeOne(e,t,i){if(dW(i))this._data.delete(t,e)&&this._onMarkerChanged.fire([t]);else{const n=[];for(const o of i){const r=Mc._toMarker(e,t,o);r&&n.push(r)}this._data.set(t,e,n),this._onMarkerChanged.fire([t])}}static _toMarker(e,t,i){let{code:n,severity:o,message:r,source:a,startLineNumber:l,startColumn:d,endLineNumber:c,endColumn:u,relatedInformation:h,tags:g}=i;if(r)return l=l>0?l:1,d=d>0?d:1,c=c>=l?c:l,u=u>0?u:d,{resource:t,owner:e,code:n,severity:o,message:r,source:a,startLineNumber:l,startColumn:d,endLineNumber:c,endColumn:u,relatedInformation:h,tags:g}}changeAll(e,t){const i=[],n=this._data.values(e);if(n)for(const o of n){const r=ht.first(o);r&&(i.push(r.resource),this._data.delete(r.resource,e))}if(as(t)){const o=new zi;for(const{resource:r,marker:a}of t){const l=Mc._toMarker(e,r,a);if(!l)continue;const d=o.get(r);d?d.push(l):(o.set(r,[l]),i.push(r))}for(const[r,a]of o)this._data.set(r,e,a)}i.length>0&&this._onMarkerChanged.fire(i)}read(e=Object.create(null)){let{owner:t,resource:i,severities:n,take:o}=e;if((!o||o<0)&&(o=-1),t&&i){const r=this._data.get(i,t);if(r){const a=[];for(const l of r)if(Mc._accept(l,n)){const d=a.push(l);if(o>0&&d===o)break}return a}else return[]}else if(!t&&!i){const r=[];for(const a of this._data.values())for(const l of a)if(Mc._accept(l,n)){const d=r.push(l);if(o>0&&d===o)return r}return r}else{const r=this._data.values(i??t),a=[];for(const l of r)for(const d of l)if(Mc._accept(d,n)){const c=a.push(d);if(o>0&&c===o)return a}return a}}static _accept(e,t){return t===void 0||(t&e.severity)===e.severity}static _merge(e){const t=new zi;for(const i of e)for(const n of i)t.set(n,!0);return Array.from(t.keys())}}class vme extends j{constructor(){super(...arguments),this._configurationModel=new ss}get configurationModel(){return this._configurationModel}reload(){return this.resetConfigurationModel(),this.configurationModel}getConfigurationDefaultOverrides(){return{}}resetConfigurationModel(){this._configurationModel=new ss;const e=Si.as(Za.Configuration).getConfigurationProperties();this.updateConfigurationModel(Object.keys(e),e)}updateConfigurationModel(e,t){const i=this.getConfigurationDefaultOverrides();for(const n of e){const o=i[n],r=t[n];o!==void 0?this._configurationModel.addValue(n,o):r?this._configurationModel.addValue(n,r.default):this._configurationModel.removeValue(n)}}}const IC=ut("audioCue");class Qe{static register(e){return new Qe(e.fileName)}constructor(e){this.fileName=e}}Qe.error=Qe.register({fileName:"error.mp3"});Qe.warning=Qe.register({fileName:"warning.mp3"});Qe.foldedArea=Qe.register({fileName:"foldedAreas.mp3"});Qe.break=Qe.register({fileName:"break.mp3"});Qe.quickFixes=Qe.register({fileName:"quickFixes.mp3"});Qe.taskCompleted=Qe.register({fileName:"taskCompleted.mp3"});Qe.taskFailed=Qe.register({fileName:"taskFailed.mp3"});Qe.terminalBell=Qe.register({fileName:"terminalBell.mp3"});Qe.diffLineInserted=Qe.register({fileName:"diffLineInserted.mp3"});Qe.diffLineDeleted=Qe.register({fileName:"diffLineDeleted.mp3"});Qe.diffLineModified=Qe.register({fileName:"diffLineModified.mp3"});Qe.chatRequestSent=Qe.register({fileName:"chatRequestSent.mp3"});Qe.chatResponsePending=Qe.register({fileName:"chatResponsePending.mp3"});Qe.chatResponseReceived1=Qe.register({fileName:"chatResponseReceived1.mp3"});Qe.chatResponseReceived2=Qe.register({fileName:"chatResponseReceived2.mp3"});Qe.chatResponseReceived3=Qe.register({fileName:"chatResponseReceived3.mp3"});Qe.chatResponseReceived4=Qe.register({fileName:"chatResponseReceived4.mp3"});Qe.clear=Qe.register({fileName:"clear.mp3"});Qe.save=Qe.register({fileName:"save.mp3"});Qe.format=Qe.register({fileName:"format.mp3"});class bme{constructor(e){this.randomOneOf=e}}class at{static register(e){const t=new bme("randomOneOf"in e.sound?e.sound.randomOneOf:[e.sound]),i=new at(t,e.name,e.settingsKey);return at._audioCues.add(i),i}constructor(e,t,i){this.sound=e,this.name=t,this.settingsKey=i}}at._audioCues=new Set;at.error=at.register({name:p("audioCues.lineHasError.name","Error on Line"),sound:Qe.error,settingsKey:"audioCues.lineHasError"});at.warning=at.register({name:p("audioCues.lineHasWarning.name","Warning on Line"),sound:Qe.warning,settingsKey:"audioCues.lineHasWarning"});at.foldedArea=at.register({name:p("audioCues.lineHasFoldedArea.name","Folded Area on Line"),sound:Qe.foldedArea,settingsKey:"audioCues.lineHasFoldedArea"});at.break=at.register({name:p("audioCues.lineHasBreakpoint.name","Breakpoint on Line"),sound:Qe.break,settingsKey:"audioCues.lineHasBreakpoint"});at.inlineSuggestion=at.register({name:p("audioCues.lineHasInlineSuggestion.name","Inline Suggestion on Line"),sound:Qe.quickFixes,settingsKey:"audioCues.lineHasInlineSuggestion"});at.terminalQuickFix=at.register({name:p("audioCues.terminalQuickFix.name","Terminal Quick Fix"),sound:Qe.quickFixes,settingsKey:"audioCues.terminalQuickFix"});at.onDebugBreak=at.register({name:p("audioCues.onDebugBreak.name","Debugger Stopped on Breakpoint"),sound:Qe.break,settingsKey:"audioCues.onDebugBreak"});at.noInlayHints=at.register({name:p("audioCues.noInlayHints","No Inlay Hints on Line"),sound:Qe.error,settingsKey:"audioCues.noInlayHints"});at.taskCompleted=at.register({name:p("audioCues.taskCompleted","Task Completed"),sound:Qe.taskCompleted,settingsKey:"audioCues.taskCompleted"});at.taskFailed=at.register({name:p("audioCues.taskFailed","Task Failed"),sound:Qe.taskFailed,settingsKey:"audioCues.taskFailed"});at.terminalCommandFailed=at.register({name:p("audioCues.terminalCommandFailed","Terminal Command Failed"),sound:Qe.error,settingsKey:"audioCues.terminalCommandFailed"});at.terminalBell=at.register({name:p("audioCues.terminalBell","Terminal Bell"),sound:Qe.terminalBell,settingsKey:"audioCues.terminalBell"});at.notebookCellCompleted=at.register({name:p("audioCues.notebookCellCompleted","Notebook Cell Completed"),sound:Qe.taskCompleted,settingsKey:"audioCues.notebookCellCompleted"});at.notebookCellFailed=at.register({name:p("audioCues.notebookCellFailed","Notebook Cell Failed"),sound:Qe.taskFailed,settingsKey:"audioCues.notebookCellFailed"});at.diffLineInserted=at.register({name:p("audioCues.diffLineInserted","Diff Line Inserted"),sound:Qe.diffLineInserted,settingsKey:"audioCues.diffLineInserted"});at.diffLineDeleted=at.register({name:p("audioCues.diffLineDeleted","Diff Line Deleted"),sound:Qe.diffLineDeleted,settingsKey:"audioCues.diffLineDeleted"});at.diffLineModified=at.register({name:p("audioCues.diffLineModified","Diff Line Modified"),sound:Qe.diffLineModified,settingsKey:"audioCues.diffLineModified"});at.chatRequestSent=at.register({name:p("audioCues.chatRequestSent","Chat Request Sent"),sound:Qe.chatRequestSent,settingsKey:"audioCues.chatRequestSent"});at.chatResponseReceived=at.register({name:p("audioCues.chatResponseReceived","Chat Response Received"),settingsKey:"audioCues.chatResponseReceived",sound:{randomOneOf:[Qe.chatResponseReceived1,Qe.chatResponseReceived2,Qe.chatResponseReceived3,Qe.chatResponseReceived4]}});at.chatResponsePending=at.register({name:p("audioCues.chatResponsePending","Chat Response Pending"),sound:Qe.chatResponsePending,settingsKey:"audioCues.chatResponsePending"});at.clear=at.register({name:p("audioCues.clear","Clear"),sound:Qe.clear,settingsKey:"audioCues.clear"});at.save=at.register({name:p("audioCues.save","Save"),sound:Qe.save,settingsKey:"audioCues.save"});at.format=at.register({name:p("audioCues.format","Format"),sound:Qe.format,settingsKey:"audioCues.format"});class Cme extends j{constructor(e,t=[]){super(),this.logger=new KJ([e,...t]),this._register(e.onDidChangeLogLevel(i=>this.setLevel(i)))}get onDidChangeLogLevel(){return this.logger.onDidChangeLogLevel}setLevel(e){this.logger.setLevel(e)}getLevel(){return this.logger.getLevel()}trace(e,...t){this.logger.trace(e,...t)}debug(e,...t){this.logger.debug(e,...t)}info(e,...t){this.logger.info(e,...t)}warn(e,...t){this.logger.warn(e,...t)}error(e,...t){this.logger.error(e,...t)}}const AU=[];function tD(s){AU.push(s)}function wme(){return AU.slice(0)}var ah=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Bn=function(s,e){return function(t,i){e(t,i,s)}};class Sme{constructor(e){this.disposed=!1,this.model=e,this._onWillDispose=new W}get textEditorModel(){return this.model}dispose(){this.disposed=!0,this._onWillDispose.fire()}}let z2=class{constructor(e){this.modelService=e}createModelReference(e){const t=this.modelService.getModel(e);return t?Promise.resolve(new _Q(new Sme(t))):Promise.reject(new Error("Model not found"))}};z2=ah([Bn(0,vi)],z2);class iD{show(){return iD.NULL_PROGRESS_RUNNER}async showWhile(e,t){await e}}iD.NULL_PROGRESS_RUNNER={done:()=>{},total:()=>{},worked:()=>{}};class yme{withProgress(e,t,i){return t({report:()=>{}})}}class Lme{constructor(){this.isExtensionDevelopment=!1,this.isBuilt=!1}}class xme{async confirm(e){return{confirmed:this.doConfirm(e.message,e.detail),checkboxChecked:!1}}doConfirm(e,t){let i=e;return t&&(i=i+`

`+t),Ci.confirm(i)}async prompt(e){var t,i;let n;if(this.doConfirm(e.message,e.detail)){const r=[...(t=e.buttons)!==null&&t!==void 0?t:[]];e.cancelButton&&typeof e.cancelButton!="string"&&typeof e.cancelButton!="boolean"&&r.push(e.cancelButton),n=await((i=r[0])===null||i===void 0?void 0:i.run({checkboxChecked:!1}))}return{result:n}}async error(e,t){await this.prompt({type:Wi.Error,message:e,detail:t})}}class vb{info(e){return this.notify({severity:Wi.Info,message:e})}warn(e){return this.notify({severity:Wi.Warning,message:e})}error(e){return this.notify({severity:Wi.Error,message:e})}notify(e){switch(e.severity){case Wi.Error:console.error(e.message);break;case Wi.Warning:console.warn(e.message);break;default:console.log(e.message);break}return vb.NO_OP}prompt(e,t,i,n){return vb.NO_OP}status(e,t){return j.None}}vb.NO_OP=new xce;let U2=class{constructor(e){this._onWillExecuteCommand=new W,this._onDidExecuteCommand=new W,this.onDidExecuteCommand=this._onDidExecuteCommand.event,this._instantiationService=e}executeCommand(e,...t){const i=Ct.getCommand(e);if(!i)return Promise.reject(new Error(`command '${e}' not found`));try{this._onWillExecuteCommand.fire({commandId:e,args:t});const n=this._instantiationService.invokeFunction.apply(this._instantiationService,[i.handler,...t]);return this._onDidExecuteCommand.fire({commandId:e,args:t}),Promise.resolve(n)}catch(n){return Promise.reject(n)}}};U2=ah([Bn(0,We)],U2);let Mm=class extends Eue{constructor(e,t,i,n,o,r){super(e,t,i,n,o),this._cachedResolver=null,this._dynamicKeybindings=[],this._domNodeListeners=[];const a=g=>{const f=new ie;f.add(Y(g,he.KEY_DOWN,m=>{const _=new ri(m);this._dispatch(_,_.target)&&(_.preventDefault(),_.stopPropagation())})),f.add(Y(g,he.KEY_UP,m=>{const _=new ri(m);this._singleModifierDispatch(_,_.target)&&_.preventDefault()})),this._domNodeListeners.push(new Dme(g,f))},l=g=>{for(let f=0;f<this._domNodeListeners.length;f++){const m=this._domNodeListeners[f];m.domNode===g&&(this._domNodeListeners.splice(f,1),m.dispose())}},d=g=>{g.getOption(61)||a(g.getContainerDomNode())},c=g=>{g.getOption(61)||l(g.getContainerDomNode())};this._register(r.onCodeEditorAdd(d)),this._register(r.onCodeEditorRemove(c)),r.listCodeEditors().forEach(d);const u=g=>{a(g.getContainerDomNode())},h=g=>{l(g.getContainerDomNode())};this._register(r.onDiffEditorAdd(u)),this._register(r.onDiffEditorRemove(h)),r.listDiffEditors().forEach(u)}addDynamicKeybinding(e,t,i,n){return Gr(Ct.registerCommand(e,i),this.addDynamicKeybindings([{keybinding:t,command:e,when:n}]))}addDynamicKeybindings(e){const t=e.map(i=>{var n;return{keybinding:KN(i.keybinding,Go),command:(n=i.command)!==null&&n!==void 0?n:null,commandArgs:i.commandArgs,when:i.when,weight1:1e3,weight2:0,extensionId:null,isBuiltinExtension:!1}});return this._dynamicKeybindings=this._dynamicKeybindings.concat(t),this.updateResolver(),Fe(()=>{for(let i=0;i<this._dynamicKeybindings.length;i++)if(this._dynamicKeybindings[i]===t[0]){this._dynamicKeybindings.splice(i,t.length),this.updateResolver();return}})}updateResolver(){this._cachedResolver=null,this._onDidUpdateKeybindings.fire()}_getResolver(){if(!this._cachedResolver){const e=this._toNormalizedKeybindingItems(Js.getDefaultKeybindings(),!0),t=this._toNormalizedKeybindingItems(this._dynamicKeybindings,!1);this._cachedResolver=new Xv(e,t,i=>this._log(i))}return this._cachedResolver}_documentHasFocus(){return Ci.document.hasFocus()}_toNormalizedKeybindingItems(e,t){const i=[];let n=0;for(const o of e){const r=o.when||void 0,a=o.keybinding;if(!a)i[n++]=new Y7(void 0,o.command,o.commandArgs,r,t,null,!1);else{const l=nb.resolveKeybinding(a,Go);for(const d of l)i[n++]=new Y7(d,o.command,o.commandArgs,r,t,null,!1)}}return i}resolveKeyboardEvent(e){const t=new ec(e.ctrlKey,e.shiftKey,e.altKey,e.metaKey,e.keyCode);return new nb([t],Go)}};Mm=ah([Bn(0,je),Bn(1,Ei),Bn(2,Do),Bn(3,Qi),Bn(4,ko),Bn(5,It)],Mm);class Dme extends j{constructor(e,t){super(),this.domNode=e,this._register(t)}}function H9(s){return s&&typeof s=="object"&&(!s.overrideIdentifier||typeof s.overrideIdentifier=="string")&&(!s.resource||s.resource instanceof Pe)}class PU{constructor(){this._onDidChangeConfiguration=new W,this.onDidChangeConfiguration=this._onDidChangeConfiguration.event;const e=new vme;this._configuration=new Ox(e.reload(),new ss,new ss,new ss),e.dispose()}getValue(e,t){const i=typeof e=="string"?e:void 0,n=H9(e)?e:H9(t)?t:{};return this._configuration.getValue(i,n,void 0)}updateValues(e){const t={data:this._configuration.toData()},i=[];for(const n of e){const[o,r]=n;this.getValue(o)!==r&&(this._configuration.updateValue(o,r),i.push(o))}if(i.length>0){const n=new xue({keys:i,overrides:[]},t,this._configuration);n.source=8,n.sourceConfig=null,this._onDidChangeConfiguration.fire(n)}return Promise.resolve()}updateValue(e,t,i,n){return this.updateValues([[e,t]])}inspect(e,t={}){return this._configuration.inspect(e,t,void 0)}}let $2=class{constructor(e,t,i){this.configurationService=e,this.modelService=t,this.languageService=i,this._onDidChangeConfiguration=new W,this.configurationService.onDidChangeConfiguration(n=>{this._onDidChangeConfiguration.fire({affectedKeys:n.affectedKeys,affectsConfiguration:(o,r)=>n.affectsConfiguration(r)})})}getValue(e,t,i){const n=H.isIPosition(t)?t:null,o=n?typeof i=="string"?i:void 0:typeof t=="string"?t:void 0,r=e?this.getLanguage(e,n):void 0;return typeof o>"u"?this.configurationService.getValue({resource:e,overrideIdentifier:r}):this.configurationService.getValue(o,{resource:e,overrideIdentifier:r})}getLanguage(e,t){const i=this.modelService.getModel(e);return i?t?i.getLanguageIdAtPosition(t.lineNumber,t.column):i.getLanguageId():this.languageService.guessLanguageIdByFilepathOrFirstLine(e)}};$2=ah([Bn(0,mt),Bn(1,vi),Bn(2,fi)],$2);let j2=class{constructor(e){this.configurationService=e}getEOL(e,t){const i=this.configurationService.getValue("files.eol",{overrideIdentifier:t,resource:e});return i&&typeof i=="string"&&i!=="auto"?i:Ss||bt?`
`:`\r
`}};j2=ah([Bn(0,mt)],j2);class kme{publicLog2(){}}class bb{constructor(){const e=Pe.from({scheme:bb.SCHEME,authority:"model",path:"/"});this.workspace={id:Iz,folders:[new $ue({uri:e,name:"",index:0})]}}getWorkspace(){return this.workspace}getWorkspaceFolder(e){return e&&e.scheme===bb.SCHEME?this.workspace.folders[0]:null}}bb.SCHEME="inmemory";function $y(s,e,t){if(!e||!(s instanceof PU))return;const i=[];Object.keys(e).forEach(n=>{Cue(n)&&i.push([`editor.${n}`,e[n]]),t&&wue(n)&&i.push([`diffEditor.${n}`,e[n]])}),i.length>0&&s.updateValues(i)}let K2=class{constructor(e){this._modelService=e}hasPreviewHandler(){return!1}async apply(e,t){const i=Array.isArray(e)?e:JP.convert(e),n=new Map;for(const a of i){if(!(a instanceof qd))throw new Error("bad edit - only text edits are supported");const l=this._modelService.getModel(a.resource);if(!l)throw new Error("bad edit - model not found");if(typeof a.versionId=="number"&&l.getVersionId()!==a.versionId)throw new Error("bad state - model changed in the meantime");let d=n.get(l);d||(d=[],n.set(l,d)),d.push(_i.replaceMove(D.lift(a.textEdit.range),a.textEdit.text))}let o=0,r=0;for(const[a,l]of n)a.pushStackElement(),a.pushEditOperations([],l,()=>[]),a.pushStackElement(),r+=1,o+=l.length;return{ariaSummary:xg(JT.bulkEditServiceSummary,o,r),isApplied:o>0}}};K2=ah([Bn(0,vi)],K2);class Ime{getUriLabel(e,t){return e.scheme==="file"?e.fsPath:e.path}getUriBasenameLabel(e){return kr(e)}}let q2=class extends e2{constructor(e,t){super(e),this._codeEditorService=t}showContextView(e,t,i){if(!t){const n=this._codeEditorService.getFocusedCodeEditor()||this._codeEditorService.getActiveCodeEditor();n&&(t=n.getContainerDomNode())}return super.showContextView(e,t,i)}};q2=ah([Bn(0,d_),Bn(1,It)],q2);class Eme{constructor(){this._neverEmitter=new W,this.onDidChangeTrust=this._neverEmitter.event}isWorkspaceTrusted(){return!0}}class Nme extends rb{constructor(){super()}}class Tme extends Cme{constructor(){super(new jJ)}}let G2=class extends m2{constructor(e,t,i,n,o,r){super(e,t,i,n,o,r),this.configure({blockMouse:!1})}};G2=ah([Bn(0,Do),Bn(1,Qi),Bn(2,rc),Bn(3,qt),Bn(4,qa),Bn(5,je)],G2);class Mme{async playAudioCue(e,t){}}class Rme{notify(e,t){}}_t(mt,PU,0);_t(cP,$2,0);_t(YV,j2,0);_t(Ag,bb,0);_t(xm,Ime,0);_t(Do,kme,0);_t(vC,xme,0);_t(YP,Lme,0);_t(Qi,vb,0);_t(ld,Mc,0);_t(fi,Nme,0);_t(lr,eme,0);_t(ko,Tme,0);_t(vi,Ty,0);_t(mP,w2,0);_t(je,H2,0);_t(kz,yme,0);_t(rh,iD,0);_t(sa,Fge,0);_t(oa,aT,0);_t(bC,K2,0);_t(Ez,Eme,0);_t(io,z2,0);_t(ad,O2,0);_t(Mr,ipe,0);_t(Ei,U2,0);_t(qt,Mm,0);_t(Ya,A2,0);_t(rc,q2,0);_t(No,C2,0);_t(dc,V2,0);_t(Nr,G2,0);_t(qa,F2,0);_t(IC,Mme,0);_t(bx,Rme,0);var He;(function(s){const e=new _C;for(const[l,d]of O5())e.set(l,d);const t=new Uy(e,!0);e.set(We,t);function i(l){n||r({});const d=e.get(l);if(!d)throw new Error("Missing service "+l);return d instanceof hl?t.invokeFunction(c=>c.get(l)):d}s.get=i;let n=!1;const o=new W;function r(l){if(n)return t;n=!0;for(const[c,u]of O5())e.get(c)||e.set(c,u);for(const c in l)if(l.hasOwnProperty(c)){const u=ut(c);e.get(u)instanceof hl&&e.set(u,l[c])}const d=wme();for(const c of d)try{t.createInstance(c)}catch(u){et(u)}return o.fire(),t}s.initialize=r;function a(l){if(n)return l();const d=new ie,c=d.add(o.event(()=>{c.dispose(),d.add(l())}));return d}s.withServices=a})(He||(He={}));let Ame;function zl(){return Ame}let OU;function Pme(s){OU=s}let FU;function Ome(s){FU=s}class BU{get TChange(){return null}reportChanges(){this.get()}read(e){return e?e.readObservable(this):this.get()}map(e,t){const i=t===void 0?void 0:e,n=t===void 0?e:t;return FU({owner:i,debugName:()=>{const o=lh(n);if(o!==void 0)return o;const a=/^\s*\(?\s*([a-zA-Z_$][a-zA-Z_$0-9]*)\s*\)?\s*=>\s*\1(?:\??)\.([a-zA-Z_$][a-zA-Z_$0-9]*)\s*$/.exec(n.toString());if(a)return`${this.debugName}.${a[2]}`;if(!i)return`${this.debugName} (mapped)`}},o=>n(this.read(o),o))}recomputeInitiallyAndOnChange(e,t){return e.add(OU(this,t)),this}}class EC extends BU{constructor(){super(...arguments),this.observers=new Set}addObserver(e){const t=this.observers.size;this.observers.add(e),t===0&&this.onFirstObserverAdded()}removeObserver(e){this.observers.delete(e)&&this.observers.size===0&&this.onLastObserverRemoved()}onFirstObserverAdded(){}onLastObserverRemoved(){}}function mi(s,e){const t=new nD(s,e);try{s(t)}finally{t.finish()}}let U1;function Jw(s){if(U1)s(U1);else{const e=new nD(s,void 0);U1=e;try{s(e)}finally{e.finish(),U1=void 0}}}async function Fme(s,e){const t=new nD(s,e);try{await s(t)}finally{t.finish()}}function Cb(s,e,t){s?e(s):mi(e,t)}class nD{constructor(e,t){var i;this._fn=e,this._getDebugName=t,this.updatingObservers=[],(i=zl())===null||i===void 0||i.handleBeginTransaction(this)}getDebugName(){return this._getDebugName?this._getDebugName():lh(this._fn)}updateObserver(e,t){this.updatingObservers.push({observer:e,observable:t}),e.beginUpdate(t)}finish(){var e;const t=this.updatingObservers;for(let i=0;i<t.length;i++){const{observer:n,observable:o}=t[i];n.endUpdate(o)}this.updatingObservers=null,(e=zl())===null||e===void 0||e.handleEndTransaction()}}const z9=new Map,Z2=new WeakMap;function FO(s,e,t,i,n){var o;const r=Z2.get(s);if(r)return r;const a=Bme(s,e,t,i,n);if(a){let l=(o=z9.get(a))!==null&&o!==void 0?o:0;l++,z9.set(a,l);const d=l===1?a:`${a}#${l}`;return Z2.set(s,d),d}}function Bme(s,e,t,i,n){const o=Z2.get(s);if(o)return o;const r=i?Wme(i)+".":"";let a;if(e!==void 0)if(typeof e=="function"){if(a=e(),a!==void 0)return r+a}else return r+e;if(t!==void 0&&(a=lh(t),a!==void 0))return r+a;if(i!==void 0){for(const l in i)if(i[l]===n)return r+l}}const U9=new Map,$9=new WeakMap;function Wme(s){var e;const t=$9.get(s);if(t)return t;const i=Vme(s);let n=(e=U9.get(i))!==null&&e!==void 0?e:0;n++,U9.set(i,n);const o=n===1?i:`${i}#${n}`;return $9.set(s,o),o}function Vme(s){const e=s.constructor;return e?e.name:"Object"}function lh(s){const e=s.toString(),i=/\/\*\*\s*@description\s*([^*]*)\*\//.exec(e),n=i?i[1]:void 0;return n==null?void 0:n.trim()}function kt(s,e){return typeof s=="string"?new Y2(void 0,s,e):new Y2(s,void 0,e)}class Y2 extends EC{get debugName(){var e;return(e=FO(this,this._debugName,void 0,this._owner,this))!==null&&e!==void 0?e:"ObservableValue"}constructor(e,t,i){super(),this._owner=e,this._debugName=t,this._value=i}get(){return this._value}set(e,t,i){var n;if(this._value===e)return;let o;t||(t=o=new nD(()=>{},()=>`Setting ${this.debugName}`));try{const r=this._value;this._setValue(e),(n=zl())===null||n===void 0||n.handleObservableChanged(this,{oldValue:r,newValue:e,change:i,didChange:!0,hadValue:!0});for(const a of this.observers)t.updateObserver(a,this),a.handleChange(this,i)}finally{o&&o.finish()}}toString(){return`${this.debugName}: ${this._value}`}_setValue(e){this._value=e}}function jy(s,e){return typeof s=="string"?new j9(void 0,s,e):new j9(s,void 0,e)}class j9 extends Y2{_setValue(e){this._value!==e&&(this._value&&this._value.dispose(),this._value=e)}dispose(){var e;(e=this._value)===null||e===void 0||e.dispose()}}const Rm=(s,e)=>s===e;function nt(s,e){return e!==void 0?new Am(s,void 0,e,void 0,void 0,void 0,Rm):new Am(void 0,void 0,s,void 0,void 0,void 0,Rm)}function X2(s,e){var t;return new Am(s.owner,s.debugName,e,void 0,void 0,void 0,(t=s.equalityComparer)!==null&&t!==void 0?t:Rm)}function Hme(s,e){var t;return new Am(s.owner,s.debugName,e,s.createEmptyChangeSummary,s.handleChange,void 0,(t=s.equalityComparer)!==null&&t!==void 0?t:Rm)}function g_(s,e){let t,i;e===void 0?(t=s,i=void 0):(i=s,t=e);const n=new ie;return new Am(i,()=>{var o;return(o=lh(t))!==null&&o!==void 0?o:"(anonymous)"},o=>(n.clear(),t(o,n)),void 0,void 0,()=>n.dispose(),Rm)}function Dc(s,e){let t,i;e===void 0?(t=s,i=void 0):(i=s,t=e);const n=new ie;return new Am(i,()=>{var o;return(o=lh(t))!==null&&o!==void 0?o:"(anonymous)"},o=>{n.clear();const r=t(o);return r&&n.add(r),r},void 0,void 0,()=>n.dispose(),Rm)}Ome(X2);class Am extends EC{get debugName(){var e;return(e=FO(this,this._debugName,this._computeFn,this._owner,this))!==null&&e!==void 0?e:"(anonymous)"}constructor(e,t,i,n,o,r=void 0,a){var l,d;super(),this._owner=e,this._debugName=t,this._computeFn=i,this.createChangeSummary=n,this._handleChange=o,this._handleLastObserverRemoved=r,this._equalityComparator=a,this.state=0,this.value=void 0,this.updateCount=0,this.dependencies=new Set,this.dependenciesToBeRemoved=new Set,this.changeSummary=void 0,this.changeSummary=(l=this.createChangeSummary)===null||l===void 0?void 0:l.call(this),(d=zl())===null||d===void 0||d.handleDerivedCreated(this)}onLastObserverRemoved(){var e;this.state=0,this.value=void 0;for(const t of this.dependencies)t.removeObserver(this);this.dependencies.clear(),(e=this._handleLastObserverRemoved)===null||e===void 0||e.call(this)}get(){var e;if(this.observers.size===0){const t=this._computeFn(this,(e=this.createChangeSummary)===null||e===void 0?void 0:e.call(this));return this.onLastObserverRemoved(),t}else{do{if(this.state===1){for(const t of this.dependencies)if(t.reportChanges(),this.state===2)break}this.state===1&&(this.state=3),this._recomputeIfNeeded()}while(this.state!==3);return this.value}}_recomputeIfNeeded(){var e,t;if(this.state===3)return;const i=this.dependenciesToBeRemoved;this.dependenciesToBeRemoved=this.dependencies,this.dependencies=i;const n=this.state!==0,o=this.value;this.state=3;const r=this.changeSummary;this.changeSummary=(e=this.createChangeSummary)===null||e===void 0?void 0:e.call(this);try{this.value=this._computeFn(this,r)}finally{for(const l of this.dependenciesToBeRemoved)l.removeObserver(this);this.dependenciesToBeRemoved.clear()}const a=n&&!this._equalityComparator(o,this.value);if((t=zl())===null||t===void 0||t.handleDerivedRecomputed(this,{oldValue:o,newValue:this.value,change:void 0,didChange:a,hadValue:n}),a)for(const l of this.observers)l.handleChange(this,void 0)}toString(){return`LazyDerived<${this.debugName}>`}beginUpdate(e){this.updateCount++;const t=this.updateCount===1;if(this.state===3&&(this.state=1,!t))for(const i of this.observers)i.handlePossibleChange(this);if(t)for(const i of this.observers)i.beginUpdate(this)}endUpdate(e){if(this.updateCount--,this.updateCount===0){const t=[...this.observers];for(const i of t)i.endUpdate(this)}if(this.updateCount<0)throw new pi}handlePossibleChange(e){if(this.state===3&&this.dependencies.has(e)&&!this.dependenciesToBeRemoved.has(e)){this.state=1;for(const t of this.observers)t.handlePossibleChange(this)}}handleChange(e,t){if(this.dependencies.has(e)&&!this.dependenciesToBeRemoved.has(e)){const i=this._handleChange?this._handleChange({changedObservable:e,change:t,didChange:o=>o===e},this.changeSummary):!0,n=this.state===3;if(i&&(this.state===1||n)&&(this.state=2,n))for(const o of this.observers)o.handlePossibleChange(this)}}readObservable(e){e.addObserver(this);const t=e.get();return this.dependencies.add(e),this.dependenciesToBeRemoved.delete(e),t}addObserver(e){const t=!this.observers.has(e)&&this.updateCount>0;super.addObserver(e),t&&e.beginUpdate(this)}removeObserver(e){const t=this.observers.has(e)&&this.updateCount>0;super.removeObserver(e),t&&e.endUpdate(this)}}function Rt(s){return new oD(void 0,s,void 0,void 0)}function sD(s,e){return new oD(s.debugName,e,void 0,void 0)}function NC(s,e){return new oD(s.debugName,e,s.createEmptyChangeSummary,s.handleChange)}function cc(s){const e=new ie,t=sD({debugName:()=>lh(s)||"(anonymous)"},i=>{e.clear(),s(i,e)});return Fe(()=>{t.dispose(),e.dispose()})}class oD{get debugName(){if(typeof this._debugName=="string")return this._debugName;if(typeof this._debugName=="function"){const t=this._debugName();if(t!==void 0)return t}const e=lh(this._runFn);return e!==void 0?e:"(anonymous)"}constructor(e,t,i,n){var o,r;this._debugName=e,this._runFn=t,this.createChangeSummary=i,this._handleChange=n,this.state=2,this.updateCount=0,this.disposed=!1,this.dependencies=new Set,this.dependenciesToBeRemoved=new Set,this.changeSummary=(o=this.createChangeSummary)===null||o===void 0?void 0:o.call(this),(r=zl())===null||r===void 0||r.handleAutorunCreated(this),this._runIfNeeded()}dispose(){this.disposed=!0;for(const e of this.dependencies)e.removeObserver(this);this.dependencies.clear()}_runIfNeeded(){var e,t,i;if(this.state===3)return;const n=this.dependenciesToBeRemoved;this.dependenciesToBeRemoved=this.dependencies,this.dependencies=n,this.state=3;const o=this.disposed;try{if(!o){(e=zl())===null||e===void 0||e.handleAutorunTriggered(this);const r=this.changeSummary;this.changeSummary=(t=this.createChangeSummary)===null||t===void 0?void 0:t.call(this),this._runFn(this,r)}}finally{o||(i=zl())===null||i===void 0||i.handleAutorunFinished(this);for(const r of this.dependenciesToBeRemoved)r.removeObserver(this);this.dependenciesToBeRemoved.clear()}}toString(){return`Autorun<${this.debugName}>`}beginUpdate(){this.state===3&&(this.state=1),this.updateCount++}endUpdate(){if(this.updateCount===1)do{if(this.state===1){this.state=3;for(const e of this.dependencies)if(e.reportChanges(),this.state===2)break}this._runIfNeeded()}while(this.state!==3);this.updateCount--,I0(()=>this.updateCount>=0)}handlePossibleChange(e){this.state===3&&this.dependencies.has(e)&&!this.dependenciesToBeRemoved.has(e)&&(this.state=1)}handleChange(e,t){this.dependencies.has(e)&&!this.dependenciesToBeRemoved.has(e)&&(!this._handleChange||this._handleChange({changedObservable:e,change:t,didChange:n=>n===e},this.changeSummary))&&(this.state=2)}readObservable(e){if(this.disposed)return e.get();e.addObserver(this);const t=e.get();return this.dependencies.add(e),this.dependenciesToBeRemoved.delete(e),t}}(function(s){s.Observer=oD})(Rt||(Rt={}));function Ky(s){return new zme(s)}class zme extends BU{constructor(e){super(),this.value=e}get debugName(){return this.toString()}get(){return this.value}addObserver(e){}removeObserver(e){}toString(){return`Const: ${this.value}`}}function Ume(s,e){return new Promise(t=>{let i=!1,n=!1;const o=s.map(a=>({isFinished:e(a),state:a})),r=Rt(a=>{const{isFinished:l,state:d}=o.read(a);l&&(i?r.dispose():n=!0,t(d))});i=!0,n&&r.dispose()})}function Mi(s,e){return new rg(s,e)}class rg extends EC{constructor(e,t){super(),this.event=e,this._getValue=t,this.hasValue=!1,this.handleEvent=i=>{var n;const o=this._getValue(i),r=this.value,a=!this.hasValue||r!==o;let l=!1;a&&(this.value=o,this.hasValue&&(l=!0,Cb(rg.globalTransaction,d=>{var c;(c=zl())===null||c===void 0||c.handleFromEventObservableTriggered(this,{oldValue:r,newValue:o,change:void 0,didChange:a,hadValue:this.hasValue});for(const u of this.observers)d.updateObserver(u,this),u.handleChange(this,void 0)},()=>{const d=this.getDebugName();return"Event fired"+(d?`: ${d}`:"")})),this.hasValue=!0),l||(n=zl())===null||n===void 0||n.handleFromEventObservableTriggered(this,{oldValue:r,newValue:o,change:void 0,didChange:a,hadValue:this.hasValue})}}getDebugName(){return lh(this._getValue)}get debugName(){const e=this.getDebugName();return"From Event"+(e?`: ${e}`:"")}onFirstObserverAdded(){this.subscription=this.event(this.handleEvent)}onLastObserverRemoved(){this.subscription.dispose(),this.subscription=void 0,this.hasValue=!1,this.value=void 0}get(){return this.subscription?(this.hasValue||this.handleEvent(void 0),this.value):this._getValue(void 0)}}(function(s){s.Observer=rg;function e(t,i){let n=!1;rg.globalTransaction===void 0&&(rg.globalTransaction=t,n=!0);try{i()}finally{n&&(rg.globalTransaction=void 0)}}s.batchEventsGlobally=e})(Mi||(Mi={}));function Ko(s,e){return new $me(s,e)}class $me extends EC{constructor(e,t){super(),this.debugName=e,this.event=t,this.handleEvent=()=>{mi(i=>{for(const n of this.observers)i.updateObserver(n,this),n.handleChange(this,void 0)},()=>this.debugName)}}onFirstObserverAdded(){this.subscription=this.event(this.handleEvent)}onLastObserverRemoved(){this.subscription.dispose(),this.subscription=void 0}get(){}}function BO(s){return typeof s=="string"?new K9(s):new K9(void 0,s)}class K9 extends EC{get debugName(){var e;return(e=FO(this,this._debugName,void 0,this._owner,this))!==null&&e!==void 0?e:"Observable Signal"}constructor(e,t){super(),this._debugName=e,this._owner=t}trigger(e,t){if(!e){mi(i=>{this.trigger(i,t)},()=>`Trigger signal ${this.debugName}`);return}for(const i of this.observers)e.updateObserver(i,this),i.handleChange(this,t)}get(){}}function TC(s,e){const t=new jme(!0,e);return s.addObserver(t),e?e(s.get()):s.reportChanges(),Fe(()=>{s.removeObserver(t)})}Pme(TC);class jme{constructor(e,t){this._forceRecompute=e,this._handleValue=t,this._counter=0}beginUpdate(e){this._counter++}endUpdate(e){this._counter--,this._counter===0&&this._forceRecompute&&(this._handleValue?this._handleValue(e.get()):e.reportChanges())}handlePossibleChange(e){}handleChange(e,t){}}function Kme(s){let e;return nt(i=>(e=s(i,e),e))}class $a{static capture(e){if(e.getScrollTop()===0||e.hasPendingScrollAnimation())return new $a(e.getScrollTop(),e.getContentHeight(),null,0,null);let t=null,i=0;const n=e.getVisibleRanges();if(n.length>0){t=n[0].getStartPosition();const o=e.getTopForPosition(t.lineNumber,t.column);i=e.getScrollTop()-o}return new $a(e.getScrollTop(),e.getContentHeight(),t,i,e.getPosition())}constructor(e,t,i,n,o){this._initialScrollTop=e,this._initialContentHeight=t,this._visiblePosition=i,this._visiblePositionScrollDelta=n,this._cursorPosition=o}restore(e){if(!(this._initialContentHeight===e.getContentHeight()&&this._initialScrollTop===e.getScrollTop())&&this._visiblePosition){const t=e.getTopForPosition(this._visiblePosition.lineNumber,this._visiblePosition.column);e.setScrollTop(t+this._visiblePositionScrollDelta)}}restoreRelativeVerticalPositionOfCursor(e){if(this._initialContentHeight===e.getContentHeight()&&this._initialScrollTop===e.getScrollTop())return;const t=e.getPosition();if(!this._cursorPosition||!t)return;const i=e.getTopForLineNumber(t.lineNumber)-e.getTopForLineNumber(this._cursorPosition.lineNumber);e.setScrollTop(e.getScrollTop()+i)}}function WO(){return kS&&!!kS.VSCODE_DEV}function WU(s){if(WO()){const e=qme();return e.add(s),{dispose(){e.delete(s)}}}else return{dispose(){}}}function qme(){$1||($1=new Set);const s=globalThis;return s.$hotReload_applyNewExports||(s.$hotReload_applyNewExports=e=>{for(const t of $1){const i=t(e);if(i)return i}}),$1}let $1;WO()&&WU(({oldExports:s,newSrc:e})=>{if(e.indexOf("/* hot-reload:patch-prototype-methods */")!==-1)return t=>{var i,n;for(const o in t){const r=t[o];if(console.log(`[hot-reload] Patching prototype methods of '${o}'`,{exportedItem:r}),typeof r=="function"&&r.prototype){const a=s[o];if(a){for(const l of Object.getOwnPropertyNames(r.prototype)){const d=Object.getOwnPropertyDescriptor(r.prototype,l),c=Object.getOwnPropertyDescriptor(a.prototype,l);((i=d==null?void 0:d.value)===null||i===void 0?void 0:i.toString())!==((n=c==null?void 0:c.value)===null||n===void 0?void 0:n.toString())&&console.log(`[hot-reload] Patching prototype method '${o}.${l}'`),Object.defineProperty(a.prototype,l,d)}t[o]=a}}}return!0}});function Gme(s,e,t,i){if(s.length===0)return e;if(e.length===0)return s;const n=[];let o=0,r=0;for(;o<s.length&&r<e.length;){const a=s[o],l=e[r],d=t(a),c=t(l);d<c?(n.push(a),o++):d>c?(n.push(l),r++):(n.push(i(a,l)),o++,r++)}for(;o<s.length;)n.push(s[o]),o++;for(;r<e.length;)n.push(e[r]),r++;return n}function qy(s,e){const t=new ie,i=s.createDecorationsCollection();return t.add(sD({debugName:()=>`Apply decorations from ${e.debugName}`},n=>{const o=e.read(n);i.set(o)})),t.add({dispose:()=>{i.clear()}}),t}function j1(s,e){return s.appendChild(e),Fe(()=>{s.removeChild(e)})}class VU extends j{get width(){return this._width}get height(){return this._height}constructor(e,t){super(),this.elementSizeObserver=this._register(new nH(e,t)),this._width=kt(this,this.elementSizeObserver.getWidth()),this._height=kt(this,this.elementSizeObserver.getHeight()),this._register(this.elementSizeObserver.onDidChange(i=>mi(n=>{this._width.set(this.elementSizeObserver.getWidth(),n),this._height.set(this.elementSizeObserver.getHeight(),n)})))}observe(e){this.elementSizeObserver.observe(e)}setAutomaticLayout(e){e?this.elementSizeObserver.startObserving():this.elementSizeObserver.stopObserving()}}function q9(s,e,t){let i=e.get(),n=i,o=i;const r=kt("animatedValue",i);let a=-1;const l=300;let d;t.add(NC({createEmptyChangeSummary:()=>({animate:!1}),handleChange:(u,h)=>(u.didChange(e)&&(h.animate=h.animate||u.change),!0)},(u,h)=>{d!==void 0&&(s.cancelAnimationFrame(d),d=void 0),n=o,i=e.read(u),a=Date.now()-(h.animate?0:l),c()}));function c(){const u=Date.now()-a;o=Math.floor(Zme(u,n,i-n,l)),u<l?d=s.requestAnimationFrame(c):o=i,r.set(o,void 0)}return r}function Zme(s,e,t,i){return s===i?e+t:t*(-Math.pow(2,-10*s/i)+1)+e}class HU extends j{constructor(e,t,i){super(),this._register(new rD(e,i)),this._register(pu(i,{height:t.actualHeight,top:t.actualTop}))}}class Gy{get afterLineNumber(){return this._afterLineNumber.get()}constructor(e,t){this._afterLineNumber=e,this.heightInPx=t,this.domNode=document.createElement("div"),this._actualTop=kt(this,void 0),this._actualHeight=kt(this,void 0),this.actualTop=this._actualTop,this.actualHeight=this._actualHeight,this.showInHiddenAreas=!0,this.onChange=this._afterLineNumber,this.onDomNodeTop=i=>{this._actualTop.set(i,void 0)},this.onComputedHeight=i=>{this._actualHeight.set(i,void 0)}}}class rD{constructor(e,t){this._editor=e,this._domElement=t,this._overlayWidgetId=`managedOverlayWidget-${rD._counter++}`,this._overlayWidget={getId:()=>this._overlayWidgetId,getDomNode:()=>this._domElement,getPosition:()=>null},this._editor.addOverlayWidget(this._overlayWidget)}dispose(){this._editor.removeOverlayWidget(this._overlayWidget)}}rD._counter=0;function pu(s,e){return Rt(t=>{for(let[i,n]of Object.entries(e))n&&typeof n=="object"&&"read"in n&&(n=n.read(t)),typeof n=="number"&&(n=`${n}px`),i=i.replace(/[A-Z]/g,o=>"-"+o.toLowerCase()),s.style[i]=n})}function fl(s,e){return Yme([s],e),s}function Yme(s,e){WO()&&Ko("reload",i=>WU(({oldExports:n})=>{if([...Object.values(n)].some(o=>s.includes(o)))return o=>(i(void 0),!0)})).read(e)}function Zy(s,e,t,i){const n=new ie,o=[];return n.add(cc((r,a)=>{const l=e.read(r),d=new Map,c=new Map;t&&t(!0),s.changeViewZones(u=>{for(const h of o)u.removeZone(h),i==null||i.delete(h);o.length=0;for(const h of l){const g=u.addZone(h);h.setZoneId&&h.setZoneId(g),o.push(g),i==null||i.add(g),d.set(h,g)}}),t&&t(!1),a.add(NC({createEmptyChangeSummary(){return{zoneIds:[]}},handleChange(u,h){const g=c.get(u.changedObservable);return g!==void 0&&h.zoneIds.push(g),!0}},(u,h)=>{for(const g of l)g.onChange&&(c.set(g.onChange,d.get(g)),g.onChange.read(u));t&&t(!0),s.changeViewZones(g=>{for(const f of h.zoneIds)g.layoutZone(f)}),t&&t(!1)}))})),n.add({dispose(){t&&t(!0),s.changeViewZones(r=>{for(const a of o)r.removeZone(a)}),i==null||i.clear(),t&&t(!1)}}),n}class Xme extends Yi{dispose(){super.dispose(!0)}}function G9(s,e){const t=R0(e,n=>n.original.startLineNumber<=s.lineNumber);if(!t)return D.fromPositions(s);if(t.original.endLineNumberExclusive<=s.lineNumber){const n=s.lineNumber-t.original.endLineNumberExclusive+t.modified.endLineNumberExclusive;return D.fromPositions(new H(n,s.column))}if(!t.innerChanges)return D.fromPositions(new H(t.modified.startLineNumber,1));const i=R0(t.innerChanges,n=>n.originalRange.getStartPosition().isBeforeOrEqual(s));if(!i){const n=s.lineNumber-t.original.startLineNumber+t.modified.startLineNumber;return D.fromPositions(new H(n,s.column))}if(i.originalRange.containsPosition(s))return i.modifiedRange;{const n=Qme(i.originalRange.getEndPosition(),s);return D.fromPositions(Jme(i.modifiedRange.getEndPosition(),n))}}function Qme(s,e){return s.lineNumber===e.lineNumber?new X0(0,e.column-s.column):new X0(e.lineNumber-s.lineNumber,e.column-1)}function Jme(s,e){return e.lineCount===0?new H(s.lineNumber,s.column+e.columnCount):new H(s.lineNumber+e.lineCount,e.columnCount+1)}function K1(s,e,t){const i=s.bindTo(e);return sD({debugName:()=>`Update ${s.key}`},n=>{i.set(t(n))})}var VO=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},HO=function(s,e){return function(t,i){e(t,i,s)}};const e_e=Ui("diff-review-insert",le.add,p("accessibleDiffViewerInsertIcon","Icon for 'Insert' in accessible diff viewer.")),t_e=Ui("diff-review-remove",le.remove,p("accessibleDiffViewerRemoveIcon","Icon for 'Remove' in accessible diff viewer.")),i_e=Ui("diff-review-close",le.close,p("accessibleDiffViewerCloseIcon","Icon for 'Close' in accessible diff viewer."));let Yc=class extends j{constructor(e,t,i,n,o,r,a,l,d){super(),this._parentNode=e,this._visible=t,this._setVisible=i,this._canClose=n,this._width=o,this._height=r,this._diffs=a,this._editors=l,this._instantiationService=d,this._state=g_(this,(c,u)=>{const h=this._visible.read(c);if(this._parentNode.style.visibility=h?"visible":"hidden",!h)return null;const g=u.add(this._instantiationService.createInstance(Q2,this._diffs,this._editors,this._setVisible,this._canClose)),f=u.add(this._instantiationService.createInstance(J2,this._parentNode,g,this._width,this._height,this._editors));return{model:g,view:f}}).recomputeInitiallyAndOnChange(this._store)}next(){mi(e=>{const t=this._visible.get();this._setVisible(!0,e),t&&this._state.get().model.nextGroup(e)})}prev(){mi(e=>{this._setVisible(!0,e),this._state.get().model.previousGroup(e)})}close(){mi(e=>{this._setVisible(!1,e)})}};Yc._ttPolicy=oc("diffReview",{createHTML:s=>s});Yc=VO([HO(8,We)],Yc);let Q2=class extends j{constructor(e,t,i,n,o){super(),this._diffs=e,this._editors=t,this._setVisible=i,this.canClose=n,this._audioCueService=o,this._groups=kt(this,[]),this._currentGroupIdx=kt(this,0),this._currentElementIdx=kt(this,0),this.groups=this._groups,this.currentGroup=this._currentGroupIdx.map((r,a)=>this._groups.read(a)[r]),this.currentGroupIndex=this._currentGroupIdx,this.currentElement=this._currentElementIdx.map((r,a)=>{var l;return(l=this.currentGroup.read(a))===null||l===void 0?void 0:l.lines[r]}),this._register(Rt(r=>{const a=this._diffs.read(r);if(!a){this._groups.set([],void 0);return}const l=n_e(a,this._editors.original.getModel().getLineCount(),this._editors.modified.getModel().getLineCount());mi(d=>{const c=this._editors.modified.getPosition();if(c){const u=l.findIndex(h=>(c==null?void 0:c.lineNumber)<h.range.modified.endLineNumberExclusive);u!==-1&&this._currentGroupIdx.set(u,d)}this._groups.set(l,d)})})),this._register(Rt(r=>{const a=this.currentElement.read(r);(a==null?void 0:a.type)===Is.Deleted?this._audioCueService.playAudioCue(at.diffLineDeleted,{source:"accessibleDiffViewer.currentElementChanged"}):(a==null?void 0:a.type)===Is.Added&&this._audioCueService.playAudioCue(at.diffLineInserted,{source:"accessibleDiffViewer.currentElementChanged"})})),this._register(Rt(r=>{var a;const l=this.currentElement.read(r);if(l&&l.type!==Is.Header){const d=(a=l.modifiedLineNumber)!==null&&a!==void 0?a:l.diff.modified.startLineNumber;this._editors.modified.setSelection(D.fromPositions(new H(d,1)))}}))}_goToGroupDelta(e,t){const i=this.groups.get();!i||i.length<=1||Cb(t,n=>{this._currentGroupIdx.set(rt.ofLength(i.length).clipCyclic(this._currentGroupIdx.get()+e),n),this._currentElementIdx.set(0,n)})}nextGroup(e){this._goToGroupDelta(1,e)}previousGroup(e){this._goToGroupDelta(-1,e)}_goToLineDelta(e){const t=this.currentGroup.get();!t||t.lines.length<=1||mi(i=>{this._currentElementIdx.set(rt.ofLength(t.lines.length).clip(this._currentElementIdx.get()+e),i)})}goToNextLine(){this._goToLineDelta(1)}goToPreviousLine(){this._goToLineDelta(-1)}goToLine(e){const t=this.currentGroup.get();if(!t)return;const i=t.lines.indexOf(e);i!==-1&&mi(n=>{this._currentElementIdx.set(i,n)})}revealCurrentElementInEditor(){this._setVisible(!1,void 0);const e=this.currentElement.get();e&&(e.type===Is.Deleted?(this._editors.original.setSelection(D.fromPositions(new H(e.originalLineNumber,1))),this._editors.original.revealLine(e.originalLineNumber),this._editors.original.focus()):(e.type!==Is.Header&&(this._editors.modified.setSelection(D.fromPositions(new H(e.modifiedLineNumber,1))),this._editors.modified.revealLine(e.modifiedLineNumber)),this._editors.modified.focus()))}close(){this._setVisible(!1,void 0),this._editors.modified.focus()}};Q2=VO([HO(4,IC)],Q2);const $_=3;function n_e(s,e,t){const i=[];for(const n of aW(s,(o,r)=>r.modified.startLineNumber-o.modified.endLineNumberExclusive<2*$_)){const o=[];o.push(new o_e);const r=new ft(Math.max(1,n[0].original.startLineNumber-$_),Math.min(n[n.length-1].original.endLineNumberExclusive+$_,e+1)),a=new ft(Math.max(1,n[0].modified.startLineNumber-$_),Math.min(n[n.length-1].modified.endLineNumberExclusive+$_,t+1));lW(n,(c,u)=>{const h=new ft(c?c.original.endLineNumberExclusive:r.startLineNumber,u?u.original.startLineNumber:r.endLineNumberExclusive),g=new ft(c?c.modified.endLineNumberExclusive:a.startLineNumber,u?u.modified.startLineNumber:a.endLineNumberExclusive);h.forEach(f=>{o.push(new l_e(f,g.startLineNumber+(f-h.startLineNumber)))}),u&&(u.original.forEach(f=>{o.push(new r_e(u,f))}),u.modified.forEach(f=>{o.push(new a_e(u,f))}))});const l=n[0].modified.join(n[n.length-1].modified),d=n[0].original.join(n[n.length-1].original);i.push(new s_e(new Gl(l,d),o))}return i}var Is;(function(s){s[s.Header=0]="Header",s[s.Unchanged=1]="Unchanged",s[s.Deleted=2]="Deleted",s[s.Added=3]="Added"})(Is||(Is={}));class s_e{constructor(e,t){this.range=e,this.lines=t}}class o_e{constructor(){this.type=Is.Header}}class r_e{constructor(e,t){this.diff=e,this.originalLineNumber=t,this.type=Is.Deleted,this.modifiedLineNumber=void 0}}class a_e{constructor(e,t){this.diff=e,this.modifiedLineNumber=t,this.type=Is.Added,this.originalLineNumber=void 0}}class l_e{constructor(e,t){this.originalLineNumber=e,this.modifiedLineNumber=t,this.type=Is.Unchanged}}let J2=class extends j{constructor(e,t,i,n,o,r){super(),this._element=e,this._model=t,this._width=i,this._height=n,this._editors=o,this._languageService=r,this.domNode=this._element,this.domNode.className="diff-review monaco-editor-background";const a=document.createElement("div");a.className="diff-review-actions",this._actionBar=this._register(new Ir(a)),this._register(Rt(l=>{this._actionBar.clear(),this._model.canClose.read(l)&&this._actionBar.push(new Os("diffreview.close",p("label.close","Close"),"close-diff-review "+Oe.asClassName(i_e),!0,async()=>t.close()),{label:!1,icon:!0})})),this._content=document.createElement("div"),this._content.className="diff-review-content",this._content.setAttribute("role","code"),this._scrollbar=this._register(new hC(this._content,{})),Qn(this.domNode,this._scrollbar.getDomNode(),a),this._register(Fe(()=>{Qn(this.domNode)})),this._register(pu(this.domNode,{width:this._width,height:this._height})),this._register(pu(this._content,{width:this._width,height:this._height})),this._register(cc((l,d)=>{this._model.currentGroup.read(l),this._render(d)})),this._register(Pi(this.domNode,"keydown",l=>{(l.equals(18)||l.equals(2066)||l.equals(530))&&(l.preventDefault(),this._model.goToNextLine()),(l.equals(16)||l.equals(2064)||l.equals(528))&&(l.preventDefault(),this._model.goToPreviousLine()),(l.equals(9)||l.equals(2057)||l.equals(521)||l.equals(1033))&&(l.preventDefault(),this._model.close()),(l.equals(10)||l.equals(3))&&(l.preventDefault(),this._model.revealCurrentElementInEditor())}))}_render(e){const t=this._editors.original.getOptions(),i=this._editors.modified.getOptions(),n=document.createElement("div");n.className="diff-review-table",n.setAttribute("role","list"),n.setAttribute("aria-label",p("ariaLabel","Accessible Diff Viewer. Use arrow up and down to navigate.")),Xn(n,i.get(50)),Qn(this._content,n);const o=this._editors.original.getModel(),r=this._editors.modified.getModel();if(!o||!r)return;const a=o.getOptions(),l=r.getOptions(),d=i.get(66),c=this._model.currentGroup.get();for(const u of(c==null?void 0:c.lines)||[]){if(!c)break;let h;if(u.type===Is.Header){const f=document.createElement("div");f.className="diff-review-row",f.setAttribute("role","listitem");const m=c.range,_=this._model.currentGroupIndex.get(),v=this._model.groups.get().length,b=x=>x===0?p("no_lines_changed","no lines changed"):x===1?p("one_line_changed","1 line changed"):p("more_lines_changed","{0} lines changed",x),C=b(m.original.length),w=b(m.modified.length);f.setAttribute("aria-label",p({key:"header",comment:["This is the ARIA label for a git diff header.","A git diff header looks like this: @@ -154,12 +159,39 @@.","That encodes that at original line 154 (which is now line 159), 12 lines were removed/changed with 39 lines.","Variables 0 and 1 refer to the diff index out of total number of diffs.","Variables 2 and 4 will be numbers (a line number).",'Variables 3 and 5 will be "no lines changed", "1 line changed" or "X lines changed", localized separately.']},"Difference {0} of {1}: original line {2}, {3}, modified line {4}, {5}",_+1,v,m.original.startLineNumber,C,m.modified.startLineNumber,w));const S=document.createElement("div");S.className="diff-review-cell diff-review-summary",S.appendChild(document.createTextNode(`${_+1}/${v}: @@ -${m.original.startLineNumber},${m.original.length} +${m.modified.startLineNumber},${m.modified.length} @@`)),f.appendChild(S),h=f}else h=this._createRow(u,d,this._width.get(),t,o,a,i,r,l);n.appendChild(h);const g=nt(f=>this._model.currentElement.read(f)===u);e.add(Rt(f=>{const m=g.read(f);h.tabIndex=m?0:-1,m&&h.focus()})),e.add(Y(h,"focus",()=>{this._model.goToLine(u)}))}this._scrollbar.scanDomNode()}_createRow(e,t,i,n,o,r,a,l,d){const c=n.get(143),u=c.glyphMarginWidth+c.lineNumbersWidth,h=a.get(143),g=10+h.glyphMarginWidth+h.lineNumbersWidth;let f="diff-review-row",m="";const _="diff-review-spacer";let v=null;switch(e.type){case Is.Added:f="diff-review-row line-insert",m=" char-insert",v=e_e;break;case Is.Deleted:f="diff-review-row line-delete",m=" char-delete",v=t_e;break}const b=document.createElement("div");b.style.minWidth=i+"px",b.className=f,b.setAttribute("role","listitem"),b.ariaLevel="";const C=document.createElement("div");C.className="diff-review-cell",C.style.height=`${t}px`,b.appendChild(C);const w=document.createElement("span");w.style.width=u+"px",w.style.minWidth=u+"px",w.className="diff-review-line-number"+m,e.originalLineNumber!==void 0?w.appendChild(document.createTextNode(String(e.originalLineNumber))):w.innerText=" ",C.appendChild(w);const S=document.createElement("span");S.style.width=g+"px",S.style.minWidth=g+"px",S.style.paddingRight="10px",S.className="diff-review-line-number"+m,e.modifiedLineNumber!==void 0?S.appendChild(document.createTextNode(String(e.modifiedLineNumber))):S.innerText=" ",C.appendChild(S);const x=document.createElement("span");if(x.className=_,v){const I=document.createElement("span");I.className=Oe.asClassName(v),I.innerText="  ",x.appendChild(I)}else x.innerText="  ";C.appendChild(x);let L;if(e.modifiedLineNumber!==void 0){let I=this._getLineHtml(l,a,d.tabSize,e.modifiedLineNumber,this._languageService.languageIdCodec);Yc._ttPolicy&&(I=Yc._ttPolicy.createHTML(I)),C.insertAdjacentHTML("beforeend",I),L=l.getLineContent(e.modifiedLineNumber)}else{let I=this._getLineHtml(o,n,r.tabSize,e.originalLineNumber,this._languageService.languageIdCodec);Yc._ttPolicy&&(I=Yc._ttPolicy.createHTML(I)),C.insertAdjacentHTML("beforeend",I),L=o.getLineContent(e.originalLineNumber)}L.length===0&&(L=p("blankLine","blank"));let k="";switch(e.type){case Is.Unchanged:e.originalLineNumber===e.modifiedLineNumber?k=p({key:"unchangedLine",comment:["The placeholders are contents of the line and should not be translated."]},"{0} unchanged line {1}",L,e.originalLineNumber):k=p("equalLine","{0} original line {1} modified line {2}",L,e.originalLineNumber,e.modifiedLineNumber);break;case Is.Added:k=p("insertLine","+ {0} modified line {1}",L,e.modifiedLineNumber);break;case Is.Deleted:k=p("deleteLine","- {0} original line {1}",L,e.originalLineNumber);break}return b.setAttribute("aria-label",k),b}_getLineHtml(e,t,i,n,o){const r=e.getLineContent(n),a=t.get(50),l=vn.createEmpty(r,o),d=sr.isBasicASCII(r,e.mightContainNonBasicASCII()),c=sr.containsRTL(r,d,e.mightContainRTL());return vx(new sh(a.isMonospace&&!t.get(33),a.canUseHalfwidthRightwardsArrow,r,!1,d,c,0,l,[],i,0,a.spaceWidth,a.middotWidth,a.wsmiddotWidth,t.get(116),t.get(98),t.get(93),t.get(51)!==$o.OFF,null)).html}};J2=VO([HO(5,fi)],J2);const d_e=Ui("diff-insert",le.add,p("diffInsertIcon","Line decoration for inserts in the diff editor.")),zU=Ui("diff-remove",le.remove,p("diffRemoveIcon","Line decoration for removals in the diff editor.")),Z9=tt.register({className:"line-insert",description:"line-insert",isWholeLine:!0,linesDecorationsClassName:"insert-sign "+Oe.asClassName(d_e),marginClassName:"gutter-insert"}),Y9=tt.register({className:"line-delete",description:"line-delete",isWholeLine:!0,linesDecorationsClassName:"delete-sign "+Oe.asClassName(zU),marginClassName:"gutter-delete"}),X9=tt.register({className:"line-insert",description:"line-insert",isWholeLine:!0,marginClassName:"gutter-insert"}),Q9=tt.register({className:"line-delete",description:"line-delete",isWholeLine:!0,marginClassName:"gutter-delete"}),J9=tt.register({className:"char-insert",description:"char-insert",shouldFillLineOnLineBreak:!0}),c_e=tt.register({className:"char-insert",description:"char-insert",isWholeLine:!0}),u_e=tt.register({className:"char-insert diff-range-empty",description:"char-insert diff-range-empty"}),eM=tt.register({className:"char-delete",description:"char-delete",shouldFillLineOnLineBreak:!0}),h_e=tt.register({className:"char-delete",description:"char-delete",isWholeLine:!0}),g_e=tt.register({className:"char-delete diff-range-empty",description:"char-delete diff-range-empty"});class mu extends j{constructor(e,t,i,n,o){super(),this._rootElement=e,this._diffModel=t,this._originalEditorLayoutInfo=i,this._modifiedEditorLayoutInfo=n,this._editors=o,this._originalScrollTop=Mi(this._editors.original.onDidScrollChange,()=>this._editors.original.getScrollTop()),this._modifiedScrollTop=Mi(this._editors.modified.onDidScrollChange,()=>this._editors.modified.getScrollTop()),this._viewZonesChanged=Ko("onDidChangeViewZones",this._editors.modified.onDidChangeViewZones),this.width=kt(this,0),this._modifiedViewZonesChangedSignal=Ko("modified.onDidChangeViewZones",this._editors.modified.onDidChangeViewZones),this._originalViewZonesChangedSignal=Ko("original.onDidChangeViewZones",this._editors.original.onDidChangeViewZones),this._state=g_(this,(h,g)=>{var f;this._element.replaceChildren();const m=this._diffModel.read(h),_=(f=m==null?void 0:m.diff.read(h))===null||f===void 0?void 0:f.movedTexts;if(!_||_.length===0){this.width.set(0,void 0);return}this._viewZonesChanged.read(h);const v=this._originalEditorLayoutInfo.read(h),b=this._modifiedEditorLayoutInfo.read(h);if(!v||!b){this.width.set(0,void 0);return}this._modifiedViewZonesChangedSignal.read(h),this._originalViewZonesChangedSignal.read(h);const C=_.map(P=>{function $(Be,Ve){const Ie=Ve.getTopForLineNumber(Be.startLineNumber,!0),pe=Ve.getTopForLineNumber(Be.endLineNumberExclusive,!0);return(Ie+pe)/2}const A=$(P.lineRangeMapping.original,this._editors.original),z=this._originalScrollTop.read(h),K=$(P.lineRangeMapping.modified,this._editors.modified),Q=this._modifiedScrollTop.read(h),ne=A-z,fe=K-Q,ve=Math.min(A,K),ye=Math.max(A,K);return{range:new rt(ve,ye),from:ne,to:fe,fromWithoutScroll:A,toWithoutScroll:K,move:P}});C.sort(iX(br(P=>P.fromWithoutScroll>P.toWithoutScroll,nX),br(P=>P.fromWithoutScroll>P.toWithoutScroll?P.fromWithoutScroll:-P.toWithoutScroll,Ud)));const w=zO.compute(C.map(P=>P.range)),S=10,x=v.verticalScrollbarWidth,L=(w.getTrackCount()-1)*10+S*2,k=x+L+(b.contentLeft-mu.movedCodeBlockPadding);let I=0;for(const P of C){const $=w.getTrack(I),A=x+S+$*10,z=15,K=15,Q=k,ne=b.glyphMarginWidth+b.lineNumbersWidth,fe=18,ve=document.createElementNS("http://www.w3.org/2000/svg","rect");ve.classList.add("arrow-rectangle"),ve.setAttribute("x",`${Q-ne}`),ve.setAttribute("y",`${P.to-fe/2}`),ve.setAttribute("width",`${ne}`),ve.setAttribute("height",`${fe}`),this._element.appendChild(ve);const ye=document.createElementNS("http://www.w3.org/2000/svg","g"),Be=document.createElementNS("http://www.w3.org/2000/svg","path");Be.setAttribute("d",`M 0 ${P.from} L ${A} ${P.from} L ${A} ${P.to} L ${Q-K} ${P.to}`),Be.setAttribute("fill","none"),ye.appendChild(Be);const Ve=document.createElementNS("http://www.w3.org/2000/svg","polygon");Ve.classList.add("arrow"),g.add(Rt(Ie=>{Be.classList.toggle("currentMove",P.move===m.activeMovedText.read(Ie)),Ve.classList.toggle("currentMove",P.move===m.activeMovedText.read(Ie))})),Ve.setAttribute("points",`${Q-K},${P.to-z/2} ${Q},${P.to} ${Q-K},${P.to+z/2}`),ye.appendChild(Ve),this._element.appendChild(ye),I++}this.width.set(L,void 0)}),this._element=document.createElementNS("http://www.w3.org/2000/svg","svg"),this._element.setAttribute("class","moved-blocks-lines"),this._rootElement.appendChild(this._element),this._register(Fe(()=>this._element.remove())),this._register(Rt(h=>{const g=this._originalEditorLayoutInfo.read(h),f=this._modifiedEditorLayoutInfo.read(h);!g||!f||(this._element.style.left=`${g.width-g.verticalScrollbarWidth}px`,this._element.style.height=`${g.height}px`,this._element.style.width=`${g.verticalScrollbarWidth+g.contentLeft-mu.movedCodeBlockPadding+this.width.read(h)}px`)})),this._register(TC(this._state));const r=nt(h=>{const g=this._diffModel.read(h),f=g==null?void 0:g.diff.read(h);return f?f.movedTexts.map(m=>({move:m,original:new Gy(Ky(m.lineRangeMapping.original.startLineNumber-1),18),modified:new Gy(Ky(m.lineRangeMapping.modified.startLineNumber-1),18)})):[]});this._register(Zy(this._editors.original,r.map(h=>h.map(g=>g.original)))),this._register(Zy(this._editors.modified,r.map(h=>h.map(g=>g.modified)))),this._register(cc((h,g)=>{const f=r.read(h);for(const m of f)g.add(new e8(this._editors.original,m.original,m.move,"original",this._diffModel.get())),g.add(new e8(this._editors.modified,m.modified,m.move,"modified",this._diffModel.get()))}));const a=Mi(this._editors.original.onDidChangeCursorPosition,()=>this._editors.original.getPosition()),l=Mi(this._editors.modified.onDidChangeCursorPosition,()=>this._editors.modified.getPosition()),d=Ko("original.onDidFocusEditorWidget",h=>this._editors.original.onDidFocusEditorWidget(()=>setTimeout(()=>h(void 0),0))),c=Ko("modified.onDidFocusEditorWidget",h=>this._editors.modified.onDidFocusEditorWidget(()=>setTimeout(()=>h(void 0),0)));let u="modified";this._register(NC({createEmptyChangeSummary:()=>{},handleChange:(h,g)=>(h.didChange(d)&&(u="original"),h.didChange(c)&&(u="modified"),!0)},h=>{d.read(h),c.read(h);const g=this._diffModel.read(h);if(!g)return;const f=g.diff.read(h);let m;if(f&&u==="original"){const _=a.read(h);_&&(m=f.movedTexts.find(v=>v.lineRangeMapping.original.contains(_.lineNumber)))}if(f&&u==="modified"){const _=l.read(h);_&&(m=f.movedTexts.find(v=>v.lineRangeMapping.modified.contains(_.lineNumber)))}m!==g.movedTextToCompare.get()&&g.movedTextToCompare.set(void 0,void 0),g.setActiveMovedText(m)}))}}mu.movedCodeBlockPadding=4;class zO{static compute(e){const t=[],i=[];for(const n of e){let o=t.findIndex(r=>!r.intersectsStrict(n));o===-1&&(t.length>=6?o=Die(t,br(a=>a.intersectWithRangeLength(n),Ud)):(o=t.length,t.push(new rP))),t[o].addRange(n),i.push(o)}return new zO(t.length,i)}constructor(e,t){this._trackCount=e,this.trackPerLineIdx=t}getTrack(e){return this.trackPerLineIdx[e]}getTrackCount(){return this._trackCount}}class e8 extends HU{constructor(e,t,i,n,o){const r=hi("div.diff-hidden-lines-widget");super(e,t,r.root),this._editor=e,this._move=i,this._kind=n,this._diffModel=o,this._nodes=hi("div.diff-moved-code-block",{style:{marginRight:"4px"}},[hi("div.text-content@textContent"),hi("div.action-bar@actionBar")]),r.root.appendChild(this._nodes.root);const a=Mi(this._editor.onDidLayoutChange,()=>this._editor.getLayoutInfo());this._register(pu(this._nodes.root,{paddingRight:a.map(h=>h.verticalScrollbarWidth)}));let l;i.changes.length>0?l=this._kind==="original"?p("codeMovedToWithChanges","Code moved with changes to line {0}-{1}",this._move.lineRangeMapping.modified.startLineNumber,this._move.lineRangeMapping.modified.endLineNumberExclusive-1):p("codeMovedFromWithChanges","Code moved with changes from line {0}-{1}",this._move.lineRangeMapping.original.startLineNumber,this._move.lineRangeMapping.original.endLineNumberExclusive-1):l=this._kind==="original"?p("codeMovedTo","Code moved to line {0}-{1}",this._move.lineRangeMapping.modified.startLineNumber,this._move.lineRangeMapping.modified.endLineNumberExclusive-1):p("codeMovedFrom","Code moved from line {0}-{1}",this._move.lineRangeMapping.original.startLineNumber,this._move.lineRangeMapping.original.endLineNumberExclusive-1);const d=this._register(new Ir(this._nodes.actionBar,{highlightToggledItems:!0})),c=new Os("",l,"",!1);d.push(c,{icon:!1,label:!0});const u=new Os("","Compare",Oe.asClassName(le.compareChanges),!0,()=>{this._editor.focus(),this._diffModel.movedTextToCompare.set(this._diffModel.movedTextToCompare.get()===i?void 0:this._move,void 0)});this._register(Rt(h=>{const g=this._diffModel.movedTextToCompare.read(h)===i;u.checked=g})),d.push(u,{icon:!1,label:!0})}}class f_e extends j{constructor(e,t,i,n){super(),this._editors=e,this._diffModel=t,this._options=i,this._decorations=nt(this,o=>{var r;const a=(r=this._diffModel.read(o))===null||r===void 0?void 0:r.diff.read(o);if(!a)return null;const l=this._diffModel.read(o).movedTextToCompare.read(o),d=this._options.renderIndicators.read(o),c=this._options.showEmptyDecorations.read(o),u=[],h=[];if(!l)for(const f of a.mappings)if(f.lineRangeMapping.original.isEmpty||u.push({range:f.lineRangeMapping.original.toInclusiveRange(),options:d?Y9:Q9}),f.lineRangeMapping.modified.isEmpty||h.push({range:f.lineRangeMapping.modified.toInclusiveRange(),options:d?Z9:X9}),f.lineRangeMapping.modified.isEmpty||f.lineRangeMapping.original.isEmpty)f.lineRangeMapping.original.isEmpty||u.push({range:f.lineRangeMapping.original.toInclusiveRange(),options:h_e}),f.lineRangeMapping.modified.isEmpty||h.push({range:f.lineRangeMapping.modified.toInclusiveRange(),options:c_e});else for(const m of f.lineRangeMapping.innerChanges||[])f.lineRangeMapping.original.contains(m.originalRange.startLineNumber)&&u.push({range:m.originalRange,options:m.originalRange.isEmpty()&&c?g_e:eM}),f.lineRangeMapping.modified.contains(m.modifiedRange.startLineNumber)&&h.push({range:m.modifiedRange,options:m.modifiedRange.isEmpty()&&c?u_e:J9});if(l)for(const f of l.changes){const m=f.original.toInclusiveRange();m&&u.push({range:m,options:d?Y9:Q9});const _=f.modified.toInclusiveRange();_&&h.push({range:_,options:d?Z9:X9});for(const v of f.innerChanges||[])u.push({range:v.originalRange,options:eM}),h.push({range:v.modifiedRange,options:J9})}const g=this._diffModel.read(o).activeMovedText.read(o);for(const f of a.movedTexts)u.push({range:f.lineRangeMapping.original.toInclusiveRange(),options:{description:"moved",blockClassName:"movedOriginal"+(f===g?" currentMove":""),blockPadding:[mu.movedCodeBlockPadding,0,mu.movedCodeBlockPadding,mu.movedCodeBlockPadding]}}),h.push({range:f.lineRangeMapping.modified.toInclusiveRange(),options:{description:"moved",blockClassName:"movedModified"+(f===g?" currentMove":""),blockPadding:[4,0,4,4]}});return{originalDecorations:u,modifiedDecorations:h}}),this._register(new p_e(e,t,i,n)),this._register(qy(this._editors.original,this._decorations.map(o=>(o==null?void 0:o.originalDecorations)||[]))),this._register(qy(this._editors.modified,this._decorations.map(o=>(o==null?void 0:o.modifiedDecorations)||[])))}}class p_e extends j{constructor(e,t,i,n){super(),this._editors=e,this._diffModel=t,this._options=i,this._widget=n;const o=[],r=nt(this,a=>{const l=this._diffModel.read(a),d=l==null?void 0:l.diff.read(a);if(!d)return o;const c=this._editors.modifiedSelections.read(a);if(c.every(f=>f.isEmpty()))return o;const u=new xa(c.map(f=>ft.fromRangeInclusive(f))),g=d.mappings.filter(f=>f.lineRangeMapping.innerChanges&&u.intersects(f.lineRangeMapping.modified)).map(f=>({mapping:f,rangeMappings:f.lineRangeMapping.innerChanges.filter(m=>c.some(_=>D.areIntersecting(m.modifiedRange,_)))}));return g.length===0||g.every(f=>f.rangeMappings.length===0)?o:g});this._register(cc((a,l)=>{const d=this._diffModel.read(a),c=d==null?void 0:d.diff.read(a);if(!d||!c||this._diffModel.read(a).movedTextToCompare.read(a)||!this._options.shouldRenderRevertArrows.read(a))return;const h=[],g=r.read(a),f=new Set(g.map(m=>m.mapping));if(g.length>0){const m=this._editors.modifiedSelections.read(a),_=new wb(m[m.length-1].positionLineNumber,this._widget,g.flatMap(v=>v.rangeMappings),!0);this._editors.modified.addGlyphMarginWidget(_),h.push(_)}for(const m of c.mappings)if(!f.has(m)&&!m.lineRangeMapping.modified.isEmpty&&m.lineRangeMapping.innerChanges){const _=new wb(m.lineRangeMapping.modified.startLineNumber,this._widget,m.lineRangeMapping.innerChanges,!1);this._editors.modified.addGlyphMarginWidget(_),h.push(_)}l.add(Fe(()=>{for(const m of h)this._editors.modified.removeGlyphMarginWidget(m)}))}))}}class wb{getId(){return this._id}constructor(e,t,i,n){this._lineNumber=e,this._widget=t,this._diffs=i,this._selection=n,this._id=`revertButton${wb.counter++}`,this._domNode=hi("div.revertButton",{title:this._selection?p("revertSelectedChanges","Revert Selected Changes"):p("revertChange","Revert Change")},[Sy(le.arrowRight)]).root,this._domNode.onmousedown=o=>{o.button!==2&&(o.stopPropagation(),o.preventDefault())},this._domNode.onmouseup=o=>{o.stopPropagation(),o.preventDefault()},this._domNode.onclick=o=>{this._widget.revertRangeMappings(this._diffs),o.stopPropagation(),o.preventDefault()}}getDomNode(){return this._domNode}getPosition(){return{lane:fg.Right,range:{startColumn:1,startLineNumber:this._lineNumber,endColumn:1,endLineNumber:this._lineNumber},zIndex:10001}}}wb.counter=0;class m_e extends j{constructor(e,t,i,n){super(),this._options=e,this._domNode=t,this._dimensions=i,this._sashes=n,this._sashRatio=kt(this,void 0),this.sashLeft=nt(this,o=>{var r;const a=(r=this._sashRatio.read(o))!==null&&r!==void 0?r:this._options.splitViewDefaultRatio.read(o);return this._computeSashLeft(a,o)}),this._sash=this._register(new ns(this._domNode,{getVerticalSashTop:o=>0,getVerticalSashLeft:o=>this.sashLeft.get(),getVerticalSashHeight:o=>this._dimensions.height.get()},{orientation:0})),this._startSashPosition=void 0,this._register(this._sash.onDidStart(()=>{this._startSashPosition=this.sashLeft.get()})),this._register(this._sash.onDidChange(o=>{const r=this._dimensions.width.get(),a=this._computeSashLeft((this._startSashPosition+(o.currentX-o.startX))/r,void 0);this._sashRatio.set(a/r,void 0)})),this._register(this._sash.onDidEnd(()=>this._sash.layout())),this._register(this._sash.onDidReset(()=>this._sashRatio.set(void 0,void 0))),this._register(Rt(o=>{const r=this._sashes.read(o);r&&(this._sash.orthogonalEndSash=r.bottom)})),this._register(Rt(o=>{const r=this._options.enableSplitViewResizing.read(o);this._sash.state=r?3:0,this.sashLeft.read(o),this._dimensions.height.read(o),this._sash.layout()}))}_computeSashLeft(e,t){const i=this._dimensions.width.read(t),n=Math.floor(this._options.splitViewDefaultRatio.read(t)*i),o=this._options.enableSplitViewResizing.read(t)?Math.floor(e*i):n,r=100;return i<=r*2?n:o<r?r:o>i-r?i-r:o}}let Sp=class{remove(){var e;(e=this.parent)===null||e===void 0||e.children.delete(this.id)}static findId(e,t){let i;typeof e=="string"?i=`${t.id}/${e}`:(i=`${t.id}/${e.name}`,t.children.get(i)!==void 0&&(i=`${t.id}/${e.name}_${e.range.startLineNumber}_${e.range.startColumn}`));let n=i;for(let o=0;t.children.get(n)!==void 0;o++)n=`${i}_${o}`;return n}static empty(e){return e.children.size===0}},t8=class extends Sp{constructor(e,t,i){super(),this.id=e,this.parent=t,this.symbol=i,this.children=new Map}},__e=class extends Sp{constructor(e,t,i,n){super(),this.id=e,this.parent=t,this.label=i,this.order=n,this.children=new Map}},v_e=class Ph extends Sp{static create(e,t,i){const n=new Yi(i),o=new Ph(t.uri),r=e.ordered(t),a=r.map((d,c)=>{var u;const h=Sp.findId(`provider_${c}`,o),g=new __e(h,o,(u=d.displayName)!==null&&u!==void 0?u:"Unknown Outline Provider",c);return Promise.resolve(d.provideDocumentSymbols(t,n.token)).then(f=>{for(const m of f||[])Ph._makeOutlineElement(m,g);return g},f=>(Zi(f),g)).then(f=>{Sp.empty(f)?f.remove():o._groups.set(h,f)})}),l=e.onDidChange(()=>{const d=e.ordered(t);Ai(d,r)||n.cancel()});return Promise.all(a).then(()=>n.token.isCancellationRequested&&!i.isCancellationRequested?Ph.create(e,t,i):o._compact()).finally(()=>{n.dispose(),l.dispose()})}static _makeOutlineElement(e,t){const i=Sp.findId(e,t),n=new t8(i,t,e);if(e.children)for(const o of e.children)Ph._makeOutlineElement(o,n);t.children.set(n.id,n)}constructor(e){super(),this.uri=e,this.id="root",this.parent=void 0,this._groups=new Map,this.children=new Map,this.id="root",this.parent=void 0}_compact(){let e=0;for(const[t,i]of this._groups)i.children.size===0?this._groups.delete(t):e+=1;if(e!==1)this.children=this._groups;else{const t=ht.first(this._groups.values());for(const[,i]of t.children)i.parent=this,this.children.set(i.id,i)}return this}getTopLevelSymbols(){const e=[];for(const t of this.children.values())t instanceof t8?e.push(t.symbol):e.push(...ht.map(t.children.values(),i=>i.symbol));return e.sort((t,i)=>D.compareRangesUsingStarts(t.range,i.range))}asListOfDocumentSymbols(){const e=this.getTopLevelSymbols(),t=[];return Ph._flattenDocumentSymbols(t,e,""),t.sort((i,n)=>H.compare(D.getStartPosition(i.range),D.getStartPosition(n.range))||H.compare(D.getEndPosition(n.range),D.getEndPosition(i.range)))}static _flattenDocumentSymbols(e,t,i){for(const n of t)e.push({kind:n.kind,tags:n.tags,name:n.name,detail:n.detail,containerName:n.containerName||i,range:n.range,selectionRange:n.selectionRange,children:void 0}),n.children&&Ph._flattenDocumentSymbols(e,n.children,n.name)}};var UU=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},$U=function(s,e){return function(t,i){e(t,i,s)}};let tM=class extends j{get isUpdatingHiddenAreas(){return this._isUpdatingHiddenAreas}constructor(e,t,i,n){super(),this._editors=e,this._diffModel=t,this._options=i,this._languageFeaturesService=n,this._modifiedOutlineSource=Dc(this,l=>{const d=this._editors.modifiedModel.read(l);return d?new iM(this._languageFeaturesService,d):void 0}),this._isUpdatingHiddenAreas=!1,this._register(this._editors.original.onDidChangeCursorPosition(l=>{if(l.reason===3){const d=this._diffModel.get();mi(c=>{for(const u of this._editors.original.getSelections()||[])d==null||d.ensureOriginalLineIsVisible(u.getStartPosition().lineNumber,c),d==null||d.ensureOriginalLineIsVisible(u.getEndPosition().lineNumber,c)})}})),this._register(this._editors.modified.onDidChangeCursorPosition(l=>{if(l.reason===3){const d=this._diffModel.get();mi(c=>{for(const u of this._editors.modified.getSelections()||[])d==null||d.ensureModifiedLineIsVisible(u.getStartPosition().lineNumber,c),d==null||d.ensureModifiedLineIsVisible(u.getEndPosition().lineNumber,c)})}}));const o=this._diffModel.map((l,d)=>{var c,u;return((c=l==null?void 0:l.diff.read(d))===null||c===void 0?void 0:c.mappings.length)===0?[]:(u=l==null?void 0:l.unchangedRegions.read(d))!==null&&u!==void 0?u:[]});this.viewZones=g_(this,(l,d)=>{const c=this._modifiedOutlineSource.read(l);if(!c)return{origViewZones:[],modViewZones:[]};const u=[],h=[],g=this._options.renderSideBySide.read(l),f=o.read(l);for(const m of f)if(!m.shouldHideControls(l)){{const _=nt(this,b=>m.getHiddenOriginalRange(b).startLineNumber-1),v=new Gy(_,24);u.push(v),d.add(new i8(this._editors.original,v,m,m.originalUnchangedRange,!g,c,b=>this._diffModel.get().ensureModifiedLineIsVisible(b,void 0),this._options))}{const _=nt(this,b=>m.getHiddenModifiedRange(b).startLineNumber-1),v=new Gy(_,24);h.push(v),d.add(new i8(this._editors.modified,v,m,m.modifiedUnchangedRange,!1,c,b=>this._diffModel.get().ensureModifiedLineIsVisible(b,void 0),this._options))}}return{origViewZones:u,modViewZones:h}});const r={description:"unchanged lines",className:"diff-unchanged-lines",isWholeLine:!0},a={description:"Fold Unchanged",glyphMarginHoverMessage:new rs(void 0,{isTrusted:!0,supportThemeIcons:!0}).appendMarkdown(p("foldUnchanged","Fold Unchanged Region")),glyphMarginClassName:"fold-unchanged "+Oe.asClassName(le.fold),zIndex:10001};this._register(qy(this._editors.original,nt(this,l=>{const d=o.read(l),c=d.map(u=>({range:u.originalUnchangedRange.toInclusiveRange(),options:r}));for(const u of d)u.shouldHideControls(l)&&c.push({range:D.fromPositions(new H(u.originalLineNumber,1)),options:a});return c}))),this._register(qy(this._editors.modified,nt(this,l=>{const d=o.read(l),c=d.map(u=>({range:u.modifiedUnchangedRange.toInclusiveRange(),options:r}));for(const u of d)u.shouldHideControls(l)&&c.push({range:ft.ofLength(u.modifiedLineNumber,1).toInclusiveRange(),options:a});return c}))),this._register(Rt(l=>{const d=o.read(l);this._isUpdatingHiddenAreas=!0;try{this._editors.original.setHiddenAreas(d.map(c=>c.getHiddenOriginalRange(l).toInclusiveRange()).filter(b0)),this._editors.modified.setHiddenAreas(d.map(c=>c.getHiddenModifiedRange(l).toInclusiveRange()).filter(b0))}finally{this._isUpdatingHiddenAreas=!1}})),this._register(this._editors.modified.onMouseUp(l=>{var d;if(!l.event.rightButton&&l.target.position&&(!((d=l.target.element)===null||d===void 0)&&d.className.includes("fold-unchanged"))){const c=l.target.position.lineNumber,u=this._diffModel.get();if(!u)return;const h=u.unchangedRegions.get().find(g=>g.modifiedUnchangedRange.includes(c));if(!h)return;h.collapseAll(void 0),l.event.stopPropagation(),l.event.preventDefault()}})),this._register(this._editors.original.onMouseUp(l=>{var d;if(!l.event.rightButton&&l.target.position&&(!((d=l.target.element)===null||d===void 0)&&d.className.includes("fold-unchanged"))){const c=l.target.position.lineNumber,u=this._diffModel.get();if(!u)return;const h=u.unchangedRegions.get().find(g=>g.originalUnchangedRange.includes(c));if(!h)return;h.collapseAll(void 0),l.event.stopPropagation(),l.event.preventDefault()}}))}};tM=UU([$U(3,xe)],tM);class i8 extends HU{constructor(e,t,i,n,o,r,a,l){const d=hi("div.diff-hidden-lines-widget");super(e,t,d.root),this._editor=e,this._unchangedRegion=i,this._unchangedRegionRange=n,this._hide=o,this._modifiedOutlineSource=r,this._revealModifiedHiddenLine=a,this._options=l,this._nodes=hi("div.diff-hidden-lines",[hi("div.top@top",{title:p("diff.hiddenLines.top","Click or drag to show more above")}),hi("div.center@content",{style:{display:"flex"}},[hi("div@first",{style:{display:"flex",justifyContent:"center",alignItems:"center",flexShrink:"0"}},[se("a",{title:p("showUnchangedRegion","Show Unchanged Region"),role:"button",onclick:()=>{this._unchangedRegion.showAll(void 0)}},...hu("$(unfold)"))]),hi("div@others",{style:{display:"flex",justifyContent:"center",alignItems:"center"}})]),hi("div.bottom@bottom",{title:p("diff.bottom","Click or drag to show more below"),role:"button"})]),d.root.appendChild(this._nodes.root);const c=Mi(this._editor.onDidLayoutChange,()=>this._editor.getLayoutInfo());this._hide?Qn(this._nodes.first):this._register(pu(this._nodes.first,{width:c.map(h=>h.contentLeft)})),this._register(Rt(h=>{const g=this._unchangedRegion.visibleLineCountTop.read(h)+this._unchangedRegion.visibleLineCountBottom.read(h)===this._unchangedRegion.lineCount;this._nodes.bottom.classList.toggle("canMoveTop",!g),this._nodes.bottom.classList.toggle("canMoveBottom",this._unchangedRegion.visibleLineCountBottom.read(h)>0),this._nodes.top.classList.toggle("canMoveTop",this._unchangedRegion.visibleLineCountTop.read(h)>0),this._nodes.top.classList.toggle("canMoveBottom",!g);const f=this._unchangedRegion.isDragged.read(h),m=this._editor.getDomNode();m&&(m.classList.toggle("draggingUnchangedRegion",!!f),f==="top"?(m.classList.toggle("canMoveTop",this._unchangedRegion.visibleLineCountTop.read(h)>0),m.classList.toggle("canMoveBottom",!g)):f==="bottom"?(m.classList.toggle("canMoveTop",!g),m.classList.toggle("canMoveBottom",this._unchangedRegion.visibleLineCountBottom.read(h)>0)):(m.classList.toggle("canMoveTop",!1),m.classList.toggle("canMoveBottom",!1)))}));const u=this._editor;this._register(Y(this._nodes.top,"mousedown",h=>{if(h.button!==0)return;this._nodes.top.classList.toggle("dragging",!0),this._nodes.root.classList.toggle("dragging",!0),h.preventDefault();const g=h.clientY;let f=!1;const m=this._unchangedRegion.visibleLineCountTop.get();this._unchangedRegion.isDragged.set("top",void 0);const _=Xe(this._nodes.top),v=Y(_,"mousemove",C=>{const S=C.clientY-g;f=f||Math.abs(S)>2;const x=Math.round(S/u.getOption(66)),L=Math.max(0,Math.min(m+x,this._unchangedRegion.getMaxVisibleLineCountTop()));this._unchangedRegion.visibleLineCountTop.set(L,void 0)}),b=Y(_,"mouseup",C=>{f||this._unchangedRegion.showMoreAbove(this._options.hideUnchangedRegionsRevealLineCount.get(),void 0),this._nodes.top.classList.toggle("dragging",!1),this._nodes.root.classList.toggle("dragging",!1),this._unchangedRegion.isDragged.set(void 0,void 0),v.dispose(),b.dispose()})})),this._register(Y(this._nodes.bottom,"mousedown",h=>{if(h.button!==0)return;this._nodes.bottom.classList.toggle("dragging",!0),this._nodes.root.classList.toggle("dragging",!0),h.preventDefault();const g=h.clientY;let f=!1;const m=this._unchangedRegion.visibleLineCountBottom.get();this._unchangedRegion.isDragged.set("bottom",void 0);const _=Xe(this._nodes.bottom),v=Y(_,"mousemove",C=>{const S=C.clientY-g;f=f||Math.abs(S)>2;const x=Math.round(S/u.getOption(66)),L=Math.max(0,Math.min(m-x,this._unchangedRegion.getMaxVisibleLineCountBottom())),k=u.getTopForLineNumber(this._unchangedRegionRange.endLineNumberExclusive);this._unchangedRegion.visibleLineCountBottom.set(L,void 0);const I=u.getTopForLineNumber(this._unchangedRegionRange.endLineNumberExclusive);u.setScrollTop(u.getScrollTop()+(I-k))}),b=Y(_,"mouseup",C=>{if(this._unchangedRegion.isDragged.set(void 0,void 0),!f){const w=u.getTopForLineNumber(this._unchangedRegionRange.endLineNumberExclusive);this._unchangedRegion.showMoreBelow(this._options.hideUnchangedRegionsRevealLineCount.get(),void 0);const S=u.getTopForLineNumber(this._unchangedRegionRange.endLineNumberExclusive);u.setScrollTop(u.getScrollTop()+(S-w))}this._nodes.bottom.classList.toggle("dragging",!1),this._nodes.root.classList.toggle("dragging",!1),v.dispose(),b.dispose()})})),this._register(Rt(h=>{const g=[];if(!this._hide){const f=i.getHiddenModifiedRange(h).length,m=p("hiddenLines","{0} hidden lines",f),_=se("span",{title:p("diff.hiddenLines.expandAll","Double click to unfold")},m);_.addEventListener("dblclick",C=>{C.button===0&&(C.preventDefault(),this._unchangedRegion.showAll(void 0))}),g.push(_);const v=this._unchangedRegion.getHiddenModifiedRange(h),b=this._modifiedOutlineSource.getBreadcrumbItems(v,h);if(b.length>0){g.push(se("span",void 0,"  |  "));for(let C=0;C<b.length;C++){const w=b[C],S=NS.toIcon(w.kind),x=hi("div.breadcrumb-item",{style:{display:"flex",alignItems:"center"}},[Sy(S)," ",w.name,...C===b.length-1?[]:[Sy(le.chevronRight)]]).root;g.push(x),x.onclick=()=>{this._revealModifiedHiddenLine(w.startLineNumber)}}}}Qn(this._nodes.others,...g)}))}}let iM=class extends j{constructor(e,t){super(),this._languageFeaturesService=e,this._textModel=t,this._currentModel=kt(this,void 0);const i=Ko("documentSymbolProvider.onDidChange",this._languageFeaturesService.documentSymbolProvider.onDidChange),n=Ko("_textModel.onDidChangeContent",ge.debounce(o=>this._textModel.onDidChangeContent(o),()=>{},100));this._register(cc(async(o,r)=>{i.read(o),n.read(o);const a=r.add(new Xme),l=await v_e.create(this._languageFeaturesService.documentSymbolProvider,this._textModel,a.token);r.isDisposed||this._currentModel.set(l,void 0)}))}getBreadcrumbItems(e,t){const i=this._currentModel.read(t);if(!i)return[];const n=i.asListOfDocumentSymbols().filter(o=>e.contains(o.range.startLineNumber)&&!e.contains(o.range.endLineNumber));return n.sort(uW(br(o=>o.range.endLineNumber-o.range.startLineNumber,Ud))),n.map(o=>({name:o.name,kind:o.kind,startLineNumber:o.range.startLineNumber}))}};iM=UU([$U(0,xe)],iM);var b_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},n8=function(s,e){return function(t,i){e(t,i,s)}},Oh;let Yy=Oh=class{constructor(e,t,i){this.editorWorkerService=t,this.telemetryService=i,this.onDidChangeEventEmitter=new W,this.onDidChange=this.onDidChangeEventEmitter.event,this.diffAlgorithm="advanced",this.diffAlgorithmOnDidChangeSubscription=void 0,this.setOptions(e)}dispose(){var e;(e=this.diffAlgorithmOnDidChangeSubscription)===null||e===void 0||e.dispose()}async computeDiff(e,t,i,n){var o,r;if(typeof this.diffAlgorithm!="string")return this.diffAlgorithm.computeDiff(e,t,i,n);if(e.getLineCount()===1&&e.getLineMaxColumn(1)===1)return t.getLineCount()===1&&t.getLineMaxColumn(1)===1?{changes:[],identical:!0,quitEarly:!1,moves:[]}:{changes:[new Dr(new ft(1,2),new ft(1,t.getLineCount()+1),[new Ru(e.getFullModelRange(),t.getFullModelRange())])],identical:!1,quitEarly:!1,moves:[]};const a=JSON.stringify([e.uri.toString(),t.uri.toString()]),l=JSON.stringify([e.id,t.id,e.getAlternativeVersionId(),t.getAlternativeVersionId(),JSON.stringify(i)]),d=Oh.diffCache.get(a);if(d&&d.context===l)return d.result;const c=cs.create(),u=await this.editorWorkerService.computeDiff(e.uri,t.uri,i,this.diffAlgorithm),h=c.elapsed();if(this.telemetryService.publicLog2("diffEditor.computeDiff",{timeMs:h,timedOut:(o=u==null?void 0:u.quitEarly)!==null&&o!==void 0?o:!0,detectedMoves:i.computeMoves?(r=u==null?void 0:u.moves.length)!==null&&r!==void 0?r:0:-1}),n.isCancellationRequested)return{changes:[],identical:!1,quitEarly:!0,moves:[]};if(!u)throw new Error("no diff result available");return Oh.diffCache.size>10&&Oh.diffCache.delete(Oh.diffCache.keys().next().value),Oh.diffCache.set(a,{result:u,context:l}),u}setOptions(e){var t;let i=!1;e.diffAlgorithm&&this.diffAlgorithm!==e.diffAlgorithm&&((t=this.diffAlgorithmOnDidChangeSubscription)===null||t===void 0||t.dispose(),this.diffAlgorithmOnDidChangeSubscription=void 0,this.diffAlgorithm=e.diffAlgorithm,typeof e.diffAlgorithm!="string"&&(this.diffAlgorithmOnDidChangeSubscription=e.diffAlgorithm.onDidChange(()=>this.onDidChangeEventEmitter.fire())),i=!0),i&&this.onDidChangeEventEmitter.fire()}};Yy.diffCache=new Map;Yy=Oh=b_e([n8(1,oa),n8(2,Do)],Yy);var C_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},w_e=function(s,e){return function(t,i){e(t,i,s)}};const jU=ut("diffProviderFactoryService");let nM=class{constructor(e){this.instantiationService=e}createDiffProvider(e){return this.instantiationService.createInstance(Yy,e)}};nM=C_e([w_e(0,We)],nM);_t(jU,nM,1);var S_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},y_e=function(s,e){return function(t,i){e(t,i,s)}};let sM=class extends j{setActiveMovedText(e){this._activeMovedText.set(e,void 0)}constructor(e,t,i){super(),this.model=e,this._options=t,this._diffProviderFactoryService=i,this._isDiffUpToDate=kt(this,!1),this.isDiffUpToDate=this._isDiffUpToDate,this._diff=kt(this,void 0),this.diff=this._diff,this._unchangedRegions=kt(this,{regions:[],originalDecorationIds:[],modifiedDecorationIds:[]}),this.unchangedRegions=nt(this,a=>this._options.hideUnchangedRegions.read(a)?this._unchangedRegions.read(a).regions:(mi(l=>{for(const d of this._unchangedRegions.get().regions)d.collapseAll(l)}),[])),this.movedTextToCompare=kt(this,void 0),this._activeMovedText=kt(this,void 0),this._hoveredMovedText=kt(this,void 0),this.activeMovedText=nt(this,a=>{var l,d;return(d=(l=this.movedTextToCompare.read(a))!==null&&l!==void 0?l:this._hoveredMovedText.read(a))!==null&&d!==void 0?d:this._activeMovedText.read(a)}),this._cancellationTokenSource=new Yi,this._diffProvider=nt(this,a=>{const l=this._diffProviderFactoryService.createDiffProvider({diffAlgorithm:this._options.diffAlgorithm.read(a)}),d=Ko("onDidChange",l.onDidChange);return{diffProvider:l,onChangeSignal:d}}),this._register(Fe(()=>this._cancellationTokenSource.cancel()));const n=BO("contentChangedSignal"),o=this._register(new jt(()=>n.trigger(void 0),200)),r=(a,l,d)=>{const c=Xy.fromDiffs(a.changes,e.original.getLineCount(),e.modified.getLineCount(),this._options.hideUnchangedRegionsMinimumLineCount.read(d),this._options.hideUnchangedRegionsContextLineCount.read(d)),u=this._unchangedRegions.get(),h=u.originalDecorationIds.map(_=>e.original.getDecorationRange(_)).map(_=>_?ft.fromRange(_):void 0),g=u.modifiedDecorationIds.map(_=>e.modified.getDecorationRange(_)).map(_=>_?ft.fromRange(_):void 0),f=e.original.deltaDecorations(u.originalDecorationIds,c.map(_=>({range:_.originalUnchangedRange.toInclusiveRange(),options:{description:"unchanged"}}))),m=e.modified.deltaDecorations(u.modifiedDecorationIds,c.map(_=>({range:_.modifiedUnchangedRange.toInclusiveRange(),options:{description:"unchanged"}})));for(const _ of c)for(let v=0;v<u.regions.length;v++)if(h[v]&&_.originalUnchangedRange.intersectsStrict(h[v])&&g[v]&&_.modifiedUnchangedRange.intersectsStrict(g[v])){_.setHiddenModifiedRange(u.regions[v].getHiddenModifiedRange(void 0),l);break}this._unchangedRegions.set({regions:c,originalDecorationIds:f,modifiedDecorationIds:m},l)};this._register(e.modified.onDidChangeContent(a=>{if(this._diff.get()){const d=Hd.fromModelContentChanges(a.changes);this._lastDiff,e.original,e.modified}this._isDiffUpToDate.set(!1,void 0),o.schedule()})),this._register(e.original.onDidChangeContent(a=>{if(this._diff.get()){const d=Hd.fromModelContentChanges(a.changes);this._lastDiff,e.original,e.modified}this._isDiffUpToDate.set(!1,void 0),o.schedule()})),this._register(cc(async(a,l)=>{var d,c;this._options.hideUnchangedRegionsMinimumLineCount.read(a),this._options.hideUnchangedRegionsContextLineCount.read(a),o.cancel(),n.read(a);const u=this._diffProvider.read(a);u.onChangeSignal.read(a),fl(GV,a),fl(rT,a),this._isDiffUpToDate.set(!1,void 0);let h=[];l.add(e.original.onDidChangeContent(m=>{const _=Hd.fromModelContentChanges(m.changes);h=ry(h,_)}));let g=[];l.add(e.modified.onDidChangeContent(m=>{const _=Hd.fromModelContentChanges(m.changes);g=ry(g,_)}));let f=await u.diffProvider.computeDiff(e.original,e.modified,{ignoreTrimWhitespace:this._options.ignoreTrimWhitespace.read(a),maxComputationTimeMs:this._options.maxComputationTimeMs.read(a),computeMoves:this._options.showMoves.read(a)},this._cancellationTokenSource.token);this._cancellationTokenSource.token.isCancellationRequested||(f=L_e(f,e.original,e.modified),f=(d=(e.original,e.modified,void 0))!==null&&d!==void 0?d:f,f=(c=(e.original,e.modified,void 0))!==null&&c!==void 0?c:f,mi(m=>{r(f,m),this._lastDiff=f;const _=UO.fromDiffResult(f);this._diff.set(_,m),this._isDiffUpToDate.set(!0,m);const v=this.movedTextToCompare.get();this.movedTextToCompare.set(v?this._lastDiff.moves.find(b=>b.lineRangeMapping.modified.intersect(v.lineRangeMapping.modified)):void 0,m)}))}))}ensureModifiedLineIsVisible(e,t){var i;if(((i=this.diff.get())===null||i===void 0?void 0:i.mappings.length)===0)return;const n=this._unchangedRegions.get().regions;for(const o of n)if(o.getHiddenModifiedRange(void 0).contains(e)){o.showModifiedLine(e,t);return}}ensureOriginalLineIsVisible(e,t){var i;if(((i=this.diff.get())===null||i===void 0?void 0:i.mappings.length)===0)return;const n=this._unchangedRegions.get().regions;for(const o of n)if(o.getHiddenOriginalRange(void 0).contains(e)){o.showOriginalLine(e,t);return}}async waitForDiff(){await Ume(this.isDiffUpToDate,e=>e)}serializeState(){return{collapsedRegions:this._unchangedRegions.get().regions.map(t=>({range:t.getHiddenModifiedRange(void 0).serialize()}))}}restoreSerializedState(e){const t=e.collapsedRegions.map(n=>ft.deserialize(n.range)),i=this._unchangedRegions.get();mi(n=>{for(const o of i.regions)for(const r of t)if(o.modifiedUnchangedRange.intersect(r)){o.setHiddenModifiedRange(r,n);break}})}};sM=S_e([y_e(2,jU)],sM);function L_e(s,e,t){return{changes:s.changes.map(i=>new Dr(i.original,i.modified,i.innerChanges?i.innerChanges.map(n=>x_e(n,e,t)):void 0)),moves:s.moves,identical:s.identical,quitEarly:s.quitEarly}}function x_e(s,e,t){let i=s.originalRange,n=s.modifiedRange;return(i.endColumn!==1||n.endColumn!==1)&&i.endColumn===e.getLineMaxColumn(i.endLineNumber)&&n.endColumn===t.getLineMaxColumn(n.endLineNumber)&&i.endLineNumber<e.getLineCount()&&n.endLineNumber<t.getLineCount()&&(i=i.setEndPosition(i.endLineNumber+1,1),n=n.setEndPosition(n.endLineNumber+1,1)),new Ru(i,n)}class UO{static fromDiffResult(e){return new UO(e.changes.map(t=>new KU(t)),e.moves||[],e.identical,e.quitEarly)}constructor(e,t,i,n){this.mappings=e,this.movedTexts=t,this.identical=i,this.quitEarly=n}}class KU{constructor(e){this.lineRangeMapping=e}}class Xy{static fromDiffs(e,t,i,n,o){const r=Dr.inverse(e,t,i),a=[];for(const l of r){let d=l.original.startLineNumber,c=l.modified.startLineNumber,u=l.original.length;const h=d===1&&c===1,g=d+u===t+1&&c+u===i+1;(h||g)&&u>=o+n?(h&&!g&&(u-=o),g&&!h&&(d+=o,c+=o,u-=o),a.push(new Xy(d,c,u,0,0))):u>=o*2+n&&(d+=o,c+=o,u-=o*2,a.push(new Xy(d,c,u,0,0)))}return a}get originalUnchangedRange(){return ft.ofLength(this.originalLineNumber,this.lineCount)}get modifiedUnchangedRange(){return ft.ofLength(this.modifiedLineNumber,this.lineCount)}constructor(e,t,i,n,o){this.originalLineNumber=e,this.modifiedLineNumber=t,this.lineCount=i,this._visibleLineCountTop=kt(this,0),this.visibleLineCountTop=this._visibleLineCountTop,this._visibleLineCountBottom=kt(this,0),this.visibleLineCountBottom=this._visibleLineCountBottom,this._shouldHideControls=nt(this,r=>this.visibleLineCountTop.read(r)+this.visibleLineCountBottom.read(r)===this.lineCount&&!this.isDragged.read(r)),this.isDragged=kt(this,void 0),this._visibleLineCountTop.set(n,void 0),this._visibleLineCountBottom.set(o,void 0)}shouldHideControls(e){return this._shouldHideControls.read(e)}getHiddenOriginalRange(e){return ft.ofLength(this.originalLineNumber+this._visibleLineCountTop.read(e),this.lineCount-this._visibleLineCountTop.read(e)-this._visibleLineCountBottom.read(e))}getHiddenModifiedRange(e){return ft.ofLength(this.modifiedLineNumber+this._visibleLineCountTop.read(e),this.lineCount-this._visibleLineCountTop.read(e)-this._visibleLineCountBottom.read(e))}setHiddenModifiedRange(e,t){const i=e.startLineNumber-this.modifiedLineNumber,n=this.modifiedLineNumber+this.lineCount-e.endLineNumberExclusive;this.setState(i,n,t)}getMaxVisibleLineCountTop(){return this.lineCount-this._visibleLineCountBottom.get()}getMaxVisibleLineCountBottom(){return this.lineCount-this._visibleLineCountTop.get()}showMoreAbove(e=10,t){const i=this.getMaxVisibleLineCountTop();this._visibleLineCountTop.set(Math.min(this._visibleLineCountTop.get()+e,i),t)}showMoreBelow(e=10,t){const i=this.lineCount-this._visibleLineCountTop.get();this._visibleLineCountBottom.set(Math.min(this._visibleLineCountBottom.get()+e,i),t)}showAll(e){this._visibleLineCountBottom.set(this.lineCount-this._visibleLineCountTop.get(),e)}showModifiedLine(e,t){const i=e+1-(this.modifiedLineNumber+this._visibleLineCountTop.get()),n=this.modifiedLineNumber-this._visibleLineCountBottom.get()+this.lineCount-e;i<n?this._visibleLineCountTop.set(this._visibleLineCountTop.get()+i,t):this._visibleLineCountBottom.set(this._visibleLineCountBottom.get()+n,t)}showOriginalLine(e,t){const i=e-this.originalLineNumber,n=this.originalLineNumber+this.lineCount-e;i<n?this._visibleLineCountTop.set(Math.min(this._visibleLineCountTop.get()+n-i,this.getMaxVisibleLineCountTop()),t):this._visibleLineCountBottom.set(Math.min(this._visibleLineCountBottom.get()+i-n,this.getMaxVisibleLineCountBottom()),t)}collapseAll(e){this._visibleLineCountTop.set(0,e),this._visibleLineCountBottom.set(0,e)}setState(e,t,i){e=Math.max(Math.min(e,this.lineCount),0),t=Math.max(Math.min(t,this.lineCount-e),0),this._visibleLineCountTop.set(e,i),this._visibleLineCountBottom.set(t,i)}}class D_e extends j{get visibility(){return this._visibility}set visibility(e){this._visibility!==e&&(this._visibility=e,this._diffActions.style.visibility=e?"visible":"hidden")}constructor(e,t,i,n,o,r,a,l,d){super(),this._getViewZoneId=e,this._marginDomNode=t,this._modifiedEditor=i,this._diff=n,this._editor=o,this._viewLineCounts=r,this._originalTextModel=a,this._contextMenuService=l,this._clipboardService=d,this._visibility=!1,this._marginDomNode.style.zIndex="10",this._diffActions=document.createElement("div"),this._diffActions.className=Oe.asClassName(le.lightBulb)+" lightbulb-glyph",this._diffActions.style.position="absolute";const c=this._modifiedEditor.getOption(66);this._diffActions.style.right="0px",this._diffActions.style.visibility="hidden",this._diffActions.style.height=`${c}px`,this._diffActions.style.lineHeight=`${c}px`,this._marginDomNode.appendChild(this._diffActions);let u=0;const h=i.getOption(126)&&!Wa,g=(f,m)=>{var _;this._contextMenuService.showContextMenu({domForShadowRoot:h&&(_=i.getDomNode())!==null&&_!==void 0?_:void 0,getAnchor:()=>({x:f,y:m}),getActions:()=>{const v=[],b=n.modified.isEmpty;return v.push(new Os("diff.clipboard.copyDeletedContent",b?n.original.length>1?p("diff.clipboard.copyDeletedLinesContent.label","Copy deleted lines"):p("diff.clipboard.copyDeletedLinesContent.single.label","Copy deleted line"):n.original.length>1?p("diff.clipboard.copyChangedLinesContent.label","Copy changed lines"):p("diff.clipboard.copyChangedLinesContent.single.label","Copy changed line"),void 0,!0,async()=>{const w=this._originalTextModel.getValueInRange(n.original.toExclusiveRange());await this._clipboardService.writeText(w)})),n.original.length>1&&v.push(new Os("diff.clipboard.copyDeletedLineContent",b?p("diff.clipboard.copyDeletedLineContent.label","Copy deleted line ({0})",n.original.startLineNumber+u):p("diff.clipboard.copyChangedLineContent.label","Copy changed line ({0})",n.original.startLineNumber+u),void 0,!0,async()=>{let w=this._originalTextModel.getLineContent(n.original.startLineNumber+u);w===""&&(w=this._originalTextModel.getEndOfLineSequence()===0?`
`:`\r
`),await this._clipboardService.writeText(w)})),i.getOption(90)||v.push(new Os("diff.inline.revertChange",p("diff.inline.revertChange.label","Revert this change"),void 0,!0,async()=>{this._editor.revert(this._diff)})),v},autoSelectFirstItem:!0})};this._register(Pi(this._diffActions,"mousedown",f=>{if(!f.leftButton)return;const{top:m,height:_}=ln(this._diffActions),v=Math.floor(c/3);f.preventDefault(),g(f.posx,m+_+v)})),this._register(i.onMouseMove(f=>{(f.target.type===8||f.target.type===5)&&f.target.detail.viewZoneId===this._getViewZoneId()?(u=this._updateLightBulbPosition(this._marginDomNode,f.event.browserEvent.y,c),this.visibility=!0):this.visibility=!1})),this._register(i.onMouseDown(f=>{f.event.leftButton&&(f.target.type===8||f.target.type===5)&&f.target.detail.viewZoneId===this._getViewZoneId()&&(f.event.preventDefault(),u=this._updateLightBulbPosition(this._marginDomNode,f.event.browserEvent.y,c),g(f.event.posx,f.event.posy+c))}))}_updateLightBulbPosition(e,t,i){const{top:n}=ln(e),o=t-n,r=Math.floor(o/i),a=r*i;if(this._diffActions.style.top=`${a}px`,this._viewLineCounts){let l=0;for(let d=0;d<this._viewLineCounts.length;d++)if(l+=this._viewLineCounts[d],r<l)return d}return r}}const s8=oc("diffEditorWidget",{createHTML:s=>s});function k_e(s,e,t,i){Xn(i,e.fontInfo);const n=t.length>0,o=new s_(1e4);let r=0,a=0;const l=[];for(let h=0;h<s.lineTokens.length;h++){const g=h+1,f=s.lineTokens[h],m=s.lineBreakData[h],_=mo.filter(t,g,1,Number.MAX_SAFE_INTEGER);if(m){let v=0;for(const b of m.breakOffsets){const C=f.sliceAndInflate(v,b,0);r=Math.max(r,o8(a,C,mo.extractWrapped(_,v,b),n,s.mightContainNonBasicASCII,s.mightContainRTL,e,o)),a++,v=b}l.push(m.breakOffsets.length)}else l.push(1),r=Math.max(r,o8(a,f,_,n,s.mightContainNonBasicASCII,s.mightContainRTL,e,o)),a++}r+=e.scrollBeyondLastColumn;const d=o.build(),c=s8?s8.createHTML(d):d;i.innerHTML=c;const u=r*e.typicalHalfwidthCharacterWidth;return{heightInLines:a,minWidthInPx:u,viewLineCounts:l}}class I_e{constructor(e,t,i,n){this.lineTokens=e,this.lineBreakData=t,this.mightContainNonBasicASCII=i,this.mightContainRTL=n}}class $O{static fromEditor(e){var t;const i=e.getOptions(),n=i.get(50),o=i.get(143);return new $O(((t=e.getModel())===null||t===void 0?void 0:t.getOptions().tabSize)||0,n,i.get(33),n.typicalHalfwidthCharacterWidth,i.get(103),i.get(66),o.decorationsWidth,i.get(116),i.get(98),i.get(93),i.get(51))}constructor(e,t,i,n,o,r,a,l,d,c,u){this.tabSize=e,this.fontInfo=t,this.disableMonospaceOptimizations=i,this.typicalHalfwidthCharacterWidth=n,this.scrollBeyondLastColumn=o,this.lineHeight=r,this.lineDecorationsWidth=a,this.stopRenderingLineAfter=l,this.renderWhitespace=d,this.renderControlCharacters=c,this.fontLigatures=u}}function o8(s,e,t,i,n,o,r,a){a.appendString('<div class="view-line'),i||a.appendString(" char-delete"),a.appendString('" style="top:'),a.appendString(String(s*r.lineHeight)),a.appendString('px;width:1000000px;">');const l=e.getLineContent(),d=sr.isBasicASCII(l,n),c=sr.containsRTL(l,d,o),u=lC(new sh(r.fontInfo.isMonospace&&!r.disableMonospaceOptimizations,r.fontInfo.canUseHalfwidthRightwardsArrow,l,!1,d,c,0,e,t,r.tabSize,0,r.fontInfo.spaceWidth,r.fontInfo.middotWidth,r.fontInfo.wsmiddotWidth,r.stopRenderingLineAfter,r.renderWhitespace,r.renderControlCharacters,r.fontLigatures!==$o.OFF,null),a);return a.appendString("</div>"),u.characterMapping.getHorizontalOffset(u.characterMapping.length)}var E_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},r8=function(s,e){return function(t,i){e(t,i,s)}};let oM=class extends j{constructor(e,t,i,n,o,r,a,l,d,c){super(),this._targetWindow=e,this._editors=t,this._diffModel=i,this._options=n,this._diffEditorWidget=o,this._canIgnoreViewZoneUpdateEvent=r,this._origViewZonesToIgnore=a,this._modViewZonesToIgnore=l,this._clipboardService=d,this._contextMenuService=c,this._originalTopPadding=kt(this,0),this._originalScrollOffset=kt(this,0),this._originalScrollOffsetAnimated=q9(this._targetWindow,this._originalScrollOffset,this._store),this._modifiedTopPadding=kt(this,0),this._modifiedScrollOffset=kt(this,0),this._modifiedScrollOffsetAnimated=q9(this._targetWindow,this._modifiedScrollOffset,this._store);const u=kt("invalidateAlignmentsState",0),h=this._register(new jt(()=>{u.set(u.get()+1,void 0)},0));this._register(this._editors.original.onDidChangeViewZones(C=>{this._canIgnoreViewZoneUpdateEvent()||h.schedule()})),this._register(this._editors.modified.onDidChangeViewZones(C=>{this._canIgnoreViewZoneUpdateEvent()||h.schedule()})),this._register(this._editors.original.onDidChangeConfiguration(C=>{(C.hasChanged(144)||C.hasChanged(66))&&h.schedule()})),this._register(this._editors.modified.onDidChangeConfiguration(C=>{(C.hasChanged(144)||C.hasChanged(66))&&h.schedule()}));const g=this._diffModel.map(C=>C?Mi(C.model.original.onDidChangeTokens,()=>C.model.original.tokenization.backgroundTokenizationState===2):void 0).map((C,w)=>C==null?void 0:C.read(w)),f=nt(C=>{const w=this._diffModel.read(C),S=w==null?void 0:w.diff.read(C);if(!w||!S)return null;u.read(C);const L=this._options.renderSideBySide.read(C);return a8(this._editors.original,this._editors.modified,S.mappings,this._origViewZonesToIgnore,this._modViewZonesToIgnore,L)}),m=nt(C=>{var w;const S=(w=this._diffModel.read(C))===null||w===void 0?void 0:w.movedTextToCompare.read(C);if(!S)return null;u.read(C);const x=S.changes.map(L=>new KU(L));return a8(this._editors.original,this._editors.modified,x,this._origViewZonesToIgnore,this._modViewZonesToIgnore,!0)});function _(){const C=document.createElement("div");return C.className="diagonal-fill",C}const v=this._register(new ie);this.viewZones=g_(this,(C,w)=>{var S,x,L,k,I,P,$,A;v.clear();const z=f.read(C)||[],K=[],Q=[],ne=this._modifiedTopPadding.read(C);ne>0&&Q.push({afterLineNumber:0,domNode:document.createElement("div"),heightInPx:ne,showInHiddenAreas:!0,suppressMouseDown:!0});const fe=this._originalTopPadding.read(C);fe>0&&K.push({afterLineNumber:0,domNode:document.createElement("div"),heightInPx:fe,showInHiddenAreas:!0,suppressMouseDown:!0});const ve=this._options.renderSideBySide.read(C),ye=ve||(S=this._editors.modified._getViewModel())===null||S===void 0?void 0:S.createLineBreaksComputer();if(ye){for(const wt of z)if(wt.diff)for(let $i=wt.originalRange.startLineNumber;$i<wt.originalRange.endLineNumberExclusive;$i++)ye==null||ye.addRequest(this._editors.original.getModel().getLineContent($i),null,null)}const Be=(x=ye==null?void 0:ye.finalize())!==null&&x!==void 0?x:[];let Ve=0;const Ie=this._editors.modified.getOption(66),pe=(L=this._diffModel.read(C))===null||L===void 0?void 0:L.movedTextToCompare.read(C),Ji=(I=(k=this._editors.original.getModel())===null||k===void 0?void 0:k.mightContainNonBasicASCII())!==null&&I!==void 0?I:!1,wn=($=(P=this._editors.original.getModel())===null||P===void 0?void 0:P.mightContainRTL())!==null&&$!==void 0?$:!1,ni=$O.fromEditor(this._editors.modified);for(const wt of z)if(wt.diff&&!ve){if(!wt.originalRange.isEmpty){g.read(C);const no=document.createElement("div");no.classList.add("view-lines","line-delete","monaco-mouse-cursor-text");const ji=new I_e(wt.originalRange.mapToLineArray(ae=>this._editors.original.getModel().tokenization.getLineTokens(ae)),wt.originalRange.mapToLineArray(ae=>Be[Ve++]),Ji,wn),Ze=[];for(const ae of wt.diff.innerChanges||[])Ze.push(new Pv(ae.originalRange.delta(-(wt.diff.original.startLineNumber-1)),eM.className,0));const zn=k_e(ji,ni,Ze,no),q=document.createElement("div");if(q.className="inline-deleted-margin-view-zone",Xn(q,ni.fontInfo),this._options.renderIndicators.read(C))for(let ae=0;ae<zn.heightInLines;ae++){const be=document.createElement("div");be.className=`delete-sign ${Oe.asClassName(zU)}`,be.setAttribute("style",`position:absolute;top:${ae*Ie}px;width:${ni.lineDecorationsWidth}px;height:${Ie}px;right:0;`),q.appendChild(be)}let Z;v.add(new D_e(()=>Vc(Z),q,this._editors.modified,wt.diff,this._diffEditorWidget,zn.viewLineCounts,this._editors.original.getModel(),this._contextMenuService,this._clipboardService));for(let ae=0;ae<zn.viewLineCounts.length;ae++){const be=zn.viewLineCounts[ae];be>1&&K.push({afterLineNumber:wt.originalRange.startLineNumber+ae,domNode:_(),heightInPx:(be-1)*Ie,showInHiddenAreas:!0,suppressMouseDown:!0})}Q.push({afterLineNumber:wt.modifiedRange.startLineNumber-1,domNode:no,heightInPx:zn.heightInLines*Ie,minWidthInPx:zn.minWidthInPx,marginDomNode:q,setZoneId(ae){Z=ae},showInHiddenAreas:!0,suppressMouseDown:!0})}const $i=document.createElement("div");$i.className="gutter-delete",K.push({afterLineNumber:wt.originalRange.endLineNumberExclusive-1,domNode:_(),heightInPx:wt.modifiedHeightInPx,marginDomNode:$i,showInHiddenAreas:!0,suppressMouseDown:!0})}else{const $i=wt.modifiedHeightInPx-wt.originalHeightInPx;if($i>0){if(pe!=null&&pe.lineRangeMapping.original.delta(-1).deltaLength(2).contains(wt.originalRange.endLineNumberExclusive-1))continue;K.push({afterLineNumber:wt.originalRange.endLineNumberExclusive-1,domNode:_(),heightInPx:$i,showInHiddenAreas:!0,suppressMouseDown:!0})}else{let no=function(){const Ze=document.createElement("div");return Ze.className="arrow-revert-change "+Oe.asClassName(le.arrowRight),w.add(Y(Ze,"mousedown",zn=>zn.stopPropagation())),w.add(Y(Ze,"click",zn=>{zn.stopPropagation(),o.revert(wt.diff)})),se("div",{},Ze)};if(pe!=null&&pe.lineRangeMapping.modified.delta(-1).deltaLength(2).contains(wt.modifiedRange.endLineNumberExclusive-1))continue;let ji;wt.diff&&wt.diff.modified.isEmpty&&this._options.shouldRenderRevertArrows.read(C)&&(ji=no()),Q.push({afterLineNumber:wt.modifiedRange.endLineNumberExclusive-1,domNode:_(),heightInPx:-$i,marginDomNode:ji,showInHiddenAreas:!0,suppressMouseDown:!0})}}for(const wt of(A=m.read(C))!==null&&A!==void 0?A:[]){if(!(pe!=null&&pe.lineRangeMapping.original.intersect(wt.originalRange))||!(pe!=null&&pe.lineRangeMapping.modified.intersect(wt.modifiedRange)))continue;const $i=wt.modifiedHeightInPx-wt.originalHeightInPx;$i>0?K.push({afterLineNumber:wt.originalRange.endLineNumberExclusive-1,domNode:_(),heightInPx:$i,showInHiddenAreas:!0,suppressMouseDown:!0}):Q.push({afterLineNumber:wt.modifiedRange.endLineNumberExclusive-1,domNode:_(),heightInPx:-$i,showInHiddenAreas:!0,suppressMouseDown:!0})}return{orig:K,mod:Q}});let b=!1;this._register(this._editors.original.onDidScrollChange(C=>{C.scrollLeftChanged&&!b&&(b=!0,this._editors.modified.setScrollLeft(C.scrollLeft),b=!1)})),this._register(this._editors.modified.onDidScrollChange(C=>{C.scrollLeftChanged&&!b&&(b=!0,this._editors.original.setScrollLeft(C.scrollLeft),b=!1)})),this._originalScrollTop=Mi(this._editors.original.onDidScrollChange,()=>this._editors.original.getScrollTop()),this._modifiedScrollTop=Mi(this._editors.modified.onDidScrollChange,()=>this._editors.modified.getScrollTop()),this._register(Rt(C=>{const w=this._originalScrollTop.read(C)-(this._originalScrollOffsetAnimated.get()-this._modifiedScrollOffsetAnimated.read(C))-(this._originalTopPadding.get()-this._modifiedTopPadding.read(C));w!==this._editors.modified.getScrollTop()&&this._editors.modified.setScrollTop(w,1)})),this._register(Rt(C=>{const w=this._modifiedScrollTop.read(C)-(this._modifiedScrollOffsetAnimated.get()-this._originalScrollOffsetAnimated.read(C))-(this._modifiedTopPadding.get()-this._originalTopPadding.read(C));w!==this._editors.original.getScrollTop()&&this._editors.original.setScrollTop(w,1)})),this._register(Rt(C=>{var w;const S=(w=this._diffModel.read(C))===null||w===void 0?void 0:w.movedTextToCompare.read(C);let x=0;if(S){const L=this._editors.original.getTopForLineNumber(S.lineRangeMapping.original.startLineNumber,!0)-this._originalTopPadding.get();x=this._editors.modified.getTopForLineNumber(S.lineRangeMapping.modified.startLineNumber,!0)-this._modifiedTopPadding.get()-L}x>0?(this._modifiedTopPadding.set(0,void 0),this._originalTopPadding.set(x,void 0)):x<0?(this._modifiedTopPadding.set(-x,void 0),this._originalTopPadding.set(0,void 0)):setTimeout(()=>{this._modifiedTopPadding.set(0,void 0),this._originalTopPadding.set(0,void 0)},400),this._editors.modified.hasTextFocus()?this._originalScrollOffset.set(this._modifiedScrollOffset.get()-x,void 0,!0):this._modifiedScrollOffset.set(this._originalScrollOffset.get()+x,void 0,!0)}))}};oM=E_e([r8(8,dc),r8(9,Nr)],oM);function a8(s,e,t,i,n,o){const r=new Qd(l8(s,i)),a=new Qd(l8(e,n)),l=s.getOption(66),d=e.getOption(66),c=[];let u=0,h=0;function g(f,m){for(;;){let _=r.peek(),v=a.peek();if(_&&_.lineNumber>=f&&(_=void 0),v&&v.lineNumber>=m&&(v=void 0),!_&&!v)break;const b=_?_.lineNumber-u:Number.MAX_VALUE,C=v?v.lineNumber-h:Number.MAX_VALUE;b<C?(r.dequeue(),v={lineNumber:_.lineNumber-u+h,heightInPx:0}):b>C?(a.dequeue(),_={lineNumber:v.lineNumber-h+u,heightInPx:0}):(r.dequeue(),a.dequeue()),c.push({originalRange:ft.ofLength(_.lineNumber,1),modifiedRange:ft.ofLength(v.lineNumber,1),originalHeightInPx:l+_.heightInPx,modifiedHeightInPx:d+v.heightInPx,diff:void 0})}}for(const f of t){let C=function(w,S){var x,L,k,I;if(w<b||S<v)return;if(_)_=!1;else if(w===b||S===v)return;const P=new ft(b,w),$=new ft(v,S);if(P.isEmpty&&$.isEmpty)return;const A=(L=(x=r.takeWhile(K=>K.lineNumber<w))===null||x===void 0?void 0:x.reduce((K,Q)=>K+Q.heightInPx,0))!==null&&L!==void 0?L:0,z=(I=(k=a.takeWhile(K=>K.lineNumber<S))===null||k===void 0?void 0:k.reduce((K,Q)=>K+Q.heightInPx,0))!==null&&I!==void 0?I:0;c.push({originalRange:P,modifiedRange:$,originalHeightInPx:P.length*l+A,modifiedHeightInPx:$.length*d+z,diff:f.lineRangeMapping}),b=w,v=S};const m=f.lineRangeMapping;g(m.original.startLineNumber,m.modified.startLineNumber);let _=!0,v=m.modified.startLineNumber,b=m.original.startLineNumber;if(o)for(const w of m.innerChanges||[])w.originalRange.startColumn>1&&w.modifiedRange.startColumn>1&&C(w.originalRange.startLineNumber,w.modifiedRange.startLineNumber),w.originalRange.endColumn<s.getModel().getLineMaxColumn(w.originalRange.endLineNumber)&&C(w.originalRange.endLineNumber,w.modifiedRange.endLineNumber);C(m.original.endLineNumberExclusive,m.modified.endLineNumberExclusive),u=m.original.endLineNumberExclusive,h=m.modified.endLineNumberExclusive}return g(Number.MAX_VALUE,Number.MAX_VALUE),c}function l8(s,e){const t=[],i=[],n=s.getOption(144).wrappingColumn!==-1,o=s._getViewModel().coordinatesConverter,r=s.getOption(66);if(n)for(let l=1;l<=s.getModel().getLineCount();l++){const d=o.getModelLineViewLineCount(l);d>1&&i.push({lineNumber:l,heightInPx:r*(d-1)})}for(const l of s.getWhitespaces()){if(e.has(l.id))continue;const d=l.afterLineNumber===0?0:o.convertViewPositionToModelPosition(new H(l.afterLineNumber,1)).lineNumber;t.push({lineNumber:d,heightInPx:l.height})}return Gme(t,i,l=>l.lineNumber,(l,d)=>({lineNumber:l.lineNumber,heightInPx:l.heightInPx+d.heightInPx}))}var N_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},T_e=function(s,e){return function(t,i){e(t,i,s)}},Fr;let Vg=Fr=class extends j{constructor(e,t,i,n,o,r,a){super(),this._editors=e,this._rootElement=t,this._diffModel=i,this._rootWidth=n,this._rootHeight=o,this._modifiedEditorLayoutInfo=r,this._themeService=a,this.width=Fr.ENTIRE_DIFF_OVERVIEW_WIDTH;const l=Mi(this._themeService.onDidColorThemeChange,()=>this._themeService.getColorTheme()),d=nt(h=>{const g=l.read(h),f=g.getColor(Wse)||(g.getColor(Fse)||fT).transparent(2),m=g.getColor(Vse)||(g.getColor(Bse)||pT).transparent(2);return{insertColor:f,removeColor:m}}),c=Mt(document.createElement("div"));c.setClassName("diffViewport"),c.setPosition("absolute");const u=hi("div.diffOverview",{style:{position:"absolute",top:"0px",width:Fr.ENTIRE_DIFF_OVERVIEW_WIDTH+"px"}}).root;this._register(j1(u,c.domNode)),this._register(Pi(u,he.POINTER_DOWN,h=>{this._editors.modified.delegateVerticalScrollbarPointerDown(h)})),this._register(Y(u,he.MOUSE_WHEEL,h=>{this._editors.modified.delegateScrollFromMouseWheelEvent(h)},{passive:!1})),this._register(j1(this._rootElement,u)),this._register(cc((h,g)=>{const f=this._diffModel.read(h),m=this._editors.original.createOverviewRuler("original diffOverviewRuler");m&&(g.add(m),g.add(j1(u,m.getDomNode())));const _=this._editors.modified.createOverviewRuler("modified diffOverviewRuler");if(_&&(g.add(_),g.add(j1(u,_.getDomNode()))),!m||!_)return;const v=Ko("viewZoneChanged",this._editors.original.onDidChangeViewZones),b=Ko("viewZoneChanged",this._editors.modified.onDidChangeViewZones),C=Ko("hiddenRangesChanged",this._editors.original.onDidChangeHiddenAreas),w=Ko("hiddenRangesChanged",this._editors.modified.onDidChangeHiddenAreas);g.add(Rt(S=>{var x;v.read(S),b.read(S),C.read(S),w.read(S);const L=d.read(S),k=(x=f==null?void 0:f.diff.read(S))===null||x===void 0?void 0:x.mappings;function I(A,z,K){const Q=K._getViewModel();return Q?A.filter(ne=>ne.length>0).map(ne=>{const fe=Q.coordinatesConverter.convertModelPositionToViewPosition(new H(ne.startLineNumber,1)),ve=Q.coordinatesConverter.convertModelPositionToViewPosition(new H(ne.endLineNumberExclusive,1)),ye=ve.lineNumber-fe.lineNumber;return new zH(fe.lineNumber,ve.lineNumber,ye,z.toString())}):[]}const P=I((k||[]).map(A=>A.lineRangeMapping.original),L.removeColor,this._editors.original),$=I((k||[]).map(A=>A.lineRangeMapping.modified),L.insertColor,this._editors.modified);m==null||m.setZones(P),_==null||_.setZones($)})),g.add(Rt(S=>{const x=this._rootHeight.read(S),L=this._rootWidth.read(S),k=this._modifiedEditorLayoutInfo.read(S);if(k){const I=Fr.ENTIRE_DIFF_OVERVIEW_WIDTH-2*Fr.ONE_OVERVIEW_WIDTH;m.setLayout({top:0,height:x,right:I+Fr.ONE_OVERVIEW_WIDTH,width:Fr.ONE_OVERVIEW_WIDTH}),_.setLayout({top:0,height:x,right:0,width:Fr.ONE_OVERVIEW_WIDTH});const P=this._editors.modifiedScrollTop.read(S),$=this._editors.modifiedScrollHeight.read(S),A=this._editors.modified.getOption(102),z=new Sm(A.verticalHasArrows?A.arrowSize:0,A.verticalScrollbarSize,0,k.height,$,P);c.setTop(z.getSliderPosition()),c.setHeight(z.getSliderSize())}else c.setTop(0),c.setHeight(0);u.style.height=x+"px",u.style.left=L-Fr.ENTIRE_DIFF_OVERVIEW_WIDTH+"px",c.setWidth(Fr.ENTIRE_DIFF_OVERVIEW_WIDTH)}))}))}};Vg.ONE_OVERVIEW_WIDTH=15;Vg.ENTIRE_DIFF_OVERVIEW_WIDTH=Fr.ONE_OVERVIEW_WIDTH*2;Vg=Fr=N_e([T_e(6,Cn)],Vg);R("diffEditor.move.border",{dark:"#8b8b8b9c",light:"#8b8b8b9c",hcDark:"#8b8b8b9c",hcLight:"#8b8b8b9c"},p("diffEditor.move.border","The border color for text that got moved in the diff editor."));R("diffEditor.moveActive.border",{dark:"#FFA500",light:"#FFA500",hcDark:"#FFA500",hcLight:"#FFA500"},p("diffEditor.moveActive.border","The active border color for text that got moved in the diff editor."));R("diffEditor.unchangedRegionShadow",{dark:"#000000",light:"#737373BF",hcDark:"#000000",hcLight:"#737373BF"},p("diffEditor.unchangedRegionShadow","The color of the shadow around unchanged region widgets."));class aD extends j{constructor(){super(...arguments),this._id=++aD.idCounter,this._onDidDispose=this._register(new W),this.onDidDispose=this._onDidDispose.event}getId(){return this.getEditorType()+":v2:"+this._id}getVisibleColumnFromPosition(e){return this._targetEditor.getVisibleColumnFromPosition(e)}getPosition(){return this._targetEditor.getPosition()}setPosition(e,t="api"){this._targetEditor.setPosition(e,t)}revealLine(e,t=0){this._targetEditor.revealLine(e,t)}revealLineInCenter(e,t=0){this._targetEditor.revealLineInCenter(e,t)}revealLineInCenterIfOutsideViewport(e,t=0){this._targetEditor.revealLineInCenterIfOutsideViewport(e,t)}revealLineNearTop(e,t=0){this._targetEditor.revealLineNearTop(e,t)}revealPosition(e,t=0){this._targetEditor.revealPosition(e,t)}revealPositionInCenter(e,t=0){this._targetEditor.revealPositionInCenter(e,t)}revealPositionInCenterIfOutsideViewport(e,t=0){this._targetEditor.revealPositionInCenterIfOutsideViewport(e,t)}revealPositionNearTop(e,t=0){this._targetEditor.revealPositionNearTop(e,t)}getSelection(){return this._targetEditor.getSelection()}getSelections(){return this._targetEditor.getSelections()}setSelection(e,t="api"){this._targetEditor.setSelection(e,t)}setSelections(e,t="api"){this._targetEditor.setSelections(e,t)}revealLines(e,t,i=0){this._targetEditor.revealLines(e,t,i)}revealLinesInCenter(e,t,i=0){this._targetEditor.revealLinesInCenter(e,t,i)}revealLinesInCenterIfOutsideViewport(e,t,i=0){this._targetEditor.revealLinesInCenterIfOutsideViewport(e,t,i)}revealLinesNearTop(e,t,i=0){this._targetEditor.revealLinesNearTop(e,t,i)}revealRange(e,t=0,i=!1,n=!0){this._targetEditor.revealRange(e,t,i,n)}revealRangeInCenter(e,t=0){this._targetEditor.revealRangeInCenter(e,t)}revealRangeInCenterIfOutsideViewport(e,t=0){this._targetEditor.revealRangeInCenterIfOutsideViewport(e,t)}revealRangeNearTop(e,t=0){this._targetEditor.revealRangeNearTop(e,t)}revealRangeNearTopIfOutsideViewport(e,t=0){this._targetEditor.revealRangeNearTopIfOutsideViewport(e,t)}revealRangeAtTop(e,t=0){this._targetEditor.revealRangeAtTop(e,t)}getSupportedActions(){return this._targetEditor.getSupportedActions()}focus(){this._targetEditor.focus()}trigger(e,t,i){this._targetEditor.trigger(e,t,i)}createDecorationsCollection(e){return this._targetEditor.createDecorationsCollection(e)}changeDecorations(e){return this._targetEditor.changeDecorations(e)}}aD.idCounter=0;var M_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},d8=function(s,e){return function(t,i){e(t,i,s)}};let rM=class extends j{get onDidContentSizeChange(){return this._onDidContentSizeChange.event}constructor(e,t,i,n,o,r,a){super(),this.originalEditorElement=e,this.modifiedEditorElement=t,this._options=i,this._createInnerEditor=o,this._instantiationService=r,this._keybindingService=a,this._onDidContentSizeChange=this._register(new W),this.original=this._register(this._createLeftHandSideEditor(i.editorOptions.get(),n.originalEditor||{})),this.modified=this._register(this._createRightHandSideEditor(i.editorOptions.get(),n.modifiedEditor||{})),this.modifiedModel=Mi(this.modified.onDidChangeModel,()=>this.modified.getModel()),this.modifiedScrollTop=Mi(this.modified.onDidScrollChange,()=>this.modified.getScrollTop()),this.modifiedScrollHeight=Mi(this.modified.onDidScrollChange,()=>this.modified.getScrollHeight()),this.modifiedSelections=Mi(this.modified.onDidChangeCursorSelection,()=>{var l;return(l=this.modified.getSelections())!==null&&l!==void 0?l:[]}),this.modifiedCursor=Mi(this.modified.onDidChangeCursorPosition,()=>{var l;return(l=this.modified.getPosition())!==null&&l!==void 0?l:new H(1,1)}),this._register(NC({createEmptyChangeSummary:()=>({}),handleChange:(l,d)=>(l.didChange(i.editorOptions)&&Object.assign(d,l.change.changedOptions),!0)},(l,d)=>{i.editorOptions.read(l),this._options.renderSideBySide.read(l),this.modified.updateOptions(this._adjustOptionsForRightHandSide(l,d)),this.original.updateOptions(this._adjustOptionsForLeftHandSide(l,d))}))}_createLeftHandSideEditor(e,t){const i=this._adjustOptionsForLeftHandSide(void 0,e),n=this._constructInnerEditor(this._instantiationService,this.originalEditorElement,i,t);return n.setContextValue("isInDiffLeftEditor",!0),n}_createRightHandSideEditor(e,t){const i=this._adjustOptionsForRightHandSide(void 0,e),n=this._constructInnerEditor(this._instantiationService,this.modifiedEditorElement,i,t);return n.setContextValue("isInDiffRightEditor",!0),n}_constructInnerEditor(e,t,i,n){const o=this._createInnerEditor(e,t,i,n);return this._register(o.onDidContentSizeChange(r=>{const a=this.original.getContentWidth()+this.modified.getContentWidth()+Vg.ENTIRE_DIFF_OVERVIEW_WIDTH,l=Math.max(this.modified.getContentHeight(),this.original.getContentHeight());this._onDidContentSizeChange.fire({contentHeight:l,contentWidth:a,contentHeightChanged:r.contentHeightChanged,contentWidthChanged:r.contentWidthChanged})})),o}_adjustOptionsForLeftHandSide(e,t){const i=this._adjustOptionsForSubEditor(t);return this._options.renderSideBySide.get()?(i.unicodeHighlight=this._options.editorOptions.get().unicodeHighlight||{},i.wordWrapOverride1=this._options.diffWordWrap.get()):(i.wordWrapOverride1="off",i.wordWrapOverride2="off",i.stickyScroll={enabled:!1},i.unicodeHighlight={nonBasicASCII:!1,ambiguousCharacters:!1,invisibleCharacters:!1}),i.glyphMargin=this._options.renderSideBySide.get(),t.originalAriaLabel&&(i.ariaLabel=t.originalAriaLabel),i.ariaLabel=this._updateAriaLabel(i.ariaLabel),i.readOnly=!this._options.originalEditable.get(),i.dropIntoEditor={enabled:!i.readOnly},i.extraEditorClassName="original-in-monaco-diff-editor",i}_adjustOptionsForRightHandSide(e,t){const i=this._adjustOptionsForSubEditor(t);return t.modifiedAriaLabel&&(i.ariaLabel=t.modifiedAriaLabel),i.ariaLabel=this._updateAriaLabel(i.ariaLabel),i.wordWrapOverride1=this._options.diffWordWrap.get(),i.revealHorizontalRightPadding=ja.revealHorizontalRightPadding.defaultValue+Vg.ENTIRE_DIFF_OVERVIEW_WIDTH,i.scrollbar.verticalHasArrows=!1,i.extraEditorClassName="modified-in-monaco-diff-editor",i}_adjustOptionsForSubEditor(e){const t={...e,dimension:{height:0,width:0}};return t.inDiffEditor=!0,t.automaticLayout=!1,t.scrollbar={...t.scrollbar||{}},t.folding=!1,t.codeLens=this._options.diffCodeLens.get(),t.fixedOverflowWidgets=!0,t.minimap={...t.minimap||{}},t.minimap.enabled=!1,this._options.hideUnchangedRegions.get()?t.stickyScroll={enabled:!1}:t.stickyScroll=this._options.editorOptions.get().stickyScroll,t}_updateAriaLabel(e){var t;e||(e="");const i=p("diff-aria-navigation-tip"," use {0} to open the accessibility help.",(t=this._keybindingService.lookupKeybinding("editor.action.accessibilityHelp"))===null||t===void 0?void 0:t.getAriaLabel());return this._options.accessibilityVerbose.get()?e+i:e?e.replaceAll(i,""):""}};rM=M_e([d8(5,We),d8(6,qt)],rM);class R_e{get editorOptions(){return this._options}constructor(e){this._diffEditorWidth=kt(this,0),this.couldShowInlineViewBecauseOfSize=nt(this,i=>this._options.read(i).renderSideBySide&&this._diffEditorWidth.read(i)<=this._options.read(i).renderSideBySideInlineBreakpoint),this.renderOverviewRuler=nt(this,i=>this._options.read(i).renderOverviewRuler),this.renderSideBySide=nt(this,i=>this._options.read(i).renderSideBySide&&!(this._options.read(i).useInlineViewWhenSpaceIsLimited&&this.couldShowInlineViewBecauseOfSize.read(i))),this.readOnly=nt(this,i=>this._options.read(i).readOnly),this.shouldRenderRevertArrows=nt(this,i=>!(!this._options.read(i).renderMarginRevertIcon||!this.renderSideBySide.read(i)||this.readOnly.read(i))),this.renderIndicators=nt(this,i=>this._options.read(i).renderIndicators),this.enableSplitViewResizing=nt(this,i=>this._options.read(i).enableSplitViewResizing),this.splitViewDefaultRatio=nt(this,i=>this._options.read(i).splitViewDefaultRatio),this.ignoreTrimWhitespace=nt(this,i=>this._options.read(i).ignoreTrimWhitespace),this.maxComputationTimeMs=nt(this,i=>this._options.read(i).maxComputationTime),this.showMoves=nt(this,i=>this._options.read(i).experimental.showMoves&&this.renderSideBySide.read(i)),this.isInEmbeddedEditor=nt(this,i=>this._options.read(i).isInEmbeddedEditor),this.diffWordWrap=nt(this,i=>this._options.read(i).diffWordWrap),this.originalEditable=nt(this,i=>this._options.read(i).originalEditable),this.diffCodeLens=nt(this,i=>this._options.read(i).diffCodeLens),this.accessibilityVerbose=nt(this,i=>this._options.read(i).accessibilityVerbose),this.diffAlgorithm=nt(this,i=>this._options.read(i).diffAlgorithm),this.showEmptyDecorations=nt(this,i=>this._options.read(i).experimental.showEmptyDecorations),this.onlyShowAccessibleDiffViewer=nt(this,i=>this._options.read(i).onlyShowAccessibleDiffViewer),this.hideUnchangedRegions=nt(this,i=>this._options.read(i).hideUnchangedRegions.enabled),this.hideUnchangedRegionsRevealLineCount=nt(this,i=>this._options.read(i).hideUnchangedRegions.revealLineCount),this.hideUnchangedRegionsContextLineCount=nt(this,i=>this._options.read(i).hideUnchangedRegions.contextLineCount),this.hideUnchangedRegionsMinimumLineCount=nt(this,i=>this._options.read(i).hideUnchangedRegions.minimumLineCount);const t={...e,...c8(e,ps)};this._options=kt(this,t)}updateOptions(e){const t=c8(e,this._options.get()),i={...this._options.get(),...e,...t};this._options.set(i,void 0,{changedOptions:e})}setWidth(e){this._diffEditorWidth.set(e,void 0)}}function c8(s,e){var t,i,n,o,r,a,l,d;return{enableSplitViewResizing:Te(s.enableSplitViewResizing,e.enableSplitViewResizing),splitViewDefaultRatio:xX(s.splitViewDefaultRatio,.5,.1,.9),renderSideBySide:Te(s.renderSideBySide,e.renderSideBySide),renderMarginRevertIcon:Te(s.renderMarginRevertIcon,e.renderMarginRevertIcon),maxComputationTime:Nh(s.maxComputationTime,e.maxComputationTime,0,1073741824),maxFileSize:Nh(s.maxFileSize,e.maxFileSize,0,1073741824),ignoreTrimWhitespace:Te(s.ignoreTrimWhitespace,e.ignoreTrimWhitespace),renderIndicators:Te(s.renderIndicators,e.renderIndicators),originalEditable:Te(s.originalEditable,e.originalEditable),diffCodeLens:Te(s.diffCodeLens,e.diffCodeLens),renderOverviewRuler:Te(s.renderOverviewRuler,e.renderOverviewRuler),diffWordWrap:Vi(s.diffWordWrap,e.diffWordWrap,["off","on","inherit"]),diffAlgorithm:Vi(s.diffAlgorithm,e.diffAlgorithm,["legacy","advanced"],{smart:"legacy",experimental:"advanced"}),accessibilityVerbose:Te(s.accessibilityVerbose,e.accessibilityVerbose),experimental:{showMoves:Te((t=s.experimental)===null||t===void 0?void 0:t.showMoves,e.experimental.showMoves),showEmptyDecorations:Te((i=s.experimental)===null||i===void 0?void 0:i.showEmptyDecorations,e.experimental.showEmptyDecorations)},hideUnchangedRegions:{enabled:Te((o=(n=s.hideUnchangedRegions)===null||n===void 0?void 0:n.enabled)!==null&&o!==void 0?o:(r=s.experimental)===null||r===void 0?void 0:r.collapseUnchangedRegions,e.hideUnchangedRegions.enabled),contextLineCount:Nh((a=s.hideUnchangedRegions)===null||a===void 0?void 0:a.contextLineCount,e.hideUnchangedRegions.contextLineCount,0,1073741824),minimumLineCount:Nh((l=s.hideUnchangedRegions)===null||l===void 0?void 0:l.minimumLineCount,e.hideUnchangedRegions.minimumLineCount,0,1073741824),revealLineCount:Nh((d=s.hideUnchangedRegions)===null||d===void 0?void 0:d.revealLineCount,e.hideUnchangedRegions.revealLineCount,0,1073741824)},isInEmbeddedEditor:Te(s.isInEmbeddedEditor,e.isInEmbeddedEditor),onlyShowAccessibleDiffViewer:Te(s.onlyShowAccessibleDiffViewer,e.onlyShowAccessibleDiffViewer),renderSideBySideInlineBreakpoint:Nh(s.renderSideBySideInlineBreakpoint,e.renderSideBySideInlineBreakpoint,0,1073741824),useInlineViewWhenSpaceIsLimited:Te(s.useInlineViewWhenSpaceIsLimited,e.useInlineViewWhenSpaceIsLimited)}}var A_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},j_=function(s,e){return function(t,i){e(t,i,s)}};let Vu=class extends aD{get onDidContentSizeChange(){return this._editors.onDidContentSizeChange}constructor(e,t,i,n,o,r,a,l){var d;super(),this._domElement=e,this._parentContextKeyService=n,this._parentInstantiationService=o,this._audioCueService=a,this._editorProgressService=l,this.elements=hi("div.monaco-diff-editor.side-by-side",{style:{position:"relative",height:"100%"}},[hi("div.noModificationsOverlay@overlay",{style:{position:"absolute",height:"100%",visibility:"hidden"}},[se("span",{},"No Changes")]),hi("div.editor.original@original",{style:{position:"absolute",height:"100%"}}),hi("div.editor.modified@modified",{style:{position:"absolute",height:"100%"}}),hi("div.accessibleDiffViewer@accessibleDiffViewer",{style:{position:"absolute",height:"100%"}})]),this._diffModel=kt(this,void 0),this._shouldDisposeDiffModel=!1,this.onDidChangeModel=ge.fromObservableLight(this._diffModel),this._contextKeyService=this._register(this._parentContextKeyService.createScoped(this._domElement)),this._instantiationService=this._parentInstantiationService.createChild(new _C([je,this._contextKeyService])),this._boundarySashes=kt(this,void 0),this._accessibleDiffViewerShouldBeVisible=kt(this,!1),this._accessibleDiffViewerVisible=nt(this,w=>this._options.onlyShowAccessibleDiffViewer.read(w)?!0:this._accessibleDiffViewerShouldBeVisible.read(w)),this._movedBlocksLinesPart=kt(this,void 0),this._layoutInfo=nt(this,w=>{var S,x,L,k,I;const P=this._rootSizeObserver.width.read(w),$=this._rootSizeObserver.height.read(w),A=(S=this._sash.read(w))===null||S===void 0?void 0:S.sashLeft.read(w),z=A??Math.max(5,this._editors.original.getLayoutInfo().decorationsLeft),K=P-z-((L=(x=this._overviewRulerPart.read(w))===null||x===void 0?void 0:x.width)!==null&&L!==void 0?L:0),Q=(I=(k=this._movedBlocksLinesPart.read(w))===null||k===void 0?void 0:k.width.read(w))!==null&&I!==void 0?I:0,ne=z-Q;return this.elements.original.style.width=ne+"px",this.elements.original.style.left="0px",this.elements.modified.style.width=K+"px",this.elements.modified.style.left=z+"px",this._editors.original.layout({width:ne,height:$},!0),this._editors.modified.layout({width:K,height:$},!0),{modifiedEditor:this._editors.modified.getLayoutInfo(),originalEditor:this._editors.original.getLayoutInfo()}}),this._diffValue=this._diffModel.map((w,S)=>w==null?void 0:w.diff.read(S)),this.onDidUpdateDiff=ge.fromObservableLight(this._diffValue),r.willCreateDiffEditor(),this._contextKeyService.createKey("isInDiffEditor",!0),this._domElement.appendChild(this.elements.root),this._register(Fe(()=>this._domElement.removeChild(this.elements.root))),this._rootSizeObserver=this._register(new VU(this.elements.root,t.dimension)),this._rootSizeObserver.setAutomaticLayout((d=t.automaticLayout)!==null&&d!==void 0?d:!1),this._options=new R_e(t),this._register(Rt(w=>{this._options.setWidth(this._rootSizeObserver.width.read(w))})),this._contextKeyService.createKey(T.isEmbeddedDiffEditor.key,!1),this._register(K1(T.isEmbeddedDiffEditor,this._contextKeyService,w=>this._options.isInEmbeddedEditor.read(w))),this._register(K1(T.comparingMovedCode,this._contextKeyService,w=>{var S;return!!(!((S=this._diffModel.read(w))===null||S===void 0)&&S.movedTextToCompare.read(w))})),this._register(K1(T.diffEditorRenderSideBySideInlineBreakpointReached,this._contextKeyService,w=>this._options.couldShowInlineViewBecauseOfSize.read(w))),this._register(K1(T.hasChanges,this._contextKeyService,w=>{var S,x,L;return((L=(x=(S=this._diffModel.read(w))===null||S===void 0?void 0:S.diff.read(w))===null||x===void 0?void 0:x.mappings.length)!==null&&L!==void 0?L:0)>0})),this._editors=this._register(this._instantiationService.createInstance(rM,this.elements.original,this.elements.modified,this._options,i,(w,S,x,L)=>this._createInnerEditor(w,S,x,L))),this._overviewRulerPart=Dc(this,w=>this._options.renderOverviewRuler.read(w)?this._instantiationService.createInstance(fl(Vg,w),this._editors,this.elements.root,this._diffModel,this._rootSizeObserver.width,this._rootSizeObserver.height,this._layoutInfo.map(S=>S.modifiedEditor)):void 0).recomputeInitiallyAndOnChange(this._store),this._sash=Dc(this,w=>{const S=this._options.renderSideBySide.read(w);return this.elements.root.classList.toggle("side-by-side",S),S?new m_e(this._options,this.elements.root,{height:this._rootSizeObserver.height,width:this._rootSizeObserver.width.map((x,L)=>{var k,I;return x-((I=(k=this._overviewRulerPart.read(L))===null||k===void 0?void 0:k.width)!==null&&I!==void 0?I:0)})},this._boundarySashes):void 0}).recomputeInitiallyAndOnChange(this._store);const c=Dc(this,w=>this._instantiationService.createInstance(fl(tM,w),this._editors,this._diffModel,this._options)).recomputeInitiallyAndOnChange(this._store);Dc(this,w=>this._instantiationService.createInstance(fl(f_e,w),this._editors,this._diffModel,this._options,this)).recomputeInitiallyAndOnChange(this._store);const u=new Set,h=new Set;let g=!1;const f=Dc(this,w=>this._instantiationService.createInstance(fl(oM,w),Xe(this._domElement),this._editors,this._diffModel,this._options,this,()=>g||c.get().isUpdatingHiddenAreas,u,h)).recomputeInitiallyAndOnChange(this._store),m=nt(this,w=>{const S=f.read(w).viewZones.read(w).orig,x=c.read(w).viewZones.read(w).origViewZones;return S.concat(x)}),_=nt(this,w=>{const S=f.read(w).viewZones.read(w).mod,x=c.read(w).viewZones.read(w).modViewZones;return S.concat(x)});this._register(Zy(this._editors.original,m,w=>{g=w},u));let v;this._register(Zy(this._editors.modified,_,w=>{g=w,g?v=$a.capture(this._editors.modified):(v==null||v.restore(this._editors.modified),v=void 0)},h)),this._accessibleDiffViewer=Dc(this,w=>this._instantiationService.createInstance(fl(Yc,w),this.elements.accessibleDiffViewer,this._accessibleDiffViewerVisible,(S,x)=>this._accessibleDiffViewerShouldBeVisible.set(S,x),this._options.onlyShowAccessibleDiffViewer.map(S=>!S),this._rootSizeObserver.width,this._rootSizeObserver.height,this._diffModel.map((S,x)=>{var L;return(L=S==null?void 0:S.diff.read(x))===null||L===void 0?void 0:L.mappings.map(k=>k.lineRangeMapping)}),this._editors)).recomputeInitiallyAndOnChange(this._store);const b=this._accessibleDiffViewerVisible.map(w=>w?"hidden":"visible");this._register(pu(this.elements.modified,{visibility:b})),this._register(pu(this.elements.original,{visibility:b})),this._createDiffEditorContributions(),r.addDiffEditor(this),this._register(TC(this._layoutInfo)),Dc(this,w=>new(fl(mu,w))(this.elements.root,this._diffModel,this._layoutInfo.map(S=>S.originalEditor),this._layoutInfo.map(S=>S.modifiedEditor),this._editors)).recomputeInitiallyAndOnChange(this._store,w=>{this._movedBlocksLinesPart.set(w,void 0)}),this._register(pu(this.elements.overlay,{width:this._layoutInfo.map((w,S)=>w.originalEditor.width+(this._options.renderSideBySide.read(S)?0:w.modifiedEditor.width)),visibility:nt(w=>{var S,x;return this._options.hideUnchangedRegions.read(w)&&((x=(S=this._diffModel.read(w))===null||S===void 0?void 0:S.diff.read(w))===null||x===void 0?void 0:x.mappings.length)===0?"visible":"hidden"})})),this._register(ge.runAndSubscribe(this._editors.modified.onDidChangeCursorPosition,w=>{var S,x;if((w==null?void 0:w.reason)===3){const L=(x=(S=this._diffModel.get())===null||S===void 0?void 0:S.diff.get())===null||x===void 0?void 0:x.mappings.find(k=>k.lineRangeMapping.modified.contains(w.position.lineNumber));L!=null&&L.lineRangeMapping.modified.isEmpty?this._audioCueService.playAudioCue(at.diffLineDeleted,{source:"diffEditor.cursorPositionChanged"}):L!=null&&L.lineRangeMapping.original.isEmpty?this._audioCueService.playAudioCue(at.diffLineInserted,{source:"diffEditor.cursorPositionChanged"}):L&&this._audioCueService.playAudioCue(at.diffLineModified,{source:"diffEditor.cursorPositionChanged"})}}));const C=this._diffModel.map(this,(w,S)=>{if(w)return w.diff.read(S)===void 0&&!w.isDiffUpToDate.read(S)});this._register(cc((w,S)=>{if(C.read(w)===!0){const x=this._editorProgressService.show(!0,1e3);S.add(Fe(()=>x.done()))}})),this._register(Fe(()=>{var w;this._shouldDisposeDiffModel&&((w=this._diffModel.get())===null||w===void 0||w.dispose())}))}_createInnerEditor(e,t,i,n){return e.createInstance(Lm,t,i,n)}_createDiffEditorContributions(){const e=Ap.getDiffEditorContributions();for(const t of e)try{this._register(this._instantiationService.createInstance(t.ctor,this))}catch(i){et(i)}}get _targetEditor(){return this._editors.modified}getEditorType(){return aC.IDiffEditor}layout(e){this._rootSizeObserver.observe(e)}hasTextFocus(){return this._editors.original.hasTextFocus()||this._editors.modified.hasTextFocus()}saveViewState(){var e;const t=this._editors.original.saveViewState(),i=this._editors.modified.saveViewState();return{original:t,modified:i,modelState:(e=this._diffModel.get())===null||e===void 0?void 0:e.serializeState()}}restoreViewState(e){var t;if(e&&e.original&&e.modified){const i=e;this._editors.original.restoreViewState(i.original),this._editors.modified.restoreViewState(i.modified),i.modelState&&((t=this._diffModel.get())===null||t===void 0||t.restoreSerializedState(i.modelState))}}handleInitialized(){this._editors.original.handleInitialized(),this._editors.modified.handleInitialized()}createViewModel(e){return this._instantiationService.createInstance(sM,e,this._options)}getModel(){var e,t;return(t=(e=this._diffModel.get())===null||e===void 0?void 0:e.model)!==null&&t!==void 0?t:null}setModel(e,t){!e&&this._diffModel.get()&&this._accessibleDiffViewer.get().close();const i=e?"model"in e?{model:e,shouldDispose:!1}:{model:this.createViewModel(e),shouldDispose:!0}:void 0;this._diffModel.get()!==(i==null?void 0:i.model)&&Cb(t,n=>{var o;Mi.batchEventsGlobally(n,()=>{this._editors.original.setModel(i?i.model.model.original:null),this._editors.modified.setModel(i?i.model.model.modified:null)});const r=this._diffModel.get(),a=this._shouldDisposeDiffModel;this._shouldDisposeDiffModel=(o=i==null?void 0:i.shouldDispose)!==null&&o!==void 0?o:!1,this._diffModel.set(i==null?void 0:i.model,n),a&&(r==null||r.dispose())})}updateOptions(e){this._options.updateOptions(e)}getContainerDomNode(){return this._domElement}getOriginalEditor(){return this._editors.original}getModifiedEditor(){return this._editors.modified}getLineChanges(){var e;const t=(e=this._diffModel.get())===null||e===void 0?void 0:e.diff.get();return t?P_e(t):null}revert(e){var t;if(e.innerChanges){this.revertRangeMappings(e.innerChanges);return}const i=(t=this._diffModel.get())===null||t===void 0?void 0:t.model;i&&this._editors.modified.executeEdits("diffEditor",[{range:e.modified.toExclusiveRange(),text:i.original.getValueInRange(e.original.toExclusiveRange())}])}revertRangeMappings(e){const t=this._diffModel.get();if(!t||!t.isDiffUpToDate.get())return;const i=e.map(n=>({range:n.modifiedRange,text:t.model.original.getValueInRange(n.originalRange)}));this._editors.modified.executeEdits("diffEditor",i)}_goTo(e){this._editors.modified.setPosition(new H(e.lineRangeMapping.modified.startLineNumber,1)),this._editors.modified.revealRangeInCenter(e.lineRangeMapping.modified.toExclusiveRange())}goToDiff(e){var t,i,n,o;const r=(i=(t=this._diffModel.get())===null||t===void 0?void 0:t.diff.get())===null||i===void 0?void 0:i.mappings;if(!r||r.length===0)return;const a=this._editors.modified.getPosition().lineNumber;let l;e==="next"?l=(n=r.find(d=>d.lineRangeMapping.modified.startLineNumber>a))!==null&&n!==void 0?n:r[0]:l=(o=R0(r,d=>d.lineRangeMapping.modified.startLineNumber<a))!==null&&o!==void 0?o:r[r.length-1],this._goTo(l),l.lineRangeMapping.modified.isEmpty?this._audioCueService.playAudioCue(at.diffLineDeleted,{source:"diffEditor.goToDiff"}):l.lineRangeMapping.original.isEmpty?this._audioCueService.playAudioCue(at.diffLineInserted,{source:"diffEditor.goToDiff"}):l&&this._audioCueService.playAudioCue(at.diffLineModified,{source:"diffEditor.goToDiff"})}revealFirstDiff(){const e=this._diffModel.get();e&&this.waitForDiff().then(()=>{var t;const i=(t=e.diff.get())===null||t===void 0?void 0:t.mappings;!i||i.length===0||this._goTo(i[0])})}accessibleDiffViewerNext(){this._accessibleDiffViewer.get().next()}accessibleDiffViewerPrev(){this._accessibleDiffViewer.get().prev()}async waitForDiff(){const e=this._diffModel.get();e&&await e.waitForDiff()}mapToOtherSide(){var e,t;const i=this._editors.modified.hasWidgetFocus(),n=i?this._editors.modified:this._editors.original,o=i?this._editors.original:this._editors.modified;let r;const a=n.getSelection();if(a){const l=(t=(e=this._diffModel.get())===null||e===void 0?void 0:e.diff.get())===null||t===void 0?void 0:t.mappings.map(d=>i?d.lineRangeMapping.flip():d.lineRangeMapping);if(l){const d=G9(a.getStartPosition(),l),c=G9(a.getEndPosition(),l);r=D.plusRange(d,c)}}return{destination:o,destinationSelection:r}}switchSide(){const{destination:e,destinationSelection:t}=this.mapToOtherSide();e.focus(),t&&e.setSelection(t)}exitCompareMove(){const e=this._diffModel.get();e&&e.movedTextToCompare.set(void 0,void 0)}collapseAllUnchangedRegions(){var e;const t=(e=this._diffModel.get())===null||e===void 0?void 0:e.unchangedRegions.get();t&&mi(i=>{for(const n of t)n.collapseAll(i)})}showAllUnchangedRegions(){var e;const t=(e=this._diffModel.get())===null||e===void 0?void 0:e.unchangedRegions.get();t&&mi(i=>{for(const n of t)n.showAll(i)})}};Vu=A_e([j_(3,je),j_(4,We),j_(5,It),j_(6,IC),j_(7,rh)],Vu);function P_e(s){return s.mappings.map(e=>{const t=e.lineRangeMapping;let i,n,o,r,a=t.innerChanges;return t.original.isEmpty?(i=t.original.startLineNumber-1,n=0,a=void 0):(i=t.original.startLineNumber,n=t.original.endLineNumberExclusive-1),t.modified.isEmpty?(o=t.modified.startLineNumber-1,r=0,a=void 0):(o=t.modified.startLineNumber,r=t.modified.endLineNumberExclusive-1),{originalStartLineNumber:i,originalEndLineNumber:n,modifiedStartLineNumber:o,modifiedEndLineNumber:r,charChanges:a==null?void 0:a.map(l=>({originalStartLineNumber:l.originalRange.startLineNumber,originalStartColumn:l.originalRange.startColumn,originalEndLineNumber:l.originalRange.endLineNumber,originalEndColumn:l.originalRange.endColumn,modifiedStartLineNumber:l.modifiedRange.startLineNumber,modifiedStartColumn:l.modifiedRange.startColumn,modifiedEndLineNumber:l.modifiedRange.endLineNumber,modifiedEndColumn:l.modifiedRange.endColumn}))}})}var jO=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},ui=function(s,e){return function(t,i){e(t,i,s)}};let O_e=0,u8=!1;function F_e(s){if(!s){if(u8)return;u8=!0}Pne(s||Ci.document.body)}let Qy=class extends Lm{constructor(e,t,i,n,o,r,a,l,d,c,u,h){const g={...t};g.ariaLabel=g.ariaLabel||Cy.editorViewAccessibleLabel,g.ariaLabel=g.ariaLabel+";"+Cy.accessibilityHelpMessage,super(e,g,{},i,n,o,r,l,d,c,u,h),a instanceof Mm?this._standaloneKeybindingService=a:this._standaloneKeybindingService=null,F_e(g.ariaContainerElement)}addCommand(e,t,i){if(!this._standaloneKeybindingService)return console.warn("Cannot add command because the editor is configured with an unrecognized KeybindingService"),null;const n="DYNAMIC_"+ ++O_e,o=ee.deserialize(i);return this._standaloneKeybindingService.addDynamicKeybinding(n,e,t,o),n}createContextKey(e,t){return this._contextKeyService.createKey(e,t)}addAction(e){if(typeof e.id!="string"||typeof e.label!="string"||typeof e.run!="function")throw new Error("Invalid action descriptor, `id`, `label` and `run` are required properties!");if(!this._standaloneKeybindingService)return console.warn("Cannot add keybinding because the editor is configured with an unrecognized KeybindingService"),j.None;const t=e.id,i=e.label,n=ee.and(ee.equals("editorId",this.getId()),ee.deserialize(e.precondition)),o=e.keybindings,r=ee.and(n,ee.deserialize(e.keybindingContext)),a=e.contextMenuGroupId||null,l=e.contextMenuOrder||0,d=(g,...f)=>Promise.resolve(e.run(this,...f)),c=new ie,u=this.getId()+":"+t;if(c.add(Ct.registerCommand(u,d)),a){const g={command:{id:u,title:i},when:n,group:a,order:l};c.add(Wn.appendMenuItem(N.EditorContext,g))}if(Array.isArray(o))for(const g of o)c.add(this._standaloneKeybindingService.addDynamicKeybinding(u,g,d,r));const h=new UH(u,i,i,void 0,n,(...g)=>Promise.resolve(e.run(this,...g)),this._contextKeyService);return this._actions.set(t,h),c.add(Fe(()=>{this._actions.delete(t)})),c}_triggerCommand(e,t){if(this._codeEditorService instanceof hy)try{this._codeEditorService.setActiveCodeEditor(this),super._triggerCommand(e,t)}finally{this._codeEditorService.setActiveCodeEditor(null)}else super._triggerCommand(e,t)}};Qy=jO([ui(2,We),ui(3,It),ui(4,Ei),ui(5,je),ui(6,qt),ui(7,Cn),ui(8,Qi),ui(9,ad),ui(10,Jt),ui(11,xe)],Qy);let aM=class extends Qy{constructor(e,t,i,n,o,r,a,l,d,c,u,h,g,f,m){const _={...t};$y(c,_,!1);const v=l.registerEditorContainer(e);typeof _.theme=="string"&&l.setTheme(_.theme),typeof _.autoDetectHighContrast<"u"&&l.setAutoDetectHighContrast(!!_.autoDetectHighContrast);const b=_.model;delete _.model,super(e,_,i,n,o,r,a,l,d,u,f,m),this._configurationService=c,this._standaloneThemeService=l,this._register(v);let C;if(typeof b>"u"){const w=g.getLanguageIdByMimeType(_.language)||_.language||er;C=qU(h,g,_.value||"",w,void 0),this._ownsModel=!0}else C=b,this._ownsModel=!1;if(this._attachModel(C),C){const w={oldModelUrl:null,newModelUrl:C.uri};this._onDidChangeModel.fire(w)}}dispose(){super.dispose()}updateOptions(e){$y(this._configurationService,e,!1),typeof e.theme=="string"&&this._standaloneThemeService.setTheme(e.theme),typeof e.autoDetectHighContrast<"u"&&this._standaloneThemeService.setAutoDetectHighContrast(!!e.autoDetectHighContrast),super.updateOptions(e)}_postDetachModelCleanup(e){super._postDetachModelCleanup(e),e&&this._ownsModel&&(e.dispose(),this._ownsModel=!1)}};aM=jO([ui(2,We),ui(3,It),ui(4,Ei),ui(5,je),ui(6,qt),ui(7,lr),ui(8,Qi),ui(9,mt),ui(10,ad),ui(11,vi),ui(12,fi),ui(13,Jt),ui(14,xe)],aM);let lM=class extends Vu{constructor(e,t,i,n,o,r,a,l,d,c,u,h){const g={...t};$y(l,g,!0);const f=r.registerEditorContainer(e);typeof g.theme=="string"&&r.setTheme(g.theme),typeof g.autoDetectHighContrast<"u"&&r.setAutoDetectHighContrast(!!g.autoDetectHighContrast),super(e,g,{},n,i,o,h,c),this._configurationService=l,this._standaloneThemeService=r,this._register(f)}dispose(){super.dispose()}updateOptions(e){$y(this._configurationService,e,!0),typeof e.theme=="string"&&this._standaloneThemeService.setTheme(e.theme),typeof e.autoDetectHighContrast<"u"&&this._standaloneThemeService.setAutoDetectHighContrast(!!e.autoDetectHighContrast),super.updateOptions(e)}_createInnerEditor(e,t,i){return e.createInstance(Qy,t,i)}getOriginalEditor(){return super.getOriginalEditor()}getModifiedEditor(){return super.getModifiedEditor()}addCommand(e,t,i){return this.getModifiedEditor().addCommand(e,t,i)}createContextKey(e,t){return this.getModifiedEditor().createContextKey(e,t)}addAction(e){return this.getModifiedEditor().addAction(e)}};lM=jO([ui(2,We),ui(3,je),ui(4,It),ui(5,lr),ui(6,Qi),ui(7,mt),ui(8,Nr),ui(9,rh),ui(10,dc),ui(11,IC)],lM);function qU(s,e,t,i,n){if(t=t||"",!i){const o=t.indexOf(`
`);let r=t;return o!==-1&&(r=t.substring(0,o)),h8(s,t,e.createByFilepathOrFirstLine(n||null,r),n)}return h8(s,t,e.createById(i),n)}function h8(s,e,t,i){return s.createModel(e,t,i)}class B_e extends j{constructor(e,t,i={orientation:0}){super(),this.submenuActionViewItems=[],this.hasSecondaryActions=!1,this._onDidChangeDropdownVisibility=this._register(new LQ),this.onDidChangeDropdownVisibility=this._onDidChangeDropdownVisibility.event,this.disposables=this._register(new ie),this.options=i,this.lookupKeybindings=typeof this.options.getKeyBinding=="function",this.toggleMenuAction=this._register(new Sb(()=>{var n;return(n=this.toggleMenuActionViewItem)===null||n===void 0?void 0:n.show()},i.toggleMenuTitle)),this.element=document.createElement("div"),this.element.className="monaco-toolbar",e.appendChild(this.element),this.actionBar=this._register(new Ir(this.element,{orientation:i.orientation,ariaLabel:i.ariaLabel,actionRunner:i.actionRunner,allowContextMenu:i.allowContextMenu,highlightToggledItems:i.highlightToggledItems,actionViewItemProvider:(n,o)=>{var r;if(n.id===Sb.ID)return this.toggleMenuActionViewItem=new Ly(n,n.menuActions,t,{actionViewItemProvider:this.options.actionViewItemProvider,actionRunner:this.actionRunner,keybindingProvider:this.options.getKeyBinding,classNames:Oe.asClassNameArray((r=i.moreIcon)!==null&&r!==void 0?r:le.toolBarMore),anchorAlignmentProvider:this.options.anchorAlignmentProvider,menuAsChild:!!this.options.renderDropdownAsChildElement,skipTelemetry:this.options.skipTelemetry,isMenu:!0}),this.toggleMenuActionViewItem.setActionContext(this.actionBar.context),this.disposables.add(this._onDidChangeDropdownVisibility.add(this.toggleMenuActionViewItem.onDidChangeVisibility)),this.toggleMenuActionViewItem;if(i.actionViewItemProvider){const a=i.actionViewItemProvider(n,o);if(a)return a}if(n instanceof cm){const a=new Ly(n,n.actions,t,{actionViewItemProvider:this.options.actionViewItemProvider,actionRunner:this.actionRunner,keybindingProvider:this.options.getKeyBinding,classNames:n.class,anchorAlignmentProvider:this.options.anchorAlignmentProvider,menuAsChild:!!this.options.renderDropdownAsChildElement,skipTelemetry:this.options.skipTelemetry});return a.setActionContext(this.actionBar.context),this.submenuActionViewItems.push(a),this.disposables.add(this._onDidChangeDropdownVisibility.add(a.onDidChangeVisibility)),a}}}))}set actionRunner(e){this.actionBar.actionRunner=e}get actionRunner(){return this.actionBar.actionRunner}getElement(){return this.element}getItemAction(e){return this.actionBar.getAction(e)}setActions(e,t){this.clear();const i=e?e.slice(0):[];this.hasSecondaryActions=!!(t&&t.length>0),this.hasSecondaryActions&&t&&(this.toggleMenuAction.menuActions=t.slice(0),i.push(this.toggleMenuAction)),i.forEach(n=>{this.actionBar.push(n,{icon:!0,label:!1,keybinding:this.getKeybindingLabel(n)})})}getKeybindingLabel(e){var t,i,n;const o=this.lookupKeybindings?(i=(t=this.options).getKeyBinding)===null||i===void 0?void 0:i.call(t,e):void 0;return(n=o==null?void 0:o.getLabel())!==null&&n!==void 0?n:void 0}clear(){this.submenuActionViewItems=[],this.disposables.clear(),this.actionBar.clear()}dispose(){this.clear(),this.disposables.dispose(),super.dispose()}}class Sb extends Os{constructor(e,t){t=t||p("moreActions","More Actions..."),super(Sb.ID,t,void 0,!0),this._menuActions=[],this.toggleDropdownMenu=e}async run(){this.toggleDropdownMenu()}get menuActions(){return this._menuActions}set menuActions(e){this._menuActions=e}}Sb.ID="toolbar.toggle.more";var GU=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Ll=function(s,e){return function(t,i){e(t,i,s)}};let Jy=class extends B_e{constructor(e,t,i,n,o,r,a){super(e,o,{getKeyBinding:d=>{var c;return(c=r.lookupKeybinding(d.id))!==null&&c!==void 0?c:void 0},...t,allowContextMenu:!0,skipTelemetry:typeof(t==null?void 0:t.telemetrySource)=="string"}),this._options=t,this._menuService=i,this._contextKeyService=n,this._contextMenuService=o,this._sessionDisposables=this._store.add(new ie);const l=t==null?void 0:t.telemetrySource;l&&this._store.add(this.actionBar.onDidRun(d=>a.publicLog2("workbenchActionExecuted",{id:d.action.id,from:l})))}setActions(e,t=[],i){var n,o,r;this._sessionDisposables.clear();const a=e.slice(),l=t.slice(),d=[];let c=0;const u=[];let h=!1;if(((n=this._options)===null||n===void 0?void 0:n.hiddenItemStrategy)!==-1)for(let g=0;g<a.length;g++){const f=a[g];!(f instanceof Xr)&&!(f instanceof E0)||f.hideActions&&(d.push(f.hideActions.toggle),f.hideActions.toggle.checked&&c++,f.hideActions.isHidden&&(h=!0,a[g]=void 0,((o=this._options)===null||o===void 0?void 0:o.hiddenItemStrategy)!==0&&(u[g]=f)))}if(((r=this._options)===null||r===void 0?void 0:r.overflowBehavior)!==void 0){const g=Jge(new Set(this._options.overflowBehavior.exempted),ht.map(a,_=>_==null?void 0:_.id)),f=this._options.overflowBehavior.maxItems-g.size;let m=0;for(let _=0;_<a.length;_++){const v=a[_];v&&(m++,!g.has(v.id)&&m>=f&&(a[_]=void 0,u[_]=v))}}GF(a),GF(u),super.setActions(a,In.join(u,l)),d.length>0&&this._sessionDisposables.add(Y(this.getElement(),"contextmenu",g=>{var f,m,_,v,b;const C=new zr(Xe(this.getElement()),g),w=this.getItemAction(C.target);if(!w)return;C.preventDefault(),C.stopPropagation();let S=!1;if(c===1&&((f=this._options)===null||f===void 0?void 0:f.hiddenItemStrategy)===0){S=!0;for(let k=0;k<d.length;k++)if(d[k].checked){d[k]=Rp({id:w.id,label:w.label,checked:!0,enabled:!1,run(){}});break}}let x;if(!S&&(w instanceof Xr||w instanceof E0)){if(!w.hideActions)return;x=w.hideActions.hide}else x=Rp({id:"label",label:p("hide","Hide"),enabled:!1,run(){}});const L=In.join([x],d);!((m=this._options)===null||m===void 0)&&m.resetMenu&&!i&&(i=[this._options.resetMenu]),h&&i&&(L.push(new In),L.push(Rp({id:"resetThisMenu",label:p("resetThisMenu","Reset Menu"),run:()=>this._menuService.resetHiddenStates(i)}))),this._contextMenuService.showContextMenu({getAnchor:()=>C,getActions:()=>L,menuId:(_=this._options)===null||_===void 0?void 0:_.contextMenu,menuActionOptions:{renderShortTitle:!0,...(v=this._options)===null||v===void 0?void 0:v.menuOptions},skipTelemetry:typeof((b=this._options)===null||b===void 0?void 0:b.telemetrySource)=="string",contextKeyService:this._contextKeyService})}))}};Jy=GU([Ll(2,qa),Ll(3,je),Ll(4,Nr),Ll(5,qt),Ll(6,Do)],Jy);let dM=class extends Jy{constructor(e,t,i,n,o,r,a,l){super(e,{resetMenu:t,...i},n,o,r,a,l),this._onDidChangeMenuItems=this._store.add(new W);const d=this._store.add(n.createMenu(t,o,{emitEventsForSubmenuChanges:!0})),c=()=>{var u,h,g;const f=[],m=[];hO(d,i==null?void 0:i.menuOptions,{primary:f,secondary:m},(u=i==null?void 0:i.toolbarOptions)===null||u===void 0?void 0:u.primaryGroup,(h=i==null?void 0:i.toolbarOptions)===null||h===void 0?void 0:h.shouldInlineSubmenu,(g=i==null?void 0:i.toolbarOptions)===null||g===void 0?void 0:g.useSeparatorsInPrimaryActions),e.classList.toggle("has-no-actions",f.length===0&&m.length===0),super.setActions(f,m)};this._store.add(d.onDidChange(()=>{c(),this._onDidChangeMenuItems.fire(this)})),c()}setActions(){throw new pi("This toolbar is populated from a menu.")}};dM=GU([Ll(3,qa),Ll(4,je),Ll(5,Nr),Ll(6,qt),Ll(7,Do)],dM);class W_e extends Eg{constructor(e){super(),this._getContext=e}runAction(e,t){return super.runAction(e,this._getContext())}}var V_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},H_e=function(s,e){return function(t,i){e(t,i,s)}};class z_e{constructor(e){this.viewModel=e}getId(){return this.viewModel}}let eL=class extends j{constructor(e,t,i,n){super(),this._container=e,this._overflowWidgetsDomNode=t,this._workbenchUIElementFactory=i,this._instantiationService=n,this._viewModel=kt(this,void 0),this._collapsed=nt(this,r=>{var a;return(a=this._viewModel.read(r))===null||a===void 0?void 0:a.collapsed.read(r)}),this._contentHeight=kt(this,500),this.height=nt(this,r=>(this._collapsed.read(r)?0:this._contentHeight.read(r))+this._outerEditorHeight),this._modifiedContentWidth=kt(this,0),this._modifiedWidth=kt(this,0),this._originalContentWidth=kt(this,0),this._originalWidth=kt(this,0),this.maxScroll=nt(this,r=>{const a=this._modifiedContentWidth.read(r)-this._modifiedWidth.read(r),l=this._originalContentWidth.read(r)-this._originalWidth.read(r);return a>l?{maxScroll:a,width:this._modifiedWidth.read(r)}:{maxScroll:l,width:this._originalWidth.read(r)}}),this._elements=hi("div.multiDiffEntry",[hi("div.content",{style:{display:"flex",flexDirection:"column",flex:"1",overflow:"hidden"}},[hi("div.header@header",[hi("div.collapse-button@collapseButton"),hi("div.title.show-file-icons@title",[]),hi("div.actions@actions")]),hi("div.editorParent",{style:{flex:"1",display:"flex",flexDirection:"column"}},[hi("div.editorContainer@editor",{style:{flex:"1"}})])])]),this.editor=this._register(this._instantiationService.createInstance(Vu,this._elements.editor,{overflowWidgetsDomNode:this._overflowWidgetsDomNode},{})),this.isModifedFocused=g8(this.editor.getModifiedEditor()),this.isOriginalFocused=g8(this.editor.getOriginalEditor()),this.isFocused=nt(this,r=>this.isModifedFocused.read(r)||this.isOriginalFocused.read(r)),this._resourceLabel=this._workbenchUIElementFactory.createResourceLabel?this._register(this._workbenchUIElementFactory.createResourceLabel(this._elements.title)):void 0,this._dataStore=new ie,this._headerHeight=this._elements.header.clientHeight;const o=new Vy(this._elements.collapseButton,{});this._register(Rt(r=>{o.element.className="",o.icon=this._collapsed.read(r)?le.chevronRight:le.chevronDown})),this._register(o.onDidClick(()=>{var r;(r=this._viewModel.get())===null||r===void 0||r.collapsed.set(!this._collapsed.get(),void 0)})),this._register(Rt(r=>{this._elements.editor.style.display=this._collapsed.read(r)?"none":"block"})),this.editor.getModifiedEditor().onDidLayoutChange(r=>{const a=this.editor.getModifiedEditor().getLayoutInfo().contentWidth;this._modifiedWidth.set(a,void 0)}),this.editor.getOriginalEditor().onDidLayoutChange(r=>{const a=this.editor.getOriginalEditor().getLayoutInfo().contentWidth;this._originalWidth.set(a,void 0)}),this._register(this.editor.onDidContentSizeChange(r=>{Jw(a=>{this._contentHeight.set(r.contentHeight,a),this._modifiedContentWidth.set(this.editor.getModifiedEditor().getContentWidth(),a),this._originalContentWidth.set(this.editor.getOriginalEditor().getContentWidth(),a)})})),this._register(Rt(r=>{const a=this.isFocused.read(r);this._elements.root.classList.toggle("focused",a)})),this._container.appendChild(this._elements.root),this._outerEditorHeight=38,this._register(this._instantiationService.createInstance(dM,this._elements.actions,N.MultiDiffEditorFileToolbar,{actionRunner:this._register(new W_e(()=>{var r,a;return(a=(r=this._viewModel.get())===null||r===void 0?void 0:r.diffEditorViewModel)===null||a===void 0?void 0:a.model.modified.uri})),menuOptions:{shouldForwardArgs:!0}}))}setScrollLeft(e){this._modifiedContentWidth.get()-this._modifiedWidth.get()>this._originalContentWidth.get()-this._originalWidth.get()?this.editor.getModifiedEditor().setScrollLeft(e):this.editor.getOriginalEditor().setScrollLeft(e)}setData(e){function t(n){return{...n,scrollBeyondLastLine:!1,hideUnchangedRegions:{enabled:!0},scrollbar:{vertical:"hidden",horizontal:"hidden",handleMouseWheel:!1,useShadows:!1},renderOverviewRuler:!1,fixedOverflowWidgets:!0}}const i=e.viewModel.entry.value;i.onOptionsDidChange&&this._dataStore.add(i.onOptionsDidChange(()=>{var n;this.editor.updateOptions(t((n=i.options)!==null&&n!==void 0?n:{}))})),Jw(n=>{var o,r;(o=this._resourceLabel)===null||o===void 0||o.setUri(e.viewModel.diffEditorViewModel.model.modified.uri),this._dataStore.clear(),this._viewModel.set(e.viewModel,n),this.editor.setModel(e.viewModel.diffEditorViewModel,n),this.editor.updateOptions(t((r=i.options)!==null&&r!==void 0?r:{}))})}render(e,t,i,n){this._elements.root.style.visibility="visible",this._elements.root.style.top=`${e.start}px`,this._elements.root.style.height=`${e.length}px`,this._elements.root.style.width=`${t}px`,this._elements.root.style.position="absolute";const o=Math.max(0,Math.min(e.length-this._headerHeight,n.start-e.start));this._elements.header.style.transform=`translateY(${o}px)`,Jw(r=>{this.editor.layout({width:t,height:e.length-this._outerEditorHeight})}),this.editor.getOriginalEditor().setScrollTop(i),this._elements.header.classList.toggle("shadow",o>0||i>0)}hide(){this._elements.root.style.top="-100000px",this._elements.root.style.visibility="hidden"}};eL=V_e([H_e(3,We)],eL);function g8(s){return Mi(e=>{const t=new ie;return t.add(s.onDidFocusEditorWidget(()=>e(!0))),t.add(s.onDidBlurEditorWidget(()=>e(!1))),t},()=>s.hasWidgetFocus())}class U_e{constructor(e){this._create=e,this._unused=new Set,this._used=new Set,this._itemData=new Map}getUnusedObj(e){var t;let i;if(this._unused.size===0)i=this._create(e),this._itemData.set(i,e);else{const n=[...this._unused.values()];i=(t=n.find(o=>this._itemData.get(o).getId()===e.getId()))!==null&&t!==void 0?t:n[0],this._unused.delete(i),this._itemData.set(i,e),i.setData(e)}return this._used.add(i),{object:i,dispose:()=>{this._used.delete(i),this._unused.size>5?i.dispose():this._unused.add(i)}}}dispose(){for(const e of this._used)e.dispose();for(const e of this._unused)e.dispose();this._used.clear(),this._unused.clear()}}var $_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},f8=function(s,e){return function(t,i){e(t,i,s)}};let cM=class extends j{constructor(e,t,i,n,o,r){super(),this._element=e,this._dimension=t,this._viewModel=i,this._workbenchUIElementFactory=n,this._parentContextKeyService=o,this._parentInstantiationService=r,this._elements=hi("div",{style:{overflowY:"hidden"}},[hi("div@content",{style:{overflow:"hidden"}}),hi("div.monaco-editor@overflowWidgetsDomNode",{})]),this._sizeObserver=this._register(new VU(this._element,void 0)),this._objectPool=this._register(new U_e(l=>{const d=this._instantiationService.createInstance(eL,this._elements.content,this._elements.overflowWidgetsDomNode,this._workbenchUIElementFactory);return d.setData(l),d})),this._scrollable=this._register(new a_({forceIntegerValues:!1,scheduleAtNextAnimationFrame:l=>yo(Xe(this._element),l),smoothScrollDuration:100})),this._scrollableElement=this._register(new Lx(this._elements.root,{vertical:1,horizontal:1,className:"monaco-component",useShadows:!1},this._scrollable)),this.scrollTop=Mi(this._scrollableElement.onScroll,()=>this._scrollableElement.getScrollPosition().scrollTop),this.scrollLeft=Mi(this._scrollableElement.onScroll,()=>this._scrollableElement.getScrollPosition().scrollLeft),this._viewItems=g_(this,(l,d)=>{const c=this._viewModel.read(l);return c?c.items.read(l).map(h=>d.add(new j_e(h,this._objectPool,this.scrollLeft))):[]}),this._totalHeight=this._viewItems.map(this,(l,d)=>l.reduce((c,u)=>c+u.contentHeight.read(d),0)),this.activeDiffItem=nt(this,l=>this._viewItems.read(l).find(d=>{var c;return(c=d.template.read(l))===null||c===void 0?void 0:c.isFocused.read(l)})),this.lastActiveDiffItem=Kme((l,d)=>{var c;return(c=this.activeDiffItem.read(l))!==null&&c!==void 0?c:d}),this._contextKeyService=this._register(this._parentContextKeyService.createScoped(this._element)),this._instantiationService=this._parentInstantiationService.createChild(new _C([je,this._contextKeyService])),this._contextKeyService.createKey(T.inMultiDiffEditor.key,!0);const a=this._parentContextKeyService.createKey(T.multiDiffEditorAllCollapsed.key,!1);this._register(Rt(l=>{const d=this._viewModel.read(l);if(d){const c=d.items.read(l).every(u=>u.collapsed.read(l));a.set(c)}})),this._register(Rt(l=>{const d=this.lastActiveDiffItem.read(l);mi(c=>{var u;(u=this._viewModel.read(l))===null||u===void 0||u.activeDiffItem.set(d==null?void 0:d.viewModel,c)})})),this._register(Rt(l=>{const d=this._dimension.read(l);this._sizeObserver.observe(d)})),this._elements.content.style.position="relative",this._register(Rt(l=>{const d=this._sizeObserver.height.read(l);this._elements.root.style.height=`${d}px`;const c=this._totalHeight.read(l);this._elements.content.style.height=`${c}px`;const u=this._sizeObserver.width.read(l);let h=u;const g=this._viewItems.read(l),f=aP(g,m=>m.maxScroll.read(l).maxScroll);if(f){const m=f.maxScroll.read(l);h=u+m.maxScroll}this._scrollableElement.setScrollDimensions({width:u,height:d,scrollHeight:c,scrollWidth:h})})),e.replaceChildren(this._scrollableElement.getDomNode()),this._register(Fe(()=>{e.replaceChildren()})),this._register(this._register(Rt(l=>{Jw(d=>{this.render(l)})})))}render(e){const t=this.scrollTop.read(e);let i=0,n=0,o=0;const r=this._sizeObserver.height.read(e),a=rt.ofStartAndLength(t,r),l=this._sizeObserver.width.read(e);for(const d of this._viewItems.read(e)){const c=d.contentHeight.read(e),u=Math.min(c,r),h=rt.ofStartAndLength(n,u),g=rt.ofStartAndLength(o,c);if(g.isBefore(a))i-=c-u,d.hide();else if(g.isAfter(a))d.hide();else{const f=Math.max(0,Math.min(a.start-g.start,c-u));i-=f;const m=rt.ofStartAndLength(t+i,r);d.render(h,f,l,m)}n+=u,o+=c}this._elements.content.style.transform=`translateY(${-(t+i)}px)`}};cM=$_e([f8(4,je),f8(5,We)],cM);class j_e extends j{constructor(e,t,i){super(),this.viewModel=e,this._objectPool=t,this._scrollLeft=i,this._lastTemplateData=kt(this,{contentHeight:500,maxScroll:{maxScroll:0,width:0}}),this._templateRef=this._register(jy(this,void 0)),this.contentHeight=nt(this,n=>{var o,r,a;return(a=(r=(o=this._templateRef.read(n))===null||o===void 0?void 0:o.object.height)===null||r===void 0?void 0:r.read(n))!==null&&a!==void 0?a:this._lastTemplateData.read(n).contentHeight}),this.maxScroll=nt(this,n=>{var o,r;return(r=(o=this._templateRef.read(n))===null||o===void 0?void 0:o.object.maxScroll.read(n))!==null&&r!==void 0?r:this._lastTemplateData.read(n).maxScroll}),this.template=nt(this,n=>{var o;return(o=this._templateRef.read(n))===null||o===void 0?void 0:o.object}),this._isHidden=kt(this,!1),this._register(Rt(n=>{var o;const r=this._scrollLeft.read(n);(o=this._templateRef.read(n))===null||o===void 0||o.object.setScrollLeft(r)})),this._register(Rt(n=>{const o=this._templateRef.read(n);!o||!this._isHidden.read(n)||o.object.isFocused.read(n)||mi(l=>{this._lastTemplateData.set({contentHeight:o.object.height.get(),maxScroll:{maxScroll:0,width:0}},l),o.object.hide(),this._templateRef.set(void 0,l)})}))}dispose(){this.hide(),super.dispose()}toString(){return`VirtualViewItem(${this.viewModel.entry.value.title})`}hide(){this._isHidden.set(!0,void 0)}render(e,t,i,n){this._isHidden.set(!1,void 0);let o=this._templateRef.get();o||(o=this._objectPool.getUnusedObj(new z_e(this.viewModel)),this._templateRef.set(o,void 0)),o.object.render(e,i,t,n)}}R("multiDiffEditor.headerBackground",{dark:"#808080",light:"#b4b4b4",hcDark:"#808080",hcLight:"#b4b4b4"},p("multiDiffEditor.headerBackground","The background color of the diff editor's header"));var K_e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},q_e=function(s,e){return function(t,i){e(t,i,s)}};let uM=class extends j{constructor(e,t,i){super(),this._element=e,this._workbenchUIElementFactory=t,this._instantiationService=i,this._dimension=kt(this,void 0),this._viewModel=kt(this,void 0),this._widgetImpl=g_(this,(n,o)=>(fl(eL,n),o.add(this._instantiationService.createInstance(fl(cM,n),this._element,this._dimension,this._viewModel,this._workbenchUIElementFactory)))),this._register(TC(this._widgetImpl))}};uM=K_e([q_e(2,We)],uM);function G_e(s,e,t){return He.initialize(t||{}).createInstance(aM,s,e)}function Z_e(s){return He.get(It).onCodeEditorAdd(t=>{s(t)})}function Y_e(s){return He.get(It).onDiffEditorAdd(t=>{s(t)})}function X_e(){return He.get(It).listCodeEditors()}function Q_e(){return He.get(It).listDiffEditors()}function J_e(s,e,t){return He.initialize(t||{}).createInstance(lM,s,e)}function eve(s,e){const t=He.initialize(e||{});return new uM(s,{},t)}function tve(s){if(typeof s.id!="string"||typeof s.run!="function")throw new Error("Invalid command descriptor, `id` and `run` are required properties!");return Ct.registerCommand(s.id,s.run)}function ive(s){if(typeof s.id!="string"||typeof s.label!="string"||typeof s.run!="function")throw new Error("Invalid action descriptor, `id`, `label` and `run` are required properties!");const e=ee.deserialize(s.precondition),t=(n,...o)=>Nn.runEditorCommand(n,o,e,(r,a,l)=>Promise.resolve(s.run(a,...l))),i=new ie;if(i.add(Ct.registerCommand(s.id,t)),s.contextMenuGroupId){const n={command:{id:s.id,title:s.label},when:e,group:s.contextMenuGroupId,order:s.contextMenuOrder||0};i.add(Wn.appendMenuItem(N.EditorContext,n))}if(Array.isArray(s.keybindings)){const n=He.get(qt);if(!(n instanceof Mm))console.warn("Cannot add keybinding because the editor is configured with an unrecognized KeybindingService");else{const o=ee.and(e,ee.deserialize(s.keybindingContext));i.add(n.addDynamicKeybindings(s.keybindings.map(r=>({keybinding:r,command:s.id,when:o}))))}}return i}function nve(s){return ZU([s])}function ZU(s){const e=He.get(qt);return e instanceof Mm?e.addDynamicKeybindings(s.map(t=>({keybinding:t.keybinding,command:t.command,commandArgs:t.commandArgs,when:ee.deserialize(t.when)}))):(console.warn("Cannot add keybinding because the editor is configured with an unrecognized KeybindingService"),j.None)}function sve(s,e,t){const i=He.get(fi),n=i.getLanguageIdByMimeType(e)||e;return qU(He.get(vi),i,s,n,t)}function ove(s,e){const t=He.get(fi),i=t.getLanguageIdByMimeType(e)||e||er;s.setLanguage(t.createById(i))}function rve(s,e,t){s&&He.get(ld).changeOne(e,s.uri,t)}function ave(s){He.get(ld).changeAll(s,[])}function lve(s){return He.get(ld).read(s)}function dve(s){return He.get(ld).onMarkerChanged(s)}function cve(s){return He.get(vi).getModel(s)}function uve(){return He.get(vi).getModels()}function hve(s){return He.get(vi).onModelAdded(s)}function gve(s){return He.get(vi).onModelRemoved(s)}function fve(s){return He.get(vi).onModelLanguageChanged(t=>{s({model:t.model,oldLanguage:t.oldLanguageId})})}function pve(s){return dne(He.get(vi),He.get(Jt),s)}function mve(s,e){const t=He.get(fi),i=He.get(lr);return pP.colorizeElement(i,t,s,e).then(()=>{i.registerEditorContainer(s)})}function _ve(s,e,t){const i=He.get(fi);return He.get(lr).registerEditorContainer(Ci.document.body),pP.colorize(i,s,e,t)}function vve(s,e,t=4){return He.get(lr).registerEditorContainer(Ci.document.body),pP.colorizeModelLine(s,e,t)}function bve(s){const e=xi.get(s);return e||{getInitialState:()=>pm,tokenize:(t,i,n)=>hP(s,n)}}function Cve(s,e){xi.getOrCreate(e);const t=bve(e),i=Kl(s),n=[];let o=t.getInitialState();for(let r=0,a=i.length;r<a;r++){const l=i[r],d=t.tokenize(l,!0,o);n[r]=d.tokens,o=d.endState}return n}function wve(s,e){He.get(lr).defineTheme(s,e)}function Sve(s){He.get(lr).setTheme(s)}function yve(){zN.clearAllFontInfos()}function Lve(s,e){return Ct.registerCommand({id:s,handler:e})}function xve(s){return He.get(No).registerOpener({async open(t){return typeof t=="string"&&(t=Pe.parse(t)),s.open(t)}})}function Dve(s){return He.get(It).registerCodeEditorOpenHandler(async(t,i,n)=>{var o;if(!i)return null;const r=(o=t.options)===null||o===void 0?void 0:o.selection;let a;return r&&typeof r.endLineNumber=="number"&&typeof r.endColumn=="number"?a=r:r&&(a={lineNumber:r.startLineNumber,column:r.startColumn}),await s.openCodeEditor(i,t.resource,a)?i:null})}function kve(){return{create:G_e,getEditors:X_e,getDiffEditors:Q_e,onDidCreateEditor:Z_e,onDidCreateDiffEditor:Y_e,createDiffEditor:J_e,addCommand:tve,addEditorAction:ive,addKeybindingRule:nve,addKeybindingRules:ZU,createModel:sve,setModelLanguage:ove,setModelMarkers:rve,getModelMarkers:lve,removeAllMarkers:ave,onDidChangeMarkers:dve,getModels:uve,getModel:cve,onDidCreateModel:hve,onWillDisposeModel:gve,onDidChangeModelLanguage:fve,createWebWorker:pve,colorizeElement:mve,colorize:_ve,colorizeModelLine:vve,tokenize:Cve,defineTheme:wve,setTheme:Sve,remeasureFonts:yve,registerCommand:Lve,registerLinkOpener:xve,registerEditorOpener:Dve,AccessibilitySupport:JE,ContentWidgetPositionPreference:oN,CursorChangeReason:rN,DefaultEndOfLine:aN,EditorAutoIndentStrategy:dN,EditorOption:cN,EndOfLinePreference:uN,EndOfLineSequence:hN,MinimapPosition:wN,MouseTargetType:SN,OverlayWidgetPositionPreference:yN,OverviewRulerLane:LN,GlyphMarginLane:gN,RenderLineNumbersType:DN,RenderMinimap:kN,ScrollbarVisibility:EN,ScrollType:IN,TextEditorCursorBlinkingStyle:PN,TextEditorCursorStyle:ON,TrackedRangeStickiness:FN,WrappingIndent:BN,InjectedTextCursorStops:pN,PositionAffinity:xN,ShowAiIconMode:TN,ConfigurationChangedEvent:yW,BareFontInfo:hg,FontInfo:HN,TextModelResolvedOptions:Aw,FindMatch:M0,ApplyUpdateResult:Tv,EditorZoom:fr,createMultiFileDiffEditor:eve,EditorType:aC,EditorOptions:ja}}function Ive(s,e){if(!e||!Array.isArray(e))return!1;for(const t of e)if(!s(t))return!1;return!0}function q1(s,e){return typeof s=="boolean"?s:e}function p8(s,e){return typeof s=="string"?s:e}function Eve(s){const e={};for(const t of s)e[t]=!0;return e}function m8(s,e=!1){e&&(s=s.map(function(i){return i.toLowerCase()}));const t=Eve(s);return e?function(i){return t[i.toLowerCase()]!==void 0&&t.hasOwnProperty(i.toLowerCase())}:function(i){return t[i]!==void 0&&t.hasOwnProperty(i)}}function hM(s,e){e=e.replace(/@@/g,"");let t=0,i;do i=!1,e=e.replace(/@(\w+)/g,function(o,r){i=!0;let a="";if(typeof s[r]=="string")a=s[r];else if(s[r]&&s[r]instanceof RegExp)a=s[r].source;else throw s[r]===void 0?oi(s,"language definition does not contain attribute '"+r+"', used at: "+e):oi(s,"attribute reference '"+r+"' must be a string, used at: "+e);return qf(a)?"":"(?:"+a+")"}),t++;while(i&&t<5);e=e.replace(/\x01/g,"@");const n=(s.ignoreCase?"i":"")+(s.unicode?"u":"");return new RegExp(e,n)}function Nve(s,e,t,i){if(i<0)return s;if(i<e.length)return e[i];if(i>=100){i=i-100;const n=t.split(".");if(n.unshift(t),i<n.length)return n[i]}return null}function Tve(s,e,t,i){let n=-1,o=t,r=t.match(/^\$(([sS]?)(\d\d?)|#)(.*)$/);r&&(r[3]&&(n=parseInt(r[3]),r[2]&&(n=n+100)),o=r[4]);let a="~",l=o;!o||o.length===0?(a="!=",l=""):/^\w*$/.test(l)?a="==":(r=o.match(/^(@|!@|~|!~|==|!=)(.*)$/),r&&(a=r[1],l=r[2]));let d;if((a==="~"||a==="!~")&&/^(\w|\|)*$/.test(l)){const c=m8(l.split("|"),s.ignoreCase);d=function(u){return a==="~"?c(u):!c(u)}}else if(a==="@"||a==="!@"){const c=s[l];if(!c)throw oi(s,"the @ match target '"+l+"' is not defined, in rule: "+e);if(!Ive(function(h){return typeof h=="string"},c))throw oi(s,"the @ match target '"+l+"' must be an array of strings, in rule: "+e);const u=m8(c,s.ignoreCase);d=function(h){return a==="@"?u(h):!u(h)}}else if(a==="~"||a==="!~")if(l.indexOf("$")<0){const c=hM(s,"^"+l+"$");d=function(u){return a==="~"?c.test(u):!c.test(u)}}else d=function(c,u,h,g){return hM(s,"^"+Ac(s,l,u,h,g)+"$").test(c)};else if(l.indexOf("$")<0){const c=du(s,l);d=function(u){return a==="=="?u===c:u!==c}}else{const c=du(s,l);d=function(u,h,g,f,m){const _=Ac(s,c,h,g,f);return a==="=="?u===_:u!==_}}return n===-1?{name:t,value:i,test:function(c,u,h,g){return d(c,c,u,h,g)}}:{name:t,value:i,test:function(c,u,h,g){const f=Nve(c,u,h,n);return d(f||"",c,u,h,g)}}}function gM(s,e,t){if(t){if(typeof t=="string")return t;if(t.token||t.token===""){if(typeof t.token!="string")throw oi(s,"a 'token' attribute must be of type string, in rule: "+e);{const i={token:t.token};if(t.token.indexOf("$")>=0&&(i.tokenSubst=!0),typeof t.bracket=="string")if(t.bracket==="@open")i.bracket=1;else if(t.bracket==="@close")i.bracket=-1;else throw oi(s,"a 'bracket' attribute must be either '@open' or '@close', in rule: "+e);if(t.next){if(typeof t.next!="string")throw oi(s,"the next state must be a string value in rule: "+e);{let n=t.next;if(!/^(@pop|@push|@popall)$/.test(n)&&(n[0]==="@"&&(n=n.substr(1)),n.indexOf("$")<0&&!Ine(s,Ac(s,n,"",[],""))))throw oi(s,"the next state '"+t.next+"' is not defined in rule: "+e);i.next=n}}return typeof t.goBack=="number"&&(i.goBack=t.goBack),typeof t.switchTo=="string"&&(i.switchTo=t.switchTo),typeof t.log=="string"&&(i.log=t.log),typeof t.nextEmbedded=="string"&&(i.nextEmbedded=t.nextEmbedded,s.usesEmbedded=!0),i}}else if(Array.isArray(t)){const i=[];for(let n=0,o=t.length;n<o;n++)i[n]=gM(s,e,t[n]);return{group:i}}else if(t.cases){const i=[];for(const o in t.cases)if(t.cases.hasOwnProperty(o)){const r=gM(s,e,t.cases[o]);o==="@default"||o==="@"||o===""?i.push({test:void 0,value:r,name:o}):o==="@eos"?i.push({test:function(a,l,d,c){return c},value:r,name:o}):i.push(Tve(s,e,o,r))}const n=s.defaultToken;return{test:function(o,r,a,l){for(const d of i)if(!d.test||d.test(o,r,a,l))return d.value;return n}}}else throw oi(s,"an action must be a string, an object with a 'token' or 'cases' attribute, or an array of actions; in rule: "+e)}else return{token:""}}class Mve{constructor(e){this.regex=new RegExp(""),this.action={token:""},this.matchOnlyAtLineStart=!1,this.name="",this.name=e}setRegex(e,t){let i;if(typeof t=="string")i=t;else if(t instanceof RegExp)i=t.source;else throw oi(e,"rules must start with a match string or regular expression: "+this.name);this.matchOnlyAtLineStart=i.length>0&&i[0]==="^",this.name=this.name+": "+i,this.regex=hM(e,"^(?:"+(this.matchOnlyAtLineStart?i.substr(1):i)+")")}setAction(e,t){this.action=gM(e,this.name,t)}}function YU(s,e){if(!e||typeof e!="object")throw new Error("Monarch: expecting a language definition object");const t={};t.languageId=s,t.includeLF=q1(e.includeLF,!1),t.noThrow=!1,t.maxStack=100,t.start=typeof e.start=="string"?e.start:null,t.ignoreCase=q1(e.ignoreCase,!1),t.unicode=q1(e.unicode,!1),t.tokenPostfix=p8(e.tokenPostfix,"."+t.languageId),t.defaultToken=p8(e.defaultToken,"source"),t.usesEmbedded=!1;const i=e;i.languageId=s,i.includeLF=t.includeLF,i.ignoreCase=t.ignoreCase,i.unicode=t.unicode,i.noThrow=t.noThrow,i.usesEmbedded=t.usesEmbedded,i.stateNames=e.tokenizer,i.defaultToken=t.defaultToken;function n(r,a,l){for(const d of l){let c=d.include;if(c){if(typeof c!="string")throw oi(t,"an 'include' attribute must be a string at: "+r);if(c[0]==="@"&&(c=c.substr(1)),!e.tokenizer[c])throw oi(t,"include target '"+c+"' is not defined at: "+r);n(r+"."+c,a,e.tokenizer[c])}else{const u=new Mve(r);if(Array.isArray(d)&&d.length>=1&&d.length<=3)if(u.setRegex(i,d[0]),d.length>=3)if(typeof d[1]=="string")u.setAction(i,{token:d[1],next:d[2]});else if(typeof d[1]=="object"){const h=d[1];h.next=d[2],u.setAction(i,h)}else throw oi(t,"a next state as the last element of a rule can only be given if the action is either an object or a string, at: "+r);else u.setAction(i,d[1]);else{if(!d.regex)throw oi(t,"a rule must either be an array, or an object with a 'regex' or 'include' field at: "+r);d.name&&typeof d.name=="string"&&(u.name=d.name),d.matchOnlyAtStart&&(u.matchOnlyAtLineStart=q1(d.matchOnlyAtLineStart,!1)),u.setRegex(i,d.regex),u.setAction(i,d.action)}a.push(u)}}}if(!e.tokenizer||typeof e.tokenizer!="object")throw oi(t,"a language definition must define the 'tokenizer' attribute as an object");t.tokenizer=[];for(const r in e.tokenizer)if(e.tokenizer.hasOwnProperty(r)){t.start||(t.start=r);const a=e.tokenizer[r];t.tokenizer[r]=new Array,n("tokenizer."+r,t.tokenizer[r],a)}if(t.usesEmbedded=i.usesEmbedded,e.brackets){if(!Array.isArray(e.brackets))throw oi(t,"the 'brackets' attribute must be defined as an array")}else e.brackets=[{open:"{",close:"}",token:"delimiter.curly"},{open:"[",close:"]",token:"delimiter.square"},{open:"(",close:")",token:"delimiter.parenthesis"},{open:"<",close:">",token:"delimiter.angle"}];const o=[];for(const r of e.brackets){let a=r;if(a&&Array.isArray(a)&&a.length===3&&(a={token:a[2],open:a[0],close:a[1]}),a.open===a.close)throw oi(t,"open and close brackets in a 'brackets' attribute must be different: "+a.open+`
 hint: use the 'bracket' attribute if matching on equal brackets is required.`);if(typeof a.open=="string"&&typeof a.token=="string"&&typeof a.close=="string")o.push({token:a.token+t.tokenPostfix,open:du(t,a.open),close:du(t,a.close)});else throw oi(t,"every element in the 'brackets' array must be a '{open,close,token}' object or array")}return t.brackets=o,t.noThrow=!0,t}function Rve(s){hm.registerLanguage(s)}function Ave(){let s=[];return s=s.concat(hm.getLanguages()),s}function Pve(s){return He.get(fi).languageIdCodec.encodeLanguageId(s)}function Ove(s,e){return He.withServices(()=>{const i=He.get(fi).onDidRequestRichLanguageFeatures(n=>{n===s&&(i.dispose(),e())});return i})}function Fve(s,e){return He.withServices(()=>{const i=He.get(fi).onDidRequestBasicLanguageFeatures(n=>{n===s&&(i.dispose(),e())});return i})}function Bve(s,e){if(!He.get(fi).isRegisteredLanguageId(s))throw new Error(`Cannot set configuration for unknown language ${s}`);return He.get(Jt).register(s,e,100)}class Wve{constructor(e,t){this._languageId=e,this._actual=t}dispose(){}getInitialState(){return this._actual.getInitialState()}tokenize(e,t,i){if(typeof this._actual.tokenize=="function")return yb.adaptTokenize(this._languageId,this._actual,e,i);throw new Error("Not supported!")}tokenizeEncoded(e,t,i){const n=this._actual.tokenizeEncoded(e,i);return new qL(n.tokens,n.endState)}}class yb{constructor(e,t,i,n){this._languageId=e,this._actual=t,this._languageService=i,this._standaloneThemeService=n}dispose(){}getInitialState(){return this._actual.getInitialState()}static _toClassicTokens(e,t){const i=[];let n=0;for(let o=0,r=e.length;o<r;o++){const a=e[o];let l=a.startIndex;o===0?l=0:l<n&&(l=n),i[o]=new S0(l,a.scopes,t),n=l}return i}static adaptTokenize(e,t,i,n){const o=t.tokenize(i,n),r=yb._toClassicTokens(o.tokens,e);let a;return o.endState.equals(n)?a=n:a=o.endState,new PA(r,a)}tokenize(e,t,i){return yb.adaptTokenize(this._languageId,this._actual,e,i)}_toBinaryTokens(e,t){const i=e.encodeLanguageId(this._languageId),n=this._standaloneThemeService.getColorTheme().tokenTheme,o=[];let r=0,a=0;for(let d=0,c=t.length;d<c;d++){const u=t[d],h=n.match(i,u.scopes)|1024;if(r>0&&o[r-1]===h)continue;let g=u.startIndex;d===0?g=0:g<a&&(g=a),o[r++]=g,o[r++]=h,a=g}const l=new Uint32Array(r);for(let d=0;d<r;d++)l[d]=o[d];return l}tokenizeEncoded(e,t,i){const n=this._actual.tokenize(e,i),o=this._toBinaryTokens(this._languageService.languageIdCodec,n.tokens);let r;return n.endState.equals(i)?r=i:r=n.endState,new qL(o,r)}}function Vve(s){return typeof s.getInitialState=="function"}function Hve(s){return"tokenizeEncoded"in s}function XU(s){return s&&typeof s.then=="function"}function zve(s){const e=He.get(lr);if(s){const t=[null];for(let i=1,n=s.length;i<n;i++)t[i]=G.fromHex(s[i]);e.setColorMapOverride(t)}else e.setColorMapOverride(null)}function QU(s,e){return Hve(e)?new Wve(s,e):new yb(s,e,He.get(fi),He.get(lr))}function KO(s,e){const t=new XQ(async()=>{const i=await Promise.resolve(e.create());return i?Vve(i)?QU(s,i):new W0(He.get(fi),He.get(lr),s,YU(s,i),He.get(mt)):null});return xi.registerFactory(s,t)}function Uve(s,e){if(!He.get(fi).isRegisteredLanguageId(s))throw new Error(`Cannot set tokens provider for unknown language ${s}`);return XU(e)?KO(s,{create:()=>e}):xi.register(s,QU(s,e))}function $ve(s,e){const t=i=>new W0(He.get(fi),He.get(lr),s,YU(s,i),He.get(mt));return XU(e)?KO(s,{create:()=>e}):xi.register(s,t(e))}function jve(s,e){return He.get(xe).referenceProvider.register(s,e)}function Kve(s,e){return He.get(xe).renameProvider.register(s,e)}function qve(s,e){return He.get(xe).signatureHelpProvider.register(s,e)}function Gve(s,e){return He.get(xe).hoverProvider.register(s,{provideHover:(i,n,o)=>{const r=i.getWordAtPosition(n);return Promise.resolve(e.provideHover(i,n,o)).then(a=>{if(a)return!a.range&&r&&(a.range=new D(n.lineNumber,r.startColumn,n.lineNumber,r.endColumn)),a.range||(a.range=new D(n.lineNumber,n.column,n.lineNumber,n.column)),a})}})}function Zve(s,e){return He.get(xe).documentSymbolProvider.register(s,e)}function Yve(s,e){return He.get(xe).documentHighlightProvider.register(s,e)}function Xve(s,e){return He.get(xe).linkedEditingRangeProvider.register(s,e)}function Qve(s,e){return He.get(xe).definitionProvider.register(s,e)}function Jve(s,e){return He.get(xe).implementationProvider.register(s,e)}function e0e(s,e){return He.get(xe).typeDefinitionProvider.register(s,e)}function t0e(s,e){return He.get(xe).codeLensProvider.register(s,e)}function i0e(s,e,t){return He.get(xe).codeActionProvider.register(s,{providedCodeActionKinds:t==null?void 0:t.providedCodeActionKinds,documentation:t==null?void 0:t.documentation,provideCodeActions:(n,o,r,a)=>{const d=He.get(ld).read({resource:n.uri}).filter(c=>D.areIntersectingOrTouching(c,o));return e.provideCodeActions(n,o,{markers:d,only:r.only,trigger:r.trigger},a)},resolveCodeAction:e.resolveCodeAction})}function n0e(s,e){return He.get(xe).documentFormattingEditProvider.register(s,e)}function s0e(s,e){return He.get(xe).documentRangeFormattingEditProvider.register(s,e)}function o0e(s,e){return He.get(xe).onTypeFormattingEditProvider.register(s,e)}function r0e(s,e){return He.get(xe).linkProvider.register(s,e)}function a0e(s,e){return He.get(xe).completionProvider.register(s,e)}function l0e(s,e){return He.get(xe).colorProvider.register(s,e)}function d0e(s,e){return He.get(xe).foldingRangeProvider.register(s,e)}function c0e(s,e){return He.get(xe).declarationProvider.register(s,e)}function u0e(s,e){return He.get(xe).selectionRangeProvider.register(s,e)}function h0e(s,e){return He.get(xe).documentSemanticTokensProvider.register(s,e)}function g0e(s,e){return He.get(xe).documentRangeSemanticTokensProvider.register(s,e)}function f0e(s,e){return He.get(xe).inlineCompletionsProvider.register(s,e)}function p0e(s,e){return He.get(xe).inlayHintsProvider.register(s,e)}function m0e(){return{register:Rve,getLanguages:Ave,onLanguage:Ove,onLanguageEncountered:Fve,getEncodedLanguageId:Pve,setLanguageConfiguration:Bve,setColorMap:zve,registerTokensProviderFactory:KO,setTokensProvider:Uve,setMonarchTokensProvider:$ve,registerReferenceProvider:jve,registerRenameProvider:Kve,registerCompletionItemProvider:a0e,registerSignatureHelpProvider:qve,registerHoverProvider:Gve,registerDocumentSymbolProvider:Zve,registerDocumentHighlightProvider:Yve,registerLinkedEditingRangeProvider:Xve,registerDefinitionProvider:Qve,registerImplementationProvider:Jve,registerTypeDefinitionProvider:e0e,registerCodeLensProvider:t0e,registerCodeActionProvider:i0e,registerDocumentFormattingEditProvider:n0e,registerDocumentRangeFormattingEditProvider:s0e,registerOnTypeFormattingEditProvider:o0e,registerLinkProvider:r0e,registerColorProvider:l0e,registerFoldingRangeProvider:d0e,registerDeclarationProvider:c0e,registerSelectionRangeProvider:u0e,registerDocumentSemanticTokensProvider:h0e,registerDocumentRangeSemanticTokensProvider:g0e,registerInlineCompletionsProvider:f0e,registerInlayHintsProvider:p0e,DocumentHighlightKind:lN,CompletionItemKind:iN,CompletionItemTag:nN,CompletionItemInsertTextRule:tN,SymbolKind:RN,SymbolTag:AN,IndentAction:fN,CompletionTriggerKind:sN,SignatureHelpTriggerKind:MN,InlayHintKind:mN,InlineCompletionTriggerKind:_N,CodeActionTriggerType:eN,FoldingRangeKind:Rs,SelectedSuggestionInfo:BW}}const qO=ut("IEditorCancelService"),JU=new me("cancellableOperation",!1,p("cancellableOperation","Whether the editor runs a cancellable operation, e.g. like 'Peek References'"));_t(qO,class{constructor(){this._tokens=new WeakMap}add(s,e){let t=this._tokens.get(s);t||(t=s.invokeWithinContext(n=>{const o=JU.bindTo(n.get(je)),r=new Ms;return{key:o,tokens:r}}),this._tokens.set(s,t));let i;return t.key.set(!0),i=t.tokens.push(e),()=>{i&&(i(),t.key.set(!t.tokens.isEmpty()),i=void 0)}}cancel(s){const e=this._tokens.get(s);if(!e)return;const t=e.tokens.pop();t&&(t.cancel(),e.key.set(!e.tokens.isEmpty()))}},1);class _0e extends Yi{constructor(e,t){super(t),this.editor=e,this._unregister=e.invokeWithinContext(i=>i.get(qO).add(e,this))}dispose(){this._unregister(),super.dispose()}}ue(new class extends Nn{constructor(){super({id:"editor.cancelOperation",kbOpts:{weight:100,primary:9},precondition:JU})}runEditorCommand(s,e){s.get(qO).cancel(e)}});let e$=class fM{constructor(e,t){if(this.flags=t,this.flags&1){const i=e.getModel();this.modelVersionId=i?xg("{0}#{1}",i.uri.toString(),i.getVersionId()):null}else this.modelVersionId=null;this.flags&4?this.position=e.getPosition():this.position=null,this.flags&2?this.selection=e.getSelection():this.selection=null,this.flags&8?(this.scrollLeft=e.getScrollLeft(),this.scrollTop=e.getScrollTop()):(this.scrollLeft=-1,this.scrollTop=-1)}_equals(e){if(!(e instanceof fM))return!1;const t=e;return!(this.modelVersionId!==t.modelVersionId||this.scrollLeft!==t.scrollLeft||this.scrollTop!==t.scrollTop||!this.position&&t.position||this.position&&!t.position||this.position&&t.position&&!this.position.equals(t.position)||!this.selection&&t.selection||this.selection&&!t.selection||this.selection&&t.selection&&!this.selection.equalsRange(t.selection))}validate(e){return this._equals(new fM(e,this.flags))}};class Hu extends _0e{constructor(e,t,i,n){super(e,n),this._listener=new ie,t&4&&this._listener.add(e.onDidChangeCursorPosition(o=>{(!i||!D.containsPosition(i,o.position))&&this.cancel()})),t&2&&this._listener.add(e.onDidChangeCursorSelection(o=>{(!i||!D.containsRange(i,o.selection))&&this.cancel()})),t&8&&this._listener.add(e.onDidScrollChange(o=>this.cancel())),t&1&&(this._listener.add(e.onDidChangeModel(o=>this.cancel())),this._listener.add(e.onDidChangeModelContent(o=>this.cancel())))}dispose(){this._listener.dispose(),super.dispose()}}class GO extends Yi{constructor(e,t){super(t),this._listener=e.onDidChangeContent(()=>this.cancel())}dispose(){this._listener.dispose(),super.dispose()}}function td(s){return s&&typeof s.getEditorType=="function"?s.getEditorType()===aC.ICodeEditor:!1}function ZO(s){return s&&typeof s.getEditorType=="function"?s.getEditorType()===aC.IDiffEditor:!1}function v0e(s){return!!s&&typeof s=="object"&&typeof s.onDidChangeActiveEditor=="function"}function t$(s){return td(s)?s:ZO(s)?s.getModifiedEditor():v0e(s)&&td(s.activeCodeEditor)?s.activeCodeEditor:null}class Pm{static _handleEolEdits(e,t){let i;const n=[];for(const o of t)typeof o.eol=="number"&&(i=o.eol),o.range&&typeof o.text=="string"&&n.push(o);return typeof i=="number"&&e.hasModel()&&e.getModel().pushEOL(i),n}static _isFullModelReplaceEdit(e,t){if(!e.hasModel())return!1;const i=e.getModel(),n=i.validateRange(t.range);return i.getFullModelRange().equalsRange(n)}static execute(e,t,i){i&&e.pushUndoStop();const n=$a.capture(e),o=Pm._handleEolEdits(e,t);o.length===1&&Pm._isFullModelReplaceEdit(e,o[0])?e.executeEdits("formatEditsCommand",o.map(r=>_i.replace(D.lift(r.range),r.text))):e.executeEdits("formatEditsCommand",o.map(r=>_i.replaceMove(D.lift(r.range),r.text))),i&&e.pushUndoStop(),n.restoreRelativeVerticalPositionOfCursor(e)}}class _8{constructor(e){this.value=e,this._lower=e.toLowerCase()}static toKey(e){return typeof e=="string"?e.toLowerCase():e._lower}}class b0e{constructor(e){if(this._set=new Set,e)for(const t of e)this.add(t)}add(e){this._set.add(_8.toKey(e))}has(e){return this._set.has(_8.toKey(e))}}function i$(s,e,t){const i=[],n=new b0e,o=s.ordered(t);for(const a of o)i.push(a),a.extensionId&&n.add(a.extensionId);const r=e.ordered(t);for(const a of r){if(a.extensionId){if(n.has(a.extensionId))continue;n.add(a.extensionId)}i.push({displayName:a.displayName,extensionId:a.extensionId,provideDocumentFormattingEdits(l,d,c){return a.provideDocumentRangeFormattingEdits(l,l.getFullModelRange(),d,c)}})}return i}class Hg{static setFormatterSelector(e){return{dispose:Hg._selectors.unshift(e)}}static async select(e,t,i){if(e.length===0)return;const n=ht.first(Hg._selectors);if(n)return await n(e,t,i)}}Hg._selectors=new Ms;async function n$(s,e,t,i,n,o,r){const a=s.get(We),{documentRangeFormattingEditProvider:l}=s.get(xe),d=td(e)?e.getModel():e,c=l.ordered(d),u=await Hg.select(c,d,i);u&&(n.report(u),await a.invokeFunction(C0e,u,e,t,o,r))}async function C0e(s,e,t,i,n,o){var r,a;const l=s.get(oa),d=s.get(ko),c=s.get(bx);let u,h;td(t)?(u=t.getModel(),h=new Hu(t,5,void 0,n)):(u=t,h=new GO(t,n));const g=[];let f=0;for(const C of SA(i).sort(D.compareRangesUsingStarts))f>0&&D.areIntersectingOrTouching(g[f-1],C)?g[f-1]=D.fromPositions(g[f-1].getStartPosition(),C.getEndPosition()):f=g.push(C);const m=async C=>{var w,S;d.trace("[format][provideDocumentRangeFormattingEdits] (request)",(w=e.extensionId)===null||w===void 0?void 0:w.value,C);const x=await e.provideDocumentRangeFormattingEdits(u,C,u.getFormattingOptions(),h.token)||[];return d.trace("[format][provideDocumentRangeFormattingEdits] (response)",(S=e.extensionId)===null||S===void 0?void 0:S.value,x),x},_=(C,w)=>{if(!C.length||!w.length)return!1;const S=C.reduce((x,L)=>D.plusRange(x,L.range),C[0].range);if(!w.some(x=>D.intersectRanges(S,x.range)))return!1;for(const x of C)for(const L of w)if(D.intersectRanges(x.range,L.range))return!0;return!1},v=[],b=[];try{if(typeof e.provideDocumentRangesFormattingEdits=="function"){d.trace("[format][provideDocumentRangeFormattingEdits] (request)",(r=e.extensionId)===null||r===void 0?void 0:r.value,g);const C=await e.provideDocumentRangesFormattingEdits(u,g,u.getFormattingOptions(),h.token)||[];d.trace("[format][provideDocumentRangeFormattingEdits] (response)",(a=e.extensionId)===null||a===void 0?void 0:a.value,C),b.push(C)}else{for(const C of g){if(h.token.isCancellationRequested)return!0;b.push(await m(C))}for(let C=0;C<g.length;++C)for(let w=C+1;w<g.length;++w){if(h.token.isCancellationRequested)return!0;if(_(b[C],b[w])){const S=D.plusRange(g[C],g[w]),x=await m(S);g.splice(w,1),g.splice(C,1),g.push(S),b.splice(w,1),b.splice(C,1),b.push(x),C=0,w=0}}}for(const C of b){if(h.token.isCancellationRequested)return!0;const w=await l.computeMoreMinimalEdits(u.uri,C);w&&v.push(...w)}}finally{h.dispose()}if(v.length===0)return!1;if(td(t))Pm.execute(t,v,!0),t.revealPositionInCenterIfOutsideViewport(t.getPosition(),1);else{const[{range:C}]=v,w=new De(C.startLineNumber,C.startColumn,C.endLineNumber,C.endColumn);u.pushEditOperations([w],v.map(S=>({text:S.text,range:D.lift(S.range),forceMoveMarkers:!0})),S=>{for(const{range:x}of S)if(D.areIntersectingOrTouching(x,w))return[new De(x.startLineNumber,x.startColumn,x.endLineNumber,x.endColumn)];return null})}return c.notify("format",o),!0}async function w0e(s,e,t,i,n,o){const r=s.get(We),a=s.get(xe),l=td(e)?e.getModel():e,d=i$(a.documentFormattingEditProvider,a.documentRangeFormattingEditProvider,l),c=await Hg.select(d,l,t);c&&(i.report(c),await r.invokeFunction(S0e,c,e,t,n,o))}async function S0e(s,e,t,i,n,o){const r=s.get(oa),a=s.get(bx);let l,d;td(t)?(l=t.getModel(),d=new Hu(t,5,void 0,n)):(l=t,d=new GO(t,n));let c;try{const u=await e.provideDocumentFormattingEdits(l,l.getFormattingOptions(),d.token);if(c=await r.computeMoreMinimalEdits(l.uri,u),d.token.isCancellationRequested)return!0}finally{d.dispose()}if(!c||c.length===0)return!1;if(td(t))Pm.execute(t,c,i!==2),i!==2&&t.revealPositionInCenterIfOutsideViewport(t.getPosition(),1);else{const[{range:u}]=c,h=new De(u.startLineNumber,u.startColumn,u.endLineNumber,u.endColumn);l.pushEditOperations([h],c.map(g=>({text:g.text,range:D.lift(g.range),forceMoveMarkers:!0})),g=>{for(const{range:f}of g)if(D.areIntersectingOrTouching(f,h))return[new De(f.startLineNumber,f.startColumn,f.endLineNumber,f.endColumn)];return null})}return a.notify("format",o),!0}async function y0e(s,e,t,i,n,o){const r=e.documentRangeFormattingEditProvider.ordered(t);for(const a of r){const l=await Promise.resolve(a.provideDocumentRangeFormattingEdits(t,i,n,o)).catch(Zi);if(as(l))return await s.computeMoreMinimalEdits(t.uri,l)}}async function L0e(s,e,t,i,n){const o=i$(e.documentFormattingEditProvider,e.documentRangeFormattingEditProvider,t);for(const r of o){const a=await Promise.resolve(r.provideDocumentFormattingEdits(t,i,n)).catch(Zi);if(as(a))return await s.computeMoreMinimalEdits(t.uri,a)}}function s$(s,e,t,i,n,o,r){const a=e.onTypeFormattingEditProvider.ordered(t);return a.length===0||a[0].autoFormatTriggerCharacters.indexOf(n)<0?Promise.resolve(void 0):Promise.resolve(a[0].provideOnTypeFormattingEdits(t,i,n,o,r)).catch(Zi).then(l=>s.computeMoreMinimalEdits(t.uri,l))}Ct.registerCommand("_executeFormatRangeProvider",async function(s,...e){const[t,i,n]=e;zt(Pe.isUri(t)),zt(D.isIRange(i));const o=s.get(io),r=s.get(oa),a=s.get(xe),l=await o.createModelReference(t);try{return y0e(r,a,l.object.textEditorModel,D.lift(i),n,ct.None)}finally{l.dispose()}});Ct.registerCommand("_executeFormatDocumentProvider",async function(s,...e){const[t,i]=e;zt(Pe.isUri(t));const n=s.get(io),o=s.get(oa),r=s.get(xe),a=await n.createModelReference(t);try{return L0e(o,r,a.object.textEditorModel,i,ct.None)}finally{a.dispose()}});Ct.registerCommand("_executeFormatOnTypeProvider",async function(s,...e){const[t,i,n,o]=e;zt(Pe.isUri(t)),zt(H.isIPosition(i)),zt(typeof n=="string");const r=s.get(io),a=s.get(oa),l=s.get(xe),d=await r.createModelReference(t);try{return s$(a,l,d.object.textEditorModel,H.lift(i),n,o,ct.None)}finally{d.dispose()}});ja.wrappingIndent.defaultValue=0;ja.glyphMargin.defaultValue=!1;ja.autoIndent.defaultValue=3;ja.overviewRulerLanes.defaultValue=2;Hg.setFormatterSelector((s,e,t)=>Promise.resolve(s[0]));const Hs=WW();Hs.editor=kve();Hs.languages=m0e();const o$=Hs.CancellationTokenSource,r$=Hs.Emitter,a$=Hs.KeyCode,l$=Hs.KeyMod,d$=Hs.Position,c$=Hs.Range,u$=Hs.Selection,h$=Hs.SelectionDirection,g$=Hs.MarkerSeverity,f$=Hs.MarkerTag,p$=Hs.Uri,m$=Hs.Token,_$=Hs.editor,v$=Hs.languages,QI=globalThis.MonacoEnvironment;(QI!=null&&QI.globalAPI||typeof define=="function"&&define.amd)&&(globalThis.monaco=Hs);typeof globalThis.require<"u"&&typeof globalThis.require.config=="function"&&globalThis.require.config({ignoreDuplicateModules:["vscode-languageserver-types","vscode-languageserver-types/main","vscode-languageserver-textdocument","vscode-languageserver-textdocument/main","vscode-nls","vscode-nls/vscode-nls","jsonc-parser","jsonc-parser/main","vscode-uri","vscode-uri/index","vs/basic-languages/typescript/typescript"]});const MC=Object.freeze(Object.defineProperty({__proto__:null,CancellationTokenSource:o$,Emitter:r$,KeyCode:a$,KeyMod:l$,MarkerSeverity:g$,MarkerTag:f$,Position:d$,Range:c$,Selection:u$,SelectionDirection:h$,Token:m$,Uri:p$,editor:_$,languages:v$},Symbol.toStringTag,{value:"Module"})),x0e="modulepreload",D0e=function(s){return"/"+s},v8={},Ee=function(e,t,i){let n=Promise.resolve();if(t&&t.length>0){const o=document.getElementsByTagName("link");n=Promise.all(t.map(r=>{if(r=D0e(r),r in v8)return;v8[r]=!0;const a=r.endsWith(".css"),l=a?'[rel="stylesheet"]':"";if(!!i)for(let u=o.length-1;u>=0;u--){const h=o[u];if(h.href===r&&(!a||h.rel==="stylesheet"))return}else if(document.querySelector(`link[href="${r}"]${l}`))return;const c=document.createElement("link");if(c.rel=a?"stylesheet":x0e,a||(c.as="script",c.crossOrigin=""),c.href=r,document.head.appendChild(c),a)return new Promise((u,h)=>{c.addEventListener("load",u),c.addEventListener("error",()=>h(new Error(`Unable to preload CSS for ${r}`)))})}))}return n.then(()=>e()).catch(o=>{const r=new Event("vite:preloadError",{cancelable:!0});if(r.payload=o,window.dispatchEvent(r),!r.defaultPrevented)throw o})};/*!-----------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Version: 0.45.0(5e5af013f8d295555a7210df0d5f2cea0bf5dd56)
 * Released under the MIT license
 * https://github.com/microsoft/monaco-editor/blob/main/LICENSE.txt
 *-----------------------------------------------------------------------------*/var k0e=Object.defineProperty,I0e=Object.getOwnPropertyDescriptor,E0e=Object.getOwnPropertyNames,N0e=Object.prototype.hasOwnProperty,b8=(s,e,t,i)=>{if(e&&typeof e=="object"||typeof e=="function")for(let n of E0e(e))!N0e.call(s,n)&&n!==t&&k0e(s,n,{get:()=>e[n],enumerable:!(i=I0e(e,n))||i.enumerable});return s},T0e=(s,e,t)=>(b8(s,e,"default"),t&&b8(t,e,"default")),Cv={};T0e(Cv,MC);var b$={},JI={},C$=class{constructor(s){Ni(this,"_languageId");Ni(this,"_loadingTriggered");Ni(this,"_lazyLoadPromise");Ni(this,"_lazyLoadPromiseResolve");Ni(this,"_lazyLoadPromiseReject");this._languageId=s,this._loadingTriggered=!1,this._lazyLoadPromise=new Promise((e,t)=>{this._lazyLoadPromiseResolve=e,this._lazyLoadPromiseReject=t})}static getOrCreate(s){return JI[s]||(JI[s]=new C$(s)),JI[s]}load(){return this._loadingTriggered||(this._loadingTriggered=!0,b$[this._languageId].loader().then(s=>this._lazyLoadPromiseResolve(s),s=>this._lazyLoadPromiseReject(s))),this._lazyLoadPromise}};function Ae(s){const e=s.id;b$[e]=s,Cv.languages.register(s);const t=C$.getOrCreate(e);Cv.languages.registerTokensProviderFactory(e,{create:async()=>(await t.load()).language}),Cv.languages.onLanguageEncountered(e,async()=>{const i=await t.load();Cv.languages.setLanguageConfiguration(e,i.conf)})}Ae({id:"abap",extensions:[".abap"],aliases:["abap","ABAP"],loader:()=>Ee(()=>import("./abap-TJ9JPO_o.js"),__vite__mapDeps([]))});Ae({id:"apex",extensions:[".cls"],aliases:["Apex","apex"],mimetypes:["text/x-apex-source","text/x-apex"],loader:()=>Ee(()=>import("./apex-fsuB5XsU.js"),__vite__mapDeps([]))});Ae({id:"azcli",extensions:[".azcli"],aliases:["Azure CLI","azcli"],loader:()=>Ee(()=>import("./azcli-5Up7nT0C.js"),__vite__mapDeps([]))});Ae({id:"bat",extensions:[".bat",".cmd"],aliases:["Batch","bat"],loader:()=>Ee(()=>import("./bat-3yt5BTLC.js"),__vite__mapDeps([]))});Ae({id:"bicep",extensions:[".bicep"],aliases:["Bicep"],loader:()=>Ee(()=>import("./bicep-fwpFf1QR.js"),__vite__mapDeps([]))});Ae({id:"cameligo",extensions:[".mligo"],aliases:["Cameligo"],loader:()=>Ee(()=>import("./cameligo-cirCWOMO.js"),__vite__mapDeps([]))});Ae({id:"clojure",extensions:[".clj",".cljs",".cljc",".edn"],aliases:["clojure","Clojure"],loader:()=>Ee(()=>import("./clojure-pRsr-ni6.js"),__vite__mapDeps([]))});Ae({id:"coffeescript",extensions:[".coffee"],aliases:["CoffeeScript","coffeescript","coffee"],mimetypes:["text/x-coffeescript","text/coffeescript"],loader:()=>Ee(()=>import("./coffee-v6Xl4flH.js"),__vite__mapDeps([]))});Ae({id:"c",extensions:[".c",".h"],aliases:["C","c"],loader:()=>Ee(()=>import("./cpp-TR_j0MGC.js"),__vite__mapDeps([]))});Ae({id:"cpp",extensions:[".cpp",".cc",".cxx",".hpp",".hh",".hxx"],aliases:["C++","Cpp","cpp"],loader:()=>Ee(()=>import("./cpp-TR_j0MGC.js"),__vite__mapDeps([]))});Ae({id:"csharp",extensions:[".cs",".csx",".cake"],aliases:["C#","csharp"],loader:()=>Ee(()=>import("./csharp-8jM-JXx5.js"),__vite__mapDeps([]))});Ae({id:"csp",extensions:[],aliases:["CSP","csp"],loader:()=>Ee(()=>import("./csp-3I2AinGx.js"),__vite__mapDeps([]))});Ae({id:"css",extensions:[".css"],aliases:["CSS","css"],mimetypes:["text/css"],loader:()=>Ee(()=>import("./css-MHM-5ikl.js"),__vite__mapDeps([]))});Ae({id:"cypher",extensions:[".cypher",".cyp"],aliases:["Cypher","OpenCypher"],loader:()=>Ee(()=>import("./cypher-VSDHz4vU.js"),__vite__mapDeps([]))});Ae({id:"dart",extensions:[".dart"],aliases:["Dart","dart"],mimetypes:["text/x-dart-source","text/x-dart"],loader:()=>Ee(()=>import("./dart-HfP09AJd.js"),__vite__mapDeps([]))});Ae({id:"dockerfile",extensions:[".dockerfile"],filenames:["Dockerfile"],aliases:["Dockerfile"],loader:()=>Ee(()=>import("./dockerfile-Ii5-xKAy.js"),__vite__mapDeps([]))});Ae({id:"ecl",extensions:[".ecl"],aliases:["ECL","Ecl","ecl"],loader:()=>Ee(()=>import("./ecl-SqIXq25X.js"),__vite__mapDeps([]))});Ae({id:"elixir",extensions:[".ex",".exs"],aliases:["Elixir","elixir","ex"],loader:()=>Ee(()=>import("./elixir-AprjDB11.js"),__vite__mapDeps([]))});Ae({id:"flow9",extensions:[".flow"],aliases:["Flow9","Flow","flow9","flow"],loader:()=>Ee(()=>import("./flow9-dknFQu1u.js"),__vite__mapDeps([]))});Ae({id:"fsharp",extensions:[".fs",".fsi",".ml",".mli",".fsx",".fsscript"],aliases:["F#","FSharp","fsharp"],loader:()=>Ee(()=>import("./fsharp-ZcRcioj2.js"),__vite__mapDeps([]))});Ae({id:"freemarker2",extensions:[".ftl",".ftlh",".ftlx"],aliases:["FreeMarker2","Apache FreeMarker2"],loader:()=>Ee(()=>import("./freemarker2-luoodEux.js"),__vite__mapDeps([])).then(s=>s.TagAutoInterpolationDollar)});Ae({id:"freemarker2.tag-angle.interpolation-dollar",aliases:["FreeMarker2 (Angle/Dollar)","Apache FreeMarker2 (Angle/Dollar)"],loader:()=>Ee(()=>import("./freemarker2-luoodEux.js"),__vite__mapDeps([])).then(s=>s.TagAngleInterpolationDollar)});Ae({id:"freemarker2.tag-bracket.interpolation-dollar",aliases:["FreeMarker2 (Bracket/Dollar)","Apache FreeMarker2 (Bracket/Dollar)"],loader:()=>Ee(()=>import("./freemarker2-luoodEux.js"),__vite__mapDeps([])).then(s=>s.TagBracketInterpolationDollar)});Ae({id:"freemarker2.tag-angle.interpolation-bracket",aliases:["FreeMarker2 (Angle/Bracket)","Apache FreeMarker2 (Angle/Bracket)"],loader:()=>Ee(()=>import("./freemarker2-luoodEux.js"),__vite__mapDeps([])).then(s=>s.TagAngleInterpolationBracket)});Ae({id:"freemarker2.tag-bracket.interpolation-bracket",aliases:["FreeMarker2 (Bracket/Bracket)","Apache FreeMarker2 (Bracket/Bracket)"],loader:()=>Ee(()=>import("./freemarker2-luoodEux.js"),__vite__mapDeps([])).then(s=>s.TagBracketInterpolationBracket)});Ae({id:"freemarker2.tag-auto.interpolation-dollar",aliases:["FreeMarker2 (Auto/Dollar)","Apache FreeMarker2 (Auto/Dollar)"],loader:()=>Ee(()=>import("./freemarker2-luoodEux.js"),__vite__mapDeps([])).then(s=>s.TagAutoInterpolationDollar)});Ae({id:"freemarker2.tag-auto.interpolation-bracket",aliases:["FreeMarker2 (Auto/Bracket)","Apache FreeMarker2 (Auto/Bracket)"],loader:()=>Ee(()=>import("./freemarker2-luoodEux.js"),__vite__mapDeps([])).then(s=>s.TagAutoInterpolationBracket)});Ae({id:"go",extensions:[".go"],aliases:["Go"],loader:()=>Ee(()=>import("./go-CCHKUeY6.js"),__vite__mapDeps([]))});Ae({id:"graphql",extensions:[".graphql",".gql"],aliases:["GraphQL","graphql","gql"],mimetypes:["application/graphql"],loader:()=>Ee(()=>import("./graphql-jfm_tSg4.js"),__vite__mapDeps([]))});Ae({id:"handlebars",extensions:[".handlebars",".hbs"],aliases:["Handlebars","handlebars","hbs"],mimetypes:["text/x-handlebars-template"],loader:()=>Ee(()=>import("./handlebars-0CA6L17_.js"),__vite__mapDeps([]))});Ae({id:"hcl",extensions:[".tf",".tfvars",".hcl"],aliases:["Terraform","tf","HCL","hcl"],loader:()=>Ee(()=>import("./hcl-dm7hMJK8.js"),__vite__mapDeps([]))});Ae({id:"html",extensions:[".html",".htm",".shtml",".xhtml",".mdoc",".jsp",".asp",".aspx",".jshtm"],aliases:["HTML","htm","html","xhtml"],mimetypes:["text/html","text/x-jshtm","text/template","text/ng-template"],loader:()=>Ee(()=>import("./html-XBxWfggt.js"),__vite__mapDeps([]))});Ae({id:"ini",extensions:[".ini",".properties",".gitconfig"],filenames:["config",".gitattributes",".gitconfig",".editorconfig"],aliases:["Ini","ini"],loader:()=>Ee(()=>import("./ini-4XJOM1A8.js"),__vite__mapDeps([]))});Ae({id:"java",extensions:[".java",".jav"],aliases:["Java","java"],mimetypes:["text/x-java-source","text/x-java"],loader:()=>Ee(()=>import("./java-TE6IXaxC.js"),__vite__mapDeps([]))});Ae({id:"javascript",extensions:[".js",".es6",".jsx",".mjs",".cjs"],firstLine:"^#!.*\\bnode",filenames:["jakefile"],aliases:["JavaScript","javascript","js"],mimetypes:["text/javascript"],loader:()=>Ee(()=>import("./javascript-V_ZQIUoq.js"),__vite__mapDeps([0,1]))});Ae({id:"julia",extensions:[".jl"],aliases:["julia","Julia"],loader:()=>Ee(()=>import("./julia-sKaYAmC_.js"),__vite__mapDeps([]))});Ae({id:"kotlin",extensions:[".kt",".kts"],aliases:["Kotlin","kotlin"],mimetypes:["text/x-kotlin-source","text/x-kotlin"],loader:()=>Ee(()=>import("./kotlin-TyeYxyee.js"),__vite__mapDeps([]))});Ae({id:"less",extensions:[".less"],aliases:["Less","less"],mimetypes:["text/x-less","text/less"],loader:()=>Ee(()=>import("./less-10a8O8cd.js"),__vite__mapDeps([]))});Ae({id:"lexon",extensions:[".lex"],aliases:["Lexon"],loader:()=>Ee(()=>import("./lexon-d-R72ieK.js"),__vite__mapDeps([]))});Ae({id:"lua",extensions:[".lua"],aliases:["Lua","lua"],loader:()=>Ee(()=>import("./lua-QYRl8EZT.js"),__vite__mapDeps([]))});Ae({id:"liquid",extensions:[".liquid",".html.liquid"],aliases:["Liquid","liquid"],mimetypes:["application/liquid"],loader:()=>Ee(()=>import("./liquid-J9NZ7w7k.js"),__vite__mapDeps([]))});Ae({id:"m3",extensions:[".m3",".i3",".mg",".ig"],aliases:["Modula-3","Modula3","modula3","m3"],loader:()=>Ee(()=>import("./m3-s7jc8T5h.js"),__vite__mapDeps([]))});Ae({id:"markdown",extensions:[".md",".markdown",".mdown",".mkdn",".mkd",".mdwn",".mdtxt",".mdtext"],aliases:["Markdown","markdown"],loader:()=>Ee(()=>import("./markdown-ZkR7NG-c.js"),__vite__mapDeps([]))});Ae({id:"mdx",extensions:[".mdx"],aliases:["MDX","mdx"],loader:()=>Ee(()=>import("./mdx-GCTLasAA.js"),__vite__mapDeps([]))});Ae({id:"mips",extensions:[".s"],aliases:["MIPS","MIPS-V"],mimetypes:["text/x-mips","text/mips","text/plaintext"],loader:()=>Ee(()=>import("./mips-1O9nyomQ.js"),__vite__mapDeps([]))});Ae({id:"msdax",extensions:[".dax",".msdax"],aliases:["DAX","MSDAX"],loader:()=>Ee(()=>import("./msdax-Oly0IuHX.js"),__vite__mapDeps([]))});Ae({id:"mysql",extensions:[],aliases:["MySQL","mysql"],loader:()=>Ee(()=>import("./mysql-O6q7BloK.js"),__vite__mapDeps([]))});Ae({id:"objective-c",extensions:[".m"],aliases:["Objective-C"],loader:()=>Ee(()=>import("./objective-c-VJ5d-7UP.js"),__vite__mapDeps([]))});Ae({id:"pascal",extensions:[".pas",".p",".pp"],aliases:["Pascal","pas"],mimetypes:["text/x-pascal-source","text/x-pascal"],loader:()=>Ee(()=>import("./pascal-X94v6yOd.js"),__vite__mapDeps([]))});Ae({id:"pascaligo",extensions:[".ligo"],aliases:["Pascaligo","ligo"],loader:()=>Ee(()=>import("./pascaligo-ZMOv8JL1.js"),__vite__mapDeps([]))});Ae({id:"perl",extensions:[".pl",".pm"],aliases:["Perl","pl"],loader:()=>Ee(()=>import("./perl-4ADiOUNK.js"),__vite__mapDeps([]))});Ae({id:"pgsql",extensions:[],aliases:["PostgreSQL","postgres","pg","postgre"],loader:()=>Ee(()=>import("./pgsql-E3aV-6NG.js"),__vite__mapDeps([]))});Ae({id:"php",extensions:[".php",".php4",".php5",".phtml",".ctp"],aliases:["PHP","php"],mimetypes:["application/x-php"],loader:()=>Ee(()=>import("./php-BRhhYih6.js"),__vite__mapDeps([]))});Ae({id:"pla",extensions:[".pla"],loader:()=>Ee(()=>import("./pla-NK1bOYPh.js"),__vite__mapDeps([]))});Ae({id:"postiats",extensions:[".dats",".sats",".hats"],aliases:["ATS","ATS/Postiats"],loader:()=>Ee(()=>import("./postiats-_JBrm6CW.js"),__vite__mapDeps([]))});Ae({id:"powerquery",extensions:[".pq",".pqm"],aliases:["PQ","M","Power Query","Power Query M"],loader:()=>Ee(()=>import("./powerquery-2p9Aor7K.js"),__vite__mapDeps([]))});Ae({id:"powershell",extensions:[".ps1",".psm1",".psd1"],aliases:["PowerShell","powershell","ps","ps1"],loader:()=>Ee(()=>import("./powershell-SfQR9My8.js"),__vite__mapDeps([]))});Ae({id:"proto",extensions:[".proto"],aliases:["protobuf","Protocol Buffers"],loader:()=>Ee(()=>import("./protobuf-xyBsbw-G.js"),__vite__mapDeps([]))});Ae({id:"pug",extensions:[".jade",".pug"],aliases:["Pug","Jade","jade"],loader:()=>Ee(()=>import("./pug-kePBK3uZ.js"),__vite__mapDeps([]))});Ae({id:"python",extensions:[".py",".rpy",".pyw",".cpy",".gyp",".gypi"],aliases:["Python","py"],firstLine:"^#!/.*\\bpython[0-9.-]*\\b",loader:()=>Ee(()=>import("./python-c26ZveU1.js"),__vite__mapDeps([]))});Ae({id:"qsharp",extensions:[".qs"],aliases:["Q#","qsharp"],loader:()=>Ee(()=>import("./qsharp-Wr4VkQWh.js"),__vite__mapDeps([]))});Ae({id:"r",extensions:[".r",".rhistory",".rmd",".rprofile",".rt"],aliases:["R","r"],loader:()=>Ee(()=>import("./r-KalBusNn.js"),__vite__mapDeps([]))});Ae({id:"razor",extensions:[".cshtml"],aliases:["Razor","razor"],mimetypes:["text/x-cshtml"],loader:()=>Ee(()=>import("./razor-1FBGDjt7.js"),__vite__mapDeps([]))});Ae({id:"redis",extensions:[".redis"],aliases:["redis"],loader:()=>Ee(()=>import("./redis-roKlMAvh.js"),__vite__mapDeps([]))});Ae({id:"redshift",extensions:[],aliases:["Redshift","redshift"],loader:()=>Ee(()=>import("./redshift-mnTILXE1.js"),__vite__mapDeps([]))});Ae({id:"restructuredtext",extensions:[".rst"],aliases:["reStructuredText","restructuredtext"],loader:()=>Ee(()=>import("./restructuredtext-ybHmQlUt.js"),__vite__mapDeps([]))});Ae({id:"ruby",extensions:[".rb",".rbx",".rjs",".gemspec",".pp"],filenames:["rakefile","Gemfile"],aliases:["Ruby","rb"],loader:()=>Ee(()=>import("./ruby-83klXaOy.js"),__vite__mapDeps([]))});Ae({id:"rust",extensions:[".rs",".rlib"],aliases:["Rust","rust"],loader:()=>Ee(()=>import("./rust-xKNHUVr8.js"),__vite__mapDeps([]))});Ae({id:"sb",extensions:[".sb"],aliases:["Small Basic","sb"],loader:()=>Ee(()=>import("./sb-x9jtjlCl.js"),__vite__mapDeps([]))});Ae({id:"scala",extensions:[".scala",".sc",".sbt"],aliases:["Scala","scala","SBT","Sbt","sbt","Dotty","dotty"],mimetypes:["text/x-scala-source","text/x-scala","text/x-sbt","text/x-dotty"],loader:()=>Ee(()=>import("./scala-rPyMEhUZ.js"),__vite__mapDeps([]))});Ae({id:"scheme",extensions:[".scm",".ss",".sch",".rkt"],aliases:["scheme","Scheme"],loader:()=>Ee(()=>import("./scheme-uVksIz2W.js"),__vite__mapDeps([]))});Ae({id:"scss",extensions:[".scss"],aliases:["Sass","sass","scss"],mimetypes:["text/x-scss","text/scss"],loader:()=>Ee(()=>import("./scss-CrS-iEwv.js"),__vite__mapDeps([]))});Ae({id:"shell",extensions:[".sh",".bash"],aliases:["Shell","sh"],loader:()=>Ee(()=>import("./shell-42F0hJVt.js"),__vite__mapDeps([]))});Ae({id:"sol",extensions:[".sol"],aliases:["sol","solidity","Solidity"],loader:()=>Ee(()=>import("./solidity-U5pxnXMX.js"),__vite__mapDeps([]))});Ae({id:"aes",extensions:[".aes"],aliases:["aes","sophia","Sophia"],loader:()=>Ee(()=>import("./sophia-ZRWFKATs.js"),__vite__mapDeps([]))});Ae({id:"sparql",extensions:[".rq"],aliases:["sparql","SPARQL"],loader:()=>Ee(()=>import("./sparql-WhVexE1W.js"),__vite__mapDeps([]))});Ae({id:"sql",extensions:[".sql"],aliases:["SQL"],loader:()=>Ee(()=>import("./sql-qrShR2_3.js"),__vite__mapDeps([]))});Ae({id:"st",extensions:[".st",".iecst",".iecplc",".lc3lib",".TcPOU",".TcDUT",".TcGVL",".TcIO"],aliases:["StructuredText","scl","stl"],loader:()=>Ee(()=>import("./st-r9-7Z7yU.js"),__vite__mapDeps([]))});Ae({id:"swift",aliases:["Swift","swift"],extensions:[".swift"],mimetypes:["text/swift"],loader:()=>Ee(()=>import("./swift-qW0zFiI_.js"),__vite__mapDeps([]))});Ae({id:"systemverilog",extensions:[".sv",".svh"],aliases:["SV","sv","SystemVerilog","systemverilog"],loader:()=>Ee(()=>import("./systemverilog-ENv5nhSN.js"),__vite__mapDeps([]))});Ae({id:"verilog",extensions:[".v",".vh"],aliases:["V","v","Verilog","verilog"],loader:()=>Ee(()=>import("./systemverilog-ENv5nhSN.js"),__vite__mapDeps([]))});Ae({id:"tcl",extensions:[".tcl"],aliases:["tcl","Tcl","tcltk","TclTk","tcl/tk","Tcl/Tk"],loader:()=>Ee(()=>import("./tcl-daRHIjOV.js"),__vite__mapDeps([]))});Ae({id:"twig",extensions:[".twig"],aliases:["Twig","twig"],mimetypes:["text/x-twig"],loader:()=>Ee(()=>import("./twig-A3qeBeAU.js"),__vite__mapDeps([]))});Ae({id:"typescript",extensions:[".ts",".tsx",".cts",".mts"],aliases:["TypeScript","ts","typescript"],mimetypes:["text/typescript"],loader:()=>Ee(()=>import("./typescript-BRZxGkNK.js"),__vite__mapDeps([]))});Ae({id:"vb",extensions:[".vb"],aliases:["Visual Basic","vb"],loader:()=>Ee(()=>import("./vb-d2CsLMQW.js"),__vite__mapDeps([]))});Ae({id:"wgsl",extensions:[".wgsl"],aliases:["WebGPU Shading Language","WGSL","wgsl"],loader:()=>Ee(()=>import("./wgsl-FNEGMQHx.js"),__vite__mapDeps([]))});Ae({id:"xml",extensions:[".xml",".xsd",".dtd",".ascx",".csproj",".config",".props",".targets",".wxi",".wxl",".wxs",".xaml",".svg",".svgz",".opf",".xslt",".xsl"],firstLine:"(\\<\\?xml.*)|(\\<svg)|(\\<\\!doctype\\s+svg)",aliases:["XML","xml"],mimetypes:["text/xml","application/xml","application/xaml+xml","application/xml-dtd"],loader:()=>Ee(()=>import("./xml-A6ZIPJ5L.js"),__vite__mapDeps([]))});Ae({id:"yaml",extensions:[".yaml",".yml"],aliases:["YAML","yaml","YML","yml"],mimetypes:["application/x-yaml","text/x-yaml"],loader:()=>Ee(()=>import("./yaml-gmsPRkRl.js"),__vite__mapDeps([]))});/*!-----------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Version: 0.45.0(5e5af013f8d295555a7210df0d5f2cea0bf5dd56)
 * Released under the MIT license
 * https://github.com/microsoft/monaco-editor/blob/main/LICENSE.txt
 *-----------------------------------------------------------------------------*/var M0e=Object.defineProperty,R0e=Object.getOwnPropertyDescriptor,A0e=Object.getOwnPropertyNames,P0e=Object.prototype.hasOwnProperty,C8=(s,e,t,i)=>{if(e&&typeof e=="object"||typeof e=="function")for(let n of A0e(e))!P0e.call(s,n)&&n!==t&&M0e(s,n,{get:()=>e[n],enumerable:!(i=R0e(e,n))||i.enumerable});return s},O0e=(s,e,t)=>(C8(s,e,"default"),t&&C8(t,e,"default")),f_={};O0e(f_,MC);var YO=class{constructor(e,t,i){Ni(this,"_onDidChange",new f_.Emitter);Ni(this,"_options");Ni(this,"_modeConfiguration");Ni(this,"_languageId");this._languageId=e,this.setOptions(t),this.setModeConfiguration(i)}get onDidChange(){return this._onDidChange.event}get languageId(){return this._languageId}get modeConfiguration(){return this._modeConfiguration}get diagnosticsOptions(){return this.options}get options(){return this._options}setOptions(e){this._options=e||Object.create(null),this._onDidChange.fire(this)}setDiagnosticsOptions(e){this.setOptions(e)}setModeConfiguration(e){this._modeConfiguration=e||Object.create(null),this._onDidChange.fire(this)}},XO={validate:!0,lint:{compatibleVendorPrefixes:"ignore",vendorPrefix:"warning",duplicateProperties:"warning",emptyRules:"warning",importStatement:"ignore",boxModel:"ignore",universalSelector:"ignore",zeroUnits:"ignore",fontFaceProperties:"warning",hexColorLength:"error",argumentsInColorFunction:"error",unknownProperties:"warning",ieHack:"ignore",unknownVendorSpecificProperties:"ignore",propertyIgnoredDueToDisplay:"warning",important:"ignore",float:"ignore",idSelector:"ignore"},data:{useDefaultDataProvider:!0},format:{newlineBetweenSelectors:!0,newlineBetweenRules:!0,spaceAroundSelectorSeparator:!1,braceStyle:"collapse",maxPreserveNewLines:void 0,preserveNewLines:!0}},QO={completionItems:!0,hovers:!0,documentSymbols:!0,definitions:!0,references:!0,documentHighlights:!0,rename:!0,colors:!0,foldingRanges:!0,diagnostics:!0,selectionRanges:!0,documentFormattingEdits:!0,documentRangeFormattingEdits:!0},w$=new YO("css",XO,QO),S$=new YO("scss",XO,QO),y$=new YO("less",XO,QO);f_.languages.css={cssDefaults:w$,lessDefaults:y$,scssDefaults:S$};function JO(){return Ee(()=>import("./cssMode-5xMOQWgc.js"),__vite__mapDeps([]))}f_.languages.onLanguage("less",()=>{JO().then(s=>s.setupMode(y$))});f_.languages.onLanguage("scss",()=>{JO().then(s=>s.setupMode(S$))});f_.languages.onLanguage("css",()=>{JO().then(s=>s.setupMode(w$))});/*!-----------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Version: 0.45.0(5e5af013f8d295555a7210df0d5f2cea0bf5dd56)
 * Released under the MIT license
 * https://github.com/microsoft/monaco-editor/blob/main/LICENSE.txt
 *-----------------------------------------------------------------------------*/var F0e=Object.defineProperty,B0e=Object.getOwnPropertyDescriptor,W0e=Object.getOwnPropertyNames,V0e=Object.prototype.hasOwnProperty,w8=(s,e,t,i)=>{if(e&&typeof e=="object"||typeof e=="function")for(let n of W0e(e))!V0e.call(s,n)&&n!==t&&F0e(s,n,{get:()=>e[n],enumerable:!(i=B0e(e,n))||i.enumerable});return s},H0e=(s,e,t)=>(w8(s,e,"default"),t&&w8(t,e,"default")),lD={};H0e(lD,MC);var z0e=class{constructor(e,t,i){Ni(this,"_onDidChange",new lD.Emitter);Ni(this,"_options");Ni(this,"_modeConfiguration");Ni(this,"_languageId");this._languageId=e,this.setOptions(t),this.setModeConfiguration(i)}get onDidChange(){return this._onDidChange.event}get languageId(){return this._languageId}get options(){return this._options}get modeConfiguration(){return this._modeConfiguration}setOptions(e){this._options=e||Object.create(null),this._onDidChange.fire(this)}setModeConfiguration(e){this._modeConfiguration=e||Object.create(null),this._onDidChange.fire(this)}},U0e={tabSize:4,insertSpaces:!1,wrapLineLength:120,unformatted:'default": "a, abbr, acronym, b, bdo, big, br, button, cite, code, dfn, em, i, img, input, kbd, label, map, object, q, samp, select, small, span, strong, sub, sup, textarea, tt, var',contentUnformatted:"pre",indentInnerHtml:!1,preserveNewLines:!0,maxPreserveNewLines:void 0,indentHandlebars:!1,endWithNewline:!1,extraLiners:"head, body, /html",wrapAttributes:"auto"},dD={format:U0e,suggest:{},data:{useDefaultDataProvider:!0}};function cD(s){return{completionItems:!0,hovers:!0,documentSymbols:!0,links:!0,documentHighlights:!0,rename:!0,colors:!0,foldingRanges:!0,selectionRanges:!0,diagnostics:s===Jv,documentFormattingEdits:s===Jv,documentRangeFormattingEdits:s===Jv}}var Jv="html",S8="handlebars",y8="razor",L$=uD(Jv,dD,cD(Jv)),$0e=L$.defaults,x$=uD(S8,dD,cD(S8)),j0e=x$.defaults,D$=uD(y8,dD,cD(y8)),K0e=D$.defaults;lD.languages.html={htmlDefaults:$0e,razorDefaults:K0e,handlebarDefaults:j0e,htmlLanguageService:L$,handlebarLanguageService:x$,razorLanguageService:D$,registerHTMLLanguageService:uD};function q0e(){return Ee(()=>import("./htmlMode-dIU2SGVq.js"),__vite__mapDeps([]))}function uD(s,e=dD,t=cD(s)){const i=new z0e(s,e,t);let n;const o=lD.languages.onLanguage(s,async()=>{n=(await q0e()).setupMode(i)});return{defaults:i,dispose(){o.dispose(),n==null||n.dispose(),n=void 0}}}/*!-----------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Version: 0.45.0(5e5af013f8d295555a7210df0d5f2cea0bf5dd56)
 * Released under the MIT license
 * https://github.com/microsoft/monaco-editor/blob/main/LICENSE.txt
 *-----------------------------------------------------------------------------*/var G0e=Object.defineProperty,Z0e=Object.getOwnPropertyDescriptor,Y0e=Object.getOwnPropertyNames,X0e=Object.prototype.hasOwnProperty,L8=(s,e,t,i)=>{if(e&&typeof e=="object"||typeof e=="function")for(let n of Y0e(e))!X0e.call(s,n)&&n!==t&&G0e(s,n,{get:()=>e[n],enumerable:!(i=Z0e(e,n))||i.enumerable});return s},Q0e=(s,e,t)=>(L8(s,e,"default"),t&&L8(t,e,"default")),RC={};Q0e(RC,MC);var J0e=class{constructor(e,t,i){Ni(this,"_onDidChange",new RC.Emitter);Ni(this,"_diagnosticsOptions");Ni(this,"_modeConfiguration");Ni(this,"_languageId");this._languageId=e,this.setDiagnosticsOptions(t),this.setModeConfiguration(i)}get onDidChange(){return this._onDidChange.event}get languageId(){return this._languageId}get modeConfiguration(){return this._modeConfiguration}get diagnosticsOptions(){return this._diagnosticsOptions}setDiagnosticsOptions(e){this._diagnosticsOptions=e||Object.create(null),this._onDidChange.fire(this)}setModeConfiguration(e){this._modeConfiguration=e||Object.create(null),this._onDidChange.fire(this)}},ebe={validate:!0,allowComments:!0,schemas:[],enableSchemaRequest:!1,schemaRequest:"warning",schemaValidation:"warning",comments:"error",trailingCommas:"error"},tbe={documentFormattingEdits:!0,documentRangeFormattingEdits:!0,completionItems:!0,hovers:!0,documentSymbols:!0,tokens:!0,colors:!0,foldingRanges:!0,diagnostics:!0,selectionRanges:!0},k$=new J0e("json",ebe,tbe);RC.languages.json={jsonDefaults:k$};function ibe(){return Ee(()=>import("./jsonMode-1qE95ezN.js"),__vite__mapDeps([]))}RC.languages.register({id:"json",extensions:[".json",".bowerrc",".jshintrc",".jscsrc",".eslintrc",".babelrc",".har"],aliases:["JSON","json"],mimetypes:["application/json"]});RC.languages.onLanguage("json",()=>{ibe().then(s=>s.setupMode(k$))});/*!-----------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Version: 0.45.0(5e5af013f8d295555a7210df0d5f2cea0bf5dd56)
 * Released under the MIT license
 * https://github.com/microsoft/monaco-editor/blob/main/LICENSE.txt
 *-----------------------------------------------------------------------------*/var nbe=Object.defineProperty,sbe=Object.getOwnPropertyDescriptor,obe=Object.getOwnPropertyNames,rbe=Object.prototype.hasOwnProperty,x8=(s,e,t,i)=>{if(e&&typeof e=="object"||typeof e=="function")for(let n of obe(e))!rbe.call(s,n)&&n!==t&&nbe(s,n,{get:()=>e[n],enumerable:!(i=sbe(e,n))||i.enumerable});return s},abe=(s,e,t)=>(x8(s,e,"default"),t&&x8(t,e,"default")),lbe="5.0.2",Om={};abe(Om,MC);var I$=(s=>(s[s.None=0]="None",s[s.CommonJS=1]="CommonJS",s[s.AMD=2]="AMD",s[s.UMD=3]="UMD",s[s.System=4]="System",s[s.ES2015=5]="ES2015",s[s.ESNext=99]="ESNext",s))(I$||{}),E$=(s=>(s[s.None=0]="None",s[s.Preserve=1]="Preserve",s[s.React=2]="React",s[s.ReactNative=3]="ReactNative",s[s.ReactJSX=4]="ReactJSX",s[s.ReactJSXDev=5]="ReactJSXDev",s))(E$||{}),N$=(s=>(s[s.CarriageReturnLineFeed=0]="CarriageReturnLineFeed",s[s.LineFeed=1]="LineFeed",s))(N$||{}),T$=(s=>(s[s.ES3=0]="ES3",s[s.ES5=1]="ES5",s[s.ES2015=2]="ES2015",s[s.ES2016=3]="ES2016",s[s.ES2017=4]="ES2017",s[s.ES2018=5]="ES2018",s[s.ES2019=6]="ES2019",s[s.ES2020=7]="ES2020",s[s.ESNext=99]="ESNext",s[s.JSON=100]="JSON",s[s.Latest=99]="Latest",s))(T$||{}),M$=(s=>(s[s.Classic=1]="Classic",s[s.NodeJs=2]="NodeJs",s))(M$||{}),R$=class{constructor(s,e,t,i,n){Ni(this,"_onDidChange",new Om.Emitter);Ni(this,"_onDidExtraLibsChange",new Om.Emitter);Ni(this,"_extraLibs");Ni(this,"_removedExtraLibs");Ni(this,"_eagerModelSync");Ni(this,"_compilerOptions");Ni(this,"_diagnosticsOptions");Ni(this,"_workerOptions");Ni(this,"_onDidExtraLibsChangeTimeout");Ni(this,"_inlayHintsOptions");Ni(this,"_modeConfiguration");this._extraLibs=Object.create(null),this._removedExtraLibs=Object.create(null),this._eagerModelSync=!1,this.setCompilerOptions(s),this.setDiagnosticsOptions(e),this.setWorkerOptions(t),this.setInlayHintsOptions(i),this.setModeConfiguration(n),this._onDidExtraLibsChangeTimeout=-1}get onDidChange(){return this._onDidChange.event}get onDidExtraLibsChange(){return this._onDidExtraLibsChange.event}get modeConfiguration(){return this._modeConfiguration}get workerOptions(){return this._workerOptions}get inlayHintsOptions(){return this._inlayHintsOptions}getExtraLibs(){return this._extraLibs}addExtraLib(s,e){let t;if(typeof e>"u"?t=`ts:extralib-${Math.random().toString(36).substring(2,15)}`:t=e,this._extraLibs[t]&&this._extraLibs[t].content===s)return{dispose:()=>{}};let i=1;return this._removedExtraLibs[t]&&(i=this._removedExtraLibs[t]+1),this._extraLibs[t]&&(i=this._extraLibs[t].version+1),this._extraLibs[t]={content:s,version:i},this._fireOnDidExtraLibsChangeSoon(),{dispose:()=>{let n=this._extraLibs[t];n&&n.version===i&&(delete this._extraLibs[t],this._removedExtraLibs[t]=i,this._fireOnDidExtraLibsChangeSoon())}}}setExtraLibs(s){for(const e in this._extraLibs)this._removedExtraLibs[e]=this._extraLibs[e].version;if(this._extraLibs=Object.create(null),s&&s.length>0)for(const e of s){const t=e.filePath||`ts:extralib-${Math.random().toString(36).substring(2,15)}`,i=e.content;let n=1;this._removedExtraLibs[t]&&(n=this._removedExtraLibs[t]+1),this._extraLibs[t]={content:i,version:n}}this._fireOnDidExtraLibsChangeSoon()}_fireOnDidExtraLibsChangeSoon(){this._onDidExtraLibsChangeTimeout===-1&&(this._onDidExtraLibsChangeTimeout=window.setTimeout(()=>{this._onDidExtraLibsChangeTimeout=-1,this._onDidExtraLibsChange.fire(void 0)},0))}getCompilerOptions(){return this._compilerOptions}setCompilerOptions(s){this._compilerOptions=s||Object.create(null),this._onDidChange.fire(void 0)}getDiagnosticsOptions(){return this._diagnosticsOptions}setDiagnosticsOptions(s){this._diagnosticsOptions=s||Object.create(null),this._onDidChange.fire(void 0)}setWorkerOptions(s){this._workerOptions=s||Object.create(null),this._onDidChange.fire(void 0)}setInlayHintsOptions(s){this._inlayHintsOptions=s||Object.create(null),this._onDidChange.fire(void 0)}setMaximumWorkerIdleTime(s){}setEagerModelSync(s){this._eagerModelSync=s}getEagerModelSync(){return this._eagerModelSync}setModeConfiguration(s){this._modeConfiguration=s||Object.create(null),this._onDidChange.fire(void 0)}},dbe=lbe,A$={completionItems:!0,hovers:!0,documentSymbols:!0,definitions:!0,references:!0,documentHighlights:!0,rename:!0,diagnostics:!0,documentRangeFormattingEdits:!0,signatureHelp:!0,onTypeFormattingEdits:!0,codeActions:!0,inlayHints:!0},P$=new R$({allowNonTsExtensions:!0,target:99},{noSemanticValidation:!1,noSyntaxValidation:!1,onlyVisible:!1},{},{},A$),O$=new R$({allowNonTsExtensions:!0,allowJs:!0,target:99},{noSemanticValidation:!0,noSyntaxValidation:!1,onlyVisible:!1},{},{},A$),cbe=()=>hD().then(s=>s.getTypeScriptWorker()),ube=()=>hD().then(s=>s.getJavaScriptWorker());Om.languages.typescript={ModuleKind:I$,JsxEmit:E$,NewLineKind:N$,ScriptTarget:T$,ModuleResolutionKind:M$,typescriptVersion:dbe,typescriptDefaults:P$,javascriptDefaults:O$,getTypeScriptWorker:cbe,getJavaScriptWorker:ube};function hD(){return Ee(()=>import("./tsMode-mcLB0RZa.js"),__vite__mapDeps([]))}Om.languages.onLanguage("typescript",()=>hD().then(s=>s.setupTypeScript(P$)));Om.languages.onLanguage("javascript",()=>hD().then(s=>s.setupJavaScript(O$)));class hbe extends ar{constructor(){super({id:"diffEditor.toggleCollapseUnchangedRegions",title:{value:p("toggleCollapseUnchangedRegions","Toggle Collapse Unchanged Regions"),original:"Toggle Collapse Unchanged Regions"},icon:le.map,toggled:ee.has("config.diffEditor.hideUnchangedRegions.enabled"),precondition:ee.has("isInDiffEditor"),menu:{when:ee.has("isInDiffEditor"),id:N.EditorTitle,order:22,group:"navigation"}})}run(e,...t){const i=e.get(mt),n=!i.getValue("diffEditor.hideUnchangedRegions.enabled");i.updateValue("diffEditor.hideUnchangedRegions.enabled",n)}}di(hbe);class F$ extends ar{constructor(){super({id:"diffEditor.toggleShowMovedCodeBlocks",title:{value:p("toggleShowMovedCodeBlocks","Toggle Show Moved Code Blocks"),original:"Toggle Show Moved Code Blocks"},precondition:ee.has("isInDiffEditor")})}run(e,...t){const i=e.get(mt),n=!i.getValue("diffEditor.experimental.showMoves");i.updateValue("diffEditor.experimental.showMoves",n)}}di(F$);class B$ extends ar{constructor(){super({id:"diffEditor.toggleUseInlineViewWhenSpaceIsLimited",title:{value:p("toggleUseInlineViewWhenSpaceIsLimited","Toggle Use Inline View When Space Is Limited"),original:"Toggle Use Inline View When Space Is Limited"},precondition:ee.has("isInDiffEditor")})}run(e,...t){const i=e.get(mt),n=!i.getValue("diffEditor.useInlineViewWhenSpaceIsLimited");i.updateValue("diffEditor.useInlineViewWhenSpaceIsLimited",n)}}di(B$);Wn.appendMenuItem(N.EditorTitle,{command:{id:new B$().desc.id,title:p("useInlineViewWhenSpaceIsLimited","Use Inline View When Space Is Limited"),toggled:ee.has("config.diffEditor.useInlineViewWhenSpaceIsLimited"),precondition:ee.has("isInDiffEditor")},order:11,group:"1_diff",when:ee.and(T.diffEditorRenderSideBySideInlineBreakpointReached,ee.has("isInDiffEditor"))});Wn.appendMenuItem(N.EditorTitle,{command:{id:new F$().desc.id,title:p("showMoves","Show Moved Code Blocks"),icon:le.move,toggled:t_.create("config.diffEditor.experimental.showMoves",!0),precondition:ee.has("isInDiffEditor")},order:10,group:"1_diff",when:ee.has("isInDiffEditor")});const gD={value:p("diffEditor","Diff Editor"),original:"Diff Editor"};class gbe extends Ga{constructor(){super({id:"diffEditor.switchSide",title:{value:p("switchSide","Switch Side"),original:"Switch Side"},icon:le.arrowSwap,precondition:ee.has("isInDiffEditor"),f1:!0,category:gD})}runEditorCommand(e,t,i){const n=m_(e);if(n instanceof Vu){if(i&&i.dryRun)return{destinationSelection:n.mapToOtherSide().destinationSelection};n.switchSide()}}}di(gbe);class fbe extends Ga{constructor(){super({id:"diffEditor.exitCompareMove",title:{value:p("exitCompareMove","Exit Compare Move"),original:"Exit Compare Move"},icon:le.close,precondition:T.comparingMovedCode,f1:!1,category:gD,keybinding:{weight:1e4,primary:9}})}runEditorCommand(e,t,...i){const n=m_(e);n instanceof Vu&&n.exitCompareMove()}}di(fbe);class pbe extends Ga{constructor(){super({id:"diffEditor.collapseAllUnchangedRegions",title:{value:p("collapseAllUnchangedRegions","Collapse All Unchanged Regions"),original:"Collapse All Unchanged Regions"},icon:le.fold,precondition:ee.has("isInDiffEditor"),f1:!0,category:gD})}runEditorCommand(e,t,...i){const n=m_(e);n instanceof Vu&&n.collapseAllUnchangedRegions()}}di(pbe);class mbe extends Ga{constructor(){super({id:"diffEditor.showAllUnchangedRegions",title:{value:p("showAllUnchangedRegions","Show All Unchanged Regions"),original:"Show All Unchanged Regions"},icon:le.unfold,precondition:ee.has("isInDiffEditor"),f1:!0,category:gD})}runEditorCommand(e,t,...i){const n=m_(e);n instanceof Vu&&n.showAllUnchangedRegions()}}di(mbe);const W$={value:p("accessibleDiffViewer","Accessible Diff Viewer"),original:"Accessible Diff Viewer"};class p_ extends ar{constructor(){super({id:p_.id,title:{value:p("editor.action.accessibleDiffViewer.next","Go to Next Difference"),original:"Go to Next Difference"},category:W$,precondition:ee.has("isInDiffEditor"),keybinding:{primary:65,weight:100},f1:!0})}run(e){const t=m_(e);t==null||t.accessibleDiffViewerNext()}}p_.id="editor.action.accessibleDiffViewer.next";Wn.appendMenuItem(N.EditorTitle,{command:{id:p_.id,title:p("Open Accessible Diff Viewer","Open Accessible Diff Viewer"),precondition:ee.has("isInDiffEditor")},order:10,group:"2_diff",when:ee.and(T.accessibleDiffViewerVisible.negate(),ee.has("isInDiffEditor"))});class AC extends ar{constructor(){super({id:AC.id,title:{value:p("editor.action.accessibleDiffViewer.prev","Go to Previous Difference"),original:"Go to Previous Difference"},category:W$,precondition:ee.has("isInDiffEditor"),keybinding:{primary:1089,weight:100},f1:!0})}run(e){const t=m_(e);t==null||t.accessibleDiffViewerPrev()}}AC.id="editor.action.accessibleDiffViewer.prev";function m_(s){var e;const t=s.get(It),i=t.listDiffEditors(),n=(e=t.getFocusedCodeEditor())!==null&&e!==void 0?e:t.getActiveCodeEditor();if(!n)return null;for(let r=0,a=i.length;r<a;r++){const l=i[r];if(l.getModifiedEditor().getId()===n.getId()||l.getOriginalEditor().getId()===n.getId())return l}const o=Jo();if(o)for(const r of i){const a=r.getContainerDomNode();if(_be(a,o))return r}return null}function _be(s,e){let t=e;for(;t;){if(t===s)return!0;t=t.parentElement}return!1}Ct.registerCommandAlias("editor.action.diffReview.next",p_.id);di(p_);Ct.registerCommandAlias("editor.action.diffReview.prev",AC.id);di(AC);var vbe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},bbe=function(s,e){return function(t,i){e(t,i,s)}},pM;const fD=new me("selectionAnchorSet",!1);let tc=pM=class{static get(e){return e.getContribution(pM.ID)}constructor(e,t){this.editor=e,this.selectionAnchorSetContextKey=fD.bindTo(t),this.modelChangeListener=e.onDidChangeModel(()=>this.selectionAnchorSetContextKey.reset())}setSelectionAnchor(){if(this.editor.hasModel()){const e=this.editor.getPosition();this.editor.changeDecorations(t=>{this.decorationId&&t.removeDecoration(this.decorationId),this.decorationId=t.addDecoration(De.fromPositions(e,e),{description:"selection-anchor",stickiness:1,hoverMessage:new rs().appendText(p("selectionAnchor","Selection Anchor")),className:"selection-anchor"})}),this.selectionAnchorSetContextKey.set(!!this.decorationId),Lo(p("anchorSet","Anchor set at {0}:{1}",e.lineNumber,e.column))}}goToSelectionAnchor(){if(this.editor.hasModel()&&this.decorationId){const e=this.editor.getModel().getDecorationRange(this.decorationId);e&&this.editor.setPosition(e.getStartPosition())}}selectFromAnchorToCursor(){if(this.editor.hasModel()&&this.decorationId){const e=this.editor.getModel().getDecorationRange(this.decorationId);if(e){const t=this.editor.getPosition();this.editor.setSelection(De.fromPositions(e.getStartPosition(),t)),this.cancelSelectionAnchor()}}}cancelSelectionAnchor(){if(this.decorationId){const e=this.decorationId;this.editor.changeDecorations(t=>{t.removeDecoration(e),this.decorationId=void 0}),this.selectionAnchorSetContextKey.set(!1)}}dispose(){this.cancelSelectionAnchor(),this.modelChangeListener.dispose()}};tc.ID="editor.contrib.selectionAnchorController";tc=pM=vbe([bbe(1,je)],tc);class Cbe extends we{constructor(){super({id:"editor.action.setSelectionAnchor",label:p("setSelectionAnchor","Set Selection Anchor"),alias:"Set Selection Anchor",precondition:void 0,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2080),weight:100}})}async run(e,t){var i;(i=tc.get(t))===null||i===void 0||i.setSelectionAnchor()}}class wbe extends we{constructor(){super({id:"editor.action.goToSelectionAnchor",label:p("goToSelectionAnchor","Go to Selection Anchor"),alias:"Go to Selection Anchor",precondition:fD})}async run(e,t){var i;(i=tc.get(t))===null||i===void 0||i.goToSelectionAnchor()}}class Sbe extends we{constructor(){super({id:"editor.action.selectFromAnchorToCursor",label:p("selectFromAnchorToCursor","Select from Anchor to Cursor"),alias:"Select from Anchor to Cursor",precondition:fD,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2089),weight:100}})}async run(e,t){var i;(i=tc.get(t))===null||i===void 0||i.selectFromAnchorToCursor()}}class ybe extends we{constructor(){super({id:"editor.action.cancelSelectionAnchor",label:p("cancelSelectionAnchor","Cancel Selection Anchor"),alias:"Cancel Selection Anchor",precondition:fD,kbOpts:{kbExpr:T.editorTextFocus,primary:9,weight:100}})}async run(e,t){var i;(i=tc.get(t))===null||i===void 0||i.cancelSelectionAnchor()}}Lt(tc.ID,tc,4);re(Cbe);re(wbe);re(Sbe);re(ybe);const Lbe=R("editorOverviewRuler.bracketMatchForeground",{dark:"#A0A0A0",light:"#A0A0A0",hcDark:"#A0A0A0",hcLight:"#A0A0A0"},p("overviewRulerBracketMatchForeground","Overview ruler marker color for matching brackets."));class xbe extends we{constructor(){super({id:"editor.action.jumpToBracket",label:p("smartSelect.jumpBracket","Go to Bracket"),alias:"Go to Bracket",precondition:void 0,kbOpts:{kbExpr:T.editorTextFocus,primary:3165,weight:100}})}run(e,t){var i;(i=Yr.get(t))===null||i===void 0||i.jumpToBracket()}}class Dbe extends we{constructor(){super({id:"editor.action.selectToBracket",label:p("smartSelect.selectToBracket","Select to Bracket"),alias:"Select to Bracket",precondition:void 0,metadata:{description:uX("smartSelect.selectToBracketDescription","Select the text inside and including the brackets or curly braces"),args:[{name:"args",schema:{type:"object",properties:{selectBrackets:{type:"boolean",default:!0}}}}]}})}run(e,t,i){var n;let o=!0;i&&i.selectBrackets===!1&&(o=!1),(n=Yr.get(t))===null||n===void 0||n.selectToBracket(o)}}class kbe extends we{constructor(){super({id:"editor.action.removeBrackets",label:p("smartSelect.removeBrackets","Remove Brackets"),alias:"Remove Brackets",precondition:void 0,kbOpts:{kbExpr:T.editorTextFocus,primary:2561,weight:100}})}run(e,t){var i;(i=Yr.get(t))===null||i===void 0||i.removeBrackets(this.id)}}class Ibe{constructor(e,t,i){this.position=e,this.brackets=t,this.options=i}}class Yr extends j{static get(e){return e.getContribution(Yr.ID)}constructor(e){super(),this._editor=e,this._lastBracketsData=[],this._lastVersionId=0,this._decorations=this._editor.createDecorationsCollection(),this._updateBracketsSoon=this._register(new jt(()=>this._updateBrackets(),50)),this._matchBrackets=this._editor.getOption(71),this._updateBracketsSoon.schedule(),this._register(e.onDidChangeCursorPosition(t=>{this._matchBrackets!=="never"&&this._updateBracketsSoon.schedule()})),this._register(e.onDidChangeModelContent(t=>{this._updateBracketsSoon.schedule()})),this._register(e.onDidChangeModel(t=>{this._lastBracketsData=[],this._updateBracketsSoon.schedule()})),this._register(e.onDidChangeModelLanguageConfiguration(t=>{this._lastBracketsData=[],this._updateBracketsSoon.schedule()})),this._register(e.onDidChangeConfiguration(t=>{t.hasChanged(71)&&(this._matchBrackets=this._editor.getOption(71),this._decorations.clear(),this._lastBracketsData=[],this._lastVersionId=0,this._updateBracketsSoon.schedule())})),this._register(e.onDidBlurEditorWidget(()=>{this._updateBracketsSoon.schedule()})),this._register(e.onDidFocusEditorWidget(()=>{this._updateBracketsSoon.schedule()}))}jumpToBracket(){if(!this._editor.hasModel())return;const e=this._editor.getModel(),t=this._editor.getSelections().map(i=>{const n=i.getStartPosition(),o=e.bracketPairs.matchBracket(n);let r=null;if(o)o[0].containsPosition(n)&&!o[1].containsPosition(n)?r=o[1].getStartPosition():o[1].containsPosition(n)&&(r=o[0].getStartPosition());else{const a=e.bracketPairs.findEnclosingBrackets(n);if(a)r=a[1].getStartPosition();else{const l=e.bracketPairs.findNextBracket(n);l&&l.range&&(r=l.range.getStartPosition())}}return r?new De(r.lineNumber,r.column,r.lineNumber,r.column):new De(n.lineNumber,n.column,n.lineNumber,n.column)});this._editor.setSelections(t),this._editor.revealRange(t[0])}selectToBracket(e){if(!this._editor.hasModel())return;const t=this._editor.getModel(),i=[];this._editor.getSelections().forEach(n=>{const o=n.getStartPosition();let r=t.bracketPairs.matchBracket(o);if(!r&&(r=t.bracketPairs.findEnclosingBrackets(o),!r)){const d=t.bracketPairs.findNextBracket(o);d&&d.range&&(r=t.bracketPairs.matchBracket(d.range.getStartPosition()))}let a=null,l=null;if(r){r.sort(D.compareRangesUsingStarts);const[d,c]=r;if(a=e?d.getStartPosition():d.getEndPosition(),l=e?c.getEndPosition():c.getStartPosition(),c.containsPosition(o)){const u=a;a=l,l=u}}a&&l&&i.push(new De(a.lineNumber,a.column,l.lineNumber,l.column))}),i.length>0&&(this._editor.setSelections(i),this._editor.revealRange(i[0]))}removeBrackets(e){if(!this._editor.hasModel())return;const t=this._editor.getModel();this._editor.getSelections().forEach(i=>{const n=i.getPosition();let o=t.bracketPairs.matchBracket(n);o||(o=t.bracketPairs.findEnclosingBrackets(n)),o&&(this._editor.pushUndoStop(),this._editor.executeEdits(e,[{range:o[0],text:""},{range:o[1],text:""}]),this._editor.pushUndoStop())})}_updateBrackets(){if(this._matchBrackets==="never")return;this._recomputeBrackets();const e=[];let t=0;for(const i of this._lastBracketsData){const n=i.brackets;n&&(e[t++]={range:n[0],options:i.options},e[t++]={range:n[1],options:i.options})}this._decorations.set(e)}_recomputeBrackets(){if(!this._editor.hasModel()||!this._editor.hasWidgetFocus()){this._lastBracketsData=[],this._lastVersionId=0;return}const e=this._editor.getSelections();if(e.length>100){this._lastBracketsData=[],this._lastVersionId=0;return}const t=this._editor.getModel(),i=t.getVersionId();let n=[];this._lastVersionId===i&&(n=this._lastBracketsData);const o=[];let r=0;for(let u=0,h=e.length;u<h;u++){const g=e[u];g.isEmpty()&&(o[r++]=g.getStartPosition())}o.length>1&&o.sort(H.compare);const a=[];let l=0,d=0;const c=n.length;for(let u=0,h=o.length;u<h;u++){const g=o[u];for(;d<c&&n[d].position.isBefore(g);)d++;if(d<c&&n[d].position.equals(g))a[l++]=n[d];else{let f=t.bracketPairs.matchBracket(g,20),m=Yr._DECORATION_OPTIONS_WITH_OVERVIEW_RULER;!f&&this._matchBrackets==="always"&&(f=t.bracketPairs.findEnclosingBrackets(g,20),m=Yr._DECORATION_OPTIONS_WITHOUT_OVERVIEW_RULER),a[l++]=new Ibe(g,f,m)}}this._lastBracketsData=a,this._lastVersionId=i}}Yr.ID="editor.contrib.bracketMatchingController";Yr._DECORATION_OPTIONS_WITH_OVERVIEW_RULER=tt.register({description:"bracket-match-overview",stickiness:1,className:"bracket-match",overviewRuler:{color:Di(Lbe),position:nr.Center}});Yr._DECORATION_OPTIONS_WITHOUT_OVERVIEW_RULER=tt.register({description:"bracket-match-no-overview",stickiness:1,className:"bracket-match"});Lt(Yr.ID,Yr,1);re(Dbe);re(xbe);re(kbe);Wn.appendMenuItem(N.MenubarGoMenu,{group:"5_infile_nav",command:{id:"editor.action.jumpToBracket",title:p({key:"miGoToBracket",comment:["&& denotes a mnemonic"]},"Go to &&Bracket")},order:2});class Ebe{constructor(e,t){this._selection=e,this._isMovingLeft=t}getEditOperations(e,t){if(this._selection.startLineNumber!==this._selection.endLineNumber||this._selection.isEmpty())return;const i=this._selection.startLineNumber,n=this._selection.startColumn,o=this._selection.endColumn;if(!(this._isMovingLeft&&n===1)&&!(!this._isMovingLeft&&o===e.getLineMaxColumn(i)))if(this._isMovingLeft){const r=new D(i,n-1,i,n),a=e.getValueInRange(r);t.addEditOperation(r,null),t.addEditOperation(new D(i,o,i,o),a)}else{const r=new D(i,o,i,o+1),a=e.getValueInRange(r);t.addEditOperation(r,null),t.addEditOperation(new D(i,n,i,n),a)}}computeCursorState(e,t){return this._isMovingLeft?new De(this._selection.startLineNumber,this._selection.startColumn-1,this._selection.endLineNumber,this._selection.endColumn-1):new De(this._selection.startLineNumber,this._selection.startColumn+1,this._selection.endLineNumber,this._selection.endColumn+1)}}class V$ extends we{constructor(e,t){super(t),this.left=e}run(e,t){if(!t.hasModel())return;const i=[],n=t.getSelections();for(const o of n)i.push(new Ebe(o,this.left));t.pushUndoStop(),t.executeCommands(this.id,i),t.pushUndoStop()}}class Nbe extends V${constructor(){super(!0,{id:"editor.action.moveCarretLeftAction",label:p("caret.moveLeft","Move Selected Text Left"),alias:"Move Selected Text Left",precondition:T.writable})}}class Tbe extends V${constructor(){super(!1,{id:"editor.action.moveCarretRightAction",label:p("caret.moveRight","Move Selected Text Right"),alias:"Move Selected Text Right",precondition:T.writable})}}re(Nbe);re(Tbe);class Mbe extends we{constructor(){super({id:"editor.action.transposeLetters",label:p("transposeLetters.label","Transpose Letters"),alias:"Transpose Letters",precondition:T.writable,kbOpts:{kbExpr:T.textInputFocus,primary:0,mac:{primary:306},weight:100}})}run(e,t){if(!t.hasModel())return;const i=t.getModel(),n=[],o=t.getSelections();for(const r of o){if(!r.isEmpty())continue;const a=r.startLineNumber,l=r.startColumn,d=i.getLineMaxColumn(a);if(a===1&&(l===1||l===2&&d===2))continue;const c=l===d?r.getPosition():Pt.rightPosition(i,r.getPosition().lineNumber,r.getPosition().column),u=Pt.leftPosition(i,c),h=Pt.leftPosition(i,u),g=i.getValueInRange(D.fromPositions(h,u)),f=i.getValueInRange(D.fromPositions(u,c)),m=D.fromPositions(h,c);n.push(new Kn(m,f+g))}n.length>0&&(t.pushUndoStop(),t.executeCommands(this.id,n),t.pushUndoStop())}}re(Mbe);const zg="9_cutcopypaste",Rbe=Ra||document.queryCommandSupported("cut"),H$=Ra||document.queryCommandSupported("copy"),Abe=typeof navigator.clipboard>"u"||yr?document.queryCommandSupported("paste"):!0;function e4(s){return s.register(),s}const Pbe=Rbe?e4(new n_({id:"editor.action.clipboardCutAction",precondition:void 0,kbOpts:Ra?{primary:2102,win:{primary:2102,secondary:[1044]},weight:100}:void 0,menuOpts:[{menuId:N.MenubarEditMenu,group:"2_ccp",title:p({key:"miCut",comment:["&& denotes a mnemonic"]},"Cu&&t"),order:1},{menuId:N.EditorContext,group:zg,title:p("actions.clipboard.cutLabel","Cut"),when:T.writable,order:1},{menuId:N.CommandPalette,group:"",title:p("actions.clipboard.cutLabel","Cut"),order:1},{menuId:N.SimpleEditorContext,group:zg,title:p("actions.clipboard.cutLabel","Cut"),when:T.writable,order:1}]})):void 0,Obe=H$?e4(new n_({id:"editor.action.clipboardCopyAction",precondition:void 0,kbOpts:Ra?{primary:2081,win:{primary:2081,secondary:[2067]},weight:100}:void 0,menuOpts:[{menuId:N.MenubarEditMenu,group:"2_ccp",title:p({key:"miCopy",comment:["&& denotes a mnemonic"]},"&&Copy"),order:2},{menuId:N.EditorContext,group:zg,title:p("actions.clipboard.copyLabel","Copy"),order:2},{menuId:N.CommandPalette,group:"",title:p("actions.clipboard.copyLabel","Copy"),order:1},{menuId:N.SimpleEditorContext,group:zg,title:p("actions.clipboard.copyLabel","Copy"),order:2}]})):void 0;Wn.appendMenuItem(N.MenubarEditMenu,{submenu:N.MenubarCopy,title:{value:p("copy as","Copy As"),original:"Copy As"},group:"2_ccp",order:3});Wn.appendMenuItem(N.EditorContext,{submenu:N.EditorContextCopy,title:{value:p("copy as","Copy As"),original:"Copy As"},group:zg,order:3});Wn.appendMenuItem(N.EditorContext,{submenu:N.EditorContextShare,title:{value:p("share","Share"),original:"Share"},group:"11_share",order:-1,when:ee.and(ee.notEquals("resourceScheme","output"),T.editorTextFocus)});Wn.appendMenuItem(N.EditorTitleContext,{submenu:N.EditorTitleContextShare,title:{value:p("share","Share"),original:"Share"},group:"11_share",order:-1});Wn.appendMenuItem(N.ExplorerContext,{submenu:N.ExplorerContextShare,title:{value:p("share","Share"),original:"Share"},group:"11_share",order:-1});const eE=Abe?e4(new n_({id:"editor.action.clipboardPasteAction",precondition:void 0,kbOpts:Ra?{primary:2100,win:{primary:2100,secondary:[1043]},linux:{primary:2100,secondary:[1043]},weight:100}:void 0,menuOpts:[{menuId:N.MenubarEditMenu,group:"2_ccp",title:p({key:"miPaste",comment:["&& denotes a mnemonic"]},"&&Paste"),order:4},{menuId:N.EditorContext,group:zg,title:p("actions.clipboard.pasteLabel","Paste"),when:T.writable,order:4},{menuId:N.CommandPalette,group:"",title:p("actions.clipboard.pasteLabel","Paste"),order:1},{menuId:N.SimpleEditorContext,group:zg,title:p("actions.clipboard.pasteLabel","Paste"),when:T.writable,order:4}]})):void 0;class Fbe extends we{constructor(){super({id:"editor.action.clipboardCopyWithSyntaxHighlightingAction",label:p("actions.clipboard.copyWithSyntaxHighlightingLabel","Copy With Syntax Highlighting"),alias:"Copy With Syntax Highlighting",precondition:void 0,kbOpts:{kbExpr:T.textInputFocus,primary:0,weight:100}})}run(e,t){!t.hasModel()||!t.getOption(37)&&t.getSelection().isEmpty()||(_T.forceCopyWithSyntaxHighlighting=!0,t.focus(),t.getContainerDomNode().ownerDocument.execCommand("copy"),_T.forceCopyWithSyntaxHighlighting=!1)}}function z$(s,e){s&&(s.addImplementation(1e4,"code-editor",(t,i)=>{const n=t.get(It).getFocusedCodeEditor();if(n&&n.hasTextFocus()){const o=n.getOption(37),r=n.getSelection();return r&&r.isEmpty()&&!o||n.getContainerDomNode().ownerDocument.execCommand(e),!0}return!1}),s.addImplementation(0,"generic-dom",(t,i)=>(i_().execCommand(e),!0)))}z$(Pbe,"cut");z$(Obe,"copy");eE&&(eE.addImplementation(1e4,"code-editor",(s,e)=>{const t=s.get(It),i=s.get(dc),n=t.getFocusedCodeEditor();return n&&n.hasTextFocus()?!n.getContainerDomNode().ownerDocument.execCommand("paste")&&Ju?(async()=>{const r=await i.readText();if(r!==""){const a=K0.INSTANCE.get(r);let l=!1,d=null,c=null;a&&(l=n.getOption(37)&&!!a.isFromEmptySelection,d=typeof a.multicursorText<"u"?a.multicursorText:null,c=a.mode),n.trigger("keyboard","paste",{text:r,pasteOnNewLine:l,multicursorText:d,mode:c})}})():!0:!1}),eE.addImplementation(0,"generic-dom",(s,e)=>(i_().execCommand("paste"),!0)));H$&&re(Fbe);class $e{constructor(e){this.value=e}equals(e){return this.value===e.value}contains(e){return this.equals(e)||this.value===""||e.value.startsWith(this.value+$e.sep)}intersects(e){return this.contains(e)||e.contains(this)}append(e){return new $e(this.value+$e.sep+e)}}$e.sep=".";$e.None=new $e("@@none@@");$e.Empty=new $e("");$e.QuickFix=new $e("quickfix");$e.Refactor=new $e("refactor");$e.RefactorExtract=$e.Refactor.append("extract");$e.RefactorInline=$e.Refactor.append("inline");$e.RefactorMove=$e.Refactor.append("move");$e.RefactorRewrite=$e.Refactor.append("rewrite");$e.Notebook=new $e("notebook");$e.Source=new $e("source");$e.SourceOrganizeImports=$e.Source.append("organizeImports");$e.SourceFixAll=$e.Source.append("fixAll");$e.SurroundWith=$e.Refactor.append("surround");var xo;(function(s){s.Refactor="refactor",s.RefactorPreview="refactor preview",s.Lightbulb="lightbulb",s.Default="other (default)",s.SourceAction="source action",s.QuickFix="quick fix action",s.FixAll="fix all",s.OrganizeImports="organize imports",s.AutoFix="auto fix",s.QuickFixHover="quick fix hover window",s.OnSave="save participants",s.ProblemsView="problems view"})(xo||(xo={}));function Bbe(s,e){return!(s.include&&!s.include.intersects(e)||s.excludes&&s.excludes.some(t=>U$(e,t,s.include))||!s.includeSourceActions&&$e.Source.contains(e))}function Wbe(s,e){const t=e.kind?new $e(e.kind):void 0;return!(s.include&&(!t||!s.include.contains(t))||s.excludes&&t&&s.excludes.some(i=>U$(t,i,s.include))||!s.includeSourceActions&&t&&$e.Source.contains(t)||s.onlyIncludePreferredActions&&!e.isPreferred)}function U$(s,e,t){return!(!e.contains(s)||t&&e.contains(t))}class xl{static fromUser(e,t){return!e||typeof e!="object"?new xl(t.kind,t.apply,!1):new xl(xl.getKindFromUser(e,t.kind),xl.getApplyFromUser(e,t.apply),xl.getPreferredUser(e))}static getApplyFromUser(e,t){switch(typeof e.apply=="string"?e.apply.toLowerCase():""){case"first":return"first";case"never":return"never";case"ifsingle":return"ifSingle";default:return t}}static getKindFromUser(e,t){return typeof e.kind=="string"?new $e(e.kind):t}static getPreferredUser(e){return typeof e.preferred=="boolean"?e.preferred:!1}constructor(e,t,i){this.kind=e,this.apply=t,this.preferred=i}}class Vbe{constructor(e,t,i){this.action=e,this.provider=t,this.highlightRange=i}async resolve(e){var t;if(!((t=this.provider)===null||t===void 0)&&t.resolveCodeAction&&!this.action.edit){let i;try{i=await this.provider.resolveCodeAction(this.action,e)}catch(n){Zi(n)}i&&(this.action.edit=i.edit)}return this}}const $$="editor.action.codeAction",t4="editor.action.quickFix",j$="editor.action.autoFix",K$="editor.action.refactor",q$="editor.action.sourceAction",i4="editor.action.organizeImports",n4="editor.action.fixAll";class e0 extends j{static codeActionsPreferredComparator(e,t){return e.isPreferred&&!t.isPreferred?-1:!e.isPreferred&&t.isPreferred?1:0}static codeActionsComparator({action:e},{action:t}){return e.isAI&&!t.isAI?1:!e.isAI&&t.isAI?-1:as(e.diagnostics)?as(t.diagnostics)?e0.codeActionsPreferredComparator(e,t):-1:as(t.diagnostics)?1:e0.codeActionsPreferredComparator(e,t)}constructor(e,t,i){super(),this.documentation=t,this._register(i),this.allActions=[...e].sort(e0.codeActionsComparator),this.validActions=this.allActions.filter(({action:n})=>!n.disabled)}get hasAutoFix(){return this.validActions.some(({action:e})=>!!e.kind&&$e.QuickFix.contains(new $e(e.kind))&&!!e.isPreferred)}get hasAIFix(){return this.validActions.some(({action:e})=>!!e.isAI)}get allAIFixes(){return this.validActions.every(({action:e})=>!!e.isAI)}}const D8={actions:[],documentation:void 0};async function t0(s,e,t,i,n,o){var r;const a=i.filter||{},l={...a,excludes:[...a.excludes||[],$e.Notebook]},d={only:(r=a.include)===null||r===void 0?void 0:r.value,trigger:i.type},c=new GO(e,o),u=i.type===2,h=Hbe(s,e,u?l:a),g=new ie,f=h.map(async _=>{try{n.report(_);const v=await _.provideCodeActions(e,t,d,c.token);if(v&&g.add(v),c.token.isCancellationRequested)return D8;const b=((v==null?void 0:v.actions)||[]).filter(w=>w&&Wbe(a,w)),C=Ube(_,b,a.include);return{actions:b.map(w=>new Vbe(w,_)),documentation:C}}catch(v){if(Ka(v))throw v;return Zi(v),D8}}),m=s.onDidChange(()=>{const _=s.all(e);Ai(_,h)||c.cancel()});try{const _=await Promise.all(f),v=_.map(C=>C.actions).flat(),b=[...Ba(_.map(C=>C.documentation)),...zbe(s,e,i,v)];return new e0(v,b,g)}finally{m.dispose(),c.dispose()}}function Hbe(s,e,t){return s.all(e).filter(i=>i.providedCodeActionKinds?i.providedCodeActionKinds.some(n=>Bbe(t,new $e(n))):!0)}function*zbe(s,e,t,i){var n,o,r;if(e&&i.length)for(const a of s.all(e))a._getAdditionalMenuItems&&(yield*(n=a._getAdditionalMenuItems)===null||n===void 0?void 0:n.call(a,{trigger:t.type,only:(r=(o=t.filter)===null||o===void 0?void 0:o.include)===null||r===void 0?void 0:r.value},i.map(l=>l.action)))}function Ube(s,e,t){if(!s.documentation)return;const i=s.documentation.map(n=>({kind:new $e(n.kind),command:n.command}));if(t){let n;for(const o of i)o.kind.contains(t)&&(n?n.kind.contains(o.kind)&&(n=o):n=o);if(n)return n==null?void 0:n.command}for(const n of e)if(n.kind){for(const o of i)if(o.kind.contains(new $e(n.kind)))return o.command}}var tL;(function(s){s.OnSave="onSave",s.FromProblemsView="fromProblemsView",s.FromCodeActions="fromCodeActions"})(tL||(tL={}));async function $be(s,e,t,i,n=ct.None){var o;const r=s.get(bC),a=s.get(Ei),l=s.get(Do),d=s.get(Qi);if(l.publicLog2("codeAction.applyCodeAction",{codeActionTitle:e.action.title,codeActionKind:e.action.kind,codeActionIsPreferred:!!e.action.isPreferred,reason:t}),await e.resolve(n),!n.isCancellationRequested&&!(!((o=e.action.edit)===null||o===void 0)&&o.edits.length&&!(await r.apply(e.action.edit,{editor:i==null?void 0:i.editor,label:e.action.title,quotableLabel:e.action.title,code:"undoredo.codeAction",respectAutoSaveConfig:t!==tL.OnSave,showPreview:i==null?void 0:i.preview})).isApplied)&&e.action.command)try{await a.executeCommand(e.action.command.id,...e.action.command.arguments||[])}catch(c){const u=jbe(c);d.error(typeof u=="string"?u:p("applyCodeActionFailed","An unknown error occurred while applying the code action"))}}function jbe(s){return typeof s=="string"?s:s instanceof Error&&typeof s.message=="string"?s.message:void 0}Ct.registerCommand("_executeCodeActionProvider",async function(s,e,t,i,n){if(!(e instanceof Pe))throw Cr();const{codeActionProvider:o}=s.get(xe),r=s.get(vi).getModel(e);if(!r)throw Cr();const a=De.isISelection(t)?De.liftSelection(t):D.isIRange(t)?r.validateRange(t):void 0;if(!a)throw Cr();const l=typeof i=="string"?new $e(i):void 0,d=await t0(o,r,a,{type:1,triggerAction:xo.Default,filter:{includeSourceActions:!0,include:l}},Gd.None,ct.None),c=[],u=Math.min(d.validActions.length,typeof n=="number"?n:0);for(let h=0;h<u;h++)c.push(d.validActions[h].resolve(ct.None));try{return await Promise.all(c),d.validActions.map(h=>h.action)}finally{setTimeout(()=>d.dispose(),100)}});var Kbe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},qbe=function(s,e){return function(t,i){e(t,i,s)}},mM;let iL=mM=class{constructor(e){this.keybindingService=e}getResolver(){const e=new ih(()=>this.keybindingService.getKeybindings().filter(t=>mM.codeActionCommands.indexOf(t.command)>=0).filter(t=>t.resolvedKeybinding).map(t=>{let i=t.commandArgs;return t.command===i4?i={kind:$e.SourceOrganizeImports.value}:t.command===n4&&(i={kind:$e.SourceFixAll.value}),{resolvedKeybinding:t.resolvedKeybinding,...xl.fromUser(i,{kind:$e.None,apply:"never"})}}));return t=>{if(t.kind){const i=this.bestKeybindingForCodeAction(t,e.value);return i==null?void 0:i.resolvedKeybinding}}}bestKeybindingForCodeAction(e,t){if(!e.kind)return;const i=new $e(e.kind);return t.filter(n=>n.kind.contains(i)).filter(n=>n.preferred?e.isPreferred:!0).reduceRight((n,o)=>n?n.kind.contains(o.kind)?o:n:o,void 0)}};iL.codeActionCommands=[K$,$$,q$,i4,n4];iL=mM=Kbe([qbe(0,qt)],iL);R("symbolIcon.arrayForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.arrayForeground","The foreground color for array symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.booleanForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.booleanForeground","The foreground color for boolean symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.classForeground",{dark:"#EE9D28",light:"#D67E00",hcDark:"#EE9D28",hcLight:"#D67E00"},p("symbolIcon.classForeground","The foreground color for class symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.colorForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.colorForeground","The foreground color for color symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.constantForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.constantForeground","The foreground color for constant symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.constructorForeground",{dark:"#B180D7",light:"#652D90",hcDark:"#B180D7",hcLight:"#652D90"},p("symbolIcon.constructorForeground","The foreground color for constructor symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.enumeratorForeground",{dark:"#EE9D28",light:"#D67E00",hcDark:"#EE9D28",hcLight:"#D67E00"},p("symbolIcon.enumeratorForeground","The foreground color for enumerator symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.enumeratorMemberForeground",{dark:"#75BEFF",light:"#007ACC",hcDark:"#75BEFF",hcLight:"#007ACC"},p("symbolIcon.enumeratorMemberForeground","The foreground color for enumerator member symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.eventForeground",{dark:"#EE9D28",light:"#D67E00",hcDark:"#EE9D28",hcLight:"#D67E00"},p("symbolIcon.eventForeground","The foreground color for event symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.fieldForeground",{dark:"#75BEFF",light:"#007ACC",hcDark:"#75BEFF",hcLight:"#007ACC"},p("symbolIcon.fieldForeground","The foreground color for field symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.fileForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.fileForeground","The foreground color for file symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.folderForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.folderForeground","The foreground color for folder symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.functionForeground",{dark:"#B180D7",light:"#652D90",hcDark:"#B180D7",hcLight:"#652D90"},p("symbolIcon.functionForeground","The foreground color for function symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.interfaceForeground",{dark:"#75BEFF",light:"#007ACC",hcDark:"#75BEFF",hcLight:"#007ACC"},p("symbolIcon.interfaceForeground","The foreground color for interface symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.keyForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.keyForeground","The foreground color for key symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.keywordForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.keywordForeground","The foreground color for keyword symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.methodForeground",{dark:"#B180D7",light:"#652D90",hcDark:"#B180D7",hcLight:"#652D90"},p("symbolIcon.methodForeground","The foreground color for method symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.moduleForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.moduleForeground","The foreground color for module symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.namespaceForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.namespaceForeground","The foreground color for namespace symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.nullForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.nullForeground","The foreground color for null symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.numberForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.numberForeground","The foreground color for number symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.objectForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.objectForeground","The foreground color for object symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.operatorForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.operatorForeground","The foreground color for operator symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.packageForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.packageForeground","The foreground color for package symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.propertyForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.propertyForeground","The foreground color for property symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.referenceForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.referenceForeground","The foreground color for reference symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.snippetForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.snippetForeground","The foreground color for snippet symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.stringForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.stringForeground","The foreground color for string symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.structForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.structForeground","The foreground color for struct symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.textForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.textForeground","The foreground color for text symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.typeParameterForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.typeParameterForeground","The foreground color for type parameter symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.unitForeground",{dark:de,light:de,hcDark:de,hcLight:de},p("symbolIcon.unitForeground","The foreground color for unit symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));R("symbolIcon.variableForeground",{dark:"#75BEFF",light:"#007ACC",hcDark:"#75BEFF",hcLight:"#007ACC"},p("symbolIcon.variableForeground","The foreground color for variable symbols. These symbols appear in the outline, breadcrumb, and suggest widget."));const G$=Object.freeze({kind:$e.Empty,title:p("codeAction.widget.id.more","More Actions...")}),Gbe=Object.freeze([{kind:$e.QuickFix,title:p("codeAction.widget.id.quickfix","Quick Fix")},{kind:$e.RefactorExtract,title:p("codeAction.widget.id.extract","Extract"),icon:le.wrench},{kind:$e.RefactorInline,title:p("codeAction.widget.id.inline","Inline"),icon:le.wrench},{kind:$e.RefactorRewrite,title:p("codeAction.widget.id.convert","Rewrite"),icon:le.wrench},{kind:$e.RefactorMove,title:p("codeAction.widget.id.move","Move"),icon:le.wrench},{kind:$e.SurroundWith,title:p("codeAction.widget.id.surround","Surround With"),icon:le.symbolSnippet},{kind:$e.Source,title:p("codeAction.widget.id.source","Source Action"),icon:le.symbolFile},G$]);function Zbe(s,e,t){if(!e)return s.map(o=>{var r;return{kind:"action",item:o,group:G$,disabled:!!o.action.disabled,label:o.action.disabled||o.action.title,canPreview:!!(!((r=o.action.edit)===null||r===void 0)&&r.edits.length)}});const i=Gbe.map(o=>({group:o,actions:[]}));for(const o of s){const r=o.action.kind?new $e(o.action.kind):$e.None;for(const a of i)if(a.group.kind.contains(r)){a.actions.push(o);break}}const n=[];for(const o of i)if(o.actions.length){n.push({kind:"header",group:o.group});for(const r of o.actions){const a=o.group;n.push({kind:"action",item:r,group:r.action.isAI?{title:a.title,kind:a.kind,icon:le.sparkle}:a,label:r.action.title,disabled:!!r.action.disabled,keybinding:t(r.action)})}}return n}var Ybe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},k8=function(s,e){return function(t,i){e(t,i,s)}},_M,yp;(function(s){s.Hidden={type:0};class e{constructor(i,n,o,r){this.actions=i,this.trigger=n,this.editorPosition=o,this.widgetPosition=r,this.type=1}}s.Showing=e})(yp||(yp={}));let Ug=_M=class extends j{constructor(e,t,i){super(),this._editor=e,this._keybindingService=t,this._onClick=this._register(new W),this.onClick=this._onClick.event,this._state=yp.Hidden,this._iconClasses=[],this._domNode=se("div.lightBulbWidget"),this._register(Xt.ignoreTarget(this._domNode)),this._editor.addContentWidget(this),this._register(this._editor.onDidChangeModelContent(n=>{const o=this._editor.getModel();(this.state.type!==1||!o||this.state.editorPosition.lineNumber>=o.getLineCount())&&this.hide()})),this._register(Bee(this._domNode,n=>{var o;if(this.state.type!==1)return;const r=this._editor.getOption(64).experimental.showAiIcon;if((r===ho.On||r===ho.OnCode)&&this.state.actions.allAIFixes&&this.state.actions.validActions.length===1){const u=this.state.actions.validActions[0].action;if(!((o=u.command)===null||o===void 0)&&o.id){i.executeCommand(u.command.id,...u.command.arguments||[]),n.preventDefault();return}}this._editor.focus(),n.preventDefault();const{top:a,height:l}=ln(this._domNode),d=this._editor.getOption(66);let c=Math.floor(d/3);this.state.widgetPosition.position!==null&&this.state.widgetPosition.position.lineNumber<this.state.editorPosition.lineNumber&&(c+=d),this._onClick.fire({x:n.posx,y:a+l+c,actions:this.state.actions,trigger:this.state.trigger})})),this._register(Y(this._domNode,"mouseenter",n=>{(n.buttons&1)===1&&this.hide()})),this._register(this._editor.onDidChangeConfiguration(n=>{n.hasChanged(64)&&(this._editor.getOption(64).enabled||this.hide(),this._updateLightBulbTitleAndIcon())})),this._register(ge.runAndSubscribe(this._keybindingService.onDidUpdateKeybindings,()=>{var n,o,r,a;this._preferredKbLabel=(o=(n=this._keybindingService.lookupKeybinding(j$))===null||n===void 0?void 0:n.getLabel())!==null&&o!==void 0?o:void 0,this._quickFixKbLabel=(a=(r=this._keybindingService.lookupKeybinding(t4))===null||r===void 0?void 0:r.getLabel())!==null&&a!==void 0?a:void 0,this._updateLightBulbTitleAndIcon()}))}dispose(){super.dispose(),this._editor.removeContentWidget(this)}getId(){return"LightBulbWidget"}getDomNode(){return this._domNode}getPosition(){return this._state.type===1?this._state.widgetPosition:null}update(e,t,i){if(e.validActions.length<=0)return this.hide();const n=this._editor.getOptions();if(!n.get(64).enabled)return this.hide();const o=this._editor.getModel();if(!o)return this.hide();const{lineNumber:r,column:a}=o.validatePosition(i),l=o.getOptions().tabSize,d=n.get(50),c=o.getLineContent(r),u=Ex(c,l),h=d.spaceWidth*u>22,g=m=>m>2&&this._editor.getTopForLineNumber(m)===this._editor.getTopForLineNumber(m-1);let f=r;if(!h){if(r>1&&!g(r-1))f-=1;else if(!g(r+1))f+=1;else if(a*d.spaceWidth<22)return this.hide()}this.state=new yp.Showing(e,t,i,{position:{lineNumber:f,column:o.getLineContent(f).match(/^\S\s*$/)?2:1},preference:_M._posPref}),this._editor.layoutContentWidget(this)}hide(){this.state!==yp.Hidden&&(this.state=yp.Hidden,this._editor.layoutContentWidget(this))}get state(){return this._state}set state(e){this._state=e,this._updateLightBulbTitleAndIcon()}_updateLightBulbTitleAndIcon(){var e,t,i;if(this._domNode.classList.remove(...this._iconClasses),this._iconClasses=[],this.state.type!==1)return;const n=()=>{this._preferredKbLabel&&(this.title=p("preferredcodeActionWithKb","Show Code Actions. Preferred Quick Fix Available ({0})",this._preferredKbLabel))},o=()=>{this._quickFixKbLabel?this.title=p("codeActionWithKb","Show Code Actions ({0})",this._quickFixKbLabel):this.title=p("codeAction","Show Code Actions")};let r;const a=this._editor.getOption(64).experimental.showAiIcon;if(a===ho.On||a===ho.OnCode)if(a===ho.On&&this.state.actions.allAIFixes)if(r=le.sparkleFilled,this.state.actions.allAIFixes&&this.state.actions.validActions.length===1)if(((e=this.state.actions.validActions[0].action.command)===null||e===void 0?void 0:e.id)==="inlineChat.start"){const l=(i=(t=this._keybindingService.lookupKeybinding("inlineChat.start"))===null||t===void 0?void 0:t.getLabel())!==null&&i!==void 0?i:void 0;this.title=l?p("codeActionStartInlineChatWithKb","Start Inline Chat ({0})",l):p("codeActionStartInlineChat","Start Inline Chat")}else this.title=p("codeActionTriggerAiAction","Trigger AI Action");else o();else this.state.actions.hasAutoFix?(this.state.actions.hasAIFix?r=le.lightbulbSparkleAutofix:r=le.lightbulbAutofix,n()):this.state.actions.hasAIFix?(r=le.lightbulbSparkle,o()):(r=le.lightBulb,o());else this.state.actions.hasAutoFix?(r=le.lightbulbAutofix,n()):(r=le.lightBulb,o());this._iconClasses=Oe.asClassNameArray(r),this._domNode.classList.add(...this._iconClasses)}set title(e){this._domNode.title=e}};Ug.ID="editor.contrib.lightbulbWidget";Ug._posPref=[0];Ug=_M=Ybe([k8(1,qt),k8(2,Ei)],Ug);var Xbe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},I8=function(s,e){return function(t,i){e(t,i,s)}},vM;let ic=vM=class{constructor(e,t,i){this._options=e,this._languageService=t,this._openerService=i,this._onDidRenderAsync=new W,this.onDidRenderAsync=this._onDidRenderAsync.event}dispose(){this._onDidRenderAsync.dispose()}render(e,t,i){if(!e)return{element:document.createElement("span"),dispose:()=>{}};const n=new ie,o=n.add(Vx(e,{...this._getRenderOptions(e,n),...t},i));return o.element.classList.add("rendered-markdown"),{element:o.element,dispose:()=>n.dispose()}}_getRenderOptions(e,t){return{codeBlockRenderer:async(i,n)=>{var o,r,a;let l;i?l=this._languageService.getLanguageIdByLanguageName(i):this._options.editor&&(l=(o=this._options.editor.getModel())===null||o===void 0?void 0:o.getLanguageId()),l||(l=er);const d=await rce(this._languageService,n,l),c=document.createElement("span");if(c.innerHTML=(a=(r=vM._ttpTokenizer)===null||r===void 0?void 0:r.createHTML(d))!==null&&a!==void 0?a:d,this._options.editor){const u=this._options.editor.getOption(50);Xn(c,u)}else this._options.codeBlockFontFamily&&(c.style.fontFamily=this._options.codeBlockFontFamily);return this._options.codeBlockFontSize!==void 0&&(c.style.fontSize=this._options.codeBlockFontSize),c},asyncRenderCallback:()=>this._onDidRenderAsync.fire(),actionHandler:{callback:i=>Z$(this._openerService,i,e.isTrusted),disposables:t}}}};ic._ttpTokenizer=oc("tokenizeToString",{createHTML(s){return s}});ic=vM=Xbe([I8(1,fi),I8(2,No)],ic);async function Z$(s,e,t){try{return await s.open(e,{fromUserGesture:!0,allowContributedOpeners:!0,allowCommands:Qbe(t)})}catch(i){return et(i),!1}}function Qbe(s){return s===!0?!0:s&&Array.isArray(s.enabledCommands)?s.enabledCommands:!1}var Jbe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},E8=function(s,e){return function(t,i){e(t,i,s)}},eS;let Co=eS=class{static get(e){return e.getContribution(eS.ID)}constructor(e,t,i){this._openerService=i,this._messageWidget=new En,this._messageListeners=new ie,this._mouseOverMessage=!1,this._editor=e,this._visible=eS.MESSAGE_VISIBLE.bindTo(t)}dispose(){var e;(e=this._message)===null||e===void 0||e.dispose(),this._messageListeners.dispose(),this._messageWidget.dispose(),this._visible.reset()}showMessage(e,t){Lo(uu(e)?e.value:e),this._visible.set(!0),this._messageWidget.clear(),this._messageListeners.clear(),this._message=uu(e)?Vx(e,{actionHandler:{callback:n=>Z$(this._openerService,n,uu(e)?e.isTrusted:void 0),disposables:this._messageListeners}}):void 0,this._messageWidget.value=new N8(this._editor,t,typeof e=="string"?e:this._message.element),this._messageListeners.add(ge.debounce(this._editor.onDidBlurEditorText,(n,o)=>o,0)(()=>{this._mouseOverMessage||this._messageWidget.value&&Yn(Jo(),this._messageWidget.value.getDomNode())||this.closeMessage()})),this._messageListeners.add(this._editor.onDidChangeCursorPosition(()=>this.closeMessage())),this._messageListeners.add(this._editor.onDidDispose(()=>this.closeMessage())),this._messageListeners.add(this._editor.onDidChangeModel(()=>this.closeMessage())),this._messageListeners.add(Y(this._messageWidget.value.getDomNode(),he.MOUSE_ENTER,()=>this._mouseOverMessage=!0,!0)),this._messageListeners.add(Y(this._messageWidget.value.getDomNode(),he.MOUSE_LEAVE,()=>this._mouseOverMessage=!1,!0));let i;this._messageListeners.add(this._editor.onMouseMove(n=>{n.target.position&&(i?i.containsPosition(n.target.position)||this.closeMessage():i=new D(t.lineNumber-3,1,n.target.position.lineNumber+3,1))}))}closeMessage(){this._visible.reset(),this._messageListeners.clear(),this._messageWidget.value&&this._messageListeners.add(N8.fadeOut(this._messageWidget.value))}};Co.ID="editor.contrib.messageController";Co.MESSAGE_VISIBLE=new me("messageVisible",!1,p("messageVisible","Whether the editor is currently showing an inline message"));Co=eS=Jbe([E8(1,je),E8(2,No)],Co);const eCe=Nn.bindToContribution(Co.get);ue(new eCe({id:"leaveEditorMessage",precondition:Co.MESSAGE_VISIBLE,handler:s=>s.closeMessage(),kbOpts:{weight:130,primary:9}}));let N8=class{static fadeOut(e){const t=()=>{e.dispose(),clearTimeout(i),e.getDomNode().removeEventListener("animationend",t)},i=setTimeout(t,110);return e.getDomNode().addEventListener("animationend",t),e.getDomNode().classList.add("fadeOut"),{dispose:t}}constructor(e,{lineNumber:t,column:i},n){this.allowEditorOverflow=!0,this.suppressMouseDown=!1,this._editor=e,this._editor.revealLinesInCenterIfOutsideViewport(t,t,0),this._position={lineNumber:t,column:i},this._domNode=document.createElement("div"),this._domNode.classList.add("monaco-editor-overlaymessage"),this._domNode.style.marginLeft="-6px";const o=document.createElement("div");o.classList.add("anchor","top"),this._domNode.appendChild(o);const r=document.createElement("div");typeof n=="string"?(r.classList.add("message"),r.textContent=n):(n.classList.add("message"),r.appendChild(n)),this._domNode.appendChild(r);const a=document.createElement("div");a.classList.add("anchor","below"),this._domNode.appendChild(a),this._editor.addContentWidget(this),this._domNode.classList.add("fadeIn")}dispose(){this._editor.removeContentWidget(this)}getId(){return"messageoverlay"}getDomNode(){return this._domNode}getPosition(){return{position:this._position,preference:[1,2],positionAffinity:1}}afterRender(e){this._domNode.classList.toggle("below",e===2)}};Lt(Co.ID,Co,4);var Y$=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},bM=function(s,e){return function(t,i){e(t,i,s)}};const X$="acceptSelectedCodeAction",Q$="previewSelectedCodeAction";class tCe{get templateId(){return"header"}renderTemplate(e){e.classList.add("group-header");const t=document.createElement("span");return e.append(t),{container:e,text:t}}renderElement(e,t,i){var n,o;i.text.textContent=(o=(n=e.group)===null||n===void 0?void 0:n.title)!==null&&o!==void 0?o:""}disposeTemplate(e){}}let CM=class{get templateId(){return"action"}constructor(e,t){this._supportsPreview=e,this._keybindingService=t}renderTemplate(e){e.classList.add(this.templateId);const t=document.createElement("div");t.className="icon",e.append(t);const i=document.createElement("span");i.className="title",e.append(i);const n=new xC(e,Go);return{container:e,icon:t,text:i,keybinding:n}}renderElement(e,t,i){var n,o,r;if(!((n=e.group)===null||n===void 0)&&n.icon?(i.icon.className=Oe.asClassName(e.group.icon),e.group.icon.color&&(i.icon.style.color=_e(e.group.icon.color.id))):(i.icon.className=Oe.asClassName(le.lightBulb),i.icon.style.color="var(--vscode-editorLightBulb-foreground)"),!e.item||!e.label)return;i.text.textContent=J$(e.label),i.keybinding.set(e.keybinding),ete(!!e.keybinding,i.keybinding.element);const a=(o=this._keybindingService.lookupKeybinding(X$))===null||o===void 0?void 0:o.getLabel(),l=(r=this._keybindingService.lookupKeybinding(Q$))===null||r===void 0?void 0:r.getLabel();i.container.classList.toggle("option-disabled",e.disabled),e.disabled?i.container.title=e.label:a&&l?this._supportsPreview&&e.canPreview?i.container.title=p({key:"label-preview",comment:['placeholders are keybindings, e.g "F2 to apply, Shift+F2 to preview"']},"{0} to apply, {1} to preview",a,l):i.container.title=p({key:"label",comment:['placeholder is a keybinding, e.g "F2 to apply"']},"{0} to apply",a):i.container.title=""}disposeTemplate(e){}};CM=Y$([bM(1,qt)],CM);class iCe extends UIEvent{constructor(){super("acceptSelectedAction")}}class T8 extends UIEvent{constructor(){super("previewSelectedAction")}}function nCe(s){if(s.kind==="action")return s.label}let wM=class extends j{constructor(e,t,i,n,o,r){super(),this._delegate=n,this._contextViewService=o,this._keybindingService=r,this._actionLineHeight=24,this._headerLineHeight=26,this.cts=this._register(new Yi),this.domNode=document.createElement("div"),this.domNode.classList.add("actionList");const a={getHeight:l=>l.kind==="header"?this._headerLineHeight:this._actionLineHeight,getTemplateId:l=>l.kind};this._list=this._register(new na(e,this.domNode,a,[new CM(t,this._keybindingService),new tCe],{keyboardSupport:!1,typeNavigationEnabled:!0,keyboardNavigationLabelProvider:{getKeyboardNavigationLabel:nCe},accessibilityProvider:{getAriaLabel:l=>{if(l.kind==="action"){let d=l.label?J$(l==null?void 0:l.label):"";return l.disabled&&(d=p({key:"customQuickFixWidget.labels",comment:["Action widget labels for accessibility."]},"{0}, Disabled Reason: {1}",d,l.disabled)),d}return null},getWidgetAriaLabel:()=>p({key:"customQuickFixWidget",comment:["An action widget option"]},"Action Widget"),getRole:l=>l.kind==="action"?"option":"separator",getWidgetRole:()=>"listbox"}})),this._list.style(gf),this._register(this._list.onMouseClick(l=>this.onListClick(l))),this._register(this._list.onMouseOver(l=>this.onListHover(l))),this._register(this._list.onDidChangeFocus(()=>this.onFocus())),this._register(this._list.onDidChangeSelection(l=>this.onListSelection(l))),this._allMenuItems=i,this._list.splice(0,this._list.length,this._allMenuItems),this._list.length&&this.focusNext()}focusCondition(e){return!e.disabled&&e.kind==="action"}hide(e){this._delegate.onHide(e),this.cts.cancel(),this._contextViewService.hideContextView()}layout(e){const t=this._allMenuItems.filter(l=>l.kind==="header").length,n=this._allMenuItems.length*this._actionLineHeight+t*this._headerLineHeight-t*this._actionLineHeight;this._list.layout(n);let o=e;if(this._allMenuItems.length>=50)o=380;else{const l=this._allMenuItems.map((d,c)=>{const u=this.domNode.ownerDocument.getElementById(this._list.getElementID(c));if(u){u.style.width="auto";const h=u.getBoundingClientRect().width;return u.style.width="",h}return 0});o=Math.max(...l,e)}const a=Math.min(n,this.domNode.ownerDocument.body.clientHeight*.7);return this._list.layout(a,o),this.domNode.style.height=`${a}px`,this._list.domFocus(),o}focusPrevious(){this._list.focusPrevious(1,!0,void 0,this.focusCondition)}focusNext(){this._list.focusNext(1,!0,void 0,this.focusCondition)}acceptSelected(e){const t=this._list.getFocus();if(t.length===0)return;const i=t[0],n=this._list.element(i);if(!this.focusCondition(n))return;const o=e?new T8:new iCe;this._list.setSelection([i],o)}onListSelection(e){if(!e.elements.length)return;const t=e.elements[0];t.item&&this.focusCondition(t)?this._delegate.onSelect(t.item,e.browserEvent instanceof T8):this._list.setSelection([])}onFocus(){var e,t;this._list.domFocus();const i=this._list.getFocus();if(i.length===0)return;const n=i[0],o=this._list.element(n);(t=(e=this._delegate).onFocus)===null||t===void 0||t.call(e,o.item)}async onListHover(e){const t=e.element;if(t&&t.item&&this.focusCondition(t)){if(this._delegate.onHover&&!t.disabled&&t.kind==="action"){const i=await this._delegate.onHover(t.item,this.cts.token);t.canPreview=i?i.canPreview:void 0}e.index&&this._list.splice(e.index,1,[t])}this._list.setFocus(typeof e.index=="number"?[e.index]:[])}onListClick(e){e.element&&this.focusCondition(e.element)&&this._list.setFocus([])}};wM=Y$([bM(4,rc),bM(5,qt)],wM);function J$(s){return s.replace(/\r\n|\r|\n/g," ")}var sCe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},tE=function(s,e){return function(t,i){e(t,i,s)}};R("actionBar.toggledBackground",{dark:Jh,light:Jh,hcDark:Jh,hcLight:Jh},p("actionBar.toggledBackground","Background color for toggled action items in action bar."));const $g={Visible:new me("codeActionMenuVisible",!1,p("codeActionMenuVisible","Whether the action widget list is visible"))},_f=ut("actionWidgetService");let jg=class extends j{get isVisible(){return $g.Visible.getValue(this._contextKeyService)||!1}constructor(e,t,i){super(),this._contextViewService=e,this._contextKeyService=t,this._instantiationService=i,this._list=this._register(new En)}show(e,t,i,n,o,r,a){const l=$g.Visible.bindTo(this._contextKeyService),d=this._instantiationService.createInstance(wM,e,t,i,n);this._contextViewService.showContextView({getAnchor:()=>o,render:c=>(l.set(!0),this._renderWidget(c,d,a??[])),onHide:c=>{l.reset(),this._onWidgetClosed(c)}},r,!1)}acceptSelected(e){var t;(t=this._list.value)===null||t===void 0||t.acceptSelected(e)}focusPrevious(){var e,t;(t=(e=this._list)===null||e===void 0?void 0:e.value)===null||t===void 0||t.focusPrevious()}focusNext(){var e,t;(t=(e=this._list)===null||e===void 0?void 0:e.value)===null||t===void 0||t.focusNext()}hide(){var e;(e=this._list.value)===null||e===void 0||e.hide(),this._list.clear()}_renderWidget(e,t,i){var n;const o=document.createElement("div");if(o.classList.add("action-widget"),e.appendChild(o),this._list.value=t,this._list.value)o.appendChild(this._list.value.domNode);else throw new Error("List has no value");const r=new ie,a=document.createElement("div"),l=e.appendChild(a);l.classList.add("context-view-block"),r.add(Y(l,he.MOUSE_DOWN,f=>f.stopPropagation()));const d=document.createElement("div"),c=e.appendChild(d);c.classList.add("context-view-pointerBlock"),r.add(Y(c,he.POINTER_MOVE,()=>c.remove())),r.add(Y(c,he.MOUSE_DOWN,()=>c.remove()));let u=0;if(i.length){const f=this._createActionBar(".action-widget-action-bar",i);f&&(o.appendChild(f.getContainer().parentElement),r.add(f),u=f.getContainer().offsetWidth)}const h=(n=this._list.value)===null||n===void 0?void 0:n.layout(u);o.style.width=`${h}px`;const g=r.add(ql(e));return r.add(g.onDidBlur(()=>this.hide())),r}_createActionBar(e,t){if(!t.length)return;const i=se(e),n=new Ir(i);return n.push(t,{icon:!1,label:!0}),n}_onWidgetClosed(e){var t;(t=this._list.value)===null||t===void 0||t.hide(e)}};jg=sCe([tE(0,rc),tE(1,je),tE(2,We)],jg);_t(_f,jg,1);const PC=1100;di(class extends ar{constructor(){super({id:"hideCodeActionWidget",title:{value:p("hideCodeActionWidget.title","Hide action widget"),original:"Hide action widget"},precondition:$g.Visible,keybinding:{weight:PC,primary:9,secondary:[1033]}})}run(s){s.get(_f).hide()}});di(class extends ar{constructor(){super({id:"selectPrevCodeAction",title:{value:p("selectPrevCodeAction.title","Select previous action"),original:"Select previous action"},precondition:$g.Visible,keybinding:{weight:PC,primary:16,secondary:[2064],mac:{primary:16,secondary:[2064,302]}}})}run(s){const e=s.get(_f);e instanceof jg&&e.focusPrevious()}});di(class extends ar{constructor(){super({id:"selectNextCodeAction",title:{value:p("selectNextCodeAction.title","Select next action"),original:"Select next action"},precondition:$g.Visible,keybinding:{weight:PC,primary:18,secondary:[2066],mac:{primary:18,secondary:[2066,300]}}})}run(s){const e=s.get(_f);e instanceof jg&&e.focusNext()}});di(class extends ar{constructor(){super({id:X$,title:{value:p("acceptSelected.title","Accept selected action"),original:"Accept selected action"},precondition:$g.Visible,keybinding:{weight:PC,primary:3,secondary:[2137]}})}run(s){const e=s.get(_f);e instanceof jg&&e.acceptSelected()}});di(class extends ar{constructor(){super({id:Q$,title:{value:p("previewSelected.title","Preview selected action"),original:"Preview selected action"},precondition:$g.Visible,keybinding:{weight:PC,primary:2051}})}run(s){const e=s.get(_f);e instanceof jg&&e.acceptSelected(!0)}});const ej=new me("supportedCodeAction","");class oCe extends j{constructor(e,t,i,n=250){super(),this._editor=e,this._markerService=t,this._signalChange=i,this._delay=n,this._autoTriggerTimer=this._register(new ea),this._register(this._markerService.onMarkerChanged(o=>this._onMarkerChanges(o))),this._register(this._editor.onDidChangeCursorPosition(()=>this._tryAutoTrigger()))}trigger(e){const t=this._getRangeOfSelectionUnlessWhitespaceEnclosed(e);this._signalChange(t?{trigger:e,selection:t}:void 0)}_onMarkerChanges(e){const t=this._editor.getModel();t&&e.some(i=>PP(i,t.uri))&&this._tryAutoTrigger()}_tryAutoTrigger(){this._autoTriggerTimer.cancelAndSet(()=>{this.trigger({type:2,triggerAction:xo.Default})},this._delay)}_getRangeOfSelectionUnlessWhitespaceEnclosed(e){var t;if(!this._editor.hasModel())return;const i=this._editor.getModel(),n=this._editor.getSelection();if(n.isEmpty()&&e.type===2){const{lineNumber:o,column:r}=n.getPosition(),a=i.getLineContent(o);if(a.length===0){if(!(((t=this._editor.getOption(64).experimental)===null||t===void 0?void 0:t.showAiIcon)===ho.On))return}else if(r===1){if(/\s/.test(a[0]))return}else if(r===i.getLineMaxColumn(o)){if(/\s/.test(a[a.length-1]))return}else if(/\s/.test(a[r-2])&&/\s/.test(a[r-1]))return}return n}}var Zh;(function(s){s.Empty={type:0};class e{constructor(i,n,o){this.trigger=i,this.position=n,this._cancellablePromise=o,this.type=1,this.actions=o.catch(r=>{if(Ka(r))return tj;throw r})}cancel(){this._cancellablePromise.cancel()}}s.Triggered=e})(Zh||(Zh={}));const tj=Object.freeze({allActions:[],validActions:[],dispose:()=>{},documentation:[],hasAutoFix:!1,hasAIFix:!1,allAIFixes:!1});class rCe extends j{constructor(e,t,i,n,o,r){super(),this._editor=e,this._registry=t,this._markerService=i,this._progressService=o,this._configurationService=r,this._codeActionOracle=this._register(new En),this._state=Zh.Empty,this._onDidChangeState=this._register(new W),this.onDidChangeState=this._onDidChangeState.event,this._disposed=!1,this._supportedCodeActions=ej.bindTo(n),this._register(this._editor.onDidChangeModel(()=>this._update())),this._register(this._editor.onDidChangeModelLanguage(()=>this._update())),this._register(this._registry.onDidChange(()=>this._update())),this._update()}dispose(){this._disposed||(this._disposed=!0,super.dispose(),this.setState(Zh.Empty,!0))}_settingEnabledNearbyQuickfixes(){var e;const t=(e=this._editor)===null||e===void 0?void 0:e.getModel();return this._configurationService?this._configurationService.getValue("editor.codeActionWidget.includeNearbyQuickFixes",{resource:t==null?void 0:t.uri}):!1}_update(){if(this._disposed)return;this._codeActionOracle.value=void 0,this.setState(Zh.Empty);const e=this._editor.getModel();if(e&&this._registry.has(e)&&!this._editor.getOption(90)){const t=this._registry.all(e).flatMap(i=>{var n;return(n=i.providedCodeActionKinds)!==null&&n!==void 0?n:[]});this._supportedCodeActions.set(t.join(" ")),this._codeActionOracle.value=new oCe(this._editor,this._markerService,i=>{var n;if(!i){this.setState(Zh.Empty);return}const o=i.selection.getStartPosition(),r=gn(async a=>{var l,d,c,u,h,g;if(this._settingEnabledNearbyQuickfixes()&&i.trigger.type===1&&(i.trigger.triggerAction===xo.QuickFix||!((d=(l=i.trigger.filter)===null||l===void 0?void 0:l.include)===null||d===void 0)&&d.contains($e.QuickFix))){const f=await t0(this._registry,e,i.selection,i.trigger,Gd.None,a),m=[...f.allActions];if(a.isCancellationRequested)return tj;if(!((c=f.validActions)===null||c===void 0?void 0:c.some(v=>v.action.kind?$e.QuickFix.contains(new $e(v.action.kind)):!1))){const v=this._markerService.read({resource:e.uri});if(v.length>0){const b=i.selection.getPosition();let C=b,w=Number.MAX_VALUE;const S=[...f.validActions];for(const L of v){const k=L.endColumn,I=L.endLineNumber,P=L.startLineNumber;if(I===b.lineNumber||P===b.lineNumber){C=new H(I,k);const $={type:i.trigger.type,triggerAction:i.trigger.triggerAction,filter:{include:!((u=i.trigger.filter)===null||u===void 0)&&u.include?(h=i.trigger.filter)===null||h===void 0?void 0:h.include:$e.QuickFix},autoApply:i.trigger.autoApply,context:{notAvailableMessage:((g=i.trigger.context)===null||g===void 0?void 0:g.notAvailableMessage)||"",position:C}},A=new De(C.lineNumber,C.column,C.lineNumber,C.column),z=await t0(this._registry,e,A,$,Gd.None,a);if(z.validActions.length!==0){for(const K of z.validActions)K.highlightRange=K.action.isPreferred;f.allActions.length===0&&m.push(...z.allActions),Math.abs(b.column-k)<w?S.unshift(...z.validActions):S.push(...z.validActions)}w=Math.abs(b.column-k)}}const x=S.filter((L,k,I)=>I.findIndex(P=>P.action.title===L.action.title)===k);return x.sort((L,k)=>L.action.isPreferred&&!k.action.isPreferred?-1:!L.action.isPreferred&&k.action.isPreferred||L.action.isAI&&!k.action.isAI?1:!L.action.isAI&&k.action.isAI?-1:0),{validActions:x,allActions:m,documentation:f.documentation,hasAutoFix:f.hasAutoFix,hasAIFix:f.hasAIFix,allAIFixes:f.allAIFixes,dispose:()=>{f.dispose()}}}}}return t0(this._registry,e,i.selection,i.trigger,Gd.None,a)});i.trigger.type===1&&((n=this._progressService)===null||n===void 0||n.showWhile(r,250)),this.setState(new Zh.Triggered(i.trigger,o,r))},void 0),this._codeActionOracle.value.trigger({type:2,triggerAction:xo.Default})}else this._supportedCodeActions.reset()}trigger(e){var t;(t=this._codeActionOracle.value)===null||t===void 0||t.trigger(e)}setState(e,t){e!==this._state&&(this._state.type===1&&this._state.cancel(),this._state=e,!t&&!this._disposed&&this._onDidChangeState.fire(e))}}var aCe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},fd=function(s,e){return function(t,i){e(t,i,s)}},tS;const lCe="quickfix-edit-highlight";let zu=tS=class extends j{static get(e){return e.getContribution(tS.ID)}constructor(e,t,i,n,o,r,a,l,d,c){super(),this._commandService=a,this._configurationService=l,this._actionWidgetService=d,this._instantiationService=c,this._activeCodeActions=this._register(new En),this._showDisabled=!1,this._disposed=!1,this._editor=e,this._model=this._register(new rCe(this._editor,o.codeActionProvider,t,i,r,l)),this._register(this._model.onDidChangeState(u=>this.update(u))),this._lightBulbWidget=new ih(()=>{const u=this._editor.getContribution(Ug.ID);return u&&this._register(u.onClick(h=>this.showCodeActionList(h.actions,h,{includeDisabledActions:!1,fromLightbulb:!0}))),u}),this._resolver=n.createInstance(iL),this._register(this._editor.onDidLayoutChange(()=>this._actionWidgetService.hide()))}dispose(){this._disposed=!0,super.dispose()}showCodeActions(e,t,i){return this.showCodeActionList(t,i,{includeDisabledActions:!1,fromLightbulb:!1})}manualTriggerAtCurrentPosition(e,t,i,n){var o;if(!this._editor.hasModel())return;(o=Co.get(this._editor))===null||o===void 0||o.closeMessage();const r=this._editor.getPosition();this._trigger({type:1,triggerAction:t,filter:i,autoApply:n,context:{notAvailableMessage:e,position:r}})}_trigger(e){return this._model.trigger(e)}async _applyCodeAction(e,t,i){try{await this._instantiationService.invokeFunction($be,e,tL.FromCodeActions,{preview:i,editor:this._editor})}finally{t&&this._trigger({type:2,triggerAction:xo.QuickFix,filter:{}})}}async update(e){var t,i,n,o,r,a,l;if(e.type!==1){(t=this._lightBulbWidget.rawValue)===null||t===void 0||t.hide();return}let d;try{d=await e.actions}catch(c){et(c);return}if(!this._disposed)if((i=this._lightBulbWidget.value)===null||i===void 0||i.update(d,e.trigger,e.position),e.trigger.type===1){if(!((n=e.trigger.filter)===null||n===void 0)&&n.include){const u=this.tryGetValidActionToApply(e.trigger,d);if(u){try{(o=this._lightBulbWidget.value)===null||o===void 0||o.hide(),await this._applyCodeAction(u,!1,!1)}finally{d.dispose()}return}if(e.trigger.context){const h=this.getInvalidActionThatWouldHaveBeenApplied(e.trigger,d);if(h&&h.action.disabled){(r=Co.get(this._editor))===null||r===void 0||r.showMessage(h.action.disabled,e.trigger.context.position),d.dispose();return}}}const c=!!(!((a=e.trigger.filter)===null||a===void 0)&&a.include);if(e.trigger.context&&(!d.allActions.length||!c&&!d.validActions.length)){(l=Co.get(this._editor))===null||l===void 0||l.showMessage(e.trigger.context.notAvailableMessage,e.trigger.context.position),this._activeCodeActions.value=d,d.dispose();return}this._activeCodeActions.value=d,this.showCodeActionList(d,this.toCoords(e.position),{includeDisabledActions:c,fromLightbulb:!1})}else this._actionWidgetService.isVisible?d.dispose():this._activeCodeActions.value=d}getInvalidActionThatWouldHaveBeenApplied(e,t){if(t.allActions.length&&(e.autoApply==="first"&&t.validActions.length===0||e.autoApply==="ifSingle"&&t.allActions.length===1))return t.allActions.find(({action:i})=>i.disabled)}tryGetValidActionToApply(e,t){if(t.validActions.length&&(e.autoApply==="first"&&t.validActions.length>0||e.autoApply==="ifSingle"&&t.validActions.length===1))return t.validActions[0]}async showCodeActionList(e,t,i){const n=this._editor.createDecorationsCollection(),o=this._editor.getDomNode();if(!o)return;const r=i.includeDisabledActions&&(this._showDisabled||e.validActions.length===0)?e.allActions:e.validActions;if(!r.length)return;const a=H.isIPosition(t)?this.toCoords(t):t,l={onSelect:async(d,c)=>{this._applyCodeAction(d,!0,!!c),this._actionWidgetService.hide(),n.clear()},onHide:()=>{var d;(d=this._editor)===null||d===void 0||d.focus(),n.clear()},onHover:async(d,c)=>{var u;if(await d.resolve(c),!c.isCancellationRequested)return{canPreview:!!(!((u=d.action.edit)===null||u===void 0)&&u.edits.length)}},onFocus:d=>{var c,u;if(d&&d.highlightRange&&d.action.diagnostics){const h=[{range:d.action.diagnostics[0],options:tS.DECORATION}];n.set(h);const g=d.action.diagnostics[0],f=(u=(c=this._editor.getModel())===null||c===void 0?void 0:c.getWordAtPosition({lineNumber:g.startLineNumber,column:g.startColumn}))===null||u===void 0?void 0:u.word;Au(p("editingNewSelection","Context: {0} at line {1} and column {2}.",f,g.startLineNumber,g.startColumn))}else n.clear()}};this._actionWidgetService.show("codeActionWidget",!0,Zbe(r,this._shouldShowHeaders(),this._resolver.getResolver()),l,a,o,this._getActionBarActions(e,t,i))}toCoords(e){if(!this._editor.hasModel())return{x:0,y:0};this._editor.revealPosition(e,1),this._editor.render();const t=this._editor.getScrolledVisiblePosition(e),i=ln(this._editor.getDomNode()),n=i.left+t.left,o=i.top+t.top+t.height;return{x:n,y:o}}_shouldShowHeaders(){var e;const t=(e=this._editor)===null||e===void 0?void 0:e.getModel();return this._configurationService.getValue("editor.codeActionWidget.showHeaders",{resource:t==null?void 0:t.uri})}_getActionBarActions(e,t,i){if(i.fromLightbulb)return[];const n=e.documentation.map(o=>{var r;return{id:o.id,label:o.title,tooltip:(r=o.tooltip)!==null&&r!==void 0?r:"",class:void 0,enabled:!0,run:()=>{var a;return this._commandService.executeCommand(o.id,...(a=o.arguments)!==null&&a!==void 0?a:[])}}});return i.includeDisabledActions&&e.validActions.length>0&&e.allActions.length!==e.validActions.length&&n.push(this._showDisabled?{id:"hideMoreActions",label:p("hideMoreActions","Hide Disabled"),enabled:!0,tooltip:"",class:void 0,run:()=>(this._showDisabled=!1,this.showCodeActionList(e,t,i))}:{id:"showMoreActions",label:p("showMoreActions","Show Disabled"),enabled:!0,tooltip:"",class:void 0,run:()=>(this._showDisabled=!0,this.showCodeActionList(e,t,i))}),n}};zu.ID="editor.contrib.codeActionController";zu.DECORATION=tt.register({description:"quickfix-highlight",className:lCe});zu=tS=aCe([fd(1,ld),fd(2,je),fd(3,We),fd(4,xe),fd(5,rh),fd(6,Ei),fd(7,mt),fd(8,_f),fd(9,We)],zu);ia((s,e)=>{((n,o)=>{o&&e.addRule(`.monaco-editor ${n} { background-color: ${o}; }`)})(".quickfix-edit-highlight",s.getColor(Rl));const i=s.getColor($c);i&&e.addRule(`.monaco-editor .quickfix-edit-highlight { border: 1px ${Oa(s.type)?"dotted":"solid"} ${i}; box-sizing: border-box; }`)});function OC(s){return ee.regex(ej.keys()[0],new RegExp("(\\s|^)"+ir(s.value)+"\\b"))}const s4={type:"object",defaultSnippets:[{body:{kind:""}}],properties:{kind:{type:"string",description:p("args.schema.kind","Kind of the code action to run.")},apply:{type:"string",description:p("args.schema.apply","Controls when the returned actions are applied."),default:"ifSingle",enum:["first","ifSingle","never"],enumDescriptions:[p("args.schema.apply.first","Always apply the first returned code action."),p("args.schema.apply.ifSingle","Apply the first returned code action if it is the only one."),p("args.schema.apply.never","Do not apply the returned code actions.")]},preferred:{type:"boolean",default:!1,description:p("args.schema.preferred","Controls if only preferred code actions should be returned.")}}};function vf(s,e,t,i,n=xo.Default){if(s.hasModel()){const o=zu.get(s);o==null||o.manualTriggerAtCurrentPosition(e,n,t,i)}}class dCe extends we{constructor(){super({id:t4,label:p("quickfix.trigger.label","Quick Fix..."),alias:"Quick Fix...",precondition:ee.and(T.writable,T.hasCodeActionsProvider),kbOpts:{kbExpr:T.textInputFocus,primary:2137,weight:100}})}run(e,t){return vf(t,p("editor.action.quickFix.noneMessage","No code actions available"),void 0,void 0,xo.QuickFix)}}class cCe extends Nn{constructor(){super({id:$$,precondition:ee.and(T.writable,T.hasCodeActionsProvider),metadata:{description:"Trigger a code action",args:[{name:"args",schema:s4}]}})}runEditorCommand(e,t,i){const n=xl.fromUser(i,{kind:$e.Empty,apply:"ifSingle"});return vf(t,typeof(i==null?void 0:i.kind)=="string"?n.preferred?p("editor.action.codeAction.noneMessage.preferred.kind","No preferred code actions for '{0}' available",i.kind):p("editor.action.codeAction.noneMessage.kind","No code actions for '{0}' available",i.kind):n.preferred?p("editor.action.codeAction.noneMessage.preferred","No preferred code actions available"):p("editor.action.codeAction.noneMessage","No code actions available"),{include:n.kind,includeSourceActions:!0,onlyIncludePreferredActions:n.preferred},n.apply)}}class uCe extends we{constructor(){super({id:K$,label:p("refactor.label","Refactor..."),alias:"Refactor...",precondition:ee.and(T.writable,T.hasCodeActionsProvider),kbOpts:{kbExpr:T.textInputFocus,primary:3120,mac:{primary:1328},weight:100},contextMenuOpts:{group:"1_modification",order:2,when:ee.and(T.writable,OC($e.Refactor))},metadata:{description:"Refactor...",args:[{name:"args",schema:s4}]}})}run(e,t,i){const n=xl.fromUser(i,{kind:$e.Refactor,apply:"never"});return vf(t,typeof(i==null?void 0:i.kind)=="string"?n.preferred?p("editor.action.refactor.noneMessage.preferred.kind","No preferred refactorings for '{0}' available",i.kind):p("editor.action.refactor.noneMessage.kind","No refactorings for '{0}' available",i.kind):n.preferred?p("editor.action.refactor.noneMessage.preferred","No preferred refactorings available"):p("editor.action.refactor.noneMessage","No refactorings available"),{include:$e.Refactor.contains(n.kind)?n.kind:$e.None,onlyIncludePreferredActions:n.preferred},n.apply,xo.Refactor)}}class hCe extends we{constructor(){super({id:q$,label:p("source.label","Source Action..."),alias:"Source Action...",precondition:ee.and(T.writable,T.hasCodeActionsProvider),contextMenuOpts:{group:"1_modification",order:2.1,when:ee.and(T.writable,OC($e.Source))},metadata:{description:"Source Action...",args:[{name:"args",schema:s4}]}})}run(e,t,i){const n=xl.fromUser(i,{kind:$e.Source,apply:"never"});return vf(t,typeof(i==null?void 0:i.kind)=="string"?n.preferred?p("editor.action.source.noneMessage.preferred.kind","No preferred source actions for '{0}' available",i.kind):p("editor.action.source.noneMessage.kind","No source actions for '{0}' available",i.kind):n.preferred?p("editor.action.source.noneMessage.preferred","No preferred source actions available"):p("editor.action.source.noneMessage","No source actions available"),{include:$e.Source.contains(n.kind)?n.kind:$e.None,includeSourceActions:!0,onlyIncludePreferredActions:n.preferred},n.apply,xo.SourceAction)}}class gCe extends we{constructor(){super({id:i4,label:p("organizeImports.label","Organize Imports"),alias:"Organize Imports",precondition:ee.and(T.writable,OC($e.SourceOrganizeImports)),kbOpts:{kbExpr:T.textInputFocus,primary:1581,weight:100}})}run(e,t){return vf(t,p("editor.action.organize.noneMessage","No organize imports action available"),{include:$e.SourceOrganizeImports,includeSourceActions:!0},"ifSingle",xo.OrganizeImports)}}class fCe extends we{constructor(){super({id:n4,label:p("fixAll.label","Fix All"),alias:"Fix All",precondition:ee.and(T.writable,OC($e.SourceFixAll))})}run(e,t){return vf(t,p("fixAll.noneMessage","No fix all action available"),{include:$e.SourceFixAll,includeSourceActions:!0},"ifSingle",xo.FixAll)}}class pCe extends we{constructor(){super({id:j$,label:p("autoFix.label","Auto Fix..."),alias:"Auto Fix...",precondition:ee.and(T.writable,OC($e.QuickFix)),kbOpts:{kbExpr:T.textInputFocus,primary:1625,mac:{primary:2649},weight:100}})}run(e,t){return vf(t,p("editor.action.autoFix.noneMessage","No auto fixes available"),{include:$e.QuickFix,onlyIncludePreferredActions:!0},"ifSingle",xo.AutoFix)}}Lt(zu.ID,zu,3);Lt(Ug.ID,Ug,4);re(dCe);re(uCe);re(hCe);re(gCe);re(pCe);re(fCe);ue(new cCe);Si.as(Za.Configuration).registerConfiguration({...Px,properties:{"editor.codeActionWidget.showHeaders":{type:"boolean",scope:5,description:p("showCodeActionHeaders","Enable/disable showing group headers in the Code Action menu."),default:!0}}});Si.as(Za.Configuration).registerConfiguration({...Px,properties:{"editor.codeActionWidget.includeNearbyQuickFixes":{type:"boolean",scope:5,description:p("includeNearbyQuickFixes","Enable/disable showing nearest Quick Fix within a line when not currently on a diagnostic."),default:!0}}});class SM{constructor(){this.lenses=[],this._disposables=new ie}dispose(){this._disposables.dispose()}get isDisposed(){return this._disposables.isDisposed}add(e,t){this._disposables.add(e);for(const i of e.lenses)this.lenses.push({symbol:i,provider:t})}}async function ij(s,e,t){const i=s.ordered(e),n=new Map,o=new SM,r=i.map(async(a,l)=>{n.set(a,l);try{const d=await Promise.resolve(a.provideCodeLenses(e,t));d&&o.add(d,a)}catch(d){Zi(d)}});return await Promise.all(r),o.lenses=o.lenses.sort((a,l)=>a.symbol.range.startLineNumber<l.symbol.range.startLineNumber?-1:a.symbol.range.startLineNumber>l.symbol.range.startLineNumber?1:n.get(a.provider)<n.get(l.provider)?-1:n.get(a.provider)>n.get(l.provider)?1:a.symbol.range.startColumn<l.symbol.range.startColumn?-1:a.symbol.range.startColumn>l.symbol.range.startColumn?1:0),o}Ct.registerCommand("_executeCodeLensProvider",function(s,...e){let[t,i]=e;zt(Pe.isUri(t)),zt(typeof i=="number"||!i);const{codeLensProvider:n}=s.get(xe),o=s.get(vi).getModel(t);if(!o)throw Cr();const r=[],a=new ie;return ij(n,o,ct.None).then(l=>{a.add(l);const d=[];for(const c of l.lenses)i==null||c.symbol.command?r.push(c.symbol):i-- >0&&c.provider.resolveCodeLens&&d.push(Promise.resolve(c.provider.resolveCodeLens(o,c.symbol,ct.None)).then(u=>r.push(u||c.symbol)));return Promise.all(d)}).then(()=>r).finally(()=>{setTimeout(()=>a.dispose(),100)})});var mCe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},_Ce=function(s,e){return function(t,i){e(t,i,s)}};const nj=ut("ICodeLensCache");class M8{constructor(e,t){this.lineCount=e,this.data=t}}let yM=class{constructor(e){this._fakeProvider=new class{provideCodeLenses(){throw new Error("not supported")}},this._cache=new nh(20,.75);const t="codelens/cache";ov(Ci,()=>e.remove(t,1));const i="codelens/cache2",n=e.get(i,1,"{}");this._deserialize(n),ge.once(e.onWillSaveState)(o=>{o.reason===db.SHUTDOWN&&e.store(i,this._serialize(),1,1)})}put(e,t){const i=t.lenses.map(r=>{var a;return{range:r.symbol.range,command:r.symbol.command&&{id:"",title:(a=r.symbol.command)===null||a===void 0?void 0:a.title}}}),n=new SM;n.add({lenses:i,dispose:()=>{}},this._fakeProvider);const o=new M8(e.getLineCount(),n);this._cache.set(e.uri.toString(),o)}get(e){const t=this._cache.get(e.uri.toString());return t&&t.lineCount===e.getLineCount()?t.data:void 0}delete(e){this._cache.delete(e.uri.toString())}_serialize(){const e=Object.create(null);for(const[t,i]of this._cache){const n=new Set;for(const o of i.data.lenses)n.add(o.symbol.range.startLineNumber);e[t]={lineCount:i.lineCount,lines:[...n.values()]}}return JSON.stringify(e)}_deserialize(e){try{const t=JSON.parse(e);for(const i in t){const n=t[i],o=[];for(const a of n.lines)o.push({range:new D(a,1,a,11)});const r=new SM;r.add({lenses:o,dispose(){}},this._fakeProvider),this._cache.set(i,new M8(n.lineCount,r))}}catch{}}};yM=mCe([_Ce(0,sa)],yM);_t(nj,yM,1);class vCe{constructor(e,t,i){this.afterColumn=1073741824,this.afterLineNumber=e,this.heightInPx=t,this._onHeight=i,this.suppressMouseDown=!0,this.domNode=document.createElement("div")}onComputedHeight(e){this._lastHeight===void 0?this._lastHeight=e:this._lastHeight!==e&&(this._lastHeight=e,this._onHeight())}isVisible(){return this._lastHeight!==0&&this.domNode.hasAttribute("monaco-visible-view-zone")}}class pD{constructor(e,t){this.allowEditorOverflow=!1,this.suppressMouseDown=!0,this._commands=new Map,this._isEmpty=!0,this._editor=e,this._id=`codelens.widget-${pD._idPool++}`,this.updatePosition(t),this._domNode=document.createElement("span"),this._domNode.className="codelens-decoration"}withCommands(e,t){this._commands.clear();const i=[];let n=!1;for(let o=0;o<e.length;o++){const r=e[o];if(r&&(n=!0,r.command)){const a=hu(r.command.title.trim());r.command.id?(i.push(se("a",{id:String(o),title:r.command.tooltip,role:"button"},...a)),this._commands.set(String(o),r.command)):i.push(se("span",{title:r.command.tooltip},...a)),o+1<e.length&&i.push(se("span",void 0," | "))}}n?(Qn(this._domNode,...i),this._isEmpty&&t&&this._domNode.classList.add("fadein"),this._isEmpty=!1):Qn(this._domNode,se("span",void 0,"no commands"))}getCommand(e){return e.parentElement===this._domNode?this._commands.get(e.id):void 0}getId(){return this._id}getDomNode(){return this._domNode}updatePosition(e){const t=this._editor.getModel().getLineFirstNonWhitespaceColumn(e);this._widgetPosition={position:{lineNumber:e,column:t},preference:[1]}}getPosition(){return this._widgetPosition||null}}pD._idPool=0;class iE{constructor(){this._removeDecorations=[],this._addDecorations=[],this._addDecorationsCallbacks=[]}addDecoration(e,t){this._addDecorations.push(e),this._addDecorationsCallbacks.push(t)}removeDecoration(e){this._removeDecorations.push(e)}commit(e){const t=e.deltaDecorations(this._removeDecorations,this._addDecorations);for(let i=0,n=t.length;i<n;i++)this._addDecorationsCallbacks[i](t[i])}}const R8=tt.register({collapseOnReplaceEdit:!0,description:"codelens"});class A8{constructor(e,t,i,n,o,r){this._isDisposed=!1,this._editor=t,this._data=e,this._decorationIds=[];let a;const l=[];this._data.forEach((d,c)=>{d.symbol.command&&l.push(d.symbol),i.addDecoration({range:d.symbol.range,options:R8},u=>this._decorationIds[c]=u),a?a=D.plusRange(a,d.symbol.range):a=D.lift(d.symbol.range)}),this._viewZone=new vCe(a.startLineNumber-1,o,r),this._viewZoneId=n.addZone(this._viewZone),l.length>0&&(this._createContentWidgetIfNecessary(),this._contentWidget.withCommands(l,!1))}_createContentWidgetIfNecessary(){this._contentWidget?this._editor.layoutContentWidget(this._contentWidget):(this._contentWidget=new pD(this._editor,this._viewZone.afterLineNumber+1),this._editor.addContentWidget(this._contentWidget))}dispose(e,t){this._decorationIds.forEach(e.removeDecoration,e),this._decorationIds=[],t==null||t.removeZone(this._viewZoneId),this._contentWidget&&(this._editor.removeContentWidget(this._contentWidget),this._contentWidget=void 0),this._isDisposed=!0}isDisposed(){return this._isDisposed}isValid(){return this._decorationIds.some((e,t)=>{const i=this._editor.getModel().getDecorationRange(e),n=this._data[t].symbol;return!!(i&&D.isEmpty(n.range)===i.isEmpty())})}updateCodeLensSymbols(e,t){this._decorationIds.forEach(t.removeDecoration,t),this._decorationIds=[],this._data=e,this._data.forEach((i,n)=>{t.addDecoration({range:i.symbol.range,options:R8},o=>this._decorationIds[n]=o)})}updateHeight(e,t){this._viewZone.heightInPx=e,t.layoutZone(this._viewZoneId),this._contentWidget&&this._editor.layoutContentWidget(this._contentWidget)}computeIfNecessary(e){if(!this._viewZone.isVisible())return null;for(let t=0;t<this._decorationIds.length;t++){const i=e.getDecorationRange(this._decorationIds[t]);i&&(this._data[t].symbol.range=i)}return this._data}updateCommands(e){this._createContentWidgetIfNecessary(),this._contentWidget.withCommands(e,!0);for(let t=0;t<this._data.length;t++){const i=e[t];if(i){const{symbol:n}=this._data[t];n.command=i.command||n.command}}}getCommand(e){var t;return(t=this._contentWidget)===null||t===void 0?void 0:t.getCommand(e)}getLineNumber(){const e=this._editor.getModel().getDecorationRange(this._decorationIds[0]);return e?e.startLineNumber:-1}update(e){if(this.isValid()){const t=this._editor.getModel().getDecorationRange(this._decorationIds[0]);t&&(this._viewZone.afterLineNumber=t.startLineNumber-1,e.layoutZone(this._viewZoneId),this._contentWidget&&(this._contentWidget.updatePosition(t.startLineNumber),this._editor.layoutContentWidget(this._contentWidget)))}}}var bCe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},K_=function(s,e){return function(t,i){e(t,i,s)}};let Fm=class{constructor(e,t,i,n,o,r){this._editor=e,this._languageFeaturesService=t,this._commandService=n,this._notificationService=o,this._codeLensCache=r,this._disposables=new ie,this._localToDispose=new ie,this._lenses=[],this._oldCodeLensModels=new ie,this._provideCodeLensDebounce=i.for(t.codeLensProvider,"CodeLensProvide",{min:250}),this._resolveCodeLensesDebounce=i.for(t.codeLensProvider,"CodeLensResolve",{min:250,salt:"resolve"}),this._resolveCodeLensesScheduler=new jt(()=>this._resolveCodeLensesInViewport(),this._resolveCodeLensesDebounce.default()),this._disposables.add(this._editor.onDidChangeModel(()=>this._onModelChange())),this._disposables.add(this._editor.onDidChangeModelLanguage(()=>this._onModelChange())),this._disposables.add(this._editor.onDidChangeConfiguration(a=>{(a.hasChanged(50)||a.hasChanged(19)||a.hasChanged(18))&&this._updateLensStyle(),a.hasChanged(17)&&this._onModelChange()})),this._disposables.add(t.codeLensProvider.onDidChange(this._onModelChange,this)),this._onModelChange(),this._updateLensStyle()}dispose(){var e;this._localDispose(),this._disposables.dispose(),this._oldCodeLensModels.dispose(),(e=this._currentCodeLensModel)===null||e===void 0||e.dispose()}_getLayoutInfo(){const e=Math.max(1.3,this._editor.getOption(66)/this._editor.getOption(52));let t=this._editor.getOption(19);return(!t||t<5)&&(t=this._editor.getOption(52)*.9|0),{fontSize:t,codeLensHeight:t*e|0}}_updateLensStyle(){const{codeLensHeight:e,fontSize:t}=this._getLayoutInfo(),i=this._editor.getOption(18),n=this._editor.getOption(50),{style:o}=this._editor.getContainerDomNode();o.setProperty("--vscode-editorCodeLens-lineHeight",`${e}px`),o.setProperty("--vscode-editorCodeLens-fontSize",`${t}px`),o.setProperty("--vscode-editorCodeLens-fontFeatureSettings",n.fontFeatureSettings),i&&(o.setProperty("--vscode-editorCodeLens-fontFamily",i),o.setProperty("--vscode-editorCodeLens-fontFamilyDefault",vo.fontFamily)),this._editor.changeViewZones(r=>{for(const a of this._lenses)a.updateHeight(e,r)})}_localDispose(){var e,t,i;(e=this._getCodeLensModelPromise)===null||e===void 0||e.cancel(),this._getCodeLensModelPromise=void 0,(t=this._resolveCodeLensesPromise)===null||t===void 0||t.cancel(),this._resolveCodeLensesPromise=void 0,this._localToDispose.clear(),this._oldCodeLensModels.clear(),(i=this._currentCodeLensModel)===null||i===void 0||i.dispose()}_onModelChange(){this._localDispose();const e=this._editor.getModel();if(!e||!this._editor.getOption(17)||e.isTooLargeForTokenization())return;const t=this._codeLensCache.get(e);if(t&&this._renderCodeLensSymbols(t),!this._languageFeaturesService.codeLensProvider.has(e)){t&&Eu(()=>{const n=this._codeLensCache.get(e);t===n&&(this._codeLensCache.delete(e),this._onModelChange())},30*1e3,this._localToDispose);return}for(const n of this._languageFeaturesService.codeLensProvider.all(e))if(typeof n.onDidChange=="function"){const o=n.onDidChange(()=>i.schedule());this._localToDispose.add(o)}const i=new jt(()=>{var n;const o=Date.now();(n=this._getCodeLensModelPromise)===null||n===void 0||n.cancel(),this._getCodeLensModelPromise=gn(r=>ij(this._languageFeaturesService.codeLensProvider,e,r)),this._getCodeLensModelPromise.then(r=>{this._currentCodeLensModel&&this._oldCodeLensModels.add(this._currentCodeLensModel),this._currentCodeLensModel=r,this._codeLensCache.put(e,r);const a=this._provideCodeLensDebounce.update(e,Date.now()-o);i.delay=a,this._renderCodeLensSymbols(r),this._resolveCodeLensesInViewportSoon()},et)},this._provideCodeLensDebounce.get(e));this._localToDispose.add(i),this._localToDispose.add(Fe(()=>this._resolveCodeLensesScheduler.cancel())),this._localToDispose.add(this._editor.onDidChangeModelContent(()=>{var n;this._editor.changeDecorations(o=>{this._editor.changeViewZones(r=>{const a=[];let l=-1;this._lenses.forEach(c=>{!c.isValid()||l===c.getLineNumber()?a.push(c):(c.update(r),l=c.getLineNumber())});const d=new iE;a.forEach(c=>{c.dispose(d,r),this._lenses.splice(this._lenses.indexOf(c),1)}),d.commit(o)})}),i.schedule(),this._resolveCodeLensesScheduler.cancel(),(n=this._resolveCodeLensesPromise)===null||n===void 0||n.cancel(),this._resolveCodeLensesPromise=void 0})),this._localToDispose.add(this._editor.onDidFocusEditorWidget(()=>{i.schedule()})),this._localToDispose.add(this._editor.onDidBlurEditorText(()=>{i.cancel()})),this._localToDispose.add(this._editor.onDidScrollChange(n=>{n.scrollTopChanged&&this._lenses.length>0&&this._resolveCodeLensesInViewportSoon()})),this._localToDispose.add(this._editor.onDidLayoutChange(()=>{this._resolveCodeLensesInViewportSoon()})),this._localToDispose.add(Fe(()=>{if(this._editor.getModel()){const n=$a.capture(this._editor);this._editor.changeDecorations(o=>{this._editor.changeViewZones(r=>{this._disposeAllLenses(o,r)})}),n.restore(this._editor)}else this._disposeAllLenses(void 0,void 0)})),this._localToDispose.add(this._editor.onMouseDown(n=>{if(n.target.type!==9)return;let o=n.target.element;if((o==null?void 0:o.tagName)==="SPAN"&&(o=o.parentElement),(o==null?void 0:o.tagName)==="A")for(const r of this._lenses){const a=r.getCommand(o);if(a){this._commandService.executeCommand(a.id,...a.arguments||[]).catch(l=>this._notificationService.error(l));break}}})),i.schedule()}_disposeAllLenses(e,t){const i=new iE;for(const n of this._lenses)n.dispose(i,t);e&&i.commit(e),this._lenses.length=0}_renderCodeLensSymbols(e){if(!this._editor.hasModel())return;const t=this._editor.getModel().getLineCount(),i=[];let n;for(const a of e.lenses){const l=a.symbol.range.startLineNumber;l<1||l>t||(n&&n[n.length-1].symbol.range.startLineNumber===l?n.push(a):(n=[a],i.push(n)))}if(!i.length&&!this._lenses.length)return;const o=$a.capture(this._editor),r=this._getLayoutInfo();this._editor.changeDecorations(a=>{this._editor.changeViewZones(l=>{const d=new iE;let c=0,u=0;for(;u<i.length&&c<this._lenses.length;){const h=i[u][0].symbol.range.startLineNumber,g=this._lenses[c].getLineNumber();g<h?(this._lenses[c].dispose(d,l),this._lenses.splice(c,1)):g===h?(this._lenses[c].updateCodeLensSymbols(i[u],d),u++,c++):(this._lenses.splice(c,0,new A8(i[u],this._editor,d,l,r.codeLensHeight,()=>this._resolveCodeLensesInViewportSoon())),c++,u++)}for(;c<this._lenses.length;)this._lenses[c].dispose(d,l),this._lenses.splice(c,1);for(;u<i.length;)this._lenses.push(new A8(i[u],this._editor,d,l,r.codeLensHeight,()=>this._resolveCodeLensesInViewportSoon())),u++;d.commit(a)})}),o.restore(this._editor)}_resolveCodeLensesInViewportSoon(){this._editor.getModel()&&this._resolveCodeLensesScheduler.schedule()}_resolveCodeLensesInViewport(){var e;(e=this._resolveCodeLensesPromise)===null||e===void 0||e.cancel(),this._resolveCodeLensesPromise=void 0;const t=this._editor.getModel();if(!t)return;const i=[],n=[];if(this._lenses.forEach(a=>{const l=a.computeIfNecessary(t);l&&(i.push(l),n.push(a))}),i.length===0)return;const o=Date.now(),r=gn(a=>{const l=i.map((d,c)=>{const u=new Array(d.length),h=d.map((g,f)=>!g.symbol.command&&typeof g.provider.resolveCodeLens=="function"?Promise.resolve(g.provider.resolveCodeLens(t,g.symbol,a)).then(m=>{u[f]=m},Zi):(u[f]=g.symbol,Promise.resolve(void 0)));return Promise.all(h).then(()=>{!a.isCancellationRequested&&!n[c].isDisposed()&&n[c].updateCommands(u)})});return Promise.all(l)});this._resolveCodeLensesPromise=r,this._resolveCodeLensesPromise.then(()=>{const a=this._resolveCodeLensesDebounce.update(t,Date.now()-o);this._resolveCodeLensesScheduler.delay=a,this._currentCodeLensModel&&this._codeLensCache.put(t,this._currentCodeLensModel),this._oldCodeLensModels.clear(),r===this._resolveCodeLensesPromise&&(this._resolveCodeLensesPromise=void 0)},a=>{et(a),r===this._resolveCodeLensesPromise&&(this._resolveCodeLensesPromise=void 0)})}async getModel(){var e;return await this._getCodeLensModelPromise,await this._resolveCodeLensesPromise,!((e=this._currentCodeLensModel)===null||e===void 0)&&e.isDisposed?void 0:this._currentCodeLensModel}};Fm.ID="css.editor.codeLens";Fm=bCe([K_(1,xe),K_(2,Er),K_(3,Ei),K_(4,Qi),K_(5,nj)],Fm);Lt(Fm.ID,Fm,1);re(class extends we{constructor(){super({id:"codelens.showLensesInCurrentLine",precondition:T.hasCodeLensProvider,label:p("showLensOnLine","Show CodeLens Commands For Current Line"),alias:"Show CodeLens Commands For Current Line"})}async run(e,t){if(!t.hasModel())return;const i=e.get(Ya),n=e.get(Ei),o=e.get(Qi),r=t.getSelection().positionLineNumber,a=t.getContribution(Fm.ID);if(!a)return;const l=await a.getModel();if(!l)return;const d=[];for(const h of l.lenses)h.symbol.command&&h.symbol.range.startLineNumber===r&&d.push({label:h.symbol.command.title,command:h.symbol.command});if(d.length===0)return;const c=await i.pick(d,{canPickMany:!1,placeHolder:p("placeHolder","Select a command")});if(!c)return;let u=c.command;if(l.isDisposed){const h=await a.getModel(),g=h==null?void 0:h.lenses.find(f=>{var m;return f.symbol.range.startLineNumber===r&&((m=f.symbol.command)===null||m===void 0?void 0:m.title)===u.title});if(!g||!g.symbol.command)return;u=g.symbol.command}try{await n.executeCommand(u.id,...u.arguments||[])}catch(h){o.error(h)}}});var CCe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},nE=function(s,e){return function(t,i){e(t,i,s)}};class o4{constructor(e,t){this._editorWorkerClient=new uP(e,!1,"editorWorkerService",t)}async provideDocumentColors(e,t){return this._editorWorkerClient.computeDefaultDocumentColors(e.uri)}provideColorPresentations(e,t,i){const n=t.range,o=t.color,r=o.alpha,a=new G(new vt(Math.round(255*o.red),Math.round(255*o.green),Math.round(255*o.blue),r)),l=r?G.Format.CSS.formatRGB(a):G.Format.CSS.formatRGBA(a),d=r?G.Format.CSS.formatHSL(a):G.Format.CSS.formatHSLA(a),c=r?G.Format.CSS.formatHex(a):G.Format.CSS.formatHexA(a),u=[];return u.push({label:l,textEdit:{range:n,text:l}}),u.push({label:d,textEdit:{range:n,text:d}}),u.push({label:c,textEdit:{range:n,text:c}}),u}}let LM=class extends j{constructor(e,t,i){super(),this._register(i.colorProvider.register("*",new o4(e,t)))}};LM=CCe([nE(0,vi),nE(1,Jt),nE(2,xe)],LM);tD(LM);async function sj(s,e,t,i=!0){return r4(new wCe,s,e,t,i)}function oj(s,e,t,i){return Promise.resolve(t.provideColorPresentations(s,e,i))}class wCe{constructor(){}async compute(e,t,i,n){const o=await e.provideDocumentColors(t,i);if(Array.isArray(o))for(const r of o)n.push({colorInfo:r,provider:e});return Array.isArray(o)}}class SCe{constructor(){}async compute(e,t,i,n){const o=await e.provideDocumentColors(t,i);if(Array.isArray(o))for(const r of o)n.push({range:r.range,color:[r.color.red,r.color.green,r.color.blue,r.color.alpha]});return Array.isArray(o)}}class yCe{constructor(e){this.colorInfo=e}async compute(e,t,i,n){const o=await e.provideColorPresentations(t,this.colorInfo,ct.None);return Array.isArray(o)&&n.push(...o),Array.isArray(o)}}async function r4(s,e,t,i,n){let o=!1,r;const a=[],l=e.ordered(t);for(let d=l.length-1;d>=0;d--){const c=l[d];if(c instanceof o4)r=c;else try{await s.compute(c,t,i,a)&&(o=!0)}catch(u){Zi(u)}}return o?a:r&&n?(await s.compute(r,t,i,a),a):[]}function rj(s,e){const{colorProvider:t}=s.get(xe),i=s.get(vi).getModel(e);if(!i)throw Cr();const n=s.get(mt).getValue("editor.defaultColorDecorators",{resource:e});return{model:i,colorProviderRegistry:t,isDefaultColorDecoratorsEnabled:n}}Ct.registerCommand("_executeDocumentColorProvider",function(s,...e){const[t]=e;if(!(t instanceof Pe))throw Cr();const{model:i,colorProviderRegistry:n,isDefaultColorDecoratorsEnabled:o}=rj(s,t);return r4(new SCe,n,i,ct.None,o)});Ct.registerCommand("_executeColorPresentationProvider",function(s,...e){const[t,i]=e,{uri:n,range:o}=i;if(!(n instanceof Pe)||!Array.isArray(t)||t.length!==4||!D.isIRange(o))throw Cr();const{model:r,colorProviderRegistry:a,isDefaultColorDecoratorsEnabled:l}=rj(s,n),[d,c,u,h]=t;return r4(new yCe({range:o,color:{red:d,green:c,blue:u,alpha:h}}),a,r,ct.None,l)});var LCe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},sE=function(s,e){return function(t,i){e(t,i,s)}},xM;const aj=Object.create({});let Uu=xM=class extends j{constructor(e,t,i,n){super(),this._editor=e,this._configurationService=t,this._languageFeaturesService=i,this._localToDispose=this._register(new ie),this._decorationsIds=[],this._colorDatas=new Map,this._colorDecoratorIds=this._editor.createDecorationsCollection(),this._ruleFactory=new cC(this._editor),this._decoratorLimitReporter=new xCe,this._colorDecorationClassRefs=this._register(new ie),this._debounceInformation=n.for(i.colorProvider,"Document Colors",{min:xM.RECOMPUTE_TIME}),this._register(e.onDidChangeModel(()=>{this._isColorDecoratorsEnabled=this.isEnabled(),this.updateColors()})),this._register(e.onDidChangeModelLanguage(()=>this.updateColors())),this._register(i.colorProvider.onDidChange(()=>this.updateColors())),this._register(e.onDidChangeConfiguration(o=>{const r=this._isColorDecoratorsEnabled;this._isColorDecoratorsEnabled=this.isEnabled(),this._isDefaultColorDecoratorsEnabled=this._editor.getOption(145);const a=r!==this._isColorDecoratorsEnabled||o.hasChanged(21),l=o.hasChanged(145);(a||l)&&(this._isColorDecoratorsEnabled?this.updateColors():this.removeAllDecorations())})),this._timeoutTimer=null,this._computePromise=null,this._isColorDecoratorsEnabled=this.isEnabled(),this._isDefaultColorDecoratorsEnabled=this._editor.getOption(145),this.updateColors()}isEnabled(){const e=this._editor.getModel();if(!e)return!1;const t=e.getLanguageId(),i=this._configurationService.getValue(t);if(i&&typeof i=="object"){const n=i.colorDecorators;if(n&&n.enable!==void 0&&!n.enable)return n.enable}return this._editor.getOption(20)}static get(e){return e.getContribution(this.ID)}dispose(){this.stop(),this.removeAllDecorations(),super.dispose()}updateColors(){if(this.stop(),!this._isColorDecoratorsEnabled)return;const e=this._editor.getModel();!e||!this._languageFeaturesService.colorProvider.has(e)||(this._localToDispose.add(this._editor.onDidChangeModelContent(()=>{this._timeoutTimer||(this._timeoutTimer=new ea,this._timeoutTimer.cancelAndSet(()=>{this._timeoutTimer=null,this.beginCompute()},this._debounceInformation.get(e)))})),this.beginCompute())}async beginCompute(){this._computePromise=gn(async e=>{const t=this._editor.getModel();if(!t)return[];const i=new cs(!1),n=await sj(this._languageFeaturesService.colorProvider,t,e,this._isDefaultColorDecoratorsEnabled);return this._debounceInformation.update(t,i.elapsed()),n});try{const e=await this._computePromise;this.updateDecorations(e),this.updateColorDecorators(e),this._computePromise=null}catch(e){et(e)}}stop(){this._timeoutTimer&&(this._timeoutTimer.cancel(),this._timeoutTimer=null),this._computePromise&&(this._computePromise.cancel(),this._computePromise=null),this._localToDispose.clear()}updateDecorations(e){const t=e.map(i=>({range:{startLineNumber:i.colorInfo.range.startLineNumber,startColumn:i.colorInfo.range.startColumn,endLineNumber:i.colorInfo.range.endLineNumber,endColumn:i.colorInfo.range.endColumn},options:tt.EMPTY}));this._editor.changeDecorations(i=>{this._decorationsIds=i.deltaDecorations(this._decorationsIds,t),this._colorDatas=new Map,this._decorationsIds.forEach((n,o)=>this._colorDatas.set(n,e[o]))})}updateColorDecorators(e){this._colorDecorationClassRefs.clear();const t=[],i=this._editor.getOption(21);for(let o=0;o<e.length&&t.length<i;o++){const{red:r,green:a,blue:l,alpha:d}=e[o].colorInfo.color,c=new vt(Math.round(r*255),Math.round(a*255),Math.round(l*255),d),u=`rgba(${c.r}, ${c.g}, ${c.b}, ${c.a})`,h=this._colorDecorationClassRefs.add(this._ruleFactory.createClassNameRef({backgroundColor:u}));t.push({range:{startLineNumber:e[o].colorInfo.range.startLineNumber,startColumn:e[o].colorInfo.range.startColumn,endLineNumber:e[o].colorInfo.range.endLineNumber,endColumn:e[o].colorInfo.range.endColumn},options:{description:"colorDetector",before:{content:qW,inlineClassName:`${h.className} colorpicker-color-decoration`,inlineClassNameAffectsLetterSpacing:!0,attachedData:aj}}})}const n=i<e.length?i:!1;this._decoratorLimitReporter.update(e.length,n),this._colorDecoratorIds.set(t)}removeAllDecorations(){this._editor.removeDecorations(this._decorationsIds),this._decorationsIds=[],this._colorDecoratorIds.clear(),this._colorDecorationClassRefs.clear()}getColorData(e){const t=this._editor.getModel();if(!t)return null;const i=t.getDecorationsInRange(D.fromPositions(e,e)).filter(n=>this._colorDatas.has(n.id));return i.length===0?null:this._colorDatas.get(i[0].id)}isColorDecoration(e){return this._colorDecoratorIds.has(e)}};Uu.ID="editor.contrib.colorDetector";Uu.RECOMPUTE_TIME=1e3;Uu=xM=LCe([sE(1,mt),sE(2,xe),sE(3,Er)],Uu);class xCe{constructor(){this._onDidChange=new W,this._computed=0,this._limited=!1}update(e,t){(e!==this._computed||t!==this._limited)&&(this._computed=e,this._limited=t,this._onDidChange.fire())}}Lt(Uu.ID,Uu,1);class DCe{get color(){return this._color}set color(e){this._color.equals(e)||(this._color=e,this._onDidChangeColor.fire(e))}get presentation(){return this.colorPresentations[this.presentationIndex]}get colorPresentations(){return this._colorPresentations}set colorPresentations(e){this._colorPresentations=e,this.presentationIndex>e.length-1&&(this.presentationIndex=0),this._onDidChangePresentation.fire(this.presentation)}constructor(e,t,i){this.presentationIndex=i,this._onColorFlushed=new W,this.onColorFlushed=this._onColorFlushed.event,this._onDidChangeColor=new W,this.onDidChangeColor=this._onDidChangeColor.event,this._onDidChangePresentation=new W,this.onDidChangePresentation=this._onDidChangePresentation.event,this.originalColor=e,this._color=e,this._colorPresentations=t}selectNextColorPresentation(){this.presentationIndex=(this.presentationIndex+1)%this.colorPresentations.length,this.flushColor(),this._onDidChangePresentation.fire(this.presentation)}guessColorPresentation(e,t){let i=-1;for(let n=0;n<this.colorPresentations.length;n++)if(t.toLowerCase()===this.colorPresentations[n].label){i=n;break}if(i===-1){const n=t.split("(")[0].toLowerCase();for(let o=0;o<this.colorPresentations.length;o++)if(this.colorPresentations[o].label.toLowerCase().startsWith(n)){i=o;break}}i!==-1&&i!==this.presentationIndex&&(this.presentationIndex=i,this._onDidChangePresentation.fire(this.presentation))}flushColor(){this._onColorFlushed.fire(this._color)}}const qo=se;class kCe extends j{constructor(e,t,i,n=!1){super(),this.model=t,this.showingStandaloneColorPicker=n,this._closeButton=null,this._domNode=qo(".colorpicker-header"),te(e,this._domNode),this._pickedColorNode=te(this._domNode,qo(".picked-color")),te(this._pickedColorNode,qo("span.codicon.codicon-color-mode")),this._pickedColorPresentation=te(this._pickedColorNode,document.createElement("span")),this._pickedColorPresentation.classList.add("picked-color-presentation");const o=p("clickToToggleColorOptions","Click to toggle color options (rgb/hsl/hex)");this._pickedColorNode.setAttribute("title",o),this._originalColorNode=te(this._domNode,qo(".original-color")),this._originalColorNode.style.backgroundColor=G.Format.CSS.format(this.model.originalColor)||"",this.backgroundColor=i.getColorTheme().getColor(ZS)||G.white,this._register(i.onDidColorThemeChange(r=>{this.backgroundColor=r.getColor(ZS)||G.white})),this._register(Y(this._pickedColorNode,he.CLICK,()=>this.model.selectNextColorPresentation())),this._register(Y(this._originalColorNode,he.CLICK,()=>{this.model.color=this.model.originalColor,this.model.flushColor()})),this._register(t.onDidChangeColor(this.onDidChangeColor,this)),this._register(t.onDidChangePresentation(this.onDidChangePresentation,this)),this._pickedColorNode.style.backgroundColor=G.Format.CSS.format(t.color)||"",this._pickedColorNode.classList.toggle("light",t.color.rgba.a<.5?this.backgroundColor.isLighter():t.color.isLighter()),this.onDidChangeColor(this.model.color),this.showingStandaloneColorPicker&&(this._domNode.classList.add("standalone-colorpicker"),this._closeButton=this._register(new ICe(this._domNode)))}get closeButton(){return this._closeButton}get pickedColorNode(){return this._pickedColorNode}get originalColorNode(){return this._originalColorNode}onDidChangeColor(e){this._pickedColorNode.style.backgroundColor=G.Format.CSS.format(e)||"",this._pickedColorNode.classList.toggle("light",e.rgba.a<.5?this.backgroundColor.isLighter():e.isLighter()),this.onDidChangePresentation()}onDidChangePresentation(){this._pickedColorPresentation.textContent=this.model.presentation?this.model.presentation.label:""}}class ICe extends j{constructor(e){super(),this._onClicked=this._register(new W),this.onClicked=this._onClicked.event,this._button=document.createElement("div"),this._button.classList.add("close-button"),te(e,this._button);const t=document.createElement("div");t.classList.add("close-button-inner-div"),te(this._button,t),te(t,qo(".button"+Oe.asCSSSelector(Ui("color-picker-close",le.close,p("closeIcon","Icon to close the color picker"))))).classList.add("close-icon"),this._button.onclick=()=>{this._onClicked.fire()}}}class ECe extends j{constructor(e,t,i,n=!1){super(),this.model=t,this.pixelRatio=i,this._insertButton=null,this._domNode=qo(".colorpicker-body"),te(e,this._domNode),this._saturationBox=new NCe(this._domNode,this.model,this.pixelRatio),this._register(this._saturationBox),this._register(this._saturationBox.onDidChange(this.onDidSaturationValueChange,this)),this._register(this._saturationBox.onColorFlushed(this.flushColor,this)),this._opacityStrip=new TCe(this._domNode,this.model,n),this._register(this._opacityStrip),this._register(this._opacityStrip.onDidChange(this.onDidOpacityChange,this)),this._register(this._opacityStrip.onColorFlushed(this.flushColor,this)),this._hueStrip=new MCe(this._domNode,this.model,n),this._register(this._hueStrip),this._register(this._hueStrip.onDidChange(this.onDidHueChange,this)),this._register(this._hueStrip.onColorFlushed(this.flushColor,this)),n&&(this._insertButton=this._register(new RCe(this._domNode)),this._domNode.classList.add("standalone-colorpicker"))}flushColor(){this.model.flushColor()}onDidSaturationValueChange({s:e,v:t}){const i=this.model.color.hsva;this.model.color=new G(new kl(i.h,e,t,i.a))}onDidOpacityChange(e){const t=this.model.color.hsva;this.model.color=new G(new kl(t.h,t.s,t.v,e))}onDidHueChange(e){const t=this.model.color.hsva,i=(1-e)*360;this.model.color=new G(new kl(i===360?0:i,t.s,t.v,t.a))}get domNode(){return this._domNode}get saturationBox(){return this._saturationBox}get enterButton(){return this._insertButton}layout(){this._saturationBox.layout(),this._opacityStrip.layout(),this._hueStrip.layout()}}class NCe extends j{constructor(e,t,i){super(),this.model=t,this.pixelRatio=i,this._onDidChange=new W,this.onDidChange=this._onDidChange.event,this._onColorFlushed=new W,this.onColorFlushed=this._onColorFlushed.event,this._domNode=qo(".saturation-wrap"),te(e,this._domNode),this._canvas=document.createElement("canvas"),this._canvas.className="saturation-box",te(this._domNode,this._canvas),this.selection=qo(".saturation-selection"),te(this._domNode,this.selection),this.layout(),this._register(Y(this._domNode,he.POINTER_DOWN,n=>this.onPointerDown(n))),this._register(this.model.onDidChangeColor(this.onDidChangeColor,this)),this.monitor=null}get domNode(){return this._domNode}onPointerDown(e){if(!e.target||!(e.target instanceof Element))return;this.monitor=this._register(new r_);const t=ln(this._domNode);e.target!==this.selection&&this.onDidChangePosition(e.offsetX,e.offsetY),this.monitor.startMonitoring(e.target,e.pointerId,e.buttons,n=>this.onDidChangePosition(n.pageX-t.left,n.pageY-t.top),()=>null);const i=Y(e.target.ownerDocument,he.POINTER_UP,()=>{this._onColorFlushed.fire(),i.dispose(),this.monitor&&(this.monitor.stopMonitoring(!0),this.monitor=null)},!0)}onDidChangePosition(e,t){const i=Math.max(0,Math.min(1,e/this.width)),n=Math.max(0,Math.min(1,1-t/this.height));this.paintSelection(i,n),this._onDidChange.fire({s:i,v:n})}layout(){this.width=this._domNode.offsetWidth,this.height=this._domNode.offsetHeight,this._canvas.width=this.width*this.pixelRatio,this._canvas.height=this.height*this.pixelRatio,this.paint();const e=this.model.color.hsva;this.paintSelection(e.s,e.v)}paint(){const e=this.model.color.hsva,t=new G(new kl(e.h,1,1,1)),i=this._canvas.getContext("2d"),n=i.createLinearGradient(0,0,this._canvas.width,0);n.addColorStop(0,"rgba(255, 255, 255, 1)"),n.addColorStop(.5,"rgba(255, 255, 255, 0.5)"),n.addColorStop(1,"rgba(255, 255, 255, 0)");const o=i.createLinearGradient(0,0,0,this._canvas.height);o.addColorStop(0,"rgba(0, 0, 0, 0)"),o.addColorStop(1,"rgba(0, 0, 0, 1)"),i.rect(0,0,this._canvas.width,this._canvas.height),i.fillStyle=G.Format.CSS.format(t),i.fill(),i.fillStyle=n,i.fill(),i.fillStyle=o,i.fill()}paintSelection(e,t){this.selection.style.left=`${e*this.width}px`,this.selection.style.top=`${this.height-t*this.height}px`}onDidChangeColor(e){if(this.monitor&&this.monitor.isMonitoring())return;this.paint();const t=e.hsva;this.paintSelection(t.s,t.v)}}class lj extends j{constructor(e,t,i=!1){super(),this.model=t,this._onDidChange=new W,this.onDidChange=this._onDidChange.event,this._onColorFlushed=new W,this.onColorFlushed=this._onColorFlushed.event,i?(this.domNode=te(e,qo(".standalone-strip")),this.overlay=te(this.domNode,qo(".standalone-overlay"))):(this.domNode=te(e,qo(".strip")),this.overlay=te(this.domNode,qo(".overlay"))),this.slider=te(this.domNode,qo(".slider")),this.slider.style.top="0px",this._register(Y(this.domNode,he.POINTER_DOWN,n=>this.onPointerDown(n))),this._register(t.onDidChangeColor(this.onDidChangeColor,this)),this.layout()}layout(){this.height=this.domNode.offsetHeight-this.slider.offsetHeight;const e=this.getValue(this.model.color);this.updateSliderPosition(e)}onDidChangeColor(e){const t=this.getValue(e);this.updateSliderPosition(t)}onPointerDown(e){if(!e.target||!(e.target instanceof Element))return;const t=this._register(new r_),i=ln(this.domNode);this.domNode.classList.add("grabbing"),e.target!==this.slider&&this.onDidChangeTop(e.offsetY),t.startMonitoring(e.target,e.pointerId,e.buttons,o=>this.onDidChangeTop(o.pageY-i.top),()=>null);const n=Y(e.target.ownerDocument,he.POINTER_UP,()=>{this._onColorFlushed.fire(),n.dispose(),t.stopMonitoring(!0),this.domNode.classList.remove("grabbing")},!0)}onDidChangeTop(e){const t=Math.max(0,Math.min(1,1-e/this.height));this.updateSliderPosition(t),this._onDidChange.fire(t)}updateSliderPosition(e){this.slider.style.top=`${(1-e)*this.height}px`}}class TCe extends lj{constructor(e,t,i=!1){super(e,t,i),this.domNode.classList.add("opacity-strip"),this.onDidChangeColor(this.model.color)}onDidChangeColor(e){super.onDidChangeColor(e);const{r:t,g:i,b:n}=e.rgba,o=new G(new vt(t,i,n,1)),r=new G(new vt(t,i,n,0));this.overlay.style.background=`linear-gradient(to bottom, ${o} 0%, ${r} 100%)`}getValue(e){return e.hsva.a}}class MCe extends lj{constructor(e,t,i=!1){super(e,t,i),this.domNode.classList.add("hue-strip")}getValue(e){return 1-e.hsva.h/360}}class RCe extends j{constructor(e){super(),this._onClicked=this._register(new W),this.onClicked=this._onClicked.event,this._button=te(e,document.createElement("button")),this._button.classList.add("insert-button"),this._button.textContent="Insert",this._button.onclick=t=>{this._onClicked.fire()}}get button(){return this._button}}class ACe extends ta{constructor(e,t,i,n,o=!1){super(),this.model=t,this.pixelRatio=i,this._register(D0.onDidChange(()=>this.layout()));const r=qo(".colorpicker-widget");e.appendChild(r),this.header=this._register(new kCe(r,this.model,n,o)),this.body=this._register(new ECe(r,this.model,this.pixelRatio,o))}layout(){this.body.layout()}}var dj=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},cj=function(s,e){return function(t,i){e(t,i,s)}};class PCe{constructor(e,t,i,n){this.owner=e,this.range=t,this.model=i,this.provider=n,this.forceShowAtRange=!0}isValidForHoverAnchor(e){return e.type===1&&this.range.startColumn<=e.range.startColumn&&this.range.endColumn>=e.range.endColumn}}let nL=class{constructor(e,t){this._editor=e,this._themeService=t,this.hoverOrdinal=2}computeSync(e,t){return[]}computeAsync(e,t,i){return tn.fromPromise(this._computeAsync(e,t,i))}async _computeAsync(e,t,i){if(!this._editor.hasModel())return[];const n=Uu.get(this._editor);if(!n)return[];for(const o of t){if(!n.isColorDecoration(o))continue;const r=n.getColorData(o.range.getStartPosition());if(r)return[await uj(this,this._editor.getModel(),r.colorInfo,r.provider)]}return[]}renderHoverParts(e,t){return hj(this,this._editor,this._themeService,t,e)}};nL=dj([cj(1,Cn)],nL);class OCe{constructor(e,t,i,n){this.owner=e,this.range=t,this.model=i,this.provider=n}}let Lb=class{constructor(e,t){this._editor=e,this._themeService=t,this._color=null}async createColorHover(e,t,i){if(!this._editor.hasModel()||!Uu.get(this._editor))return null;const o=await sj(i,this._editor.getModel(),ct.None);let r=null,a=null;for(const u of o){const h=u.colorInfo;D.containsRange(h.range,e.range)&&(r=h,a=u.provider)}const l=r??e,d=a??t,c=!!r;return{colorHover:await uj(this,this._editor.getModel(),l,d),foundInEditor:c}}async updateEditorModel(e){if(!this._editor.hasModel())return;const t=e.model;let i=new D(e.range.startLineNumber,e.range.startColumn,e.range.endLineNumber,e.range.endColumn);this._color&&(await iS(this._editor.getModel(),t,this._color,i,e),i=gj(this._editor,i,t))}renderHoverParts(e,t){return hj(this,this._editor,this._themeService,t,e)}set color(e){this._color=e}get color(){return this._color}};Lb=dj([cj(1,Cn)],Lb);async function uj(s,e,t,i){const n=e.getValueInRange(t.range),{red:o,green:r,blue:a,alpha:l}=t.color,d=new vt(Math.round(o*255),Math.round(r*255),Math.round(a*255),l),c=new G(d),u=await oj(e,t,i,ct.None),h=new DCe(c,[],0);return h.colorPresentations=u||[],h.guessColorPresentation(c,n),s instanceof nL?new PCe(s,D.lift(t.range),h,i):new OCe(s,D.lift(t.range),h,i)}function hj(s,e,t,i,n){if(i.length===0||!e.hasModel())return j.None;if(n.setMinimumDimensions){const h=e.getOption(66)+8;n.setMinimumDimensions(new Dt(302,h))}const o=new ie,r=i[0],a=e.getModel(),l=r.model,d=o.add(new ACe(n.fragment,l,e.getOption(141),t,s instanceof Lb));n.setColorPicker(d);let c=!1,u=new D(r.range.startLineNumber,r.range.startColumn,r.range.endLineNumber,r.range.endColumn);if(s instanceof Lb){const h=i[0].model.color;s.color=h,iS(a,l,h,u,r),o.add(l.onColorFlushed(g=>{s.color=g}))}else o.add(l.onColorFlushed(async h=>{await iS(a,l,h,u,r),c=!0,u=gj(e,u,l,n)}));return o.add(l.onDidChangeColor(h=>{iS(a,l,h,u,r)})),o.add(e.onDidChangeModelContent(h=>{c?c=!1:(n.hide(),e.focus())})),o}function gj(s,e,t,i){let n,o;if(t.presentation.textEdit){n=[t.presentation.textEdit],o=new D(t.presentation.textEdit.range.startLineNumber,t.presentation.textEdit.range.startColumn,t.presentation.textEdit.range.endLineNumber,t.presentation.textEdit.range.endColumn);const r=s.getModel()._setTrackedRange(null,o,3);s.pushUndoStop(),s.executeEdits("colorpicker",n),o=s.getModel()._getTrackedRange(r)||o}else n=[{range:e,text:t.presentation.label,forceMoveMarkers:!1}],o=e.setEndPosition(e.endLineNumber,e.startColumn+t.presentation.label.length),s.pushUndoStop(),s.executeEdits("colorpicker",n);return t.presentation.additionalTextEdits&&(n=[...t.presentation.additionalTextEdits],s.executeEdits("colorpicker",n),i&&i.hide()),s.pushUndoStop(),o}async function iS(s,e,t,i,n){const o=await oj(s,{range:i,color:{red:t.rgba.r/255,green:t.rgba.g/255,blue:t.rgba.b/255,alpha:t.rgba.a}},n.provider,ct.None);e.colorPresentations=o||[]}function DM(s,e){return!!s[e]}class oE{constructor(e,t){this.target=e.target,this.isLeftClick=e.event.leftButton,this.isMiddleClick=e.event.middleButton,this.isRightClick=e.event.rightButton,this.hasTriggerModifier=DM(e.event,t.triggerModifier),this.hasSideBySideModifier=DM(e.event,t.triggerSideBySideModifier),this.isNoneOrSingleMouseDown=e.event.detail<=1}}class P8{constructor(e,t){this.keyCodeIsTriggerKey=e.keyCode===t.triggerKey,this.keyCodeIsSideBySideKey=e.keyCode===t.triggerSideBySideKey,this.hasTriggerModifier=DM(e,t.triggerModifier)}}class G1{constructor(e,t,i,n){this.triggerKey=e,this.triggerModifier=t,this.triggerSideBySideKey=i,this.triggerSideBySideModifier=n}equals(e){return this.triggerKey===e.triggerKey&&this.triggerModifier===e.triggerModifier&&this.triggerSideBySideKey===e.triggerSideBySideKey&&this.triggerSideBySideModifier===e.triggerSideBySideModifier}}function O8(s){return s==="altKey"?bt?new G1(57,"metaKey",6,"altKey"):new G1(5,"ctrlKey",6,"altKey"):bt?new G1(6,"altKey",57,"metaKey"):new G1(6,"altKey",5,"ctrlKey")}class mD extends j{constructor(e,t){var i;super(),this._onMouseMoveOrRelevantKeyDown=this._register(new W),this.onMouseMoveOrRelevantKeyDown=this._onMouseMoveOrRelevantKeyDown.event,this._onExecute=this._register(new W),this.onExecute=this._onExecute.event,this._onCancel=this._register(new W),this.onCancel=this._onCancel.event,this._editor=e,this._extractLineNumberFromMouseEvent=(i=t==null?void 0:t.extractLineNumberFromMouseEvent)!==null&&i!==void 0?i:n=>n.target.position?n.target.position.lineNumber:0,this._opts=O8(this._editor.getOption(77)),this._lastMouseMoveEvent=null,this._hasTriggerKeyOnMouseDown=!1,this._lineNumberOnMouseDown=0,this._register(this._editor.onDidChangeConfiguration(n=>{if(n.hasChanged(77)){const o=O8(this._editor.getOption(77));if(this._opts.equals(o))return;this._opts=o,this._lastMouseMoveEvent=null,this._hasTriggerKeyOnMouseDown=!1,this._lineNumberOnMouseDown=0,this._onCancel.fire()}})),this._register(this._editor.onMouseMove(n=>this._onEditorMouseMove(new oE(n,this._opts)))),this._register(this._editor.onMouseDown(n=>this._onEditorMouseDown(new oE(n,this._opts)))),this._register(this._editor.onMouseUp(n=>this._onEditorMouseUp(new oE(n,this._opts)))),this._register(this._editor.onKeyDown(n=>this._onEditorKeyDown(new P8(n,this._opts)))),this._register(this._editor.onKeyUp(n=>this._onEditorKeyUp(new P8(n,this._opts)))),this._register(this._editor.onMouseDrag(()=>this._resetHandler())),this._register(this._editor.onDidChangeCursorSelection(n=>this._onDidChangeCursorSelection(n))),this._register(this._editor.onDidChangeModel(n=>this._resetHandler())),this._register(this._editor.onDidChangeModelContent(()=>this._resetHandler())),this._register(this._editor.onDidScrollChange(n=>{(n.scrollTopChanged||n.scrollLeftChanged)&&this._resetHandler()}))}_onDidChangeCursorSelection(e){e.selection&&e.selection.startColumn!==e.selection.endColumn&&this._resetHandler()}_onEditorMouseMove(e){this._lastMouseMoveEvent=e,this._onMouseMoveOrRelevantKeyDown.fire([e,null])}_onEditorMouseDown(e){this._hasTriggerKeyOnMouseDown=e.hasTriggerModifier,this._lineNumberOnMouseDown=this._extractLineNumberFromMouseEvent(e)}_onEditorMouseUp(e){const t=this._extractLineNumberFromMouseEvent(e);this._hasTriggerKeyOnMouseDown&&this._lineNumberOnMouseDown&&this._lineNumberOnMouseDown===t&&this._onExecute.fire(e)}_onEditorKeyDown(e){this._lastMouseMoveEvent&&(e.keyCodeIsTriggerKey||e.keyCodeIsSideBySideKey&&e.hasTriggerModifier)?this._onMouseMoveOrRelevantKeyDown.fire([this._lastMouseMoveEvent,e]):e.hasTriggerModifier&&this._onCancel.fire()}_onEditorKeyUp(e){e.keyCodeIsTriggerKey&&this._onCancel.fire()}_resetHandler(){this._lastMouseMoveEvent=null,this._hasTriggerKeyOnMouseDown=!1,this._onCancel.fire()}}var FCe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},pd=function(s,e){return function(t,i){e(t,i,s)}};let $u=class extends Lm{constructor(e,t,i,n,o,r,a,l,d,c,u,h,g){super(e,{...n.getRawOptions(),overflowWidgetsDomNode:n.getOverflowWidgetsDomNode()},i,o,r,a,l,d,c,u,h,g),this._parentEditor=n,this._overwriteOptions=t,super.updateOptions(this._overwriteOptions),this._register(n.onDidChangeConfiguration(f=>this._onParentConfigurationChanged(f)))}getParentEditor(){return this._parentEditor}_onParentConfigurationChanged(e){super.updateOptions(this._parentEditor.getRawOptions()),super.updateOptions(this._overwriteOptions)}updateOptions(e){jL(this._overwriteOptions,e,!0),super.updateOptions(this._overwriteOptions)}};$u=FCe([pd(4,We),pd(5,It),pd(6,Ei),pd(7,je),pd(8,Cn),pd(9,Qi),pd(10,ad),pd(11,Jt),pd(12,xe)],$u);const F8=new G(new vt(0,122,204)),BCe={showArrow:!0,showFrame:!0,className:"",frameColor:F8,arrowColor:F8,keepEditorSelection:!1},WCe="vs.editor.contrib.zoneWidget";class VCe{constructor(e,t,i,n,o,r,a,l){this.id="",this.domNode=e,this.afterLineNumber=t,this.afterColumn=i,this.heightInLines=n,this.showInHiddenAreas=a,this.ordinal=l,this._onDomNodeTop=o,this._onComputedHeight=r}onDomNodeTop(e){this._onDomNodeTop(e)}onComputedHeight(e){this._onComputedHeight(e)}}class HCe{constructor(e,t){this._id=e,this._domNode=t}getId(){return this._id}getDomNode(){return this._domNode}getPosition(){return null}}class _D{constructor(e){this._editor=e,this._ruleName=_D._IdGenerator.nextId(),this._decorations=this._editor.createDecorationsCollection(),this._color=null,this._height=-1}dispose(){this.hide(),XN(this._ruleName)}set color(e){this._color!==e&&(this._color=e,this._updateStyle())}set height(e){this._height!==e&&(this._height=e,this._updateStyle())}_updateStyle(){XN(this._ruleName),BS(`.monaco-editor ${this._ruleName}`,`border-style: solid; border-color: transparent; border-bottom-color: ${this._color}; border-width: ${this._height}px; bottom: -${this._height}px; margin-left: -${this._height}px; `)}show(e){e.column===1&&(e={lineNumber:e.lineNumber,column:2}),this._decorations.set([{range:D.fromPositions(e),options:{description:"zone-widget-arrow",className:this._ruleName,stickiness:1}}])}hide(){this._decorations.clear()}}_D._IdGenerator=new cO(".arrow-decoration-");class zCe{constructor(e,t={}){this._arrow=null,this._overlayWidget=null,this._resizeSash=null,this._viewZone=null,this._disposables=new ie,this.container=null,this._isShowing=!1,this.editor=e,this._positionMarkerId=this.editor.createDecorationsCollection(),this.options=yd(t),jL(this.options,BCe,!1),this.domNode=document.createElement("div"),this.options.isAccessible||(this.domNode.setAttribute("aria-hidden","true"),this.domNode.setAttribute("role","presentation")),this._disposables.add(this.editor.onDidLayoutChange(i=>{const n=this._getWidth(i);this.domNode.style.width=n+"px",this.domNode.style.left=this._getLeft(i)+"px",this._onWidth(n)}))}dispose(){this._overlayWidget&&(this.editor.removeOverlayWidget(this._overlayWidget),this._overlayWidget=null),this._viewZone&&this.editor.changeViewZones(e=>{this._viewZone&&e.removeZone(this._viewZone.id),this._viewZone=null}),this._positionMarkerId.clear(),this._disposables.dispose()}create(){this.domNode.classList.add("zone-widget"),this.options.className&&this.domNode.classList.add(this.options.className),this.container=document.createElement("div"),this.container.classList.add("zone-widget-container"),this.domNode.appendChild(this.container),this.options.showArrow&&(this._arrow=new _D(this.editor),this._disposables.add(this._arrow)),this._fillContainer(this.container),this._initSash(),this._applyStyles()}style(e){e.frameColor&&(this.options.frameColor=e.frameColor),e.arrowColor&&(this.options.arrowColor=e.arrowColor),this._applyStyles()}_applyStyles(){if(this.container&&this.options.frameColor){const e=this.options.frameColor.toString();this.container.style.borderTopColor=e,this.container.style.borderBottomColor=e}if(this._arrow&&this.options.arrowColor){const e=this.options.arrowColor.toString();this._arrow.color=e}}_getWidth(e){return e.width-e.minimap.minimapWidth-e.verticalScrollbarWidth}_getLeft(e){return e.minimap.minimapWidth>0&&e.minimap.minimapLeft===0?e.minimap.minimapWidth:0}_onViewZoneTop(e){this.domNode.style.top=e+"px"}_onViewZoneHeight(e){var t;if(this.domNode.style.height=`${e}px`,this.container){const i=e-this._decoratingElementsHeight();this.container.style.height=`${i}px`;const n=this.editor.getLayoutInfo();this._doLayout(i,this._getWidth(n))}(t=this._resizeSash)===null||t===void 0||t.layout()}get position(){const e=this._positionMarkerId.getRange(0);if(e)return e.getStartPosition()}show(e,t){const i=D.isIRange(e)?D.lift(e):D.fromPositions(e);this._isShowing=!0,this._showImpl(i,t),this._isShowing=!1,this._positionMarkerId.set([{range:i,options:tt.EMPTY}])}hide(){var e;this._viewZone&&(this.editor.changeViewZones(t=>{this._viewZone&&t.removeZone(this._viewZone.id)}),this._viewZone=null),this._overlayWidget&&(this.editor.removeOverlayWidget(this._overlayWidget),this._overlayWidget=null),(e=this._arrow)===null||e===void 0||e.hide(),this._positionMarkerId.clear()}_decoratingElementsHeight(){const e=this.editor.getOption(66);let t=0;if(this.options.showArrow){const i=Math.round(e/3);t+=2*i}if(this.options.showFrame){const i=Math.round(e/9);t+=2*i}return t}_showImpl(e,t){const i=e.getStartPosition(),n=this.editor.getLayoutInfo(),o=this._getWidth(n);this.domNode.style.width=`${o}px`,this.domNode.style.left=this._getLeft(n)+"px";const r=document.createElement("div");r.style.overflow="hidden";const a=this.editor.getOption(66);if(!this.options.allowUnlimitedHeight){const h=Math.max(12,this.editor.getLayoutInfo().height/a*.8);t=Math.min(t,h)}let l=0,d=0;if(this._arrow&&this.options.showArrow&&(l=Math.round(a/3),this._arrow.height=l,this._arrow.show(i)),this.options.showFrame&&(d=Math.round(a/9)),this.editor.changeViewZones(h=>{this._viewZone&&h.removeZone(this._viewZone.id),this._overlayWidget&&(this.editor.removeOverlayWidget(this._overlayWidget),this._overlayWidget=null),this.domNode.style.top="-1000px",this._viewZone=new VCe(r,i.lineNumber,i.column,t,g=>this._onViewZoneTop(g),g=>this._onViewZoneHeight(g),this.options.showInHiddenAreas,this.options.ordinal),this._viewZone.id=h.addZone(this._viewZone),this._overlayWidget=new HCe(WCe+this._viewZone.id,this.domNode),this.editor.addOverlayWidget(this._overlayWidget)}),this.container&&this.options.showFrame){const h=this.options.frameWidth?this.options.frameWidth:d;this.container.style.borderTopWidth=h+"px",this.container.style.borderBottomWidth=h+"px"}const c=t*a-this._decoratingElementsHeight();this.container&&(this.container.style.top=l+"px",this.container.style.height=c+"px",this.container.style.overflow="hidden"),this._doLayout(c,o),this.options.keepEditorSelection||this.editor.setSelection(e);const u=this.editor.getModel();if(u){const h=u.validateRange(new D(e.startLineNumber,1,e.endLineNumber+1,1));this.revealRange(h,h.startLineNumber===u.getLineCount())}}revealRange(e,t){t?this.editor.revealLineNearTop(e.endLineNumber,0):this.editor.revealRange(e,0)}setCssClass(e,t){this.container&&(t&&this.container.classList.remove(t),this.container.classList.add(e))}_onWidth(e){}_doLayout(e,t){}_relayout(e){this._viewZone&&this._viewZone.heightInLines!==e&&this.editor.changeViewZones(t=>{this._viewZone&&(this._viewZone.heightInLines=e,t.layoutZone(this._viewZone.id))})}_initSash(){if(this._resizeSash)return;this._resizeSash=this._disposables.add(new ns(this.domNode,this,{orientation:1})),this.options.isResizeable||(this._resizeSash.state=0);let e;this._disposables.add(this._resizeSash.onDidStart(t=>{this._viewZone&&(e={startY:t.startY,heightInLines:this._viewZone.heightInLines})})),this._disposables.add(this._resizeSash.onDidEnd(()=>{e=void 0})),this._disposables.add(this._resizeSash.onDidChange(t=>{if(e){const i=(t.currentY-e.startY)/this.editor.getOption(66),n=i<0?Math.ceil(i):Math.floor(i),o=e.heightInLines+n;o>5&&o<35&&this._relayout(o)}}))}getHorizontalSashLeft(){return 0}getHorizontalSashTop(){return(this.domNode.style.height===null?0:parseInt(this.domNode.style.height))-this._decoratingElementsHeight()/2}getHorizontalSashWidth(){const e=this.editor.getLayoutInfo();return e.width-e.minimap.minimapWidth}}var fj=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},pj=function(s,e){return function(t,i){e(t,i,s)}};const mj=ut("IPeekViewService");_t(mj,class{constructor(){this._widgets=new Map}addExclusiveWidget(s,e){const t=this._widgets.get(s);t&&(t.listener.dispose(),t.widget.dispose());const i=()=>{const n=this._widgets.get(s);n&&n.widget===e&&(n.listener.dispose(),this._widgets.delete(s))};this._widgets.set(s,{widget:e,listener:e.onDidClose(i)})}},1);var eo;(function(s){s.inPeekEditor=new me("inReferenceSearchEditor",!0,p("inReferenceSearchEditor","Whether the current code editor is embedded inside peek")),s.notInPeekEditor=s.inPeekEditor.toNegated()})(eo||(eo={}));let xb=class{constructor(e,t){e instanceof $u&&eo.inPeekEditor.bindTo(t)}dispose(){}};xb.ID="editor.contrib.referenceController";xb=fj([pj(1,je)],xb);Lt(xb.ID,xb,0);function UCe(s){const e=s.get(It).getFocusedCodeEditor();return e instanceof $u?e.getParentEditor():e}const $Ce={headerBackgroundColor:G.white,primaryHeadingColor:G.fromHex("#333333"),secondaryHeadingColor:G.fromHex("#6c6c6cb3")};let sL=class extends zCe{constructor(e,t,i){super(e,t),this.instantiationService=i,this._onDidClose=new W,this.onDidClose=this._onDidClose.event,jL(this.options,$Ce,!1)}dispose(){this.disposed||(this.disposed=!0,super.dispose(),this._onDidClose.fire(this))}style(e){const t=this.options;e.headerBackgroundColor&&(t.headerBackgroundColor=e.headerBackgroundColor),e.primaryHeadingColor&&(t.primaryHeadingColor=e.primaryHeadingColor),e.secondaryHeadingColor&&(t.secondaryHeadingColor=e.secondaryHeadingColor),super.style(e)}_applyStyles(){super._applyStyles();const e=this.options;this._headElement&&e.headerBackgroundColor&&(this._headElement.style.backgroundColor=e.headerBackgroundColor.toString()),this._primaryHeading&&e.primaryHeadingColor&&(this._primaryHeading.style.color=e.primaryHeadingColor.toString()),this._secondaryHeading&&e.secondaryHeadingColor&&(this._secondaryHeading.style.color=e.secondaryHeadingColor.toString()),this._bodyElement&&e.frameColor&&(this._bodyElement.style.borderColor=e.frameColor.toString())}_fillContainer(e){this.setCssClass("peekview-widget"),this._headElement=se(".head"),this._bodyElement=se(".body"),this._fillHead(this._headElement),this._fillBody(this._bodyElement),e.appendChild(this._headElement),e.appendChild(this._bodyElement)}_fillHead(e,t){this._titleElement=se(".peekview-title"),this.options.supportOnTitleClick&&(this._titleElement.classList.add("clickable"),Pi(this._titleElement,"click",o=>this._onTitleClick(o))),te(this._headElement,this._titleElement),this._fillTitleIcon(this._titleElement),this._primaryHeading=se("span.filename"),this._secondaryHeading=se("span.dirname"),this._metaHeading=se("span.meta"),te(this._titleElement,this._primaryHeading,this._secondaryHeading,this._metaHeading);const i=se(".peekview-actions");te(this._headElement,i);const n=this._getActionBarOptions();this._actionbarWidget=new Ir(i,n),this._disposables.add(this._actionbarWidget),t||this._actionbarWidget.push(new Os("peekview.close",p("label.close","Close"),Oe.asClassName(le.close),!0,()=>(this.dispose(),Promise.resolve())),{label:!1,icon:!0})}_fillTitleIcon(e){}_getActionBarOptions(){return{actionViewItemProvider:Kge.bind(void 0,this.instantiationService),orientation:0}}_onTitleClick(e){}setTitle(e,t){this._primaryHeading&&this._secondaryHeading&&(this._primaryHeading.innerText=e,this._primaryHeading.setAttribute("title",e),t?this._secondaryHeading.innerText=t:Vn(this._secondaryHeading))}setMetaTitle(e){this._metaHeading&&(e?(this._metaHeading.innerText=e,go(this._metaHeading)):ks(this._metaHeading))}_doLayout(e,t){if(!this._isShowing&&e<0){this.dispose();return}const i=Math.ceil(this.editor.getOption(66)*1.2),n=Math.round(e-(i+2));this._doLayoutHead(i,t),this._doLayoutBody(n,t)}_doLayoutHead(e,t){this._headElement&&(this._headElement.style.height=`${e}px`,this._headElement.style.lineHeight=this._headElement.style.height)}_doLayoutBody(e,t){this._bodyElement&&(this._bodyElement.style.height=`${e}px`)}};sL=fj([pj(2,We)],sL);const jCe=R("peekViewTitle.background",{dark:"#252526",light:"#F3F3F3",hcDark:G.black,hcLight:G.white},p("peekViewTitleBackground","Background color of the peek view title area.")),_j=R("peekViewTitleLabel.foreground",{dark:G.white,light:G.black,hcDark:G.white,hcLight:$r},p("peekViewTitleForeground","Color of the peek view title.")),vj=R("peekViewTitleDescription.foreground",{dark:"#ccccccb3",light:"#616161",hcDark:"#FFFFFF99",hcLight:"#292929"},p("peekViewTitleInfoForeground","Color of the peek view title info.")),KCe=R("peekView.border",{dark:Xs,light:Xs,hcDark:pt,hcLight:pt},p("peekViewBorder","Color of the peek view borders and arrow.")),qCe=R("peekViewResult.background",{dark:"#252526",light:"#F3F3F3",hcDark:G.black,hcLight:G.white},p("peekViewResultsBackground","Background color of the peek view result list."));R("peekViewResult.lineForeground",{dark:"#bbbbbb",light:"#646465",hcDark:G.white,hcLight:$r},p("peekViewResultsMatchForeground","Foreground color for line nodes in the peek view result list."));R("peekViewResult.fileForeground",{dark:G.white,light:"#1E1E1E",hcDark:G.white,hcLight:$r},p("peekViewResultsFileForeground","Foreground color for file nodes in the peek view result list."));R("peekViewResult.selectionBackground",{dark:"#3399ff33",light:"#3399ff33",hcDark:null,hcLight:null},p("peekViewResultsSelectionBackground","Background color of the selected entry in the peek view result list."));R("peekViewResult.selectionForeground",{dark:G.white,light:"#6C6C6C",hcDark:G.white,hcLight:$r},p("peekViewResultsSelectionForeground","Foreground color of the selected entry in the peek view result list."));const Xc=R("peekViewEditor.background",{dark:"#001F33",light:"#F2F8FC",hcDark:G.black,hcLight:G.white},p("peekViewEditorBackground","Background color of the peek view editor."));R("peekViewEditorGutter.background",{dark:Xc,light:Xc,hcDark:Xc,hcLight:Xc},p("peekViewEditorGutterBackground","Background color of the gutter in the peek view editor."));R("peekViewEditorStickyScroll.background",{dark:Xc,light:Xc,hcDark:Xc,hcLight:Xc},p("peekViewEditorStickScrollBackground","Background color of sticky scroll in the peek view editor."));R("peekViewResult.matchHighlightBackground",{dark:"#ea5c004d",light:"#ea5c004d",hcDark:null,hcLight:null},p("peekViewResultsMatchHighlight","Match highlight color in the peek view result list."));R("peekViewEditor.matchHighlightBackground",{dark:"#ff8f0099",light:"#f5d802de",hcDark:null,hcLight:null},p("peekViewEditorMatchHighlight","Match highlight color in the peek view editor."));R("peekViewEditor.matchHighlightBorder",{dark:null,light:null,hcDark:ai,hcLight:ai},p("peekViewEditorMatchHighlightBorder","Match highlight border in the peek view editor."));class ju{constructor(e,t,i,n){this.isProviderFirst=e,this.parent=t,this.link=i,this._rangeCallback=n,this.id=r2.nextId()}get uri(){return this.link.uri}get range(){var e,t;return(t=(e=this._range)!==null&&e!==void 0?e:this.link.targetSelectionRange)!==null&&t!==void 0?t:this.link.range}set range(e){this._range=e,this._rangeCallback(this)}get ariaMessage(){var e;const t=(e=this.parent.getPreview(this))===null||e===void 0?void 0:e.preview(this.range);return t?p({key:"aria.oneReference.preview",comment:["Placeholders are: 0: filename, 1:line number, 2: column number, 3: preview snippet of source code"]},"{0} in {1} on line {2} at column {3}",t.value,kr(this.uri),this.range.startLineNumber,this.range.startColumn):p("aria.oneReference","in {0} on line {1} at column {2}",kr(this.uri),this.range.startLineNumber,this.range.startColumn)}}class GCe{constructor(e){this._modelReference=e}dispose(){this._modelReference.dispose()}preview(e,t=8){const i=this._modelReference.object.textEditorModel;if(!i)return;const{startLineNumber:n,startColumn:o,endLineNumber:r,endColumn:a}=e,l=i.getWordUntilPosition({lineNumber:n,column:o-t}),d=new D(n,l.startColumn,n,o),c=new D(r,a,r,1073741824),u=i.getValueInRange(d).replace(/^\s+/,""),h=i.getValueInRange(e),g=i.getValueInRange(c).replace(/\s+$/,"");return{value:u+h+g,highlight:{start:u.length,end:u.length+h.length}}}}class Db{constructor(e,t){this.parent=e,this.uri=t,this.children=[],this._previews=new zi}dispose(){Bt(this._previews.values()),this._previews.clear()}getPreview(e){return this._previews.get(e.uri)}get ariaMessage(){const e=this.children.length;return e===1?p("aria.fileReferences.1","1 symbol in {0}, full path {1}",kr(this.uri),this.uri.fsPath):p("aria.fileReferences.N","{0} symbols in {1}, full path {2}",e,kr(this.uri),this.uri.fsPath)}async resolve(e){if(this._previews.size!==0)return this;for(const t of this.children)if(!this._previews.has(t.uri))try{const i=await e.createModelReference(t.uri);this._previews.set(t.uri,new GCe(i))}catch(i){et(i)}return this}}class wo{constructor(e,t){this.groups=[],this.references=[],this._onDidChangeReferenceRange=new W,this.onDidChangeReferenceRange=this._onDidChangeReferenceRange.event,this._links=e,this._title=t;const[i]=e;e.sort(wo._compareReferences);let n;for(const o of e)if((!n||!li.isEqual(n.uri,o.uri,!0))&&(n=new Db(this,o.uri),this.groups.push(n)),n.children.length===0||wo._compareReferences(o,n.children[n.children.length-1])!==0){const r=new ju(i===o,n,o,a=>this._onDidChangeReferenceRange.fire(a));this.references.push(r),n.children.push(r)}}dispose(){Bt(this.groups),this._onDidChangeReferenceRange.dispose(),this.groups.length=0}clone(){return new wo(this._links,this._title)}get title(){return this._title}get isEmpty(){return this.groups.length===0}get ariaMessage(){return this.isEmpty?p("aria.result.0","No results found"):this.references.length===1?p("aria.result.1","Found 1 symbol in {0}",this.references[0].uri.fsPath):this.groups.length===1?p("aria.result.n1","Found {0} symbols in {1}",this.references.length,this.groups[0].uri.fsPath):p("aria.result.nm","Found {0} symbols in {1} files",this.references.length,this.groups.length)}nextOrPreviousReference(e,t){const{parent:i}=e;let n=i.children.indexOf(e);const o=i.children.length,r=i.parent.groups.length;return r===1||t&&n+1<o||!t&&n>0?(t?n=(n+1)%o:n=(n+o-1)%o,i.children[n]):(n=i.parent.groups.indexOf(i),t?(n=(n+1)%r,i.parent.groups[n].children[0]):(n=(n+r-1)%r,i.parent.groups[n].children[i.parent.groups[n].children.length-1]))}nearestReference(e,t){const i=this.references.map((n,o)=>({idx:o,prefixLen:Dg(n.uri.toString(),e.toString()),offsetDist:Math.abs(n.range.startLineNumber-t.lineNumber)*100+Math.abs(n.range.startColumn-t.column)})).sort((n,o)=>n.prefixLen>o.prefixLen?-1:n.prefixLen<o.prefixLen?1:n.offsetDist<o.offsetDist?-1:n.offsetDist>o.offsetDist?1:0)[0];if(i)return this.references[i.idx]}referenceAt(e,t){for(const i of this.references)if(i.uri.toString()===e.toString()&&D.containsPosition(i.range,t))return i}firstReference(){for(const e of this.references)if(e.isProviderFirst)return e;return this.references[0]}static _compareReferences(e,t){return li.compare(e.uri,t.uri)||D.compareRangesUsingStarts(e.range,t.range)}}var vD=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},bD=function(s,e){return function(t,i){e(t,i,s)}},kM;let IM=class{constructor(e){this._resolverService=e}hasChildren(e){return e instanceof wo||e instanceof Db}getChildren(e){if(e instanceof wo)return e.groups;if(e instanceof Db)return e.resolve(this._resolverService).then(t=>t.children);throw new Error("bad tree")}};IM=vD([bD(0,io)],IM);class ZCe{getHeight(){return 23}getTemplateId(e){return e instanceof Db?kb.id:FC.id}}let EM=class{constructor(e){this._keybindingService=e}getKeyboardNavigationLabel(e){var t;if(e instanceof ju){const i=(t=e.parent.getPreview(e))===null||t===void 0?void 0:t.preview(e.range);if(i)return i.value}return kr(e.uri)}};EM=vD([bD(0,qt)],EM);class YCe{getId(e){return e instanceof ju?e.id:e.uri}}let NM=class extends j{constructor(e,t){super(),this._labelService=t;const i=document.createElement("div");i.classList.add("reference-file"),this.file=this._register(new Hy(i,{supportHighlights:!0})),this.badge=new E2(te(i,se(".count")),{},Xz),e.appendChild(i)}set(e,t){const i=Tx(e.uri);this.file.setLabel(this._labelService.getUriBasenameLabel(e.uri),this._labelService.getUriLabel(i,{relative:!0}),{title:this._labelService.getUriLabel(e.uri),matches:t});const n=e.children.length;this.badge.setCount(n),n>1?this.badge.setTitleFormat(p("referencesCount","{0} references",n)):this.badge.setTitleFormat(p("referenceCount","{0} reference",n))}};NM=vD([bD(1,xm)],NM);let kb=kM=class{constructor(e){this._instantiationService=e,this.templateId=kM.id}renderTemplate(e){return this._instantiationService.createInstance(NM,e)}renderElement(e,t,i){i.set(e.element,CC(e.filterData))}disposeTemplate(e){e.dispose()}};kb.id="FileReferencesRenderer";kb=kM=vD([bD(0,We)],kb);class XCe{constructor(e){this.label=new fu(e)}set(e,t){var i;const n=(i=e.parent.getPreview(e))===null||i===void 0?void 0:i.preview(e.range);if(!n||!n.value)this.label.set(`${kr(e.uri)}:${e.range.startLineNumber+1}:${e.range.startColumn+1}`);else{const{value:o,highlight:r}=n;t&&!Fa.isDefault(t)?(this.label.element.classList.toggle("referenceMatch",!1),this.label.set(o,CC(t))):(this.label.element.classList.toggle("referenceMatch",!0),this.label.set(o,[r]))}}}class FC{constructor(){this.templateId=FC.id}renderTemplate(e){return new XCe(e)}renderElement(e,t,i){i.set(e.element,e.filterData)}disposeTemplate(){}}FC.id="OneReferenceRenderer";class QCe{getWidgetAriaLabel(){return p("treeAriaLabel","References")}getAriaLabel(e){return e.ariaMessage}}var JCe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},md=function(s,e){return function(t,i){e(t,i,s)}};class CD{constructor(e,t){this._editor=e,this._model=t,this._decorations=new Map,this._decorationIgnoreSet=new Set,this._callOnDispose=new ie,this._callOnModelChange=new ie,this._callOnDispose.add(this._editor.onDidChangeModel(()=>this._onModelChanged())),this._onModelChanged()}dispose(){this._callOnModelChange.dispose(),this._callOnDispose.dispose(),this.removeDecorations()}_onModelChanged(){this._callOnModelChange.clear();const e=this._editor.getModel();if(e){for(const t of this._model.references)if(t.uri.toString()===e.uri.toString()){this._addDecorations(t.parent);return}}}_addDecorations(e){if(!this._editor.hasModel())return;this._callOnModelChange.add(this._editor.getModel().onDidChangeDecorations(()=>this._onDecorationChanged()));const t=[],i=[];for(let n=0,o=e.children.length;n<o;n++){const r=e.children[n];this._decorationIgnoreSet.has(r.id)||r.uri.toString()===this._editor.getModel().uri.toString()&&(t.push({range:r.range,options:CD.DecorationOptions}),i.push(n))}this._editor.changeDecorations(n=>{const o=n.deltaDecorations([],t);for(let r=0;r<o.length;r++)this._decorations.set(o[r],e.children[i[r]])})}_onDecorationChanged(){const e=[],t=this._editor.getModel();if(t){for(const[i,n]of this._decorations){const o=t.getDecorationRange(i);if(!o)continue;let r=!1;if(!D.equalsRange(o,n.range)){if(D.spansMultipleLines(o))r=!0;else{const a=n.range.endColumn-n.range.startColumn,l=o.endColumn-o.startColumn;a!==l&&(r=!0)}r?(this._decorationIgnoreSet.add(n.id),e.push(i)):n.range=o}}for(let i=0,n=e.length;i<n;i++)this._decorations.delete(e[i]);this._editor.removeDecorations(e)}}removeDecorations(){this._editor.removeDecorations([...this._decorations.keys()]),this._decorations.clear()}}CD.DecorationOptions=tt.register({description:"reference-decoration",stickiness:1,className:"reference-decoration"});class e1e{constructor(){this.ratio=.7,this.heightInLines=18}static fromJSON(e){let t,i;try{const n=JSON.parse(e);t=n.ratio,i=n.heightInLines}catch{}return{ratio:t||.7,heightInLines:i||18}}}class t1e extends D2{}let TM=class extends sL{constructor(e,t,i,n,o,r,a,l,d,c,u,h){super(e,{showFrame:!1,showArrow:!0,isResizeable:!0,isAccessible:!0,supportOnTitleClick:!0},r),this._defaultTreeKeyboardSupport=t,this.layoutData=i,this._textModelResolverService=o,this._instantiationService=r,this._peekViewService=a,this._uriLabel=l,this._undoRedoService=d,this._keybindingService=c,this._languageService=u,this._languageConfigurationService=h,this._disposeOnNewModel=new ie,this._callOnDispose=new ie,this._onDidSelectReference=new W,this.onDidSelectReference=this._onDidSelectReference.event,this._dim=new Dt(0,0),this._applyTheme(n.getColorTheme()),this._callOnDispose.add(n.onDidColorThemeChange(this._applyTheme.bind(this))),this._peekViewService.addExclusiveWidget(e,this),this.create()}dispose(){this.setModel(void 0),this._callOnDispose.dispose(),this._disposeOnNewModel.dispose(),Bt(this._preview),Bt(this._previewNotAvailableMessage),Bt(this._tree),Bt(this._previewModelReference),this._splitView.dispose(),super.dispose()}_applyTheme(e){const t=e.getColor(KCe)||G.transparent;this.style({arrowColor:t,frameColor:t,headerBackgroundColor:e.getColor(jCe)||G.transparent,primaryHeadingColor:e.getColor(_j),secondaryHeadingColor:e.getColor(vj)})}show(e){super.show(e,this.layoutData.heightInLines||18)}focusOnReferenceTree(){this._tree.domFocus()}focusOnPreviewEditor(){this._preview.focus()}isPreviewEditorFocused(){return this._preview.hasTextFocus()}_onTitleClick(e){this._preview&&this._preview.getModel()&&this._onDidSelectReference.fire({element:this._getFocusedReference(),kind:e.ctrlKey||e.metaKey||e.altKey?"side":"open",source:"title"})}_fillBody(e){this.setCssClass("reference-zone-widget"),this._messageContainer=te(e,se("div.messages")),ks(this._messageContainer),this._splitView=new tU(e,{orientation:1}),this._previewContainer=te(e,se("div.preview.inline"));const t={scrollBeyondLastLine:!1,scrollbar:{verticalScrollbarSize:14,horizontal:"auto",useShadows:!0,verticalHasArrows:!1,horizontalHasArrows:!1,alwaysConsumeMouseWheel:!0},overviewRulerLanes:2,fixedOverflowWidgets:!0,minimap:{enabled:!1}};this._preview=this._instantiationService.createInstance($u,this._previewContainer,t,{},this.editor),ks(this._previewContainer),this._previewNotAvailableMessage=new Xl(p("missingPreviewMessage","no preview available"),er,Xl.DEFAULT_CREATION_OPTIONS,null,this._undoRedoService,this._languageService,this._languageConfigurationService),this._treeContainer=te(e,se("div.ref-tree.inline"));const i={keyboardSupport:this._defaultTreeKeyboardSupport,accessibilityProvider:new QCe,keyboardNavigationLabelProvider:this._instantiationService.createInstance(EM),identityProvider:new YCe,openOnSingleClick:!0,selectionNavigation:!0,overrideStyles:{listBackground:qCe}};this._defaultTreeKeyboardSupport&&this._callOnDispose.add(Pi(this._treeContainer,"keydown",o=>{o.equals(9)&&(this._keybindingService.dispatchEvent(o,o.target),o.stopPropagation())},!0)),this._tree=this._instantiationService.createInstance(t1e,"ReferencesWidget",this._treeContainer,new ZCe,[this._instantiationService.createInstance(kb),this._instantiationService.createInstance(FC)],this._instantiationService.createInstance(IM),i),this._splitView.addView({onDidChange:ge.None,element:this._previewContainer,minimumSize:200,maximumSize:Number.MAX_VALUE,layout:o=>{this._preview.layout({height:this._dim.height,width:o})}},Ay.Distribute),this._splitView.addView({onDidChange:ge.None,element:this._treeContainer,minimumSize:100,maximumSize:Number.MAX_VALUE,layout:o=>{this._treeContainer.style.height=`${this._dim.height}px`,this._treeContainer.style.width=`${o}px`,this._tree.layout(this._dim.height,o)}},Ay.Distribute),this._disposables.add(this._splitView.onDidSashChange(()=>{this._dim.width&&(this.layoutData.ratio=this._splitView.getViewSize(0)/this._dim.width)},void 0));const n=(o,r)=>{o instanceof ju&&(r==="show"&&this._revealReference(o,!1),this._onDidSelectReference.fire({element:o,kind:r,source:"tree"}))};this._tree.onDidOpen(o=>{o.sideBySide?n(o.element,"side"):o.editorOptions.pinned?n(o.element,"goto"):n(o.element,"show")}),ks(this._treeContainer)}_onWidth(e){this._dim&&this._doLayoutBody(this._dim.height,e)}_doLayoutBody(e,t){super._doLayoutBody(e,t),this._dim=new Dt(t,e),this.layoutData.heightInLines=this._viewZone?this._viewZone.heightInLines:this.layoutData.heightInLines,this._splitView.layout(t),this._splitView.resizeView(0,t*this.layoutData.ratio)}setSelection(e){return this._revealReference(e,!0).then(()=>{this._model&&(this._tree.setSelection([e]),this._tree.setFocus([e]))})}setModel(e){return this._disposeOnNewModel.clear(),this._model=e,this._model?this._onNewModel():Promise.resolve()}_onNewModel(){return this._model?this._model.isEmpty?(this.setTitle(""),this._messageContainer.innerText=p("noResults","No results"),go(this._messageContainer),Promise.resolve(void 0)):(ks(this._messageContainer),this._decorationsManager=new CD(this._preview,this._model),this._disposeOnNewModel.add(this._decorationsManager),this._disposeOnNewModel.add(this._model.onDidChangeReferenceRange(e=>this._tree.rerender(e))),this._disposeOnNewModel.add(this._preview.onMouseDown(e=>{const{event:t,target:i}=e;if(t.detail!==2)return;const n=this._getFocusedReference();n&&this._onDidSelectReference.fire({element:{uri:n.uri,range:i.range},kind:t.ctrlKey||t.metaKey||t.altKey?"side":"open",source:"editor"})})),this.container.classList.add("results-loaded"),go(this._treeContainer),go(this._previewContainer),this._splitView.layout(this._dim.width),this.focusOnReferenceTree(),this._tree.setInput(this._model.groups.length===1?this._model.groups[0]:this._model)):Promise.resolve(void 0)}_getFocusedReference(){const[e]=this._tree.getFocus();if(e instanceof ju)return e;if(e instanceof Db&&e.children.length>0)return e.children[0]}async revealReference(e){await this._revealReference(e,!1),this._onDidSelectReference.fire({element:e,kind:"goto",source:"tree"})}async _revealReference(e,t){if(this._revealedReference===e)return;this._revealedReference=e,e.uri.scheme!==it.inMemory?this.setTitle(Ale(e.uri),this._uriLabel.getUriLabel(Tx(e.uri))):this.setTitle(p("peekView.alternateTitle","References"));const i=this._textModelResolverService.createModelReference(e.uri);this._tree.getInput()===e.parent?this._tree.reveal(e):(t&&this._tree.reveal(e.parent),await this._tree.expand(e.parent),this._tree.reveal(e));const n=await i;if(!this._model){n.dispose();return}Bt(this._previewModelReference);const o=n.object;if(o){const r=this._preview.getModel()===o.textEditorModel?0:1,a=D.lift(e.range).collapseToStart();this._previewModelReference=n,this._preview.setModel(o.textEditorModel),this._preview.setSelection(a),this._preview.revealRangeInCenter(a,r)}else this._preview.setModel(this._previewNotAvailableMessage),n.dispose()}};TM=JCe([md(3,Cn),md(4,io),md(5,We),md(6,mj),md(7,xm),md(8,Mx),md(9,qt),md(10,fi),md(11,Jt)],TM);var i1e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Af=function(s,e){return function(t,i){e(t,i,s)}},nS;const bf=new me("referenceSearchVisible",!1,p("referenceSearchVisible","Whether reference peek is visible, like 'Peek References' or 'Peek Definition'"));let Ku=nS=class{static get(e){return e.getContribution(nS.ID)}constructor(e,t,i,n,o,r,a,l){this._defaultTreeKeyboardSupport=e,this._editor=t,this._editorService=n,this._notificationService=o,this._instantiationService=r,this._storageService=a,this._configurationService=l,this._disposables=new ie,this._requestIdPool=0,this._ignoreModelChangeEvent=!1,this._referenceSearchVisible=bf.bindTo(i)}dispose(){var e,t;this._referenceSearchVisible.reset(),this._disposables.dispose(),(e=this._widget)===null||e===void 0||e.dispose(),(t=this._model)===null||t===void 0||t.dispose(),this._widget=void 0,this._model=void 0}toggleWidget(e,t,i){let n;if(this._widget&&(n=this._widget.position),this.closeWidget(),n&&e.containsPosition(n))return;this._peekMode=i,this._referenceSearchVisible.set(!0),this._disposables.add(this._editor.onDidChangeModelLanguage(()=>{this.closeWidget()})),this._disposables.add(this._editor.onDidChangeModel(()=>{this._ignoreModelChangeEvent||this.closeWidget()}));const o="peekViewLayout",r=e1e.fromJSON(this._storageService.get(o,0,"{}"));this._widget=this._instantiationService.createInstance(TM,this._editor,this._defaultTreeKeyboardSupport,r),this._widget.setTitle(p("labelLoading","Loading...")),this._widget.show(e),this._disposables.add(this._widget.onDidClose(()=>{t.cancel(),this._widget&&(this._storageService.store(o,JSON.stringify(this._widget.layoutData),0,1),this._widget=void 0),this.closeWidget()})),this._disposables.add(this._widget.onDidSelectReference(l=>{const{element:d,kind:c}=l;if(d)switch(c){case"open":(l.source!=="editor"||!this._configurationService.getValue("editor.stablePeek"))&&this.openReference(d,!1,!1);break;case"side":this.openReference(d,!0,!1);break;case"goto":i?this._gotoReference(d,!0):this.openReference(d,!1,!0);break}}));const a=++this._requestIdPool;t.then(l=>{var d;if(a!==this._requestIdPool||!this._widget){l.dispose();return}return(d=this._model)===null||d===void 0||d.dispose(),this._model=l,this._widget.setModel(this._model).then(()=>{if(this._widget&&this._model&&this._editor.hasModel()){this._model.isEmpty?this._widget.setMetaTitle(""):this._widget.setMetaTitle(p("metaTitle.N","{0} ({1})",this._model.title,this._model.references.length));const c=this._editor.getModel().uri,u=new H(e.startLineNumber,e.startColumn),h=this._model.nearestReference(c,u);if(h)return this._widget.setSelection(h).then(()=>{this._widget&&this._editor.getOption(86)==="editor"&&this._widget.focusOnPreviewEditor()})}})},l=>{this._notificationService.error(l)})}changeFocusBetweenPreviewAndReferences(){this._widget&&(this._widget.isPreviewEditorFocused()?this._widget.focusOnReferenceTree():this._widget.focusOnPreviewEditor())}async goToNextOrPreviousReference(e){if(!this._editor.hasModel()||!this._model||!this._widget)return;const t=this._widget.position;if(!t)return;const i=this._model.nearestReference(this._editor.getModel().uri,t);if(!i)return;const n=this._model.nextOrPreviousReference(i,e),o=this._editor.hasTextFocus(),r=this._widget.isPreviewEditorFocused();await this._widget.setSelection(n),await this._gotoReference(n,!1),o?this._editor.focus():this._widget&&r&&this._widget.focusOnPreviewEditor()}async revealReference(e){!this._editor.hasModel()||!this._model||!this._widget||await this._widget.revealReference(e)}closeWidget(e=!0){var t,i;(t=this._widget)===null||t===void 0||t.dispose(),(i=this._model)===null||i===void 0||i.dispose(),this._referenceSearchVisible.reset(),this._disposables.clear(),this._widget=void 0,this._model=void 0,e&&this._editor.focus(),this._requestIdPool+=1}_gotoReference(e,t){var i;(i=this._widget)===null||i===void 0||i.hide(),this._ignoreModelChangeEvent=!0;const n=D.lift(e.range).collapseToStart();return this._editorService.openCodeEditor({resource:e.uri,options:{selection:n,selectionSource:"code.jump",pinned:t}},this._editor).then(o=>{var r;if(this._ignoreModelChangeEvent=!1,!o||!this._widget){this.closeWidget();return}if(this._editor===o)this._widget.show(n),this._widget.focusOnReferenceTree();else{const a=nS.get(o),l=this._model.clone();this.closeWidget(),o.focus(),a==null||a.toggleWidget(n,gn(d=>Promise.resolve(l)),(r=this._peekMode)!==null&&r!==void 0?r:!1)}},o=>{this._ignoreModelChangeEvent=!1,et(o)})}openReference(e,t,i){t||this.closeWidget();const{uri:n,range:o}=e;this._editorService.openCodeEditor({resource:n,options:{selection:o,selectionSource:"code.jump",pinned:i}},this._editor,t)}};Ku.ID="editor.contrib.referencesController";Ku=nS=i1e([Af(2,je),Af(3,It),Af(4,Qi),Af(5,We),Af(6,sa),Af(7,mt)],Ku);function Cf(s,e){const t=UCe(s);if(!t)return;const i=Ku.get(t);i&&e(i)}Js.registerCommandAndKeybindingRule({id:"togglePeekWidgetFocus",weight:100,primary:dn(2089,60),when:ee.or(bf,eo.inPeekEditor),handler(s){Cf(s,e=>{e.changeFocusBetweenPreviewAndReferences()})}});Js.registerCommandAndKeybindingRule({id:"goToNextReference",weight:90,primary:62,secondary:[70],when:ee.or(bf,eo.inPeekEditor),handler(s){Cf(s,e=>{e.goToNextOrPreviousReference(!0)})}});Js.registerCommandAndKeybindingRule({id:"goToPreviousReference",weight:90,primary:1086,secondary:[1094],when:ee.or(bf,eo.inPeekEditor),handler(s){Cf(s,e=>{e.goToNextOrPreviousReference(!1)})}});Ct.registerCommandAlias("goToNextReferenceFromEmbeddedEditor","goToNextReference");Ct.registerCommandAlias("goToPreviousReferenceFromEmbeddedEditor","goToPreviousReference");Ct.registerCommandAlias("closeReferenceSearchEditor","closeReferenceSearch");Ct.registerCommand("closeReferenceSearch",s=>Cf(s,e=>e.closeWidget()));Js.registerKeybindingRule({id:"closeReferenceSearch",weight:-1,primary:9,secondary:[1033],when:ee.and(eo.inPeekEditor,ee.not("config.editor.stablePeek"))});Js.registerKeybindingRule({id:"closeReferenceSearch",weight:250,primary:9,secondary:[1033],when:ee.and(bf,ee.not("config.editor.stablePeek"))});Js.registerCommandAndKeybindingRule({id:"revealReference",weight:200,primary:3,mac:{primary:3,secondary:[2066]},when:ee.and(bf,mU,kO.negate(),IO.negate()),handler(s){var e;const i=(e=s.get(Mr).lastFocusedList)===null||e===void 0?void 0:e.getFocus();Array.isArray(i)&&i[0]instanceof ju&&Cf(s,n=>n.revealReference(i[0]))}});Js.registerCommandAndKeybindingRule({id:"openReferenceToSide",weight:100,primary:2051,mac:{primary:259},when:ee.and(bf,mU,kO.negate(),IO.negate()),handler(s){var e;const i=(e=s.get(Mr).lastFocusedList)===null||e===void 0?void 0:e.getFocus();Array.isArray(i)&&i[0]instanceof ju&&Cf(s,n=>n.openReference(i[0],!0,!0))}});Ct.registerCommand("openReference",s=>{var e;const i=(e=s.get(Mr).lastFocusedList)===null||e===void 0?void 0:e.getFocus();Array.isArray(i)&&i[0]instanceof ju&&Cf(s,n=>n.openReference(i[0],!1,!0))});var bj=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},wv=function(s,e){return function(t,i){e(t,i,s)}};const a4=new me("hasSymbols",!1,p("hasSymbols","Whether there are symbol locations that can be navigated via keyboard-only.")),wD=ut("ISymbolNavigationService");let MM=class{constructor(e,t,i,n){this._editorService=t,this._notificationService=i,this._keybindingService=n,this._currentModel=void 0,this._currentIdx=-1,this._ignoreEditorChange=!1,this._ctxHasSymbols=a4.bindTo(e)}reset(){var e,t;this._ctxHasSymbols.reset(),(e=this._currentState)===null||e===void 0||e.dispose(),(t=this._currentMessage)===null||t===void 0||t.dispose(),this._currentModel=void 0,this._currentIdx=-1}put(e){const t=e.parent.parent;if(t.references.length<=1){this.reset();return}this._currentModel=t,this._currentIdx=t.references.indexOf(e),this._ctxHasSymbols.set(!0),this._showMessage();const i=new RM(this._editorService),n=i.onDidChange(o=>{if(this._ignoreEditorChange)return;const r=this._editorService.getActiveCodeEditor();if(!r)return;const a=r.getModel(),l=r.getPosition();if(!a||!l)return;let d=!1,c=!1;for(const u of t.references)if(PP(u.uri,a.uri))d=!0,c=c||D.containsPosition(u.range,l);else if(d)break;(!d||!c)&&this.reset()});this._currentState=Gr(i,n)}revealNext(e){if(!this._currentModel)return Promise.resolve();this._currentIdx+=1,this._currentIdx%=this._currentModel.references.length;const t=this._currentModel.references[this._currentIdx];return this._showMessage(),this._ignoreEditorChange=!0,this._editorService.openCodeEditor({resource:t.uri,options:{selection:D.collapseToStart(t.range),selectionRevealType:3}},e).finally(()=>{this._ignoreEditorChange=!1})}_showMessage(){var e;(e=this._currentMessage)===null||e===void 0||e.dispose();const t=this._keybindingService.lookupKeybinding("editor.gotoNextSymbolFromResult"),i=t?p("location.kb","Symbol {0} of {1}, {2} for next",this._currentIdx+1,this._currentModel.references.length,t.getLabel()):p("location","Symbol {0} of {1}",this._currentIdx+1,this._currentModel.references.length);this._currentMessage=this._notificationService.status(i)}};MM=bj([wv(0,je),wv(1,It),wv(2,Qi),wv(3,qt)],MM);_t(wD,MM,1);ue(new class extends Nn{constructor(){super({id:"editor.gotoNextSymbolFromResult",precondition:a4,kbOpts:{weight:100,primary:70}})}runEditorCommand(s,e){return s.get(wD).revealNext(e)}});Js.registerCommandAndKeybindingRule({id:"editor.gotoNextSymbolFromResult.cancel",weight:100,when:a4,primary:9,handler(s){s.get(wD).reset()}});let RM=class{constructor(e){this._listener=new Map,this._disposables=new ie,this._onDidChange=new W,this.onDidChange=this._onDidChange.event,this._disposables.add(e.onCodeEditorRemove(this._onDidRemoveEditor,this)),this._disposables.add(e.onCodeEditorAdd(this._onDidAddEditor,this)),e.listCodeEditors().forEach(this._onDidAddEditor,this)}dispose(){this._disposables.dispose(),this._onDidChange.dispose(),Bt(this._listener.values())}_onDidAddEditor(e){this._listener.set(e,Gr(e.onDidChangeCursorPosition(t=>this._onDidChange.fire({editor:e})),e.onDidChangeModelContent(t=>this._onDidChange.fire({editor:e}))))}_onDidRemoveEditor(e){var t;(t=this._listener.get(e))===null||t===void 0||t.dispose(),this._listener.delete(e)}};RM=bj([wv(0,It)],RM);async function BC(s,e,t,i){const o=t.ordered(s).map(a=>Promise.resolve(i(a,s,e)).then(void 0,l=>{Zi(l)})),r=await Promise.all(o);return Ba(r.flat())}function SD(s,e,t,i){return BC(e,t,s,(n,o,r)=>n.provideDefinition(o,r,i))}function Cj(s,e,t,i){return BC(e,t,s,(n,o,r)=>n.provideDeclaration(o,r,i))}function wj(s,e,t,i){return BC(e,t,s,(n,o,r)=>n.provideImplementation(o,r,i))}function Sj(s,e,t,i){return BC(e,t,s,(n,o,r)=>n.provideTypeDefinition(o,r,i))}function yD(s,e,t,i,n){return BC(e,t,s,async(o,r,a)=>{const l=await o.provideReferences(r,a,{includeDeclaration:!0},n);if(!i||!l||l.length!==2)return l;const d=await o.provideReferences(r,a,{includeDeclaration:!1},n);return d&&d.length===1?d:l})}async function WC(s){const e=await s(),t=new wo(e,""),i=t.references.map(n=>n.link);return t.dispose(),i}od("_executeDefinitionProvider",(s,e,t)=>{const i=s.get(xe),n=SD(i.definitionProvider,e,t,ct.None);return WC(()=>n)});od("_executeTypeDefinitionProvider",(s,e,t)=>{const i=s.get(xe),n=Sj(i.typeDefinitionProvider,e,t,ct.None);return WC(()=>n)});od("_executeDeclarationProvider",(s,e,t)=>{const i=s.get(xe),n=Cj(i.declarationProvider,e,t,ct.None);return WC(()=>n)});od("_executeReferenceProvider",(s,e,t)=>{const i=s.get(xe),n=yD(i.referenceProvider,e,t,!1,ct.None);return WC(()=>n)});od("_executeImplementationProvider",(s,e,t)=>{const i=s.get(xe),n=wj(i.implementationProvider,e,t,ct.None);return WC(()=>n)});var q_,G_,Z_,Z1,Y1,X1,Q1,J1;Wn.appendMenuItem(N.EditorContext,{submenu:N.EditorContextPeek,title:p("peek.submenu","Peek"),group:"navigation",order:100});class Bm{static is(e){return!e||typeof e!="object"?!1:!!(e instanceof Bm||H.isIPosition(e.position)&&e.model)}constructor(e,t){this.model=e,this.position=t}}class Cs extends Ga{static all(){return Cs._allSymbolNavigationCommands.values()}static _patchConfig(e){const t={...e,f1:!0};if(t.menu)for(const i of ht.wrap(t.menu))(i.id===N.EditorContext||i.id===N.EditorContextPeek)&&(i.when=ee.and(e.precondition,i.when));return t}constructor(e,t){super(Cs._patchConfig(t)),this.configuration=e,Cs._allSymbolNavigationCommands.set(t.id,this)}runEditorCommand(e,t,i,n){if(!t.hasModel())return Promise.resolve(void 0);const o=e.get(Qi),r=e.get(It),a=e.get(rh),l=e.get(wD),d=e.get(xe),c=e.get(We),u=t.getModel(),h=t.getPosition(),g=Bm.is(i)?i:new Bm(u,h),f=new Hu(t,5),m=sx(this._getLocationModel(d,g.model,g.position,f.token),f.token).then(async _=>{var v;if(!_||f.token.isCancellationRequested)return;Lo(_.ariaMessage);let b;if(_.referenceAt(u.uri,h)){const w=this._getAlternativeCommand(t);!Cs._activeAlternativeCommands.has(w)&&Cs._allSymbolNavigationCommands.has(w)&&(b=Cs._allSymbolNavigationCommands.get(w))}const C=_.references.length;if(C===0){if(!this.configuration.muteMessage){const w=u.getWordAtPosition(h);(v=Co.get(t))===null||v===void 0||v.showMessage(this._getNoResultFoundMessage(w),h)}}else if(C===1&&b)Cs._activeAlternativeCommands.add(this.desc.id),c.invokeFunction(w=>b.runEditorCommand(w,t,i,n).finally(()=>{Cs._activeAlternativeCommands.delete(this.desc.id)}));else return this._onResult(r,l,t,_,n)},_=>{o.error(_)}).finally(()=>{f.dispose()});return a.showWhile(m,250),m}async _onResult(e,t,i,n,o){const r=this._getGoToPreference(i);if(!(i instanceof $u)&&(this.configuration.openInPeek||r==="peek"&&n.references.length>1))this._openInPeek(i,n,o);else{const a=n.firstReference(),l=n.references.length>1&&r==="gotoAndPeek",d=await this._openReference(i,e,a,this.configuration.openToSide,!l);l&&d?this._openInPeek(d,n,o):n.dispose(),r==="goto"&&t.put(a)}}async _openReference(e,t,i,n,o){let r;if(GQ(i)&&(r=i.targetSelectionRange),r||(r=i.range),!r)return;const a=await t.openCodeEditor({resource:i.uri,options:{selection:D.collapseToStart(r),selectionRevealType:3,selectionSource:"code.jump"}},e,n);if(a){if(o){const l=a.getModel(),d=a.createDecorationsCollection([{range:r,options:{description:"symbol-navigate-action-highlight",className:"symbolHighlight"}}]);setTimeout(()=>{a.getModel()===l&&d.clear()},350)}return a}}_openInPeek(e,t,i){const n=Ku.get(e);n&&e.hasModel()?n.toggleWidget(i??e.getSelection(),gn(o=>Promise.resolve(t)),this.configuration.openInPeek):t.dispose()}}Cs._allSymbolNavigationCommands=new Map;Cs._activeAlternativeCommands=new Set;class VC extends Cs{async _getLocationModel(e,t,i,n){return new wo(await SD(e.definitionProvider,t,i,n),p("def.title","Definitions"))}_getNoResultFoundMessage(e){return e&&e.word?p("noResultWord","No definition found for '{0}'",e.word):p("generic.noResults","No definition found")}_getAlternativeCommand(e){return e.getOption(58).alternativeDefinitionCommand}_getGoToPreference(e){return e.getOption(58).multipleDefinitions}}di((q_=class extends VC{constructor(){super({openToSide:!1,openInPeek:!1,muteMessage:!1},{id:q_.id,title:{value:p("actions.goToDecl.label","Go to Definition"),original:"Go to Definition",mnemonicTitle:p({key:"miGotoDefinition",comment:["&& denotes a mnemonic"]},"Go to &&Definition")},precondition:ee.and(T.hasDefinitionProvider,T.isInWalkThroughSnippet.toNegated()),keybinding:[{when:T.editorTextFocus,primary:70,weight:100},{when:ee.and(T.editorTextFocus,gU),primary:2118,weight:100}],menu:[{id:N.EditorContext,group:"navigation",order:1.1},{id:N.MenubarGoMenu,precondition:null,group:"4_symbol_nav",order:2}]}),Ct.registerCommandAlias("editor.action.goToDeclaration",q_.id)}},q_.id="editor.action.revealDefinition",q_));di((G_=class extends VC{constructor(){super({openToSide:!0,openInPeek:!1,muteMessage:!1},{id:G_.id,title:{value:p("actions.goToDeclToSide.label","Open Definition to the Side"),original:"Open Definition to the Side"},precondition:ee.and(T.hasDefinitionProvider,T.isInWalkThroughSnippet.toNegated()),keybinding:[{when:T.editorTextFocus,primary:dn(2089,70),weight:100},{when:ee.and(T.editorTextFocus,gU),primary:dn(2089,2118),weight:100}]}),Ct.registerCommandAlias("editor.action.openDeclarationToTheSide",G_.id)}},G_.id="editor.action.revealDefinitionAside",G_));di((Z_=class extends VC{constructor(){super({openToSide:!1,openInPeek:!0,muteMessage:!1},{id:Z_.id,title:{value:p("actions.previewDecl.label","Peek Definition"),original:"Peek Definition"},precondition:ee.and(T.hasDefinitionProvider,eo.notInPeekEditor,T.isInWalkThroughSnippet.toNegated()),keybinding:{when:T.editorTextFocus,primary:582,linux:{primary:3140},weight:100},menu:{id:N.EditorContextPeek,group:"peek",order:2}}),Ct.registerCommandAlias("editor.action.previewDeclaration",Z_.id)}},Z_.id="editor.action.peekDefinition",Z_));class yj extends Cs{async _getLocationModel(e,t,i,n){return new wo(await Cj(e.declarationProvider,t,i,n),p("decl.title","Declarations"))}_getNoResultFoundMessage(e){return e&&e.word?p("decl.noResultWord","No declaration found for '{0}'",e.word):p("decl.generic.noResults","No declaration found")}_getAlternativeCommand(e){return e.getOption(58).alternativeDeclarationCommand}_getGoToPreference(e){return e.getOption(58).multipleDeclarations}}di((Z1=class extends yj{constructor(){super({openToSide:!1,openInPeek:!1,muteMessage:!1},{id:Z1.id,title:{value:p("actions.goToDeclaration.label","Go to Declaration"),original:"Go to Declaration",mnemonicTitle:p({key:"miGotoDeclaration",comment:["&& denotes a mnemonic"]},"Go to &&Declaration")},precondition:ee.and(T.hasDeclarationProvider,T.isInWalkThroughSnippet.toNegated()),menu:[{id:N.EditorContext,group:"navigation",order:1.3},{id:N.MenubarGoMenu,precondition:null,group:"4_symbol_nav",order:3}]})}_getNoResultFoundMessage(e){return e&&e.word?p("decl.noResultWord","No declaration found for '{0}'",e.word):p("decl.generic.noResults","No declaration found")}},Z1.id="editor.action.revealDeclaration",Z1));di(class extends yj{constructor(){super({openToSide:!1,openInPeek:!0,muteMessage:!1},{id:"editor.action.peekDeclaration",title:{value:p("actions.peekDecl.label","Peek Declaration"),original:"Peek Declaration"},precondition:ee.and(T.hasDeclarationProvider,eo.notInPeekEditor,T.isInWalkThroughSnippet.toNegated()),menu:{id:N.EditorContextPeek,group:"peek",order:3}})}});class Lj extends Cs{async _getLocationModel(e,t,i,n){return new wo(await Sj(e.typeDefinitionProvider,t,i,n),p("typedef.title","Type Definitions"))}_getNoResultFoundMessage(e){return e&&e.word?p("goToTypeDefinition.noResultWord","No type definition found for '{0}'",e.word):p("goToTypeDefinition.generic.noResults","No type definition found")}_getAlternativeCommand(e){return e.getOption(58).alternativeTypeDefinitionCommand}_getGoToPreference(e){return e.getOption(58).multipleTypeDefinitions}}di((Y1=class extends Lj{constructor(){super({openToSide:!1,openInPeek:!1,muteMessage:!1},{id:Y1.ID,title:{value:p("actions.goToTypeDefinition.label","Go to Type Definition"),original:"Go to Type Definition",mnemonicTitle:p({key:"miGotoTypeDefinition",comment:["&& denotes a mnemonic"]},"Go to &&Type Definition")},precondition:ee.and(T.hasTypeDefinitionProvider,T.isInWalkThroughSnippet.toNegated()),keybinding:{when:T.editorTextFocus,primary:0,weight:100},menu:[{id:N.EditorContext,group:"navigation",order:1.4},{id:N.MenubarGoMenu,precondition:null,group:"4_symbol_nav",order:3}]})}},Y1.ID="editor.action.goToTypeDefinition",Y1));di((X1=class extends Lj{constructor(){super({openToSide:!1,openInPeek:!0,muteMessage:!1},{id:X1.ID,title:{value:p("actions.peekTypeDefinition.label","Peek Type Definition"),original:"Peek Type Definition"},precondition:ee.and(T.hasTypeDefinitionProvider,eo.notInPeekEditor,T.isInWalkThroughSnippet.toNegated()),menu:{id:N.EditorContextPeek,group:"peek",order:4}})}},X1.ID="editor.action.peekTypeDefinition",X1));class xj extends Cs{async _getLocationModel(e,t,i,n){return new wo(await wj(e.implementationProvider,t,i,n),p("impl.title","Implementations"))}_getNoResultFoundMessage(e){return e&&e.word?p("goToImplementation.noResultWord","No implementation found for '{0}'",e.word):p("goToImplementation.generic.noResults","No implementation found")}_getAlternativeCommand(e){return e.getOption(58).alternativeImplementationCommand}_getGoToPreference(e){return e.getOption(58).multipleImplementations}}di((Q1=class extends xj{constructor(){super({openToSide:!1,openInPeek:!1,muteMessage:!1},{id:Q1.ID,title:{value:p("actions.goToImplementation.label","Go to Implementations"),original:"Go to Implementations",mnemonicTitle:p({key:"miGotoImplementation",comment:["&& denotes a mnemonic"]},"Go to &&Implementations")},precondition:ee.and(T.hasImplementationProvider,T.isInWalkThroughSnippet.toNegated()),keybinding:{when:T.editorTextFocus,primary:2118,weight:100},menu:[{id:N.EditorContext,group:"navigation",order:1.45},{id:N.MenubarGoMenu,precondition:null,group:"4_symbol_nav",order:4}]})}},Q1.ID="editor.action.goToImplementation",Q1));di((J1=class extends xj{constructor(){super({openToSide:!1,openInPeek:!0,muteMessage:!1},{id:J1.ID,title:{value:p("actions.peekImplementation.label","Peek Implementations"),original:"Peek Implementations"},precondition:ee.and(T.hasImplementationProvider,eo.notInPeekEditor,T.isInWalkThroughSnippet.toNegated()),keybinding:{when:T.editorTextFocus,primary:3142,weight:100},menu:{id:N.EditorContextPeek,group:"peek",order:5}})}},J1.ID="editor.action.peekImplementation",J1));class Dj extends Cs{_getNoResultFoundMessage(e){return e?p("references.no","No references found for '{0}'",e.word):p("references.noGeneric","No references found")}_getAlternativeCommand(e){return e.getOption(58).alternativeReferenceCommand}_getGoToPreference(e){return e.getOption(58).multipleReferences}}di(class extends Dj{constructor(){super({openToSide:!1,openInPeek:!1,muteMessage:!1},{id:"editor.action.goToReferences",title:{value:p("goToReferences.label","Go to References"),original:"Go to References",mnemonicTitle:p({key:"miGotoReference",comment:["&& denotes a mnemonic"]},"Go to &&References")},precondition:ee.and(T.hasReferenceProvider,eo.notInPeekEditor,T.isInWalkThroughSnippet.toNegated()),keybinding:{when:T.editorTextFocus,primary:1094,weight:100},menu:[{id:N.EditorContext,group:"navigation",order:1.45},{id:N.MenubarGoMenu,precondition:null,group:"4_symbol_nav",order:5}]})}async _getLocationModel(e,t,i,n){return new wo(await yD(e.referenceProvider,t,i,!0,n),p("ref.title","References"))}});di(class extends Dj{constructor(){super({openToSide:!1,openInPeek:!0,muteMessage:!1},{id:"editor.action.referenceSearch.trigger",title:{value:p("references.action.label","Peek References"),original:"Peek References"},precondition:ee.and(T.hasReferenceProvider,eo.notInPeekEditor,T.isInWalkThroughSnippet.toNegated()),menu:{id:N.EditorContextPeek,group:"peek",order:6}})}async _getLocationModel(e,t,i,n){return new wo(await yD(e.referenceProvider,t,i,!1,n),p("ref.title","References"))}});class n1e extends Cs{constructor(e,t,i){super(e,{id:"editor.action.goToLocation",title:{value:p("label.generic","Go to Any Symbol"),original:"Go to Any Symbol"},precondition:ee.and(eo.notInPeekEditor,T.isInWalkThroughSnippet.toNegated())}),this._references=t,this._gotoMultipleBehaviour=i}async _getLocationModel(e,t,i,n){return new wo(this._references,p("generic.title","Locations"))}_getNoResultFoundMessage(e){return e&&p("generic.noResult","No results for '{0}'",e.word)||""}_getGoToPreference(e){var t;return(t=this._gotoMultipleBehaviour)!==null&&t!==void 0?t:e.getOption(58).multipleReferences}_getAlternativeCommand(){return""}}Ct.registerCommand({id:"editor.action.goToLocations",metadata:{description:"Go to locations from a position in a file",args:[{name:"uri",description:"The text document in which to start",constraint:Pe},{name:"position",description:"The position at which to start",constraint:H.isIPosition},{name:"locations",description:"An array of locations.",constraint:Array},{name:"multiple",description:"Define what to do when having multiple results, either `peek`, `gotoAndPeek`, or `goto"},{name:"noResultsMessage",description:"Human readable message that shows when locations is empty."}]},handler:async(s,e,t,i,n,o,r)=>{zt(Pe.isUri(e)),zt(H.isIPosition(t)),zt(Array.isArray(i)),zt(typeof n>"u"||typeof n=="string"),zt(typeof r>"u"||typeof r=="boolean");const a=s.get(It),l=await a.openCodeEditor({resource:e},a.getFocusedCodeEditor());if(td(l))return l.setPosition(t),l.revealPositionInCenterIfOutsideViewport(t,0),l.invokeWithinContext(d=>{const c=new class extends n1e{_getNoResultFoundMessage(u){return o||super._getNoResultFoundMessage(u)}}({muteMessage:!o,openInPeek:!!r,openToSide:!1},i,n);d.get(We).invokeFunction(c.run.bind(c),l)})}});Ct.registerCommand({id:"editor.action.peekLocations",metadata:{description:"Peek locations from a position in a file",args:[{name:"uri",description:"The text document in which to start",constraint:Pe},{name:"position",description:"The position at which to start",constraint:H.isIPosition},{name:"locations",description:"An array of locations.",constraint:Array},{name:"multiple",description:"Define what to do when having multiple results, either `peek`, `gotoAndPeek`, or `goto"}]},handler:async(s,e,t,i,n)=>{s.get(Ei).executeCommand("editor.action.goToLocations",e,t,i,n,void 0,!0)}});Ct.registerCommand({id:"editor.action.findReferences",handler:(s,e,t)=>{zt(Pe.isUri(e)),zt(H.isIPosition(t));const i=s.get(xe),n=s.get(It);return n.openCodeEditor({resource:e},n.getFocusedCodeEditor()).then(o=>{if(!td(o)||!o.hasModel())return;const r=Ku.get(o);if(!r)return;const a=gn(d=>yD(i.referenceProvider,o.getModel(),H.lift(t),!1,d).then(c=>new wo(c,p("ref.title","References")))),l=new D(t.lineNumber,t.column,t.lineNumber,t.column);return Promise.resolve(r.toggleWidget(l,a,!1))})}});Ct.registerCommandAlias("editor.action.showReferences","editor.action.peekLocations");var s1e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},rE=function(s,e){return function(t,i){e(t,i,s)}},Sv;let Kg=Sv=class{constructor(e,t,i,n){this.textModelResolverService=t,this.languageService=i,this.languageFeaturesService=n,this.toUnhook=new ie,this.toUnhookForKeyboard=new ie,this.currentWordAtPosition=null,this.previousPromise=null,this.editor=e,this.linkDecorations=this.editor.createDecorationsCollection();const o=new mD(e);this.toUnhook.add(o),this.toUnhook.add(o.onMouseMoveOrRelevantKeyDown(([r,a])=>{this.startFindDefinitionFromMouse(r,a??void 0)})),this.toUnhook.add(o.onExecute(r=>{this.isEnabled(r)&&this.gotoDefinition(r.target.position,r.hasSideBySideModifier).catch(a=>{et(a)}).finally(()=>{this.removeLinkDecorations()})})),this.toUnhook.add(o.onCancel(()=>{this.removeLinkDecorations(),this.currentWordAtPosition=null}))}static get(e){return e.getContribution(Sv.ID)}async startFindDefinitionFromCursor(e){await this.startFindDefinition(e),this.toUnhookForKeyboard.add(this.editor.onDidChangeCursorPosition(()=>{this.currentWordAtPosition=null,this.removeLinkDecorations(),this.toUnhookForKeyboard.clear()})),this.toUnhookForKeyboard.add(this.editor.onKeyDown(t=>{t&&(this.currentWordAtPosition=null,this.removeLinkDecorations(),this.toUnhookForKeyboard.clear())}))}startFindDefinitionFromMouse(e,t){if(e.target.type===9&&this.linkDecorations.length>0)return;if(!this.editor.hasModel()||!this.isEnabled(e,t)){this.currentWordAtPosition=null,this.removeLinkDecorations();return}const i=e.target.position;this.startFindDefinition(i)}async startFindDefinition(e){var t;this.toUnhookForKeyboard.clear();const i=e?(t=this.editor.getModel())===null||t===void 0?void 0:t.getWordAtPosition(e):null;if(!i){this.currentWordAtPosition=null,this.removeLinkDecorations();return}if(this.currentWordAtPosition&&this.currentWordAtPosition.startColumn===i.startColumn&&this.currentWordAtPosition.endColumn===i.endColumn&&this.currentWordAtPosition.word===i.word)return;this.currentWordAtPosition=i;const n=new e$(this.editor,15);this.previousPromise&&(this.previousPromise.cancel(),this.previousPromise=null),this.previousPromise=gn(a=>this.findDefinition(e,a));let o;try{o=await this.previousPromise}catch(a){et(a);return}if(!o||!o.length||!n.validate(this.editor)){this.removeLinkDecorations();return}const r=o[0].originSelectionRange?D.lift(o[0].originSelectionRange):new D(e.lineNumber,i.startColumn,e.lineNumber,i.endColumn);if(o.length>1){let a=r;for(const{originSelectionRange:l}of o)l&&(a=D.plusRange(a,l));this.addDecoration(a,new rs().appendText(p("multipleResults","Click to show {0} definitions.",o.length)))}else{const a=o[0];if(!a.uri)return;this.textModelResolverService.createModelReference(a.uri).then(l=>{if(!l.object||!l.object.textEditorModel){l.dispose();return}const{object:{textEditorModel:d}}=l,{startLineNumber:c}=a.range;if(c<1||c>d.getLineCount()){l.dispose();return}const u=this.getPreviewValue(d,c,a),h=this.languageService.guessLanguageIdByFilepathOrFirstLine(d.uri);this.addDecoration(r,u?new rs().appendCodeblock(h||"",u):void 0),l.dispose()})}}getPreviewValue(e,t,i){let n=i.range;return n.endLineNumber-n.startLineNumber>=Sv.MAX_SOURCE_PREVIEW_LINES&&(n=this.getPreviewRangeBasedOnIndentation(e,t)),this.stripIndentationFromPreviewRange(e,t,n)}stripIndentationFromPreviewRange(e,t,i){let o=e.getLineFirstNonWhitespaceColumn(t);for(let a=t+1;a<i.endLineNumber;a++){const l=e.getLineFirstNonWhitespaceColumn(a);o=Math.min(o,l)}return e.getValueInRange(i).replace(new RegExp(`^\\s{${o-1}}`,"gm"),"").trim()}getPreviewRangeBasedOnIndentation(e,t){const i=e.getLineFirstNonWhitespaceColumn(t),n=Math.min(e.getLineCount(),t+Sv.MAX_SOURCE_PREVIEW_LINES);let o=t+1;for(;o<n;o++){const r=e.getLineFirstNonWhitespaceColumn(o);if(i===r)break}return new D(t,1,o+1,1)}addDecoration(e,t){const i={range:e,options:{description:"goto-definition-link",inlineClassName:"goto-definition-link",hoverMessage:t}};this.linkDecorations.set([i])}removeLinkDecorations(){this.linkDecorations.clear()}isEnabled(e,t){var i;return this.editor.hasModel()&&e.isLeftClick&&e.isNoneOrSingleMouseDown&&e.target.type===6&&!(((i=e.target.detail.injectedText)===null||i===void 0?void 0:i.options)instanceof Wu)&&(e.hasTriggerModifier||(t?t.keyCodeIsTriggerKey:!1))&&this.languageFeaturesService.definitionProvider.has(this.editor.getModel())}findDefinition(e,t){const i=this.editor.getModel();return i?SD(this.languageFeaturesService.definitionProvider,i,e,t):Promise.resolve(null)}gotoDefinition(e,t){return this.editor.setPosition(e),this.editor.invokeWithinContext(i=>{const n=!t&&this.editor.getOption(87)&&!this.isInPeekEditor(i);return new VC({openToSide:t,openInPeek:n,muteMessage:!0},{title:{value:"",original:""},id:"",precondition:void 0}).run(i)})}isInPeekEditor(e){const t=e.get(je);return eo.inPeekEditor.getValue(t)}dispose(){this.toUnhook.dispose(),this.toUnhookForKeyboard.dispose()}};Kg.ID="editor.contrib.gotodefinitionatposition";Kg.MAX_SOURCE_PREVIEW_LINES=8;Kg=Sv=s1e([rE(1,io),rE(2,fi),rE(3,xe)],Kg);Lt(Kg.ID,Kg,2);const ew=se;class kj extends j{constructor(){super(),this.containerDomNode=document.createElement("div"),this.containerDomNode.className="monaco-hover",this.containerDomNode.tabIndex=0,this.containerDomNode.setAttribute("role","tooltip"),this.contentsDomNode=document.createElement("div"),this.contentsDomNode.className="monaco-hover-content",this.scrollbar=this._register(new hC(this.contentsDomNode,{consumeMouseWheelIfScrollbarIsNeeded:!0})),this.containerDomNode.appendChild(this.scrollbar.getDomNode())}onContentsChanged(){this.scrollbar.scanDomNode()}}class l4 extends j{static render(e,t,i){return new l4(e,t,i)}constructor(e,t,i){super(),this.actionContainer=te(e,ew("div.action-container")),this.actionContainer.setAttribute("tabindex","0"),this.action=te(this.actionContainer,ew("a.action")),this.action.setAttribute("role","button"),t.iconClass&&te(this.action,ew(`span.icon.${t.iconClass}`));const n=te(this.action,ew("span"));n.textContent=i?`${t.label} (${i})`:t.label,this._register(Y(this.actionContainer,he.CLICK,o=>{o.stopPropagation(),o.preventDefault(),t.run(this.actionContainer)})),this._register(Y(this.actionContainer,he.KEY_DOWN,o=>{const r=new ri(o);(r.equals(3)||r.equals(10))&&(o.stopPropagation(),o.preventDefault(),t.run(this.actionContainer))})),this.setEnabled(!0)}setEnabled(e){e?(this.actionContainer.classList.remove("disabled"),this.actionContainer.removeAttribute("aria-disabled")):(this.actionContainer.classList.add("disabled"),this.actionContainer.setAttribute("aria-disabled","true"))}}function o1e(s,e){return s&&e?p("acessibleViewHint","Inspect this in the accessible view with {0}.",e):s?p("acessibleViewHintNoKbOpen","Inspect this in the accessible view via the command Open Accessible View which is currently not triggerable via keybinding."):""}let r1e=class{constructor(e,t,i){this.value=e,this.isComplete=t,this.hasLoadingMessage=i}};class Ij extends j{constructor(e,t){super(),this._editor=e,this._computer=t,this._onResult=this._register(new W),this.onResult=this._onResult.event,this._firstWaitScheduler=this._register(new jt(()=>this._triggerAsyncComputation(),0)),this._secondWaitScheduler=this._register(new jt(()=>this._triggerSyncComputation(),0)),this._loadingMessageScheduler=this._register(new jt(()=>this._triggerLoadingMessage(),0)),this._state=0,this._asyncIterable=null,this._asyncIterableDone=!1,this._result=[]}dispose(){this._asyncIterable&&(this._asyncIterable.cancel(),this._asyncIterable=null),super.dispose()}get _hoverTime(){return this._editor.getOption(60).delay}get _firstWaitTime(){return this._hoverTime/2}get _secondWaitTime(){return this._hoverTime-this._firstWaitTime}get _loadingMessageTime(){return 3*this._hoverTime}_setState(e,t=!0){this._state=e,t&&this._fireResult()}_triggerAsyncComputation(){this._setState(2),this._secondWaitScheduler.schedule(this._secondWaitTime),this._computer.computeAsync?(this._asyncIterableDone=!1,this._asyncIterable=ree(e=>this._computer.computeAsync(e)),(async()=>{try{for await(const e of this._asyncIterable)e&&(this._result.push(e),this._fireResult());this._asyncIterableDone=!0,(this._state===3||this._state===4)&&this._setState(0)}catch(e){et(e)}})()):this._asyncIterableDone=!0}_triggerSyncComputation(){this._computer.computeSync&&(this._result=this._result.concat(this._computer.computeSync())),this._setState(this._asyncIterableDone?0:3)}_triggerLoadingMessage(){this._state===3&&this._setState(4)}_fireResult(){if(this._state===1||this._state===2)return;const e=this._state===0,t=this._state===4;this._onResult.fire(new r1e(this._result.slice(0),e,t))}start(e){if(e===0)this._state===0&&(this._setState(1),this._firstWaitScheduler.schedule(this._firstWaitTime),this._loadingMessageScheduler.schedule(this._loadingMessageTime));else switch(this._state){case 0:this._triggerAsyncComputation(),this._secondWaitScheduler.cancel(),this._triggerSyncComputation();break;case 2:this._secondWaitScheduler.cancel(),this._triggerSyncComputation();break}}cancel(){this._firstWaitScheduler.cancel(),this._secondWaitScheduler.cancel(),this._loadingMessageScheduler.cancel(),this._asyncIterable&&(this._asyncIterable.cancel(),this._asyncIterable=null),this._result=[],this._setState(0,!1)}}class aE{constructor(e,t,i,n){this.priority=e,this.range=t,this.initialMousePosX=i,this.initialMousePosY=n,this.type=1}equals(e){return e.type===1&&this.range.equalsRange(e.range)}canAdoptVisibleHover(e,t){return e.type===1&&t.lineNumber===this.range.startLineNumber}}class sS{constructor(e,t,i,n,o,r){this.priority=e,this.owner=t,this.range=i,this.initialMousePosX=n,this.initialMousePosY=o,this.supportsMarkerHover=r,this.type=2}equals(e){return e.type===2&&this.owner===e.owner}canAdoptVisibleHover(e,t){return e.type===2&&this.owner===e.owner}}const wf=new class{constructor(){this._participants=[]}register(e){this._participants.push(e)}getAll(){return this._participants}};class d4{constructor(){this._onDidWillResize=new W,this.onDidWillResize=this._onDidWillResize.event,this._onDidResize=new W,this.onDidResize=this._onDidResize.event,this._sashListener=new ie,this._size=new Dt(0,0),this._minSize=new Dt(0,0),this._maxSize=new Dt(Number.MAX_SAFE_INTEGER,Number.MAX_SAFE_INTEGER),this.domNode=document.createElement("div"),this._eastSash=new ns(this.domNode,{getVerticalSashLeft:()=>this._size.width},{orientation:0}),this._westSash=new ns(this.domNode,{getVerticalSashLeft:()=>0},{orientation:0}),this._northSash=new ns(this.domNode,{getHorizontalSashTop:()=>0},{orientation:1,orthogonalEdge:My.North}),this._southSash=new ns(this.domNode,{getHorizontalSashTop:()=>this._size.height},{orientation:1,orthogonalEdge:My.South}),this._northSash.orthogonalStartSash=this._westSash,this._northSash.orthogonalEndSash=this._eastSash,this._southSash.orthogonalStartSash=this._westSash,this._southSash.orthogonalEndSash=this._eastSash;let e,t=0,i=0;this._sashListener.add(ge.any(this._northSash.onDidStart,this._eastSash.onDidStart,this._southSash.onDidStart,this._westSash.onDidStart)(()=>{e===void 0&&(this._onDidWillResize.fire(),e=this._size,t=0,i=0)})),this._sashListener.add(ge.any(this._northSash.onDidEnd,this._eastSash.onDidEnd,this._southSash.onDidEnd,this._westSash.onDidEnd)(()=>{e!==void 0&&(e=void 0,t=0,i=0,this._onDidResize.fire({dimension:this._size,done:!0}))})),this._sashListener.add(this._eastSash.onDidChange(n=>{e&&(i=n.currentX-n.startX,this.layout(e.height+t,e.width+i),this._onDidResize.fire({dimension:this._size,done:!1,east:!0}))})),this._sashListener.add(this._westSash.onDidChange(n=>{e&&(i=-(n.currentX-n.startX),this.layout(e.height+t,e.width+i),this._onDidResize.fire({dimension:this._size,done:!1,west:!0}))})),this._sashListener.add(this._northSash.onDidChange(n=>{e&&(t=-(n.currentY-n.startY),this.layout(e.height+t,e.width+i),this._onDidResize.fire({dimension:this._size,done:!1,north:!0}))})),this._sashListener.add(this._southSash.onDidChange(n=>{e&&(t=n.currentY-n.startY,this.layout(e.height+t,e.width+i),this._onDidResize.fire({dimension:this._size,done:!1,south:!0}))})),this._sashListener.add(ge.any(this._eastSash.onDidReset,this._westSash.onDidReset)(n=>{this._preferredSize&&(this.layout(this._size.height,this._preferredSize.width),this._onDidResize.fire({dimension:this._size,done:!0}))})),this._sashListener.add(ge.any(this._northSash.onDidReset,this._southSash.onDidReset)(n=>{this._preferredSize&&(this.layout(this._preferredSize.height,this._size.width),this._onDidResize.fire({dimension:this._size,done:!0}))}))}dispose(){this._northSash.dispose(),this._southSash.dispose(),this._eastSash.dispose(),this._westSash.dispose(),this._sashListener.dispose(),this._onDidResize.dispose(),this._onDidWillResize.dispose(),this.domNode.remove()}enableSashes(e,t,i,n){this._northSash.state=e?3:0,this._eastSash.state=t?3:0,this._southSash.state=i?3:0,this._westSash.state=n?3:0}layout(e=this.size.height,t=this.size.width){const{height:i,width:n}=this._minSize,{height:o,width:r}=this._maxSize;e=Math.max(i,Math.min(o,e)),t=Math.max(n,Math.min(r,t));const a=new Dt(t,e);Dt.equals(a,this._size)||(this.domNode.style.height=e+"px",this.domNode.style.width=t+"px",this._size=a,this._northSash.layout(),this._eastSash.layout(),this._southSash.layout(),this._westSash.layout())}clearSashHoverState(){this._eastSash.clearSashHoverState(),this._westSash.clearSashHoverState(),this._northSash.clearSashHoverState(),this._southSash.clearSashHoverState()}get size(){return this._size}set maxSize(e){this._maxSize=e}get maxSize(){return this._maxSize}set minSize(e){this._minSize=e}get minSize(){return this._minSize}set preferredSize(e){this._preferredSize=e}get preferredSize(){return this._preferredSize}}const a1e=30,l1e=24;class d1e extends j{constructor(e,t=new Dt(10,10)){super(),this._editor=e,this.allowEditorOverflow=!0,this.suppressMouseDown=!1,this._resizableNode=this._register(new d4),this._contentPosition=null,this._isResizing=!1,this._resizableNode.domNode.style.position="absolute",this._resizableNode.minSize=Dt.lift(t),this._resizableNode.layout(t.height,t.width),this._resizableNode.enableSashes(!0,!0,!0,!0),this._register(this._resizableNode.onDidResize(i=>{this._resize(new Dt(i.dimension.width,i.dimension.height)),i.done&&(this._isResizing=!1)})),this._register(this._resizableNode.onDidWillResize(()=>{this._isResizing=!0}))}get isResizing(){return this._isResizing}getDomNode(){return this._resizableNode.domNode}getPosition(){return this._contentPosition}get position(){var e;return!((e=this._contentPosition)===null||e===void 0)&&e.position?H.lift(this._contentPosition.position):void 0}_availableVerticalSpaceAbove(e){const t=this._editor.getDomNode(),i=this._editor.getScrolledVisiblePosition(e);return!t||!i?void 0:ln(t).top+i.top-a1e}_availableVerticalSpaceBelow(e){const t=this._editor.getDomNode(),i=this._editor.getScrolledVisiblePosition(e);if(!t||!i)return;const n=ln(t),o=Nu(t.ownerDocument.body),r=n.top+i.top+i.height;return o.height-r-l1e}_findPositionPreference(e,t){var i,n;const o=Math.min((i=this._availableVerticalSpaceBelow(t))!==null&&i!==void 0?i:1/0,e),r=Math.min((n=this._availableVerticalSpaceAbove(t))!==null&&n!==void 0?n:1/0,e),a=Math.min(Math.max(r,o),e),l=Math.min(e,a);let d;return this._editor.getOption(60).above?d=l<=r?1:2:d=l<=o?2:1,d===1?this._resizableNode.enableSashes(!0,!0,!1,!1):this._resizableNode.enableSashes(!1,!0,!0,!1),d}_resize(e){this._resizableNode.layout(e.height,e.width)}}var c4=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},ag=function(s,e){return function(t,i){e(t,i,s)}},oS,al;const B8=se;let oL=oS=class extends j{constructor(e,t,i){super(),this._editor=e,this._instantiationService=t,this._keybindingService=i,this._currentResult=null,this._widget=this._register(this._instantiationService.createInstance(_u,this._editor)),this._participants=[];for(const n of wf.getAll())this._participants.push(this._instantiationService.createInstance(n,this._editor));this._participants.sort((n,o)=>n.hoverOrdinal-o.hoverOrdinal),this._computer=new aL(this._editor,this._participants),this._hoverOperation=this._register(new Ij(this._editor,this._computer)),this._register(this._hoverOperation.onResult(n=>{if(!this._computer.anchor)return;const o=n.hasLoadingMessage?this._addLoadingMessage(n.value):n.value;this._withResult(new Ej(this._computer.anchor,o,n.isComplete))})),this._register(Pi(this._widget.getDomNode(),"keydown",n=>{n.equals(9)&&this.hide()})),this._register(xi.onDidChange(()=>{this._widget.position&&this._currentResult&&this._setCurrentResult(this._currentResult)}))}get widget(){return this._widget}maybeShowAt(e){if(this._widget.isResizing)return!0;const t=[];for(const n of this._participants)if(n.suggestHoverAnchor){const o=n.suggestHoverAnchor(e);o&&t.push(o)}const i=e.target;if(i.type===6&&t.push(new aE(0,i.range,e.event.posx,e.event.posy)),i.type===7){const n=this._editor.getOption(50).typicalHalfwidthCharacterWidth/2;!i.detail.isAfterLines&&typeof i.detail.horizontalDistanceToText=="number"&&i.detail.horizontalDistanceToText<n&&t.push(new aE(0,i.range,e.event.posx,e.event.posy))}return t.length===0?this._startShowingOrUpdateHover(null,0,0,!1,e):(t.sort((n,o)=>o.priority-n.priority),this._startShowingOrUpdateHover(t[0],0,0,!1,e))}startShowingAtRange(e,t,i,n){this._startShowingOrUpdateHover(new aE(0,e,void 0,void 0),t,i,n,null)}_startShowingOrUpdateHover(e,t,i,n,o){return!this._widget.position||!this._currentResult?e?(this._startHoverOperationIfNecessary(e,t,i,n,!1),!0):!1:this._editor.getOption(60).sticky&&o&&this._widget.isMouseGettingCloser(o.event.posx,o.event.posy)?(e&&this._startHoverOperationIfNecessary(e,t,i,n,!0),!0):e?e&&this._currentResult.anchor.equals(e)?!0:e.canAdoptVisibleHover(this._currentResult.anchor,this._widget.position)?(this._setCurrentResult(this._currentResult.filter(e)),this._startHoverOperationIfNecessary(e,t,i,n,!1),!0):(this._setCurrentResult(null),this._startHoverOperationIfNecessary(e,t,i,n,!1),!0):(this._setCurrentResult(null),!1)}_startHoverOperationIfNecessary(e,t,i,n,o){this._computer.anchor&&this._computer.anchor.equals(e)||(this._hoverOperation.cancel(),this._computer.anchor=e,this._computer.shouldFocus=n,this._computer.source=i,this._computer.insistOnKeepingHoverVisible=o,this._hoverOperation.start(t))}_setCurrentResult(e){this._currentResult!==e&&(e&&e.messages.length===0&&(e=null),this._currentResult=e,this._currentResult?this._renderMessages(this._currentResult.anchor,this._currentResult.messages):this._widget.hide())}hide(){this._computer.anchor=null,this._hoverOperation.cancel(),this._setCurrentResult(null)}get isColorPickerVisible(){return this._widget.isColorPickerVisible}get isVisibleFromKeyboard(){return this._widget.isVisibleFromKeyboard}get isVisible(){return this._widget.isVisible}get isFocused(){return this._widget.isFocused}get isResizing(){return this._widget.isResizing}containsNode(e){return e?this._widget.getDomNode().contains(e):!1}_addLoadingMessage(e){if(this._computer.anchor){for(const t of this._participants)if(t.createLoadingMessage){const i=t.createLoadingMessage(this._computer.anchor);if(i)return e.slice(0).concat([i])}}return e}_withResult(e){this._widget.position&&this._currentResult&&this._currentResult.isComplete&&(!e.isComplete||this._computer.insistOnKeepingHoverVisible&&e.messages.length===0)||this._setCurrentResult(e)}_renderMessages(e,t){const{showAtPosition:i,showAtSecondaryPosition:n,highlightRange:o}=oS.computeHoverRanges(this._editor,e.range,t),r=new ie,a=r.add(new rL(this._keybindingService)),l=document.createDocumentFragment();let d=null;const c={fragment:l,statusBar:a,setColorPicker:h=>d=h,onContentsChanged:()=>this._widget.onContentsChanged(),setMinimumDimensions:h=>this._widget.setMinimumDimensions(h),hide:()=>this.hide()};for(const h of this._participants){const g=t.filter(f=>f.owner===h);g.length>0&&r.add(h.renderHoverParts(c,g))}const u=t.some(h=>h.isBeforeContent);if(a.hasContent&&l.appendChild(a.hoverElement),l.hasChildNodes()){if(o){const h=this._editor.createDecorationsCollection();h.set([{range:o,options:oS._DECORATION_OPTIONS}]),r.add(Fe(()=>{h.clear()}))}this._widget.showAt(l,new u1e(d,i,n,this._editor.getOption(60).above,this._computer.shouldFocus,this._computer.source,u,e.initialMousePosX,e.initialMousePosY,r))}else r.dispose()}static computeHoverRanges(e,t,i){let n=1;if(e.hasModel()){const d=e._getViewModel(),c=d.coordinatesConverter,u=c.convertModelRangeToViewRange(t),h=new H(u.startLineNumber,d.getLineMinColumn(u.startLineNumber));n=c.convertViewPositionToModelPosition(h).column}const o=t.startLineNumber;let r=t.startColumn,a=i[0].range,l=null;for(const d of i)a=D.plusRange(a,d.range),d.range.startLineNumber===o&&d.range.endLineNumber===o&&(r=Math.max(Math.min(r,d.range.startColumn),n)),d.forceShowAtRange&&(l=d.range);return{showAtPosition:l?l.getStartPosition():new H(o,t.startColumn),showAtSecondaryPosition:l?l.getStartPosition():new H(o,r),highlightRange:a}}focus(){this._widget.focus()}scrollUp(){this._widget.scrollUp()}scrollDown(){this._widget.scrollDown()}scrollLeft(){this._widget.scrollLeft()}scrollRight(){this._widget.scrollRight()}pageUp(){this._widget.pageUp()}pageDown(){this._widget.pageDown()}goToTop(){this._widget.goToTop()}goToBottom(){this._widget.goToBottom()}};oL._DECORATION_OPTIONS=tt.register({description:"content-hover-highlight",className:"hoverHighlight"});oL=oS=c4([ag(1,We),ag(2,qt)],oL);class Ej{constructor(e,t,i){this.anchor=e,this.messages=t,this.isComplete=i}filter(e){const t=this.messages.filter(i=>i.isValidForHoverAnchor(e));return t.length===this.messages.length?this:new c1e(this,this.anchor,t,this.isComplete)}}class c1e extends Ej{constructor(e,t,i,n){super(t,i,n),this.original=e}filter(e){return this.original.filter(e)}}class u1e{constructor(e,t,i,n,o,r,a,l,d,c){this.colorPicker=e,this.showAtPosition=t,this.showAtSecondaryPosition=i,this.preferAbove=n,this.stoleFocus=o,this.source=r,this.isBeforeContent=a,this.initialMousePosX=l,this.initialMousePosY=d,this.disposables=c,this.closestMouseDistance=void 0}}const W8=30,lE=10,h1e=6;let _u=al=class extends d1e{get isColorPickerVisible(){var e;return!!(!((e=this._visibleData)===null||e===void 0)&&e.colorPicker)}get isVisibleFromKeyboard(){var e;return((e=this._visibleData)===null||e===void 0?void 0:e.source)===1}get isVisible(){var e;return(e=this._hoverVisibleKey.get())!==null&&e!==void 0?e:!1}get isFocused(){var e;return(e=this._hoverFocusedKey.get())!==null&&e!==void 0?e:!1}constructor(e,t,i,n,o){const r=e.getOption(66)+8,a=150,l=new Dt(a,r);super(e,l),this._configurationService=i,this._accessibilityService=n,this._keybindingService=o,this._hover=this._register(new kj),this._minimumSize=l,this._hoverVisibleKey=T.hoverVisible.bindTo(t),this._hoverFocusedKey=T.hoverFocused.bindTo(t),te(this._resizableNode.domNode,this._hover.containerDomNode),this._resizableNode.domNode.style.zIndex="50",this._register(this._editor.onDidLayoutChange(()=>{this.isVisible&&this._updateMaxDimensions()})),this._register(this._editor.onDidChangeConfiguration(c=>{c.hasChanged(50)&&this._updateFont()}));const d=this._register(ql(this._resizableNode.domNode));this._register(d.onDidFocus(()=>{this._hoverFocusedKey.set(!0)})),this._register(d.onDidBlur(()=>{this._hoverFocusedKey.set(!1)})),this._setHoverData(void 0),this._editor.addContentWidget(this)}dispose(){var e;super.dispose(),(e=this._visibleData)===null||e===void 0||e.disposables.dispose(),this._editor.removeContentWidget(this)}getId(){return al.ID}static _applyDimensions(e,t,i){const n=typeof t=="number"?`${t}px`:t,o=typeof i=="number"?`${i}px`:i;e.style.width=n,e.style.height=o}_setContentsDomNodeDimensions(e,t){const i=this._hover.contentsDomNode;return al._applyDimensions(i,e,t)}_setContainerDomNodeDimensions(e,t){const i=this._hover.containerDomNode;return al._applyDimensions(i,e,t)}_setHoverWidgetDimensions(e,t){this._setContentsDomNodeDimensions(e,t),this._setContainerDomNodeDimensions(e,t),this._layoutContentWidget()}static _applyMaxDimensions(e,t,i){const n=typeof t=="number"?`${t}px`:t,o=typeof i=="number"?`${i}px`:i;e.style.maxWidth=n,e.style.maxHeight=o}_setHoverWidgetMaxDimensions(e,t){al._applyMaxDimensions(this._hover.contentsDomNode,e,t),al._applyMaxDimensions(this._hover.containerDomNode,e,t),this._hover.containerDomNode.style.setProperty("--vscode-hover-maxWidth",typeof e=="number"?`${e}px`:e),this._layoutContentWidget()}_hasHorizontalScrollbar(){const e=this._hover.scrollbar.getScrollDimensions();return e.scrollWidth>e.width}_adjustContentsBottomPadding(){const e=this._hover.contentsDomNode,t=`${this._hover.scrollbar.options.horizontalScrollbarSize}px`;e.style.paddingBottom!==t&&(e.style.paddingBottom=t)}_setAdjustedHoverWidgetDimensions(e){this._setHoverWidgetMaxDimensions("none","none");const t=e.width,i=e.height;this._setHoverWidgetDimensions(t,i),this._hasHorizontalScrollbar()&&(this._adjustContentsBottomPadding(),this._setContentsDomNodeDimensions(t,i-lE))}_updateResizableNodeMaxDimensions(){var e,t;const i=(e=this._findMaximumRenderingWidth())!==null&&e!==void 0?e:1/0,n=(t=this._findMaximumRenderingHeight())!==null&&t!==void 0?t:1/0;this._resizableNode.maxSize=new Dt(i,n),this._setHoverWidgetMaxDimensions(i,n)}_resize(e){var t,i;al._lastDimensions=new Dt(e.width,e.height),this._setAdjustedHoverWidgetDimensions(e),this._resizableNode.layout(e.height,e.width),this._updateResizableNodeMaxDimensions(),this._hover.scrollbar.scanDomNode(),this._editor.layoutContentWidget(this),(i=(t=this._visibleData)===null||t===void 0?void 0:t.colorPicker)===null||i===void 0||i.layout()}_findAvailableSpaceVertically(){var e;const t=(e=this._visibleData)===null||e===void 0?void 0:e.showAtPosition;if(t)return this._positionPreference===1?this._availableVerticalSpaceAbove(t):this._availableVerticalSpaceBelow(t)}_findMaximumRenderingHeight(){const e=this._findAvailableSpaceVertically();if(!e)return;let t=h1e;return Array.from(this._hover.contentsDomNode.children).forEach(i=>{t+=i.clientHeight}),this._hasHorizontalScrollbar()&&(t+=lE),Math.min(e,t)}_isHoverTextOverflowing(){this._hover.containerDomNode.style.setProperty("--vscode-hover-whiteSpace","nowrap"),this._hover.containerDomNode.style.setProperty("--vscode-hover-sourceWhiteSpace","nowrap");const e=Array.from(this._hover.contentsDomNode.children).some(t=>t.scrollWidth>t.clientWidth);return this._hover.containerDomNode.style.removeProperty("--vscode-hover-whiteSpace"),this._hover.containerDomNode.style.removeProperty("--vscode-hover-sourceWhiteSpace"),e}_findMaximumRenderingWidth(){if(!this._editor||!this._editor.hasModel())return;const e=this._isHoverTextOverflowing(),t=typeof this._contentWidth>"u"?0:this._contentWidth-2;return e||this._hover.containerDomNode.clientWidth<t?Nu(this._hover.containerDomNode.ownerDocument.body).width-14:this._hover.containerDomNode.clientWidth+2}isMouseGettingCloser(e,t){if(!this._visibleData)return!1;if(typeof this._visibleData.initialMousePosX>"u"||typeof this._visibleData.initialMousePosY>"u")return this._visibleData.initialMousePosX=e,this._visibleData.initialMousePosY=t,!1;const i=ln(this.getDomNode());typeof this._visibleData.closestMouseDistance>"u"&&(this._visibleData.closestMouseDistance=V8(this._visibleData.initialMousePosX,this._visibleData.initialMousePosY,i.left,i.top,i.width,i.height));const n=V8(e,t,i.left,i.top,i.width,i.height);return n>this._visibleData.closestMouseDistance+4?!1:(this._visibleData.closestMouseDistance=Math.min(this._visibleData.closestMouseDistance,n),!0)}_setHoverData(e){var t;(t=this._visibleData)===null||t===void 0||t.disposables.dispose(),this._visibleData=e,this._hoverVisibleKey.set(!!e),this._hover.containerDomNode.classList.toggle("hidden",!e)}_updateFont(){const{fontSize:e,lineHeight:t}=this._editor.getOption(50),i=this._hover.contentsDomNode;i.style.fontSize=`${e}px`,i.style.lineHeight=`${t/e}`,Array.prototype.slice.call(this._hover.contentsDomNode.getElementsByClassName("code")).forEach(o=>this._editor.applyFontInfo(o))}_updateContent(e){const t=this._hover.contentsDomNode;t.style.paddingBottom="",t.textContent="",t.appendChild(e)}_layoutContentWidget(){this._editor.layoutContentWidget(this),this._hover.onContentsChanged()}_updateMaxDimensions(){const e=Math.max(this._editor.getLayoutInfo().height/4,250,al._lastDimensions.height),t=Math.max(this._editor.getLayoutInfo().width*.66,500,al._lastDimensions.width);this._setHoverWidgetMaxDimensions(t,e)}_render(e,t){this._setHoverData(t),this._updateFont(),this._updateContent(e),this._updateMaxDimensions(),this.onContentsChanged(),this._editor.render()}getPosition(){var e;return this._visibleData?{position:this._visibleData.showAtPosition,secondaryPosition:this._visibleData.showAtSecondaryPosition,positionAffinity:this._visibleData.isBeforeContent?3:void 0,preference:[(e=this._positionPreference)!==null&&e!==void 0?e:1]}:null}showAt(e,t){var i,n,o,r;if(!this._editor||!this._editor.hasModel())return;this._render(e,t);const a=Qh(this._hover.containerDomNode),l=t.showAtPosition;this._positionPreference=(i=this._findPositionPreference(a,l))!==null&&i!==void 0?i:1,this.onContentsChanged(),t.stoleFocus&&this._hover.containerDomNode.focus(),(n=t.colorPicker)===null||n===void 0||n.layout();const c=this._hover.containerDomNode.ownerDocument.activeElement===this._hover.containerDomNode&&o1e(this._configurationService.getValue("accessibility.verbosity.hover")===!0&&this._accessibilityService.isScreenReaderOptimized(),(r=(o=this._keybindingService.lookupKeybinding("editor.action.accessibleView"))===null||o===void 0?void 0:o.getAriaLabel())!==null&&r!==void 0?r:"");c&&(this._hover.contentsDomNode.ariaLabel=this._hover.contentsDomNode.textContent+", "+c)}hide(){if(!this._visibleData)return;const e=this._visibleData.stoleFocus||this._hoverFocusedKey.get();this._setHoverData(void 0),this._resizableNode.maxSize=new Dt(1/0,1/0),this._resizableNode.clearSashHoverState(),this._hoverFocusedKey.set(!1),this._editor.layoutContentWidget(this),e&&this._editor.focus()}_removeConstraintsRenderNormally(){const e=this._editor.getLayoutInfo();this._resizableNode.layout(e.height,e.width),this._setHoverWidgetDimensions("auto","auto")}_adjustHoverHeightForScrollbar(e){var t;const i=this._hover.containerDomNode,n=this._hover.contentsDomNode,o=(t=this._findMaximumRenderingHeight())!==null&&t!==void 0?t:1/0;this._setContainerDomNodeDimensions(js(i),Math.min(o,e)),this._setContentsDomNodeDimensions(js(n),Math.min(o,e-lE))}setMinimumDimensions(e){this._minimumSize=new Dt(Math.max(this._minimumSize.width,e.width),Math.max(this._minimumSize.height,e.height)),this._updateMinimumWidth()}_updateMinimumWidth(){const e=typeof this._contentWidth>"u"?this._minimumSize.width:Math.min(this._contentWidth,this._minimumSize.width);this._resizableNode.minSize=new Dt(e,this._minimumSize.height)}onContentsChanged(){var e;this._removeConstraintsRenderNormally();const t=this._hover.containerDomNode;let i=Qh(t),n=js(t);if(this._resizableNode.layout(i,n),this._setHoverWidgetDimensions(n,i),i=Qh(t),n=js(t),this._contentWidth=n,this._updateMinimumWidth(),this._resizableNode.layout(i,n),this._hasHorizontalScrollbar()&&(this._adjustContentsBottomPadding(),this._adjustHoverHeightForScrollbar(i)),!((e=this._visibleData)===null||e===void 0)&&e.showAtPosition){const o=Qh(this._hover.containerDomNode);this._positionPreference=this._findPositionPreference(o,this._visibleData.showAtPosition)}this._layoutContentWidget()}focus(){this._hover.containerDomNode.focus()}scrollUp(){const e=this._hover.scrollbar.getScrollPosition().scrollTop,t=this._editor.getOption(50);this._hover.scrollbar.setScrollPosition({scrollTop:e-t.lineHeight})}scrollDown(){const e=this._hover.scrollbar.getScrollPosition().scrollTop,t=this._editor.getOption(50);this._hover.scrollbar.setScrollPosition({scrollTop:e+t.lineHeight})}scrollLeft(){const e=this._hover.scrollbar.getScrollPosition().scrollLeft;this._hover.scrollbar.setScrollPosition({scrollLeft:e-W8})}scrollRight(){const e=this._hover.scrollbar.getScrollPosition().scrollLeft;this._hover.scrollbar.setScrollPosition({scrollLeft:e+W8})}pageUp(){const e=this._hover.scrollbar.getScrollPosition().scrollTop,t=this._hover.scrollbar.getScrollDimensions().height;this._hover.scrollbar.setScrollPosition({scrollTop:e-t})}pageDown(){const e=this._hover.scrollbar.getScrollPosition().scrollTop,t=this._hover.scrollbar.getScrollDimensions().height;this._hover.scrollbar.setScrollPosition({scrollTop:e+t})}goToTop(){this._hover.scrollbar.setScrollPosition({scrollTop:0})}goToBottom(){this._hover.scrollbar.setScrollPosition({scrollTop:this._hover.scrollbar.getScrollDimensions().scrollHeight})}};_u.ID="editor.contrib.resizableContentHoverWidget";_u._lastDimensions=new Dt(0,0);_u=al=c4([ag(1,je),ag(2,mt),ag(3,ad),ag(4,qt)],_u);let rL=class extends j{get hasContent(){return this._hasContent}constructor(e){super(),this._keybindingService=e,this._hasContent=!1,this.hoverElement=B8("div.hover-row.status-bar"),this.actionsElement=te(this.hoverElement,B8("div.actions"))}addAction(e){const t=this._keybindingService.lookupKeybinding(e.commandId),i=t?t.getLabel():null;return this._hasContent=!0,this._register(l4.render(this.actionsElement,e,i))}append(e){const t=te(this.actionsElement,e);return this._hasContent=!0,t}};rL=c4([ag(0,qt)],rL);class aL{get anchor(){return this._anchor}set anchor(e){this._anchor=e}get shouldFocus(){return this._shouldFocus}set shouldFocus(e){this._shouldFocus=e}get source(){return this._source}set source(e){this._source=e}get insistOnKeepingHoverVisible(){return this._insistOnKeepingHoverVisible}set insistOnKeepingHoverVisible(e){this._insistOnKeepingHoverVisible=e}constructor(e,t){this._editor=e,this._participants=t,this._anchor=null,this._shouldFocus=!1,this._source=0,this._insistOnKeepingHoverVisible=!1}static _getLineDecorations(e,t){if(t.type!==1&&!t.supportsMarkerHover)return[];const i=e.getModel(),n=t.range.startLineNumber;if(n>i.getLineCount())return[];const o=i.getLineMaxColumn(n);return e.getLineDecorations(n).filter(r=>{if(r.options.isWholeLine)return!0;const a=r.range.startLineNumber===n?r.range.startColumn:1,l=r.range.endLineNumber===n?r.range.endColumn:o;if(r.options.showIfCollapsed){if(a>t.range.startColumn+1||t.range.endColumn-1>l)return!1}else if(a>t.range.startColumn||t.range.endColumn>l)return!1;return!0})}computeAsync(e){const t=this._anchor;if(!this._editor.hasModel()||!t)return tn.EMPTY;const i=aL._getLineDecorations(this._editor,t);return tn.merge(this._participants.map(n=>n.computeAsync?n.computeAsync(t,i,e):tn.EMPTY))}computeSync(){if(!this._editor.hasModel()||!this._anchor)return[];const e=aL._getLineDecorations(this._editor,this._anchor);let t=[];for(const i of this._participants)t=t.concat(i.computeSync(this._anchor,e));return Ba(t)}}function V8(s,e,t,i,n,o){const r=t+n/2,a=i+o/2,l=Math.max(Math.abs(s-r)-n/2,0),d=Math.max(Math.abs(e-a)-o/2,0);return Math.sqrt(l*l+d*d)}const H8=se;class Jp extends j{constructor(e,t,i){super(),this._renderDisposeables=this._register(new ie),this._editor=e,this._isVisible=!1,this._messages=[],this._hover=this._register(new kj),this._hover.containerDomNode.classList.toggle("hidden",!this._isVisible),this._markdownRenderer=this._register(new ic({editor:this._editor},t,i)),this._computer=new g1e(this._editor),this._hoverOperation=this._register(new Ij(this._editor,this._computer)),this._register(this._hoverOperation.onResult(n=>{this._withResult(n.value)})),this._register(this._editor.onDidChangeModelDecorations(()=>this._onModelDecorationsChanged())),this._register(this._editor.onDidChangeConfiguration(n=>{n.hasChanged(50)&&this._updateFont()})),this._editor.addOverlayWidget(this)}dispose(){this._editor.removeOverlayWidget(this),super.dispose()}getId(){return Jp.ID}getDomNode(){return this._hover.containerDomNode}getPosition(){return null}_updateFont(){Array.prototype.slice.call(this._hover.contentsDomNode.getElementsByClassName("code")).forEach(t=>this._editor.applyFontInfo(t))}_onModelDecorationsChanged(){this._isVisible&&(this._hoverOperation.cancel(),this._hoverOperation.start(0))}startShowingAt(e){this._computer.lineNumber!==e&&(this._hoverOperation.cancel(),this.hide(),this._computer.lineNumber=e,this._hoverOperation.start(0))}hide(){this._computer.lineNumber=-1,this._hoverOperation.cancel(),this._isVisible&&(this._isVisible=!1,this._hover.containerDomNode.classList.toggle("hidden",!this._isVisible))}_withResult(e){this._messages=e,this._messages.length>0?this._renderMessages(this._computer.lineNumber,this._messages):this.hide()}_renderMessages(e,t){this._renderDisposeables.clear();const i=document.createDocumentFragment();for(const n of t){const o=H8("div.hover-row.markdown-hover"),r=te(o,H8("div.hover-contents")),a=this._renderDisposeables.add(this._markdownRenderer.render(n.value));r.appendChild(a.element),i.appendChild(o)}this._updateContents(i),this._showAt(e)}_updateContents(e){this._hover.contentsDomNode.textContent="",this._hover.contentsDomNode.appendChild(e),this._updateFont()}_showAt(e){this._isVisible||(this._isVisible=!0,this._hover.containerDomNode.classList.toggle("hidden",!this._isVisible));const t=this._editor.getLayoutInfo(),i=this._editor.getTopForLineNumber(e),n=this._editor.getScrollTop(),o=this._editor.getOption(66),r=this._hover.containerDomNode.clientHeight,a=i-n-(r-o)/2;this._hover.containerDomNode.style.left=`${t.glyphMarginLeft+t.glyphMarginWidth}px`,this._hover.containerDomNode.style.top=`${Math.max(Math.round(a),0)}px`}}Jp.ID="editor.contrib.modesGlyphHoverWidget";class g1e{get lineNumber(){return this._lineNumber}set lineNumber(e){this._lineNumber=e}constructor(e){this._editor=e,this._lineNumber=-1}computeSync(){const e=n=>({value:n}),t=this._editor.getLineDecorations(this._lineNumber),i=[];if(!t)return i;for(const n of t){if(!n.options.glyphMarginClassName)continue;const o=n.options.glyphMarginHoverMessage;!o||Im(o)||i.push(...SA(o).map(e))}return i}}class f1e{constructor(e,t,i){this.provider=e,this.hover=t,this.ordinal=i}}async function p1e(s,e,t,i,n){try{const o=await Promise.resolve(s.provideHover(t,i,n));if(o&&_1e(o))return new f1e(s,o,e)}catch(o){Zi(o)}}function u4(s,e,t,i){const o=s.ordered(e).map((r,a)=>p1e(r,a,e,t,i));return tn.fromPromises(o).coalesce()}function m1e(s,e,t,i){return u4(s,e,t,i).map(n=>n.hover).toPromise()}od("_executeHoverProvider",(s,e,t)=>{const i=s.get(xe);return m1e(i.hoverProvider,e,t,ct.None)});function _1e(s){const e=typeof s.range<"u",t=typeof s.contents<"u"&&s.contents&&s.contents.length>0;return e&&t}var v1e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},tw=function(s,e){return function(t,i){e(t,i,s)}};const z8=se;class Da{constructor(e,t,i,n,o){this.owner=e,this.range=t,this.contents=i,this.isBeforeContent=n,this.ordinal=o}isValidForHoverAnchor(e){return e.type===1&&this.range.startColumn<=e.range.startColumn&&this.range.endColumn>=e.range.endColumn}}let lL=class{constructor(e,t,i,n,o){this._editor=e,this._languageService=t,this._openerService=i,this._configurationService=n,this._languageFeaturesService=o,this.hoverOrdinal=3}createLoadingMessage(e){return new Da(this,e.range,[new rs().appendText(p("modesContentHover.loading","Loading..."))],!1,2e3)}computeSync(e,t){if(!this._editor.hasModel()||e.type!==1)return[];const i=this._editor.getModel(),n=e.range.startLineNumber,o=i.getLineMaxColumn(n),r=[];let a=1e3;const l=i.getLineLength(n),d=i.getLanguageIdAtPosition(e.range.startLineNumber,e.range.startColumn),c=this._editor.getOption(116),u=this._configurationService.getValue("editor.maxTokenizationLineLength",{overrideIdentifier:d});let h=!1;c>=0&&l>c&&e.range.startColumn>=c&&(h=!0,r.push(new Da(this,e.range,[{value:p("stopped rendering","Rendering paused for long line for performance reasons. This can be configured via `editor.stopRenderingLineAfter`.")}],!1,a++))),!h&&typeof u=="number"&&l>=u&&r.push(new Da(this,e.range,[{value:p("too many characters","Tokenization is skipped for long lines for performance reasons. This can be configured via `editor.maxTokenizationLineLength`.")}],!1,a++));let g=!1;for(const f of t){const m=f.range.startLineNumber===n?f.range.startColumn:1,_=f.range.endLineNumber===n?f.range.endColumn:o,v=f.options.hoverMessage;if(!v||Im(v))continue;f.options.beforeContentClassName&&(g=!0);const b=new D(e.range.startLineNumber,m,e.range.startLineNumber,_);r.push(new Da(this,b,SA(v),g,a++))}return r}computeAsync(e,t,i){if(!this._editor.hasModel()||e.type!==1)return tn.EMPTY;const n=this._editor.getModel();if(!this._languageFeaturesService.hoverProvider.has(n))return tn.EMPTY;const o=new H(e.range.startLineNumber,e.range.startColumn);return u4(this._languageFeaturesService.hoverProvider,n,o,i).filter(r=>!Im(r.hover.contents)).map(r=>{const a=r.hover.range?D.lift(r.hover.range):e.range;return new Da(this,a,r.hover.contents,!1,r.ordinal)})}renderHoverParts(e,t){return Nj(e,t,this._editor,this._languageService,this._openerService)}};lL=v1e([tw(1,fi),tw(2,No),tw(3,mt),tw(4,xe)],lL);function Nj(s,e,t,i,n){e.sort((r,a)=>r.ordinal-a.ordinal);const o=new ie;for(const r of e)for(const a of r.contents){if(Im(a))continue;const l=z8("div.hover-row.markdown-hover"),d=te(l,z8("div.hover-contents")),c=o.add(new ic({editor:t},i,n));o.add(c.onDidRenderAsync(()=>{d.className="hover-contents code-hover-contents",s.onContentsChanged()}));const u=o.add(c.render(a));d.appendChild(u.element),s.fragment.appendChild(l)}return o}var Tj=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},dL=function(s,e){return function(t,i){e(t,i,s)}};class U8{constructor(e,t,i){this.marker=e,this.index=t,this.total=i}}let AM=class{constructor(e,t,i){this._markerService=t,this._configService=i,this._onDidChange=new W,this.onDidChange=this._onDidChange.event,this._dispoables=new ie,this._markers=[],this._nextIdx=-1,Pe.isUri(e)?this._resourceFilter=a=>a.toString()===e.toString():e&&(this._resourceFilter=e);const n=this._configService.getValue("problems.sortOrder"),o=(a,l)=>{let d=x0(a.resource.toString(),l.resource.toString());return d===0&&(n==="position"?d=D.compareRangesUsingStarts(a,l)||Ii.compare(a.severity,l.severity):d=Ii.compare(a.severity,l.severity)||D.compareRangesUsingStarts(a,l)),d},r=()=>{this._markers=this._markerService.read({resource:Pe.isUri(e)?e:void 0,severities:Ii.Error|Ii.Warning|Ii.Info}),typeof e=="function"&&(this._markers=this._markers.filter(a=>this._resourceFilter(a.resource))),this._markers.sort(o)};r(),this._dispoables.add(t.onMarkerChanged(a=>{(!this._resourceFilter||a.some(l=>this._resourceFilter(l)))&&(r(),this._nextIdx=-1,this._onDidChange.fire())}))}dispose(){this._dispoables.dispose(),this._onDidChange.dispose()}matches(e){return!this._resourceFilter&&!e?!0:!this._resourceFilter||!e?!1:this._resourceFilter(e)}get selected(){const e=this._markers[this._nextIdx];return e&&new U8(e,this._nextIdx+1,this._markers.length)}_initIdx(e,t,i){let n=!1,o=this._markers.findIndex(r=>r.resource.toString()===e.uri.toString());o<0&&(o=_0(this._markers,{resource:e.uri},(r,a)=>x0(r.resource.toString(),a.resource.toString())),o<0&&(o=~o));for(let r=o;r<this._markers.length;r++){let a=D.lift(this._markers[r]);if(a.isEmpty()){const l=e.getWordAtPosition(a.getStartPosition());l&&(a=new D(a.startLineNumber,l.startColumn,a.startLineNumber,l.endColumn))}if(t&&(a.containsPosition(t)||t.isBeforeOrEqual(a.getStartPosition()))){this._nextIdx=r,n=!0;break}if(this._markers[r].resource.toString()!==e.uri.toString())break}n||(this._nextIdx=i?0:this._markers.length-1),this._nextIdx<0&&(this._nextIdx=this._markers.length-1)}resetIndex(){this._nextIdx=-1}move(e,t,i){if(this._markers.length===0)return!1;const n=this._nextIdx;return this._nextIdx===-1?this._initIdx(t,i,e):e?this._nextIdx=(this._nextIdx+1)%this._markers.length:e||(this._nextIdx=(this._nextIdx-1+this._markers.length)%this._markers.length),n!==this._nextIdx}find(e,t){let i=this._markers.findIndex(n=>n.resource.toString()===e.toString());if(!(i<0)){for(;i<this._markers.length;i++)if(D.containsPosition(this._markers[i],t))return new U8(this._markers[i],i+1,this._markers.length)}}};AM=Tj([dL(1,ld),dL(2,mt)],AM);const Mj=ut("IMarkerNavigationService");let PM=class{constructor(e,t){this._markerService=e,this._configService=t,this._provider=new Ms}getMarkerList(e){for(const t of this._provider){const i=t.getMarkerList(e);if(i)return i}return new AM(e,this._markerService,this._configService)}};PM=Tj([dL(0,ld),dL(1,mt)],PM);_t(Mj,PM,1);var OM;(function(s){function e(t){switch(t){case Wi.Ignore:return"severity-ignore "+Oe.asClassName(le.info);case Wi.Info:return Oe.asClassName(le.info);case Wi.Warning:return Oe.asClassName(le.warning);case Wi.Error:return Oe.asClassName(le.error);default:return""}}s.className=e})(OM||(OM={}));var b1e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Pf=function(s,e){return function(t,i){e(t,i,s)}},FM;class C1e{constructor(e,t,i,n,o){this._openerService=n,this._labelService=o,this._lines=0,this._longestLineLength=0,this._relatedDiagnostics=new WeakMap,this._disposables=new ie,this._editor=t;const r=document.createElement("div");r.className="descriptioncontainer",this._messageBlock=document.createElement("div"),this._messageBlock.classList.add("message"),this._messageBlock.setAttribute("aria-live","assertive"),this._messageBlock.setAttribute("role","alert"),r.appendChild(this._messageBlock),this._relatedBlock=document.createElement("div"),r.appendChild(this._relatedBlock),this._disposables.add(Pi(this._relatedBlock,"click",a=>{a.preventDefault();const l=this._relatedDiagnostics.get(a.target);l&&i(l)})),this._scrollable=new CH(r,{horizontal:1,vertical:1,useShadows:!1,horizontalScrollbarSize:6,verticalScrollbarSize:6}),e.appendChild(this._scrollable.getDomNode()),this._disposables.add(this._scrollable.onScroll(a=>{r.style.left=`-${a.scrollLeft}px`,r.style.top=`-${a.scrollTop}px`})),this._disposables.add(this._scrollable)}dispose(){Bt(this._disposables)}update(e){const{source:t,message:i,relatedInformation:n,code:o}=e;let r=((t==null?void 0:t.length)||0)+2;o&&(typeof o=="string"?r+=o.length:r+=o.value.length);const a=Kl(i);this._lines=a.length,this._longestLineLength=0;for(const h of a)this._longestLineLength=Math.max(h.length+r,this._longestLineLength);Vn(this._messageBlock),this._messageBlock.setAttribute("aria-label",this.getAriaLabel(e)),this._editor.applyFontInfo(this._messageBlock);let l=this._messageBlock;for(const h of a)l=document.createElement("div"),l.innerText=h,h===""&&(l.style.height=this._messageBlock.style.lineHeight),this._messageBlock.appendChild(l);if(t||o){const h=document.createElement("span");if(h.classList.add("details"),l.appendChild(h),t){const g=document.createElement("span");g.innerText=t,g.classList.add("source"),h.appendChild(g)}if(o)if(typeof o=="string"){const g=document.createElement("span");g.innerText=`(${o})`,g.classList.add("code"),h.appendChild(g)}else{this._codeLink=se("a.code-link"),this._codeLink.setAttribute("href",`${o.target.toString()}`),this._codeLink.onclick=f=>{this._openerService.open(o.target,{allowCommands:!0}),f.preventDefault(),f.stopPropagation()};const g=te(this._codeLink,se("span"));g.innerText=o.value,h.appendChild(this._codeLink)}}if(Vn(this._relatedBlock),this._editor.applyFontInfo(this._relatedBlock),as(n)){const h=this._relatedBlock.appendChild(document.createElement("div"));h.style.paddingTop=`${Math.floor(this._editor.getOption(66)*.66)}px`,this._lines+=1;for(const g of n){const f=document.createElement("div"),m=document.createElement("a");m.classList.add("filename"),m.innerText=`${this._labelService.getUriBasenameLabel(g.resource)}(${g.startLineNumber}, ${g.startColumn}): `,m.title=this._labelService.getUriLabel(g.resource),this._relatedDiagnostics.set(m,g);const _=document.createElement("span");_.innerText=g.message,f.appendChild(m),f.appendChild(_),this._lines+=1,h.appendChild(f)}}const d=this._editor.getOption(50),c=Math.ceil(d.typicalFullwidthCharacterWidth*this._longestLineLength*.75),u=d.lineHeight*this._lines;this._scrollable.setScrollDimensions({scrollWidth:c,scrollHeight:u})}layout(e,t){this._scrollable.getDomNode().style.height=`${e}px`,this._scrollable.getDomNode().style.width=`${t}px`,this._scrollable.setScrollDimensions({width:t,height:e})}getHeightInLines(){return Math.min(17,this._lines)}getAriaLabel(e){let t="";switch(e.severity){case Ii.Error:t=p("Error","Error");break;case Ii.Warning:t=p("Warning","Warning");break;case Ii.Info:t=p("Info","Info");break;case Ii.Hint:t=p("Hint","Hint");break}let i=p("marker aria","{0} at {1}. ",t,e.startLineNumber+":"+e.startColumn);const n=this._editor.getModel();return n&&e.startLineNumber<=n.getLineCount()&&e.startLineNumber>=1&&(i=`${n.getLineContent(e.startLineNumber)}, ${i}`),i}}let Wm=FM=class extends sL{constructor(e,t,i,n,o,r,a){super(e,{showArrow:!0,showFrame:!0,isAccessible:!0,frameWidth:1},o),this._themeService=t,this._openerService=i,this._menuService=n,this._contextKeyService=r,this._labelService=a,this._callOnDispose=new ie,this._onDidSelectRelatedInformation=new W,this.onDidSelectRelatedInformation=this._onDidSelectRelatedInformation.event,this._severity=Ii.Warning,this._backgroundColor=G.white,this._applyTheme(t.getColorTheme()),this._callOnDispose.add(t.onDidColorThemeChange(this._applyTheme.bind(this))),this.create()}_applyTheme(e){this._backgroundColor=e.getColor(L1e);let t=BM,i=w1e;this._severity===Ii.Warning?(t=rS,i=S1e):this._severity===Ii.Info&&(t=WM,i=y1e);const n=e.getColor(t),o=e.getColor(i);this.style({arrowColor:n,frameColor:n,headerBackgroundColor:o,primaryHeadingColor:e.getColor(_j),secondaryHeadingColor:e.getColor(vj)})}_applyStyles(){this._parentContainer&&(this._parentContainer.style.backgroundColor=this._backgroundColor?this._backgroundColor.toString():""),super._applyStyles()}dispose(){this._callOnDispose.dispose(),super.dispose()}_fillHead(e){super._fillHead(e),this._disposables.add(this._actionbarWidget.actionRunner.onWillRun(n=>this.editor.focus()));const t=[],i=this._menuService.createMenu(FM.TitleMenu,this._contextKeyService);hO(i,void 0,t),this._actionbarWidget.push(t,{label:!1,icon:!0,index:0}),i.dispose()}_fillTitleIcon(e){this._icon=te(e,se(""))}_fillBody(e){this._parentContainer=e,e.classList.add("marker-widget"),this._parentContainer.tabIndex=0,this._parentContainer.setAttribute("role","tooltip"),this._container=document.createElement("div"),e.appendChild(this._container),this._message=new C1e(this._container,this.editor,t=>this._onDidSelectRelatedInformation.fire(t),this._openerService,this._labelService),this._disposables.add(this._message)}show(){throw new Error("call showAtMarker")}showAtMarker(e,t,i){this._container.classList.remove("stale"),this._message.update(e),this._severity=e.severity,this._applyTheme(this._themeService.getColorTheme());const n=D.lift(e),o=this.editor.getPosition(),r=o&&n.containsPosition(o)?o:n.getStartPosition();super.show(r,this.computeRequiredHeight());const a=this.editor.getModel();if(a){const l=i>1?p("problems","{0} of {1} problems",t,i):p("change","{0} of {1} problem",t,i);this.setTitle(kr(a.uri),l)}this._icon.className=`codicon ${OM.className(Ii.toSeverity(this._severity))}`,this.editor.revealPositionNearTop(r,0),this.editor.focus()}updateMarker(e){this._container.classList.remove("stale"),this._message.update(e)}showStale(){this._container.classList.add("stale"),this._relayout()}_doLayoutBody(e,t){super._doLayoutBody(e,t),this._heightInPixel=e,this._message.layout(e,t),this._container.style.height=`${e}px`}_onWidth(e){this._message.layout(this._heightInPixel,e)}_relayout(){super._relayout(this.computeRequiredHeight())}computeRequiredHeight(){return 3+this._message.getHeightInLines()}};Wm.TitleMenu=new N("gotoErrorTitleMenu");Wm=FM=b1e([Pf(1,Cn),Pf(2,No),Pf(3,qa),Pf(4,We),Pf(5,je),Pf(6,xm)],Wm);const $8=U0(Nl,mse),j8=U0(Yo,H0),K8=U0(Xs,z0),BM=R("editorMarkerNavigationError.background",{dark:$8,light:$8,hcDark:pt,hcLight:pt},p("editorMarkerNavigationError","Editor marker navigation widget error color.")),w1e=R("editorMarkerNavigationError.headerBackground",{dark:Me(BM,.1),light:Me(BM,.1),hcDark:null,hcLight:null},p("editorMarkerNavigationErrorHeaderBackground","Editor marker navigation widget error heading background.")),rS=R("editorMarkerNavigationWarning.background",{dark:j8,light:j8,hcDark:pt,hcLight:pt},p("editorMarkerNavigationWarning","Editor marker navigation widget warning color.")),S1e=R("editorMarkerNavigationWarning.headerBackground",{dark:Me(rS,.1),light:Me(rS,.1),hcDark:"#0C141F",hcLight:Me(rS,.2)},p("editorMarkerNavigationWarningBackground","Editor marker navigation widget warning heading background.")),WM=R("editorMarkerNavigationInfo.background",{dark:K8,light:K8,hcDark:pt,hcLight:pt},p("editorMarkerNavigationInfo","Editor marker navigation widget info color.")),y1e=R("editorMarkerNavigationInfo.headerBackground",{dark:Me(WM,.1),light:Me(WM,.1),hcDark:null,hcLight:null},p("editorMarkerNavigationInfoHeaderBackground","Editor marker navigation widget info heading background.")),L1e=R("editorMarkerNavigation.background",{dark:bn,light:bn,hcDark:bn,hcLight:bn},p("editorMarkerNavigationBackground","Editor marker navigation widget background."));var x1e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},iw=function(s,e){return function(t,i){e(t,i,s)}},yv;let qu=yv=class{static get(e){return e.getContribution(yv.ID)}constructor(e,t,i,n,o){this._markerNavigationService=t,this._contextKeyService=i,this._editorService=n,this._instantiationService=o,this._sessionDispoables=new ie,this._editor=e,this._widgetVisible=Rj.bindTo(this._contextKeyService)}dispose(){this._cleanUp(),this._sessionDispoables.dispose()}_cleanUp(){this._widgetVisible.reset(),this._sessionDispoables.clear(),this._widget=void 0,this._model=void 0}_getOrCreateModel(e){if(this._model&&this._model.matches(e))return this._model;let t=!1;return this._model&&(t=!0,this._cleanUp()),this._model=this._markerNavigationService.getMarkerList(e),t&&this._model.move(!0,this._editor.getModel(),this._editor.getPosition()),this._widget=this._instantiationService.createInstance(Wm,this._editor),this._widget.onDidClose(()=>this.close(),this,this._sessionDispoables),this._widgetVisible.set(!0),this._sessionDispoables.add(this._model),this._sessionDispoables.add(this._widget),this._sessionDispoables.add(this._editor.onDidChangeCursorPosition(i=>{var n,o,r;(!(!((n=this._model)===null||n===void 0)&&n.selected)||!D.containsPosition((o=this._model)===null||o===void 0?void 0:o.selected.marker,i.position))&&((r=this._model)===null||r===void 0||r.resetIndex())})),this._sessionDispoables.add(this._model.onDidChange(()=>{if(!this._widget||!this._widget.position||!this._model)return;const i=this._model.find(this._editor.getModel().uri,this._widget.position);i?this._widget.updateMarker(i.marker):this._widget.showStale()})),this._sessionDispoables.add(this._widget.onDidSelectRelatedInformation(i=>{this._editorService.openCodeEditor({resource:i.resource,options:{pinned:!0,revealIfOpened:!0,selection:D.lift(i).collapseToStart()}},this._editor),this.close(!1)})),this._sessionDispoables.add(this._editor.onDidChangeModel(()=>this._cleanUp())),this._model}close(e=!0){this._cleanUp(),e&&this._editor.focus()}showAtMarker(e){if(this._editor.hasModel()){const t=this._getOrCreateModel(this._editor.getModel().uri);t.resetIndex(),t.move(!0,this._editor.getModel(),new H(e.startLineNumber,e.startColumn)),t.selected&&this._widget.showAtMarker(t.selected.marker,t.selected.index,t.selected.total)}}async nagivate(e,t){var i,n;if(this._editor.hasModel()){const o=this._getOrCreateModel(t?void 0:this._editor.getModel().uri);if(o.move(e,this._editor.getModel(),this._editor.getPosition()),!o.selected)return;if(o.selected.marker.resource.toString()!==this._editor.getModel().uri.toString()){this._cleanUp();const r=await this._editorService.openCodeEditor({resource:o.selected.marker.resource,options:{pinned:!1,revealIfOpened:!0,selectionRevealType:2,selection:o.selected.marker}},this._editor);r&&((i=yv.get(r))===null||i===void 0||i.close(),(n=yv.get(r))===null||n===void 0||n.nagivate(e,t))}else this._widget.showAtMarker(o.selected.marker,o.selected.index,o.selected.total)}}};qu.ID="editor.contrib.markerController";qu=yv=x1e([iw(1,Mj),iw(2,je),iw(3,It),iw(4,We)],qu);class LD extends we{constructor(e,t,i){super(i),this._next=e,this._multiFile=t}async run(e,t){var i;t.hasModel()&&((i=qu.get(t))===null||i===void 0||i.nagivate(this._next,this._multiFile))}}class vu extends LD{constructor(){super(!0,!1,{id:vu.ID,label:vu.LABEL,alias:"Go to Next Problem (Error, Warning, Info)",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:578,weight:100},menuOpts:{menuId:Wm.TitleMenu,title:vu.LABEL,icon:Ui("marker-navigation-next",le.arrowDown,p("nextMarkerIcon","Icon for goto next marker.")),group:"navigation",order:1}})}}vu.ID="editor.action.marker.next";vu.LABEL=p("markerAction.next.label","Go to Next Problem (Error, Warning, Info)");class wg extends LD{constructor(){super(!1,!1,{id:wg.ID,label:wg.LABEL,alias:"Go to Previous Problem (Error, Warning, Info)",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:1602,weight:100},menuOpts:{menuId:Wm.TitleMenu,title:wg.LABEL,icon:Ui("marker-navigation-previous",le.arrowUp,p("previousMarkerIcon","Icon for goto previous marker.")),group:"navigation",order:2}})}}wg.ID="editor.action.marker.prev";wg.LABEL=p("markerAction.previous.label","Go to Previous Problem (Error, Warning, Info)");class D1e extends LD{constructor(){super(!0,!0,{id:"editor.action.marker.nextInFiles",label:p("markerAction.nextInFiles.label","Go to Next Problem in Files (Error, Warning, Info)"),alias:"Go to Next Problem in Files (Error, Warning, Info)",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:66,weight:100},menuOpts:{menuId:N.MenubarGoMenu,title:p({key:"miGotoNextProblem",comment:["&& denotes a mnemonic"]},"Next &&Problem"),group:"6_problem_nav",order:1}})}}class k1e extends LD{constructor(){super(!1,!0,{id:"editor.action.marker.prevInFiles",label:p("markerAction.previousInFiles.label","Go to Previous Problem in Files (Error, Warning, Info)"),alias:"Go to Previous Problem in Files (Error, Warning, Info)",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:1090,weight:100},menuOpts:{menuId:N.MenubarGoMenu,title:p({key:"miGotoPreviousProblem",comment:["&& denotes a mnemonic"]},"Previous &&Problem"),group:"6_problem_nav",order:2}})}}Lt(qu.ID,qu,4);re(vu);re(wg);re(D1e);re(k1e);const Rj=new me("markersNavigationVisible",!1),I1e=Nn.bindToContribution(qu.get);ue(new I1e({id:"closeMarkersNavigation",precondition:Rj,handler:s=>s.close(),kbOpts:{weight:150,kbExpr:T.focus,primary:9,secondary:[1033]}}));var E1e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},dE=function(s,e){return function(t,i){e(t,i,s)}};const Ar=se;class N1e{constructor(e,t,i){this.owner=e,this.range=t,this.marker=i}isValidForHoverAnchor(e){return e.type===1&&this.range.startColumn<=e.range.startColumn&&this.range.endColumn>=e.range.endColumn}}const q8={type:1,filter:{include:$e.QuickFix},triggerAction:xo.QuickFixHover};let VM=class{constructor(e,t,i,n){this._editor=e,this._markerDecorationsService=t,this._openerService=i,this._languageFeaturesService=n,this.hoverOrdinal=1,this.recentMarkerCodeActionsInfo=void 0}computeSync(e,t){if(!this._editor.hasModel()||e.type!==1&&!e.supportsMarkerHover)return[];const i=this._editor.getModel(),n=e.range.startLineNumber,o=i.getLineMaxColumn(n),r=[];for(const a of t){const l=a.range.startLineNumber===n?a.range.startColumn:1,d=a.range.endLineNumber===n?a.range.endColumn:o,c=this._markerDecorationsService.getMarker(i.uri,a);if(!c)continue;const u=new D(e.range.startLineNumber,l,e.range.startLineNumber,d);r.push(new N1e(this,u,c))}return r}renderHoverParts(e,t){if(!t.length)return j.None;const i=new ie;t.forEach(o=>e.fragment.appendChild(this.renderMarkerHover(o,i)));const n=t.length===1?t[0]:t.sort((o,r)=>Ii.compare(o.marker.severity,r.marker.severity))[0];return this.renderMarkerStatusbar(e,n,i),i}renderMarkerHover(e,t){const i=Ar("div.hover-row"),n=te(i,Ar("div.marker.hover-contents")),{source:o,message:r,code:a,relatedInformation:l}=e.marker;this._editor.applyFontInfo(n);const d=te(n,Ar("span"));if(d.style.whiteSpace="pre-wrap",d.innerText=r,o||a)if(a&&typeof a!="string"){const c=Ar("span");if(o){const f=te(c,Ar("span"));f.innerText=o}const u=te(c,Ar("a.code-link"));u.setAttribute("href",a.target.toString()),t.add(Y(u,"click",f=>{this._openerService.open(a.target,{allowCommands:!0}),f.preventDefault(),f.stopPropagation()}));const h=te(u,Ar("span"));h.innerText=a.value;const g=te(n,c);g.style.opacity="0.6",g.style.paddingLeft="6px"}else{const c=te(n,Ar("span"));c.style.opacity="0.6",c.style.paddingLeft="6px",c.innerText=o&&a?`${o}(${a})`:o||`(${a})`}if(as(l))for(const{message:c,resource:u,startLineNumber:h,startColumn:g}of l){const f=te(n,Ar("div"));f.style.marginTop="8px";const m=te(f,Ar("a"));m.innerText=`${kr(u)}(${h}, ${g}): `,m.style.cursor="pointer",t.add(Y(m,"click",v=>{v.stopPropagation(),v.preventDefault(),this._openerService&&this._openerService.open(u,{fromUserGesture:!0,editorOptions:{selection:{startLineNumber:h,startColumn:g}}}).catch(et)}));const _=te(f,Ar("span"));_.innerText=c,this._editor.applyFontInfo(_)}return i}renderMarkerStatusbar(e,t,i){if((t.marker.severity===Ii.Error||t.marker.severity===Ii.Warning||t.marker.severity===Ii.Info)&&e.statusBar.addAction({label:p("view problem","View Problem"),commandId:vu.ID,run:()=>{var n;e.hide(),(n=qu.get(this._editor))===null||n===void 0||n.showAtMarker(t.marker),this._editor.focus()}}),!this._editor.getOption(90)){const n=e.statusBar.append(Ar("div"));this.recentMarkerCodeActionsInfo&&(Ny.makeKey(this.recentMarkerCodeActionsInfo.marker)===Ny.makeKey(t.marker)?this.recentMarkerCodeActionsInfo.hasCodeActions||(n.textContent=p("noQuickFixes","No quick fixes available")):this.recentMarkerCodeActionsInfo=void 0);const o=this.recentMarkerCodeActionsInfo&&!this.recentMarkerCodeActionsInfo.hasCodeActions?j.None:i.add(Eu(()=>n.textContent=p("checkingForQuickFixes","Checking for quick fixes..."),200));n.textContent||(n.textContent=" ");const r=this.getCodeActions(t.marker);i.add(Fe(()=>r.cancel())),r.then(a=>{if(o.dispose(),this.recentMarkerCodeActionsInfo={marker:t.marker,hasCodeActions:a.validActions.length>0},!this.recentMarkerCodeActionsInfo.hasCodeActions){a.dispose(),n.textContent=p("noQuickFixes","No quick fixes available");return}n.style.display="none";let l=!1;i.add(Fe(()=>{l||a.dispose()})),e.statusBar.addAction({label:p("quick fixes","Quick Fix..."),commandId:t4,run:d=>{l=!0;const c=zu.get(this._editor),u=ln(d);e.hide(),c==null||c.showCodeActions(q8,a,{x:u.left,y:u.top,width:u.width,height:u.height})}})},et)}}getCodeActions(e){return gn(t=>t0(this._languageFeaturesService.codeActionProvider,this._editor.getModel(),new D(e.startLineNumber,e.startColumn,e.endLineNumber,e.endColumn),q8,Gd.None,t))}};VM=E1e([dE(1,mP),dE(2,No),dE(3,xe)],VM);const Aj="editor.action.inlineSuggest.commit",Pj="editor.action.inlineSuggest.showPrevious",Oj="editor.action.inlineSuggest.showNext";var h4=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},ka=function(s,e){return function(t,i){e(t,i,s)}},aS;let HM=class extends j{constructor(e,t,i){super(),this.editor=e,this.model=t,this.instantiationService=i,this.alwaysShowToolbar=Mi(this.editor.onDidChangeConfiguration,()=>this.editor.getOption(62).showToolbar==="always"),this.sessionPosition=void 0,this.position=nt(this,n=>{var o,r,a;const l=(o=this.model.read(n))===null||o===void 0?void 0:o.ghostText.read(n);if(!this.alwaysShowToolbar.read(n)||!l||l.parts.length===0)return this.sessionPosition=void 0,null;const d=l.parts[0].column;this.sessionPosition&&this.sessionPosition.lineNumber!==l.lineNumber&&(this.sessionPosition=void 0);const c=new H(l.lineNumber,Math.min(d,(a=(r=this.sessionPosition)===null||r===void 0?void 0:r.column)!==null&&a!==void 0?a:Number.MAX_SAFE_INTEGER));return this.sessionPosition=c,c}),this._register(cc((n,o)=>{const r=this.model.read(n);if(!r||!this.alwaysShowToolbar.read(n))return;const a=o.add(this.instantiationService.createInstance(Gu,this.editor,!0,this.position,r.selectedInlineCompletionIndex,r.inlineCompletionsCount,r.selectedInlineCompletion.map(l=>{var d;return(d=l==null?void 0:l.inlineCompletion.source.inlineCompletions.commands)!==null&&d!==void 0?d:[]})));e.addContentWidget(a),o.add(Fe(()=>e.removeContentWidget(a))),o.add(Rt(l=>{this.position.read(l)&&r.lastTriggerKind.read(l)!==jd.Explicit&&r.triggerExplicitly()}))}))}};HM=h4([ka(2,We)],HM);const T1e=Ui("inline-suggestion-hints-next",le.chevronRight,p("parameterHintsNextIcon","Icon for show next parameter hint.")),M1e=Ui("inline-suggestion-hints-previous",le.chevronLeft,p("parameterHintsPreviousIcon","Icon for show previous parameter hint."));let Gu=aS=class extends j{static get dropDownVisible(){return this._dropDownVisible}createCommandAction(e,t,i){const n=new Os(e,t,i,!0,()=>this._commandService.executeCommand(e)),o=this.keybindingService.lookupKeybinding(e,this._contextKeyService);let r=t;return o&&(r=p({key:"content",comment:["A label","A keybinding"]},"{0} ({1})",t,o.getLabel())),n.tooltip=r,n}constructor(e,t,i,n,o,r,a,l,d,c,u){super(),this.editor=e,this.withBorder=t,this._position=i,this._currentSuggestionIdx=n,this._suggestionCount=o,this._extraCommands=r,this._commandService=a,this.keybindingService=d,this._contextKeyService=c,this._menuService=u,this.id=`InlineSuggestionHintsContentWidget${aS.id++}`,this.allowEditorOverflow=!0,this.suppressMouseDown=!1,this.nodes=hi("div.inlineSuggestionsHints",{className:this.withBorder?".withBorder":""},[hi("div@toolBar")]),this.previousAction=this.createCommandAction(Pj,p("previous","Previous"),Oe.asClassName(M1e)),this.availableSuggestionCountAction=new Os("inlineSuggestionHints.availableSuggestionCount","",void 0,!1),this.nextAction=this.createCommandAction(Oj,p("next","Next"),Oe.asClassName(T1e)),this.inlineCompletionsActionsMenus=this._register(this._menuService.createMenu(N.InlineCompletionsActions,this._contextKeyService)),this.clearAvailableSuggestionCountLabelDebounced=this._register(new jt(()=>{this.availableSuggestionCountAction.label=""},100)),this.disableButtonsDebounced=this._register(new jt(()=>{this.previousAction.enabled=this.nextAction.enabled=!1},100)),this.lastCommands=[],this.toolBar=this._register(l.createInstance(zM,this.nodes.toolBar,N.InlineSuggestionToolbar,{menuOptions:{renderShortTitle:!0},toolbarOptions:{primaryGroup:h=>h.startsWith("primary")},actionViewItemProvider:(h,g)=>{if(h instanceof Xr)return l.createInstance(A1e,h,void 0);if(h===this.availableSuggestionCountAction){const f=new R1e(void 0,h,{label:!0,icon:!1});return f.setClass("availableSuggestionCount"),f}},telemetrySource:"InlineSuggestionToolbar"})),this.toolBar.setPrependedPrimaryActions([this.previousAction,this.availableSuggestionCountAction,this.nextAction]),this._register(this.toolBar.onDidChangeDropdownVisibility(h=>{aS._dropDownVisible=h})),this._register(Rt(h=>{this._position.read(h),this.editor.layoutContentWidget(this)})),this._register(Rt(h=>{const g=this._suggestionCount.read(h),f=this._currentSuggestionIdx.read(h);g!==void 0?(this.clearAvailableSuggestionCountLabelDebounced.cancel(),this.availableSuggestionCountAction.label=`${f+1}/${g}`):this.clearAvailableSuggestionCountLabelDebounced.schedule(),g!==void 0&&g>1?(this.disableButtonsDebounced.cancel(),this.previousAction.enabled=this.nextAction.enabled=!0):this.disableButtonsDebounced.schedule()})),this._register(Rt(h=>{const g=this._extraCommands.read(h);if(Ai(this.lastCommands,g))return;this.lastCommands=g;const f=g.map(m=>({class:void 0,id:m.id,enabled:!0,tooltip:m.tooltip||"",label:m.title,run:_=>this._commandService.executeCommand(m.id)}));for(const[m,_]of this.inlineCompletionsActionsMenus.getActions())for(const v of _)v instanceof Xr&&f.push(v);f.length>0&&f.unshift(new In),this.toolBar.setAdditionalSecondaryActions(f)}))}getId(){return this.id}getDomNode(){return this.nodes.root}getPosition(){return{position:this._position.get(),preference:[1,2],positionAffinity:3}}};Gu._dropDownVisible=!1;Gu.id=0;Gu=aS=h4([ka(6,Ei),ka(7,We),ka(8,qt),ka(9,je),ka(10,qa)],Gu);class R1e extends Em{constructor(){super(...arguments),this._className=void 0}setClass(e){this._className=e}render(e){super.render(e),this._className&&e.classList.add(this._className)}}let A1e=class extends Og{updateLabel(){const e=this._keybindingService.lookupKeybinding(this._action.id,this._contextKeyService);if(!e)return super.updateLabel();if(this.label){const t=hi("div.keybinding").root;new xC(t,Go,{disableTitle:!0,...Cpe}).set(e),this.label.textContent=this._action.label,this.label.appendChild(t),this.label.classList.add("inlineSuggestionStatusBarItemLabel")}}},zM=class extends Jy{constructor(e,t,i,n,o,r,a,l){super(e,{resetMenu:t,...i},n,o,r,a,l),this.menuId=t,this.options2=i,this.menuService=n,this.contextKeyService=o,this.menu=this._store.add(this.menuService.createMenu(this.menuId,this.contextKeyService,{emitEventsForSubmenuChanges:!0})),this.additionalActions=[],this.prependedPrimaryActions=[],this._store.add(this.menu.onDidChange(()=>this.updateToolbar())),this.updateToolbar()}updateToolbar(){var e,t,i,n,o,r,a;const l=[],d=[];hO(this.menu,(e=this.options2)===null||e===void 0?void 0:e.menuOptions,{primary:l,secondary:d},(i=(t=this.options2)===null||t===void 0?void 0:t.toolbarOptions)===null||i===void 0?void 0:i.primaryGroup,(o=(n=this.options2)===null||n===void 0?void 0:n.toolbarOptions)===null||o===void 0?void 0:o.shouldInlineSubmenu,(a=(r=this.options2)===null||r===void 0?void 0:r.toolbarOptions)===null||a===void 0?void 0:a.useSeparatorsInPrimaryActions),d.push(...this.additionalActions),l.unshift(...this.prependedPrimaryActions),this.setActions(l,d)}setPrependedPrimaryActions(e){Ai(this.prependedPrimaryActions,e,(t,i)=>t===i)||(this.prependedPrimaryActions=e,this.updateToolbar())}setAdditionalSecondaryActions(e){Ai(this.additionalActions,e,(t,i)=>t===i)||(this.additionalActions=e,this.updateToolbar())}};zM=h4([ka(3,qa),ka(4,je),ka(5,Nr),ka(6,qt),ka(7,Do)],zM);var P1e=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},nw=function(s,e){return function(t,i){e(t,i,s)}},UM;const O1e=!1;let to=UM=class extends j{static get(e){return e.getContribution(UM.ID)}constructor(e,t,i,n,o){super(),this._editor=e,this._instantiationService=t,this._openerService=i,this._languageService=n,this._keybindingService=o,this._toUnhook=new ie,this._hoverActivatedByColorDecoratorClick=!1,this._isMouseDown=!1,this._hoverClicked=!1,this._contentWidget=null,this._glyphWidget=null,this._reactToEditorMouseMoveRunner=this._register(new jt(()=>this._reactToEditorMouseMove(this._mouseMoveEvent),0)),this._hookEvents(),this._register(this._editor.onDidChangeConfiguration(r=>{r.hasChanged(60)&&(this._unhookEvents(),this._hookEvents())}))}_hookEvents(){const e=this._editor.getOption(60);this._isHoverEnabled=e.enabled,this._isHoverSticky=e.sticky,this._hidingDelay=e.hidingDelay,this._isHoverEnabled?(this._toUnhook.add(this._editor.onMouseDown(t=>this._onEditorMouseDown(t))),this._toUnhook.add(this._editor.onMouseUp(t=>this._onEditorMouseUp(t))),this._toUnhook.add(this._editor.onMouseMove(t=>this._onEditorMouseMove(t))),this._toUnhook.add(this._editor.onKeyDown(t=>this._onKeyDown(t)))):(this._toUnhook.add(this._editor.onMouseMove(t=>this._onEditorMouseMove(t))),this._toUnhook.add(this._editor.onKeyDown(t=>this._onKeyDown(t)))),this._toUnhook.add(this._editor.onMouseLeave(t=>this._onEditorMouseLeave(t))),this._toUnhook.add(this._editor.onDidChangeModel(()=>{this._cancelScheduler(),this._hideWidgets()})),this._toUnhook.add(this._editor.onDidChangeModelContent(()=>this._cancelScheduler())),this._toUnhook.add(this._editor.onDidScrollChange(t=>this._onEditorScrollChanged(t)))}_cancelScheduler(){this._mouseMoveEvent=void 0,this._reactToEditorMouseMoveRunner.cancel()}_unhookEvents(){this._toUnhook.clear()}_onEditorScrollChanged(e){(e.scrollTopChanged||e.scrollLeftChanged)&&this._hideWidgets()}_onEditorMouseDown(e){var t;this._isMouseDown=!0;const i=e.target;if(i.type===9&&i.detail===_u.ID){this._hoverClicked=!0;return}i.type===12&&i.detail===Jp.ID||(i.type!==12&&(this._hoverClicked=!1),!((t=this._contentWidget)===null||t===void 0)&&t.widget.isResizing||this._hideWidgets())}_onEditorMouseUp(e){this._isMouseDown=!1}_onEditorMouseLeave(e){var t,i;this._cancelScheduler();const n=e.event.browserEvent.relatedTarget;!((t=this._contentWidget)===null||t===void 0)&&t.widget.isResizing||!((i=this._contentWidget)===null||i===void 0)&&i.containsNode(n)||this._hideWidgets()}_isMouseOverWidget(e){var t,i,n,o,r;const a=e.target;return!!(this._isHoverSticky&&a.type===9&&a.detail===_u.ID||this._isHoverSticky&&(!((t=this._contentWidget)===null||t===void 0)&&t.containsNode((i=e.event.browserEvent.view)===null||i===void 0?void 0:i.document.activeElement))&&!(!((o=(n=e.event.browserEvent.view)===null||n===void 0?void 0:n.getSelection())===null||o===void 0)&&o.isCollapsed)||!this._isHoverSticky&&a.type===9&&a.detail===_u.ID&&(!((r=this._contentWidget)===null||r===void 0)&&r.isColorPickerVisible)||this._isHoverSticky&&a.type===12&&a.detail===Jp.ID)}_onEditorMouseMove(e){var t,i,n,o;if(this._mouseMoveEvent=e,!((t=this._contentWidget)===null||t===void 0)&&t.isFocused||!((i=this._contentWidget)===null||i===void 0)&&i.isResizing||this._isMouseDown&&this._hoverClicked||this._isHoverSticky&&(!((n=this._contentWidget)===null||n===void 0)&&n.isVisibleFromKeyboard))return;if(this._isMouseOverWidget(e)){this._reactToEditorMouseMoveRunner.cancel();return}if(!((o=this._contentWidget)===null||o===void 0)&&o.isVisible&&this._isHoverSticky&&this._hidingDelay>0){this._reactToEditorMouseMoveRunner.isScheduled()||this._reactToEditorMouseMoveRunner.schedule(this._hidingDelay);return}this._reactToEditorMouseMove(e)}_reactToEditorMouseMove(e){var t,i,n;if(!e)return;const o=e.target,r=(t=o.element)===null||t===void 0?void 0:t.classList.contains("colorpicker-color-decoration"),a=this._editor.getOption(146);if(r&&(a==="click"&&!this._hoverActivatedByColorDecoratorClick||a==="hover"&&!this._isHoverEnabled&&!O1e||a==="clickAndHover"&&!this._isHoverEnabled&&!this._hoverActivatedByColorDecoratorClick)||!r&&!this._isHoverEnabled&&!this._hoverActivatedByColorDecoratorClick){this._hideWidgets();return}if(this._getOrCreateContentWidget().maybeShowAt(e)){(i=this._glyphWidget)===null||i===void 0||i.hide();return}if(o.type===2&&o.position){(n=this._contentWidget)===null||n===void 0||n.hide(),this._glyphWidget||(this._glyphWidget=new Jp(this._editor,this._languageService,this._openerService)),this._glyphWidget.startShowingAt(o.position.lineNumber);return}this._hideWidgets()}_onKeyDown(e){var t;if(!this._editor.hasModel())return;const i=this._keybindingService.softDispatch(e,this._editor.getDomNode()),n=i.kind===1||i.kind===2&&i.commandId==="editor.action.showHover"&&((t=this._contentWidget)===null||t===void 0?void 0:t.isVisible);e.keyCode!==5&&e.keyCode!==6&&e.keyCode!==57&&e.keyCode!==4&&!n&&this._hideWidgets()}_hideWidgets(){var e,t,i;this._isMouseDown&&this._hoverClicked&&(!((e=this._contentWidget)===null||e===void 0)&&e.isColorPickerVisible)||Gu.dropDownVisible||(this._hoverActivatedByColorDecoratorClick=!1,this._hoverClicked=!1,(t=this._glyphWidget)===null||t===void 0||t.hide(),(i=this._contentWidget)===null||i===void 0||i.hide())}_getOrCreateContentWidget(){return this._contentWidget||(this._contentWidget=this._instantiationService.createInstance(oL,this._editor)),this._contentWidget}showContentHover(e,t,i,n,o=!1){this._hoverActivatedByColorDecoratorClick=o,this._getOrCreateContentWidget().startShowingAtRange(e,t,i,n)}focus(){var e;(e=this._contentWidget)===null||e===void 0||e.focus()}scrollUp(){var e;(e=this._contentWidget)===null||e===void 0||e.scrollUp()}scrollDown(){var e;(e=this._contentWidget)===null||e===void 0||e.scrollDown()}scrollLeft(){var e;(e=this._contentWidget)===null||e===void 0||e.scrollLeft()}scrollRight(){var e;(e=this._contentWidget)===null||e===void 0||e.scrollRight()}pageUp(){var e;(e=this._contentWidget)===null||e===void 0||e.pageUp()}pageDown(){var e;(e=this._contentWidget)===null||e===void 0||e.pageDown()}goToTop(){var e;(e=this._contentWidget)===null||e===void 0||e.goToTop()}goToBottom(){var e;(e=this._contentWidget)===null||e===void 0||e.goToBottom()}get isColorPickerVisible(){var e;return(e=this._contentWidget)===null||e===void 0?void 0:e.isColorPickerVisible}get isHoverVisible(){var e;return(e=this._contentWidget)===null||e===void 0?void 0:e.isVisible}dispose(){var e,t;super.dispose(),this._unhookEvents(),this._toUnhook.dispose(),(e=this._glyphWidget)===null||e===void 0||e.dispose(),(t=this._contentWidget)===null||t===void 0||t.dispose()}};to.ID="editor.contrib.hover";to=UM=P1e([nw(1,We),nw(2,No),nw(3,fi),nw(4,qt)],to);var ga;(function(s){s.NoAutoFocus="noAutoFocus",s.FocusIfVisible="focusIfVisible",s.AutoFocusImmediately="autoFocusImmediately"})(ga||(ga={}));class F1e extends we{constructor(){super({id:"editor.action.showHover",label:p({key:"showOrFocusHover",comment:["Label for action that will trigger the showing/focusing of a hover in the editor.","If the hover is not visible, it will show the hover.","This allows for users to show the hover without using the mouse."]},"Show or Focus Hover"),metadata:{description:"Show or Focus Hover",args:[{name:"args",schema:{type:"object",properties:{focus:{description:"Controls if and when the hover should take focus upon being triggered by this action.",enum:[ga.NoAutoFocus,ga.FocusIfVisible,ga.AutoFocusImmediately],enumDescriptions:[p("showOrFocusHover.focus.noAutoFocus","The hover will not automatically take focus."),p("showOrFocusHover.focus.focusIfVisible","The hover will take focus only if it is already visible."),p("showOrFocusHover.focus.autoFocusImmediately","The hover will automatically take focus when it appears.")],default:ga.FocusIfVisible}}}}]},alias:"Show or Focus Hover",precondition:void 0,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2087),weight:100}})}run(e,t,i){if(!t.hasModel())return;const n=to.get(t);if(!n)return;const o=i==null?void 0:i.focus;let r=ga.FocusIfVisible;o in ga?r=o:typeof o=="boolean"&&o&&(r=ga.AutoFocusImmediately);const a=d=>{const c=t.getPosition(),u=new D(c.lineNumber,c.column,c.lineNumber,c.column);n.showContentHover(u,1,1,d)},l=t.getOption(2)===2;n.isHoverVisible?r!==ga.NoAutoFocus?n.focus():a(l):a(l||r===ga.AutoFocusImmediately)}}class B1e extends we{constructor(){super({id:"editor.action.showDefinitionPreviewHover",label:p({key:"showDefinitionPreviewHover",comment:["Label for action that will trigger the showing of definition preview hover in the editor.","This allows for users to show the definition preview hover without using the mouse."]},"Show Definition Preview Hover"),alias:"Show Definition Preview Hover",precondition:void 0})}run(e,t){const i=to.get(t);if(!i)return;const n=t.getPosition();if(!n)return;const o=new D(n.lineNumber,n.column,n.lineNumber,n.column),r=Kg.get(t);if(!r)return;r.startFindDefinitionFromCursor(n).then(()=>{i.showContentHover(o,1,1,!0)})}}class W1e extends we{constructor(){super({id:"editor.action.scrollUpHover",label:p({key:"scrollUpHover",comment:["Action that allows to scroll up in the hover widget with the up arrow when the hover widget is focused."]},"Scroll Up Hover"),alias:"Scroll Up Hover",precondition:T.hoverFocused,kbOpts:{kbExpr:T.hoverFocused,primary:16,weight:100}})}run(e,t){const i=to.get(t);i&&i.scrollUp()}}class V1e extends we{constructor(){super({id:"editor.action.scrollDownHover",label:p({key:"scrollDownHover",comment:["Action that allows to scroll down in the hover widget with the up arrow when the hover widget is focused."]},"Scroll Down Hover"),alias:"Scroll Down Hover",precondition:T.hoverFocused,kbOpts:{kbExpr:T.hoverFocused,primary:18,weight:100}})}run(e,t){const i=to.get(t);i&&i.scrollDown()}}class H1e extends we{constructor(){super({id:"editor.action.scrollLeftHover",label:p({key:"scrollLeftHover",comment:["Action that allows to scroll left in the hover widget with the left arrow when the hover widget is focused."]},"Scroll Left Hover"),alias:"Scroll Left Hover",precondition:T.hoverFocused,kbOpts:{kbExpr:T.hoverFocused,primary:15,weight:100}})}run(e,t){const i=to.get(t);i&&i.scrollLeft()}}class z1e extends we{constructor(){super({id:"editor.action.scrollRightHover",label:p({key:"scrollRightHover",comment:["Action that allows to scroll right in the hover widget with the right arrow when the hover widget is focused."]},"Scroll Right Hover"),alias:"Scroll Right Hover",precondition:T.hoverFocused,kbOpts:{kbExpr:T.hoverFocused,primary:17,weight:100}})}run(e,t){const i=to.get(t);i&&i.scrollRight()}}class U1e extends we{constructor(){super({id:"editor.action.pageUpHover",label:p({key:"pageUpHover",comment:["Action that allows to page up in the hover widget with the page up command when the hover widget is focused."]},"Page Up Hover"),alias:"Page Up Hover",precondition:T.hoverFocused,kbOpts:{kbExpr:T.hoverFocused,primary:11,secondary:[528],weight:100}})}run(e,t){const i=to.get(t);i&&i.pageUp()}}class $1e extends we{constructor(){super({id:"editor.action.pageDownHover",label:p({key:"pageDownHover",comment:["Action that allows to page down in the hover widget with the page down command when the hover widget is focused."]},"Page Down Hover"),alias:"Page Down Hover",precondition:T.hoverFocused,kbOpts:{kbExpr:T.hoverFocused,primary:12,secondary:[530],weight:100}})}run(e,t){const i=to.get(t);i&&i.pageDown()}}class j1e extends we{constructor(){super({id:"editor.action.goToTopHover",label:p({key:"goToTopHover",comment:["Action that allows to go to the top of the hover widget with the home command when the hover widget is focused."]},"Go To Top Hover"),alias:"Go To Bottom Hover",precondition:T.hoverFocused,kbOpts:{kbExpr:T.hoverFocused,primary:14,secondary:[2064],weight:100}})}run(e,t){const i=to.get(t);i&&i.goToTop()}}class K1e extends we{constructor(){super({id:"editor.action.goToBottomHover",label:p({key:"goToBottomHover",comment:["Action that allows to go to the bottom in the hover widget with the end command when the hover widget is focused."]},"Go To Bottom Hover"),alias:"Go To Bottom Hover",precondition:T.hoverFocused,kbOpts:{kbExpr:T.hoverFocused,primary:13,secondary:[2066],weight:100}})}run(e,t){const i=to.get(t);i&&i.goToBottom()}}Lt(to.ID,to,2);re(F1e);re(B1e);re(W1e);re(V1e);re(H1e);re(z1e);re(U1e);re($1e);re(j1e);re(K1e);wf.register(lL);wf.register(VM);ia((s,e)=>{const t=s.getColor(Tse);t&&(e.addRule(`.monaco-editor .monaco-hover .hover-row:not(:first-child):not(:empty) { border-top: 1px solid ${t.transparent(.5)}; }`),e.addRule(`.monaco-editor .monaco-hover hr { border-top: 1px solid ${t.transparent(.5)}; }`),e.addRule(`.monaco-editor .monaco-hover hr { border-bottom: 0px solid ${t.transparent(.5)}; }`))});class $M extends j{constructor(e){super(),this._editor=e,this._register(e.onMouseDown(t=>this.onMouseDown(t)))}dispose(){super.dispose()}onMouseDown(e){const t=this._editor.getOption(146);if(t!=="click"&&t!=="clickAndHover")return;const i=e.target;if(i.type!==6||!i.detail.injectedText||i.detail.injectedText.options.attachedData!==aj||!i.range)return;const n=this._editor.getContribution(to.ID);if(n&&!n.isColorPickerVisible){const o=new D(i.range.startLineNumber,i.range.startColumn+1,i.range.endLineNumber,i.range.endColumn+1);n.showContentHover(o,1,0,!1,!0)}}}$M.ID="editor.contrib.colorContribution";Lt($M.ID,$M,2);wf.register(nL);var Fj=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Sa=function(s,e){return function(t,i){e(t,i,s)}},jM,KM;let Zu=jM=class extends j{constructor(e,t,i,n,o,r,a){super(),this._editor=e,this._modelService=i,this._keybindingService=n,this._instantiationService=o,this._languageFeatureService=r,this._languageConfigurationService=a,this._standaloneColorPickerWidget=null,this._standaloneColorPickerVisible=T.standaloneColorPickerVisible.bindTo(t),this._standaloneColorPickerFocused=T.standaloneColorPickerFocused.bindTo(t)}showOrFocus(){var e;this._editor.hasModel()&&(this._standaloneColorPickerVisible.get()?this._standaloneColorPickerFocused.get()||(e=this._standaloneColorPickerWidget)===null||e===void 0||e.focus():this._standaloneColorPickerWidget=new cL(this._editor,this._standaloneColorPickerVisible,this._standaloneColorPickerFocused,this._instantiationService,this._modelService,this._keybindingService,this._languageFeatureService,this._languageConfigurationService))}hide(){var e;this._standaloneColorPickerFocused.set(!1),this._standaloneColorPickerVisible.set(!1),(e=this._standaloneColorPickerWidget)===null||e===void 0||e.hide(),this._editor.focus()}insertColor(){var e;(e=this._standaloneColorPickerWidget)===null||e===void 0||e.updateEditor(),this.hide()}static get(e){return e.getContribution(jM.ID)}};Zu.ID="editor.contrib.standaloneColorPickerController";Zu=jM=Fj([Sa(1,je),Sa(2,vi),Sa(3,qt),Sa(4,We),Sa(5,xe),Sa(6,Jt)],Zu);Lt(Zu.ID,Zu,1);const G8=8,q1e=22;let cL=KM=class extends j{constructor(e,t,i,n,o,r,a,l){var d;super(),this._editor=e,this._standaloneColorPickerVisible=t,this._standaloneColorPickerFocused=i,this._modelService=o,this._keybindingService=r,this._languageFeaturesService=a,this._languageConfigurationService=l,this.allowEditorOverflow=!0,this._position=void 0,this._body=document.createElement("div"),this._colorHover=null,this._selectionSetInEditor=!1,this._onResult=this._register(new W),this.onResult=this._onResult.event,this._standaloneColorPickerVisible.set(!0),this._standaloneColorPickerParticipant=n.createInstance(Lb,this._editor),this._position=(d=this._editor._getViewModel())===null||d===void 0?void 0:d.getPrimaryCursorState().modelState.position;const c=this._editor.getSelection(),u=c?{startLineNumber:c.startLineNumber,startColumn:c.startColumn,endLineNumber:c.endLineNumber,endColumn:c.endColumn}:{startLineNumber:0,endLineNumber:0,endColumn:0,startColumn:0},h=this._register(ql(this._body));this._register(h.onDidBlur(g=>{this.hide()})),this._register(h.onDidFocus(g=>{this.focus()})),this._register(this._editor.onDidChangeCursorPosition(()=>{this._selectionSetInEditor?this._selectionSetInEditor=!1:this.hide()})),this._register(this._editor.onMouseMove(g=>{var f;const m=(f=g.target.element)===null||f===void 0?void 0:f.classList;m&&m.contains("colorpicker-color-decoration")&&this.hide()})),this._register(this.onResult(g=>{this._render(g.value,g.foundInEditor)})),this._start(u),this._body.style.zIndex="50",this._editor.addContentWidget(this)}updateEditor(){this._colorHover&&this._standaloneColorPickerParticipant.updateEditorModel(this._colorHover)}getId(){return KM.ID}getDomNode(){return this._body}getPosition(){if(!this._position)return null;const e=this._editor.getOption(60).above;return{position:this._position,secondaryPosition:this._position,preference:e?[1,2]:[2,1],positionAffinity:2}}hide(){this.dispose(),this._standaloneColorPickerVisible.set(!1),this._standaloneColorPickerFocused.set(!1),this._editor.removeContentWidget(this),this._editor.focus()}focus(){this._standaloneColorPickerFocused.set(!0),this._body.focus()}async _start(e){const t=await this._computeAsync(e);t&&this._onResult.fire(new G1e(t.result,t.foundInEditor))}async _computeAsync(e){if(!this._editor.hasModel())return null;const t={range:e,color:{red:0,green:0,blue:0,alpha:1}},i=await this._standaloneColorPickerParticipant.createColorHover(t,new o4(this._modelService,this._languageConfigurationService),this._languageFeaturesService.colorProvider);return i?{result:i.colorHover,foundInEditor:i.foundInEditor}:null}_render(e,t){const i=document.createDocumentFragment(),n=this._register(new rL(this._keybindingService));let o;const r={fragment:i,statusBar:n,setColorPicker:m=>o=m,onContentsChanged:()=>{},hide:()=>this.hide()};if(this._colorHover=e,this._register(this._standaloneColorPickerParticipant.renderHoverParts(r,[e])),o===void 0)return;this._body.classList.add("standalone-colorpicker-body"),this._body.style.maxHeight=Math.max(this._editor.getLayoutInfo().height/4,250)+"px",this._body.style.maxWidth=Math.max(this._editor.getLayoutInfo().width*.66,500)+"px",this._body.tabIndex=0,this._body.appendChild(i),o.layout();const a=o.body,l=a.saturationBox.domNode.clientWidth,d=a.domNode.clientWidth-l-q1e-G8,c=o.body.enterButton;c==null||c.onClicked(()=>{this.updateEditor(),this.hide()});const u=o.header,h=u.pickedColorNode;h.style.width=l+G8+"px";const g=u.originalColorNode;g.style.width=d+"px";const f=o.header.closeButton;f==null||f.onClicked(()=>{this.hide()}),t&&(c&&(c.button.textContent="Replace"),this._selectionSetInEditor=!0,this._editor.setSelection(e.range)),this._editor.layoutContentWidget(this)}};cL.ID="editor.contrib.standaloneColorPickerWidget";cL=KM=Fj([Sa(3,We),Sa(4,vi),Sa(5,qt),Sa(6,xe),Sa(7,Jt)],cL);class G1e{constructor(e,t){this.value=e,this.foundInEditor=t}}class Z1e extends Ga{constructor(){super({id:"editor.action.showOrFocusStandaloneColorPicker",title:{value:p("showOrFocusStandaloneColorPicker","Show or Focus Standalone Color Picker"),mnemonicTitle:p({key:"mishowOrFocusStandaloneColorPicker",comment:["&& denotes a mnemonic"]},"&&Show or Focus Standalone Color Picker"),original:"Show or Focus Standalone Color Picker"},precondition:void 0,menu:[{id:N.CommandPalette}]})}runEditorCommand(e,t){var i;(i=Zu.get(t))===null||i===void 0||i.showOrFocus()}}class Y1e extends we{constructor(){super({id:"editor.action.hideColorPicker",label:p({key:"hideColorPicker",comment:["Action that hides the color picker"]},"Hide the Color Picker"),alias:"Hide the Color Picker",precondition:T.standaloneColorPickerVisible.isEqualTo(!0),kbOpts:{primary:9,weight:100}})}run(e,t){var i;(i=Zu.get(t))===null||i===void 0||i.hide()}}class X1e extends we{constructor(){super({id:"editor.action.insertColorWithStandaloneColorPicker",label:p({key:"insertColorWithStandaloneColorPicker",comment:["Action that inserts color with standalone color picker"]},"Insert Color with Standalone Color Picker"),alias:"Insert Color with Standalone Color Picker",precondition:T.standaloneColorPickerFocused.isEqualTo(!0),kbOpts:{primary:3,weight:100}})}run(e,t){var i;(i=Zu.get(t))===null||i===void 0||i.insertColor()}}re(Y1e);re(X1e);di(Z1e);class Qc{constructor(e,t,i){this.languageConfigurationService=i,this._selection=e,this._insertSpace=t,this._usedEndToken=null}static _haystackHasNeedleAtOffset(e,t,i){if(i<0)return!1;const n=t.length,o=e.length;if(i+n>o)return!1;for(let r=0;r<n;r++){const a=e.charCodeAt(i+r),l=t.charCodeAt(r);if(a!==l&&!(a>=65&&a<=90&&a+32===l)&&!(l>=65&&l<=90&&l+32===a))return!1}return!0}_createOperationsForBlockComment(e,t,i,n,o,r){const a=e.startLineNumber,l=e.startColumn,d=e.endLineNumber,c=e.endColumn,u=o.getLineContent(a),h=o.getLineContent(d);let g=u.lastIndexOf(t,l-1+t.length),f=h.indexOf(i,c-1-i.length);if(g!==-1&&f!==-1)if(a===d)u.substring(g+t.length,f).indexOf(i)>=0&&(g=-1,f=-1);else{const _=u.substring(g+t.length),v=h.substring(0,f);(_.indexOf(i)>=0||v.indexOf(i)>=0)&&(g=-1,f=-1)}let m;g!==-1&&f!==-1?(n&&g+t.length<u.length&&u.charCodeAt(g+t.length)===32&&(t=t+" "),n&&f>0&&h.charCodeAt(f-1)===32&&(i=" "+i,f-=1),m=Qc._createRemoveBlockCommentOperations(new D(a,g+t.length+1,d,f+1),t,i)):(m=Qc._createAddBlockCommentOperations(e,t,i,this._insertSpace),this._usedEndToken=m.length===1?i:null);for(const _ of m)r.addTrackedEditOperation(_.range,_.text)}static _createRemoveBlockCommentOperations(e,t,i){const n=[];return D.isEmpty(e)?n.push(_i.delete(new D(e.startLineNumber,e.startColumn-t.length,e.endLineNumber,e.endColumn+i.length))):(n.push(_i.delete(new D(e.startLineNumber,e.startColumn-t.length,e.startLineNumber,e.startColumn))),n.push(_i.delete(new D(e.endLineNumber,e.endColumn,e.endLineNumber,e.endColumn+i.length)))),n}static _createAddBlockCommentOperations(e,t,i,n){const o=[];return D.isEmpty(e)?o.push(_i.replace(new D(e.startLineNumber,e.startColumn,e.endLineNumber,e.endColumn),t+"  "+i)):(o.push(_i.insert(new H(e.startLineNumber,e.startColumn),t+(n?" ":""))),o.push(_i.insert(new H(e.endLineNumber,e.endColumn),(n?" ":"")+i))),o}getEditOperations(e,t){const i=this._selection.startLineNumber,n=this._selection.startColumn;e.tokenization.tokenizeIfCheap(i);const o=e.getLanguageIdAtPosition(i,n),r=this.languageConfigurationService.getLanguageConfiguration(o).comments;!r||!r.blockCommentStartToken||!r.blockCommentEndToken||this._createOperationsForBlockComment(this._selection,r.blockCommentStartToken,r.blockCommentEndToken,this._insertSpace,e,t)}computeCursorState(e,t){const i=t.getInverseEditOperations();if(i.length===2){const n=i[0],o=i[1];return new De(n.range.endLineNumber,n.range.endColumn,o.range.startLineNumber,o.range.startColumn)}else{const n=i[0].range,o=this._usedEndToken?-this._usedEndToken.length-1:0;return new De(n.endLineNumber,n.endColumn+o,n.endLineNumber,n.endColumn+o)}}}class Sd{constructor(e,t,i,n,o,r,a){this.languageConfigurationService=e,this._selection=t,this._tabSize=i,this._type=n,this._insertSpace=o,this._selectionId=null,this._deltaColumn=0,this._moveEndPositionDown=!1,this._ignoreEmptyLines=r,this._ignoreFirstLine=a||!1}static _gatherPreflightCommentStrings(e,t,i,n){e.tokenization.tokenizeIfCheap(t);const o=e.getLanguageIdAtPosition(t,1),r=n.getLanguageConfiguration(o).comments,a=r?r.lineCommentToken:null;if(!a)return null;const l=[];for(let d=0,c=i-t+1;d<c;d++)l[d]={ignore:!1,commentStr:a,commentStrOffset:0,commentStrLength:a.length};return l}static _analyzeLines(e,t,i,n,o,r,a,l){let d=!0,c;e===0?c=!0:e===1?c=!1:c=!0;for(let u=0,h=n.length;u<h;u++){const g=n[u],f=o+u;if(f===o&&a){g.ignore=!0;continue}const m=i.getLineContent(f),_=ws(m);if(_===-1){g.ignore=r,g.commentStrOffset=m.length;continue}if(d=!1,g.ignore=!1,g.commentStrOffset=_,c&&!Qc._haystackHasNeedleAtOffset(m,g.commentStr,_)&&(e===0?c=!1:e===1||(g.ignore=!0)),c&&t){const v=_+g.commentStrLength;v<m.length&&m.charCodeAt(v)===32&&(g.commentStrLength+=1)}}if(e===0&&d){c=!1;for(let u=0,h=n.length;u<h;u++)n[u].ignore=!1}return{supported:!0,shouldRemoveComments:c,lines:n}}static _gatherPreflightData(e,t,i,n,o,r,a,l){const d=Sd._gatherPreflightCommentStrings(i,n,o,l);return d===null?{supported:!1}:Sd._analyzeLines(e,t,i,d,n,r,a,l)}_executeLineComments(e,t,i,n){let o;i.shouldRemoveComments?o=Sd._createRemoveLineCommentsOperations(i.lines,n.startLineNumber):(Sd._normalizeInsertionPoint(e,i.lines,n.startLineNumber,this._tabSize),o=this._createAddLineCommentsOperations(i.lines,n.startLineNumber));const r=new H(n.positionLineNumber,n.positionColumn);for(let a=0,l=o.length;a<l;a++)t.addEditOperation(o[a].range,o[a].text),D.isEmpty(o[a].range)&&D.getStartPosition(o[a].range).equals(r)&&e.getLineContent(r.lineNumber).length+1===r.column&&(this._deltaColumn=(o[a].text||"").length);this._selectionId=t.trackSelection(n)}_attemptRemoveBlockComment(e,t,i,n){let o=t.startLineNumber,r=t.endLineNumber;const a=n.length+Math.max(e.getLineFirstNonWhitespaceColumn(t.startLineNumber),t.startColumn);let l=e.getLineContent(o).lastIndexOf(i,a-1),d=e.getLineContent(r).indexOf(n,t.endColumn-1-i.length);return l!==-1&&d===-1&&(d=e.getLineContent(o).indexOf(n,l+i.length),r=o),l===-1&&d!==-1&&(l=e.getLineContent(r).lastIndexOf(i,d),o=r),t.isEmpty()&&(l===-1||d===-1)&&(l=e.getLineContent(o).indexOf(i),l!==-1&&(d=e.getLineContent(o).indexOf(n,l+i.length))),l!==-1&&e.getLineContent(o).charCodeAt(l+i.length)===32&&(i+=" "),d!==-1&&e.getLineContent(r).charCodeAt(d-1)===32&&(n=" "+n,d-=1),l!==-1&&d!==-1?Qc._createRemoveBlockCommentOperations(new D(o,l+i.length+1,r,d+1),i,n):null}_executeBlockComment(e,t,i){e.tokenization.tokenizeIfCheap(i.startLineNumber);const n=e.getLanguageIdAtPosition(i.startLineNumber,1),o=this.languageConfigurationService.getLanguageConfiguration(n).comments;if(!o||!o.blockCommentStartToken||!o.blockCommentEndToken)return;const r=o.blockCommentStartToken,a=o.blockCommentEndToken;let l=this._attemptRemoveBlockComment(e,i,r,a);if(!l){if(i.isEmpty()){const d=e.getLineContent(i.startLineNumber);let c=ws(d);c===-1&&(c=d.length),l=Qc._createAddBlockCommentOperations(new D(i.startLineNumber,c+1,i.startLineNumber,d.length+1),r,a,this._insertSpace)}else l=Qc._createAddBlockCommentOperations(new D(i.startLineNumber,e.getLineFirstNonWhitespaceColumn(i.startLineNumber),i.endLineNumber,e.getLineMaxColumn(i.endLineNumber)),r,a,this._insertSpace);l.length===1&&(this._deltaColumn=r.length+1)}this._selectionId=t.trackSelection(i);for(const d of l)t.addEditOperation(d.range,d.text)}getEditOperations(e,t){let i=this._selection;if(this._moveEndPositionDown=!1,i.startLineNumber===i.endLineNumber&&this._ignoreFirstLine){t.addEditOperation(new D(i.startLineNumber,e.getLineMaxColumn(i.startLineNumber),i.startLineNumber+1,1),i.startLineNumber===e.getLineCount()?"":`
`),this._selectionId=t.trackSelection(i);return}i.startLineNumber<i.endLineNumber&&i.endColumn===1&&(this._moveEndPositionDown=!0,i=i.setEndPosition(i.endLineNumber-1,e.getLineMaxColumn(i.endLineNumber-1)));const n=Sd._gatherPreflightData(this._type,this._insertSpace,e,i.startLineNumber,i.endLineNumber,this._ignoreEmptyLines,this._ignoreFirstLine,this.languageConfigurationService);return n.supported?this._executeLineComments(e,t,n,i):this._executeBlockComment(e,t,i)}computeCursorState(e,t){let i=t.getTrackedSelection(this._selectionId);return this._moveEndPositionDown&&(i=i.setEndPosition(i.endLineNumber+1,1)),new De(i.selectionStartLineNumber,i.selectionStartColumn+this._deltaColumn,i.positionLineNumber,i.positionColumn+this._deltaColumn)}static _createRemoveLineCommentsOperations(e,t){const i=[];for(let n=0,o=e.length;n<o;n++){const r=e[n];r.ignore||i.push(_i.delete(new D(t+n,r.commentStrOffset+1,t+n,r.commentStrOffset+r.commentStrLength+1)))}return i}_createAddLineCommentsOperations(e,t){const i=[],n=this._insertSpace?" ":"";for(let o=0,r=e.length;o<r;o++){const a=e[o];a.ignore||i.push(_i.insert(new H(t+o,a.commentStrOffset+1),a.commentStr+n))}return i}static nextVisibleColumn(e,t,i,n){return i?e+(t-e%t):e+n}static _normalizeInsertionPoint(e,t,i,n){let o=1073741824,r,a;for(let l=0,d=t.length;l<d;l++){if(t[l].ignore)continue;const c=e.getLineContent(i+l);let u=0;for(let h=0,g=t[l].commentStrOffset;u<o&&h<g;h++)u=Sd.nextVisibleColumn(u,n,c.charCodeAt(h)===9,1);u<o&&(o=u)}o=Math.floor(o/n)*n;for(let l=0,d=t.length;l<d;l++){if(t[l].ignore)continue;const c=e.getLineContent(i+l);let u=0;for(r=0,a=t[l].commentStrOffset;u<o&&r<a;r++)u=Sd.nextVisibleColumn(u,n,c.charCodeAt(r)===9,1);u>o?t[l].commentStrOffset=r-1:t[l].commentStrOffset=r}}}class g4 extends we{constructor(e,t){super(t),this._type=e}run(e,t){const i=e.get(Jt);if(!t.hasModel())return;const n=t.getModel(),o=[],r=n.getOptions(),a=t.getOption(23),l=t.getSelections().map((c,u)=>({selection:c,index:u,ignoreFirstLine:!1}));l.sort((c,u)=>D.compareRangesUsingStarts(c.selection,u.selection));let d=l[0];for(let c=1;c<l.length;c++){const u=l[c];d.selection.endLineNumber===u.selection.startLineNumber&&(d.index<u.index?u.ignoreFirstLine=!0:(d.ignoreFirstLine=!0,d=u))}for(const c of l)o.push(new Sd(i,c.selection,r.tabSize,this._type,a.insertSpace,a.ignoreEmptyLines,c.ignoreFirstLine));t.pushUndoStop(),t.executeCommands(this.id,o),t.pushUndoStop()}}class Q1e extends g4{constructor(){super(0,{id:"editor.action.commentLine",label:p("comment.line","Toggle Line Comment"),alias:"Toggle Line Comment",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:2138,weight:100},menuOpts:{menuId:N.MenubarEditMenu,group:"5_insert",title:p({key:"miToggleLineComment",comment:["&& denotes a mnemonic"]},"&&Toggle Line Comment"),order:1}})}}class J1e extends g4{constructor(){super(1,{id:"editor.action.addCommentLine",label:p("comment.line.add","Add Line Comment"),alias:"Add Line Comment",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2081),weight:100}})}}class ewe extends g4{constructor(){super(2,{id:"editor.action.removeCommentLine",label:p("comment.line.remove","Remove Line Comment"),alias:"Remove Line Comment",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2099),weight:100}})}}class twe extends we{constructor(){super({id:"editor.action.blockComment",label:p("comment.block","Toggle Block Comment"),alias:"Toggle Block Comment",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:1567,linux:{primary:3103},weight:100},menuOpts:{menuId:N.MenubarEditMenu,group:"5_insert",title:p({key:"miToggleBlockComment",comment:["&& denotes a mnemonic"]},"Toggle &&Block Comment"),order:2}})}run(e,t){const i=e.get(Jt);if(!t.hasModel())return;const n=t.getOption(23),o=[],r=t.getSelections();for(const a of r)o.push(new Qc(a,n.insertSpace,i));t.pushUndoStop(),t.executeCommands(this.id,o),t.pushUndoStop()}}re(Q1e);re(J1e);re(ewe);re(twe);var iwe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},kh=function(s,e){return function(t,i){e(t,i,s)}},qM;let Vm=qM=class{static get(e){return e.getContribution(qM.ID)}constructor(e,t,i,n,o,r,a,l){this._contextMenuService=t,this._contextViewService=i,this._contextKeyService=n,this._keybindingService=o,this._menuService=r,this._configurationService=a,this._workspaceContextService=l,this._toDispose=new ie,this._contextMenuIsBeingShownCount=0,this._editor=e,this._toDispose.add(this._editor.onContextMenu(d=>this._onContextMenu(d))),this._toDispose.add(this._editor.onMouseWheel(d=>{if(this._contextMenuIsBeingShownCount>0){const c=this._contextViewService.getContextViewElement(),u=d.srcElement;u.shadowRoot&&Tg(c)===u.shadowRoot||this._contextViewService.hideContextView()}})),this._toDispose.add(this._editor.onKeyDown(d=>{this._editor.getOption(24)&&d.keyCode===58&&(d.preventDefault(),d.stopPropagation(),this.showContextMenu())}))}_onContextMenu(e){if(!this._editor.hasModel())return;if(!this._editor.getOption(24)){this._editor.focus(),e.target.position&&!this._editor.getSelection().containsPosition(e.target.position)&&this._editor.setPosition(e.target.position);return}if(e.target.type===12||e.target.type===6&&e.target.detail.injectedText)return;if(e.event.preventDefault(),e.event.stopPropagation(),e.target.type===11)return this._showScrollbarContextMenu(e.event);if(e.target.type!==6&&e.target.type!==7&&e.target.type!==1)return;if(this._editor.focus(),e.target.position){let i=!1;for(const n of this._editor.getSelections())if(n.containsPosition(e.target.position)){i=!0;break}i||this._editor.setPosition(e.target.position)}let t=null;e.target.type!==1&&(t=e.event),this.showContextMenu(t)}showContextMenu(e){if(!this._editor.getOption(24)||!this._editor.hasModel())return;const t=this._getMenuActions(this._editor.getModel(),this._editor.isSimpleWidget?N.SimpleEditorContext:N.EditorContext);t.length>0&&this._doShowContextMenu(t,e)}_getMenuActions(e,t){const i=[],n=this._menuService.createMenu(t,this._contextKeyService),o=n.getActions({arg:e.uri});n.dispose();for(const r of o){const[,a]=r;let l=0;for(const d of a)if(d instanceof E0){const c=this._getMenuActions(e,d.item.submenu);c.length>0&&(i.push(new cm(d.id,d.label,c)),l++)}else i.push(d),l++;l&&i.push(new In)}return i.length&&i.pop(),i}_doShowContextMenu(e,t=null){if(!this._editor.hasModel())return;const i=this._editor.getOption(60);this._editor.updateOptions({hover:{enabled:!1}});let n=t;if(!n){this._editor.revealPosition(this._editor.getPosition(),1),this._editor.render();const r=this._editor.getScrolledVisiblePosition(this._editor.getPosition()),a=ln(this._editor.getDomNode()),l=a.left+r.left,d=a.top+r.top+r.height;n={x:l,y:d}}const o=this._editor.getOption(126)&&!Wa;this._contextMenuIsBeingShownCount++,this._contextMenuService.showContextMenu({domForShadowRoot:o?this._editor.getDomNode():void 0,getAnchor:()=>n,getActions:()=>e,getActionViewItem:r=>{const a=this._keybindingFor(r);if(a)return new Em(r,r,{label:!0,keybinding:a.getLabel(),isMenu:!0});const l=r;return typeof l.getActionViewItem=="function"?l.getActionViewItem():new Em(r,r,{icon:!0,label:!0,isMenu:!0})},getKeyBinding:r=>this._keybindingFor(r),onHide:r=>{this._contextMenuIsBeingShownCount--,this._editor.updateOptions({hover:i})}})}_showScrollbarContextMenu(e){if(!this._editor.hasModel()||jue(this._workspaceContextService.getWorkspace()))return;const t=this._editor.getOption(72);let i=0;const n=d=>({id:`menu-action-${++i}`,label:d.label,tooltip:"",class:void 0,enabled:typeof d.enabled>"u"?!0:d.enabled,checked:d.checked,run:d.run}),o=(d,c)=>new cm(`menu-action-${++i}`,d,c,void 0),r=(d,c,u,h,g)=>{if(!c)return n({label:d,enabled:c,run:()=>{}});const f=_=>()=>{this._configurationService.updateValue(u,_)},m=[];for(const _ of g)m.push(n({label:_.label,checked:h===_.value,run:f(_.value)}));return o(d,m)},a=[];a.push(n({label:p("context.minimap.minimap","Minimap"),checked:t.enabled,run:()=>{this._configurationService.updateValue("editor.minimap.enabled",!t.enabled)}})),a.push(new In),a.push(n({label:p("context.minimap.renderCharacters","Render Characters"),enabled:t.enabled,checked:t.renderCharacters,run:()=>{this._configurationService.updateValue("editor.minimap.renderCharacters",!t.renderCharacters)}})),a.push(r(p("context.minimap.size","Vertical size"),t.enabled,"editor.minimap.size",t.size,[{label:p("context.minimap.size.proportional","Proportional"),value:"proportional"},{label:p("context.minimap.size.fill","Fill"),value:"fill"},{label:p("context.minimap.size.fit","Fit"),value:"fit"}])),a.push(r(p("context.minimap.slider","Slider"),t.enabled,"editor.minimap.showSlider",t.showSlider,[{label:p("context.minimap.slider.mouseover","Mouse Over"),value:"mouseover"},{label:p("context.minimap.slider.always","Always"),value:"always"}]));const l=this._editor.getOption(126)&&!Wa;this._contextMenuIsBeingShownCount++,this._contextMenuService.showContextMenu({domForShadowRoot:l?this._editor.getDomNode():void 0,getAnchor:()=>e,getActions:()=>a,onHide:d=>{this._contextMenuIsBeingShownCount--,this._editor.focus()}})}_keybindingFor(e){return this._keybindingService.lookupKeybinding(e.id)}dispose(){this._contextMenuIsBeingShownCount>0&&this._contextViewService.hideContextView(),this._toDispose.dispose()}};Vm.ID="editor.contrib.contextmenu";Vm=qM=iwe([kh(1,Nr),kh(2,rc),kh(3,je),kh(4,qt),kh(5,qa),kh(6,mt),kh(7,Ag)],Vm);class nwe extends we{constructor(){super({id:"editor.action.showContextMenu",label:p("action.showContextMenu.label","Show Editor Context Menu"),alias:"Show Editor Context Menu",precondition:void 0,kbOpts:{kbExpr:T.textInputFocus,primary:1092,weight:100}})}run(e,t){var i;(i=Vm.get(t))===null||i===void 0||i.showContextMenu()}}Lt(Vm.ID,Vm,2);re(nwe);class cE{constructor(e){this.selections=e}equals(e){const t=this.selections.length,i=e.selections.length;if(t!==i)return!1;for(let n=0;n<t;n++)if(!this.selections[n].equalsSelection(e.selections[n]))return!1;return!0}}class uE{constructor(e,t,i){this.cursorState=e,this.scrollTop=t,this.scrollLeft=i}}class qg extends j{static get(e){return e.getContribution(qg.ID)}constructor(e){super(),this._editor=e,this._isCursorUndoRedo=!1,this._undoStack=[],this._redoStack=[],this._register(e.onDidChangeModel(t=>{this._undoStack=[],this._redoStack=[]})),this._register(e.onDidChangeModelContent(t=>{this._undoStack=[],this._redoStack=[]})),this._register(e.onDidChangeCursorSelection(t=>{if(this._isCursorUndoRedo||!t.oldSelections||t.oldModelVersionId!==t.modelVersionId)return;const i=new cE(t.oldSelections);this._undoStack.length>0&&this._undoStack[this._undoStack.length-1].cursorState.equals(i)||(this._undoStack.push(new uE(i,e.getScrollTop(),e.getScrollLeft())),this._redoStack=[],this._undoStack.length>50&&this._undoStack.shift())}))}cursorUndo(){!this._editor.hasModel()||this._undoStack.length===0||(this._redoStack.push(new uE(new cE(this._editor.getSelections()),this._editor.getScrollTop(),this._editor.getScrollLeft())),this._applyState(this._undoStack.pop()))}cursorRedo(){!this._editor.hasModel()||this._redoStack.length===0||(this._undoStack.push(new uE(new cE(this._editor.getSelections()),this._editor.getScrollTop(),this._editor.getScrollLeft())),this._applyState(this._redoStack.pop()))}_applyState(e){this._isCursorUndoRedo=!0,this._editor.setSelections(e.cursorState.selections),this._editor.setScrollPosition({scrollTop:e.scrollTop,scrollLeft:e.scrollLeft}),this._isCursorUndoRedo=!1}}qg.ID="editor.contrib.cursorUndoRedoController";class swe extends we{constructor(){super({id:"cursorUndo",label:p("cursor.undo","Cursor Undo"),alias:"Cursor Undo",precondition:void 0,kbOpts:{kbExpr:T.textInputFocus,primary:2099,weight:100}})}run(e,t,i){var n;(n=qg.get(t))===null||n===void 0||n.cursorUndo()}}class owe extends we{constructor(){super({id:"cursorRedo",label:p("cursor.redo","Cursor Redo"),alias:"Cursor Redo",precondition:void 0})}run(e,t,i){var n;(n=qg.get(t))===null||n===void 0||n.cursorRedo()}}Lt(qg.ID,qg,0);re(swe);re(owe);class rwe{constructor(e,t,i){this.selection=e,this.targetPosition=t,this.copy=i,this.targetSelection=null}getEditOperations(e,t){const i=e.getValueInRange(this.selection);if(this.copy||t.addEditOperation(this.selection,null),t.addEditOperation(new D(this.targetPosition.lineNumber,this.targetPosition.column,this.targetPosition.lineNumber,this.targetPosition.column),i),this.selection.containsPosition(this.targetPosition)&&!(this.copy&&(this.selection.getEndPosition().equals(this.targetPosition)||this.selection.getStartPosition().equals(this.targetPosition)))){this.targetSelection=this.selection;return}if(this.copy){this.targetSelection=new De(this.targetPosition.lineNumber,this.targetPosition.column,this.selection.endLineNumber-this.selection.startLineNumber+this.targetPosition.lineNumber,this.selection.startLineNumber===this.selection.endLineNumber?this.targetPosition.column+this.selection.endColumn-this.selection.startColumn:this.selection.endColumn);return}if(this.targetPosition.lineNumber>this.selection.endLineNumber){this.targetSelection=new De(this.targetPosition.lineNumber-this.selection.endLineNumber+this.selection.startLineNumber,this.targetPosition.column,this.targetPosition.lineNumber,this.selection.startLineNumber===this.selection.endLineNumber?this.targetPosition.column+this.selection.endColumn-this.selection.startColumn:this.selection.endColumn);return}if(this.targetPosition.lineNumber<this.selection.endLineNumber){this.targetSelection=new De(this.targetPosition.lineNumber,this.targetPosition.column,this.targetPosition.lineNumber+this.selection.endLineNumber-this.selection.startLineNumber,this.selection.startLineNumber===this.selection.endLineNumber?this.targetPosition.column+this.selection.endColumn-this.selection.startColumn:this.selection.endColumn);return}this.selection.endColumn<=this.targetPosition.column?this.targetSelection=new De(this.targetPosition.lineNumber-this.selection.endLineNumber+this.selection.startLineNumber,this.selection.startLineNumber===this.selection.endLineNumber?this.targetPosition.column-this.selection.endColumn+this.selection.startColumn:this.targetPosition.column-this.selection.endColumn+this.selection.startColumn,this.targetPosition.lineNumber,this.selection.startLineNumber===this.selection.endLineNumber?this.targetPosition.column:this.selection.endColumn):this.targetSelection=new De(this.targetPosition.lineNumber-this.selection.endLineNumber+this.selection.startLineNumber,this.targetPosition.column,this.targetPosition.lineNumber,this.targetPosition.column+this.selection.endColumn-this.selection.startColumn)}computeCursorState(e,t){return this.targetSelection}}function Of(s){return bt?s.altKey:s.ctrlKey}class Zd extends j{constructor(e){super(),this._editor=e,this._dndDecorationIds=this._editor.createDecorationsCollection(),this._register(this._editor.onMouseDown(t=>this._onEditorMouseDown(t))),this._register(this._editor.onMouseUp(t=>this._onEditorMouseUp(t))),this._register(this._editor.onMouseDrag(t=>this._onEditorMouseDrag(t))),this._register(this._editor.onMouseDrop(t=>this._onEditorMouseDrop(t))),this._register(this._editor.onMouseDropCanceled(()=>this._onEditorMouseDropCanceled())),this._register(this._editor.onKeyDown(t=>this.onEditorKeyDown(t))),this._register(this._editor.onKeyUp(t=>this.onEditorKeyUp(t))),this._register(this._editor.onDidBlurEditorWidget(()=>this.onEditorBlur())),this._register(this._editor.onDidBlurEditorText(()=>this.onEditorBlur())),this._mouseDown=!1,this._modifierPressed=!1,this._dragSelection=null}onEditorBlur(){this._removeDecoration(),this._dragSelection=null,this._mouseDown=!1,this._modifierPressed=!1}onEditorKeyDown(e){!this._editor.getOption(35)||this._editor.getOption(22)||(Of(e)&&(this._modifierPressed=!0),this._mouseDown&&Of(e)&&this._editor.updateOptions({mouseStyle:"copy"}))}onEditorKeyUp(e){!this._editor.getOption(35)||this._editor.getOption(22)||(Of(e)&&(this._modifierPressed=!1),this._mouseDown&&e.keyCode===Zd.TRIGGER_KEY_VALUE&&this._editor.updateOptions({mouseStyle:"default"}))}_onEditorMouseDown(e){this._mouseDown=!0}_onEditorMouseUp(e){this._mouseDown=!1,this._editor.updateOptions({mouseStyle:"text"})}_onEditorMouseDrag(e){const t=e.target;if(this._dragSelection===null){const n=(this._editor.getSelections()||[]).filter(o=>t.position&&o.containsPosition(t.position));if(n.length===1)this._dragSelection=n[0];else return}Of(e.event)?this._editor.updateOptions({mouseStyle:"copy"}):this._editor.updateOptions({mouseStyle:"default"}),t.position&&(this._dragSelection.containsPosition(t.position)?this._removeDecoration():this.showAt(t.position))}_onEditorMouseDropCanceled(){this._editor.updateOptions({mouseStyle:"text"}),this._removeDecoration(),this._dragSelection=null,this._mouseDown=!1}_onEditorMouseDrop(e){if(e.target&&(this._hitContent(e.target)||this._hitMargin(e.target))&&e.target.position){const t=new H(e.target.position.lineNumber,e.target.position.column);if(this._dragSelection===null){let i=null;if(e.event.shiftKey){const n=this._editor.getSelection();if(n){const{selectionStartLineNumber:o,selectionStartColumn:r}=n;i=[new De(o,r,t.lineNumber,t.column)]}}else i=(this._editor.getSelections()||[]).map(n=>n.containsPosition(t)?new De(t.lineNumber,t.column,t.lineNumber,t.column):n);this._editor.setSelections(i||[],"mouse",3)}else(!this._dragSelection.containsPosition(t)||(Of(e.event)||this._modifierPressed)&&(this._dragSelection.getEndPosition().equals(t)||this._dragSelection.getStartPosition().equals(t)))&&(this._editor.pushUndoStop(),this._editor.executeCommand(Zd.ID,new rwe(this._dragSelection,t,Of(e.event)||this._modifierPressed)),this._editor.pushUndoStop())}this._editor.updateOptions({mouseStyle:"text"}),this._removeDecoration(),this._dragSelection=null,this._mouseDown=!1}showAt(e){this._dndDecorationIds.set([{range:new D(e.lineNumber,e.column,e.lineNumber,e.column),options:Zd._DECORATION_OPTIONS}]),this._editor.revealPosition(e,1)}_removeDecoration(){this._dndDecorationIds.clear()}_hitContent(e){return e.type===6||e.type===7}_hitMargin(e){return e.type===2||e.type===3||e.type===4}dispose(){this._removeDecoration(),this._dragSelection=null,this._mouseDown=!1,this._modifierPressed=!1,super.dispose()}}Zd.ID="editor.contrib.dragAndDrop";Zd.TRIGGER_KEY_VALUE=bt?6:5;Zd._DECORATION_OPTIONS=tt.register({description:"dnd-target",className:"dnd-target"});Lt(Zd.ID,Zd,2);const xD=function(){if(typeof crypto=="object"&&typeof crypto.randomUUID=="function")return crypto.randomUUID.bind(crypto);let s;typeof crypto=="object"&&typeof crypto.getRandomValues=="function"?s=crypto.getRandomValues.bind(crypto):s=function(i){for(let n=0;n<i.length;n++)i[n]=Math.floor(Math.random()*256);return i};const e=new Uint8Array(16),t=[];for(let i=0;i<256;i++)t.push(i.toString(16).padStart(2,"0"));return function(){s(e),e[6]=e[6]&15|64,e[8]=e[8]&63|128;let n=0,o="";return o+=t[e[n++]],o+=t[e[n++]],o+=t[e[n++]],o+=t[e[n++]],o+="-",o+=t[e[n++]],o+=t[e[n++]],o+="-",o+=t[e[n++]],o+=t[e[n++]],o+="-",o+=t[e[n++]],o+=t[e[n++]],o+="-",o+=t[e[n++]],o+=t[e[n++]],o+=t[e[n++]],o+=t[e[n++]],o+=t[e[n++]],o+=t[e[n++]],o}}();function f4(s){return{asString:async()=>s,asFile:()=>{},value:typeof s=="string"?s:void 0}}function awe(s,e,t){const i={id:xD(),name:s,uri:e,data:t};return{asString:async()=>"",asFile:()=>i,value:void 0}}class Bj{constructor(){this._entries=new Map}get size(){let e=0;for(const t of this._entries)e++;return e}has(e){return this._entries.has(this.toKey(e))}matches(e){const t=[...this._entries.keys()];return ht.some(this,([i,n])=>n.asFile())&&t.push("files"),Vj(uL(e),t)}get(e){var t;return(t=this._entries.get(this.toKey(e)))===null||t===void 0?void 0:t[0]}append(e,t){const i=this._entries.get(e);i?i.push(t):this._entries.set(this.toKey(e),[t])}replace(e,t){this._entries.set(this.toKey(e),[t])}delete(e){this._entries.delete(this.toKey(e))}*[Symbol.iterator](){for(const[e,t]of this._entries)for(const i of t)yield[e,i]}toKey(e){return uL(e)}}function uL(s){return s.toLowerCase()}function Wj(s,e){return Vj(uL(s),e.map(uL))}function Vj(s,e){if(s==="*/*")return e.length>0;if(e.includes(s))return!0;const t=s.match(/^([a-z]+)\/([a-z]+|\*)$/i);if(!t)return!1;const[i,n,o]=t;return o==="*"?e.some(r=>r.startsWith(n+"/")):!1}const DD=Object.freeze({create:s=>Lu(s.map(e=>e.toString())).join(`\r
`),split:s=>s.split(`\r
`),parse:s=>DD.split(s).filter(e=>!e.startsWith("#"))}),Z8={EDITORS:"CodeEditors",FILES:"CodeFiles"};class lwe{}const dwe={DragAndDropContribution:"workbench.contributions.dragAndDrop"};Si.add(dwe.DragAndDropContribution,new lwe);class Ib{constructor(){}static getInstance(){return Ib.INSTANCE}hasData(e){return e&&e===this.proto}getData(e){if(this.hasData(e))return this.data}}Ib.INSTANCE=new Ib;function Hj(s){const e=new Bj;for(const t of s.items){const i=t.type;if(t.kind==="string"){const n=new Promise(o=>t.getAsString(o));e.append(i,f4(n))}else if(t.kind==="file"){const n=t.getAsFile();n&&e.append(i,cwe(n))}}return e}function cwe(s){const e=s.path?Pe.parse(s.path):void 0;return awe(s.name,e,async()=>new Uint8Array(await s.arrayBuffer()))}const uwe=Object.freeze([Z8.EDITORS,Z8.FILES,ab.RESOURCES,ab.INTERNAL_URI_LIST]);function zj(s,e=!1){const t=Hj(s),i=t.get(ab.INTERNAL_URI_LIST);if(i)t.replace(Hi.uriList,i);else if(e||!t.has(Hi.uriList)){const n=[];for(const o of s.items){const r=o.getAsFile();if(r){const a=r.path;try{a?n.push(Pe.file(a).toString()):n.push(Pe.parse(r.name,!0).toString())}catch{}}}n.length&&t.replace(Hi.uriList,f4(DD.create(n)))}for(const n of uwe)t.delete(n);return t}function hwe(s,e,t){var i,n;return{edits:[...e.map(o=>new qd(s,typeof t.insertText=="string"?{range:o,text:t.insertText,insertAsSnippet:!1}:{range:o,text:t.insertText.snippet,insertAsSnippet:!0})),...(n=(i=t.additionalEdit)===null||i===void 0?void 0:i.edits)!==null&&n!==void 0?n:[]]}}function Uj(s){var e;function t(a,l){return"providerId"in a&&a.providerId===l.providerId||"mimeType"in a&&a.mimeType===l.handledMimeType}const i=new Map;for(const a of s)for(const l of(e=a.yieldTo)!==null&&e!==void 0?e:[])for(const d of s)if(d!==a&&t(l,d)){let c=i.get(a);c||(c=[],i.set(a,c)),c.push(d)}if(!i.size)return Array.from(s);const n=new Set,o=[];function r(a){if(!a.length)return[];const l=a[0];if(o.includes(l))return console.warn(`Yield to cycle detected for ${l.providerId}`),a;if(n.has(l))return r(a.slice(1));let d=[];const c=i.get(l);return c&&(o.push(l),d=r(c),o.pop()),n.add(l),[...d,l,...r(a.slice(1))]}return r(Array.from(s))}var gwe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},fwe=function(s,e){return function(t,i){e(t,i,s)}};const pwe=tt.register({description:"inline-progress-widget",stickiness:1,showIfCollapsed:!0,after:{content:qW,inlineClassName:"inline-editor-progress-decoration",inlineClassNameAffectsLetterSpacing:!0}});class kD extends j{constructor(e,t,i,n,o){super(),this.typeId=e,this.editor=t,this.range=i,this.delegate=o,this.allowEditorOverflow=!1,this.suppressMouseDown=!0,this.create(n),this.editor.addContentWidget(this),this.editor.layoutContentWidget(this)}create(e){this.domNode=se(".inline-progress-widget"),this.domNode.role="button",this.domNode.title=e;const t=se("span.icon");this.domNode.append(t),t.classList.add(...Oe.asClassNameArray(le.loading),"codicon-modifier-spin");const i=()=>{const n=this.editor.getOption(66);this.domNode.style.height=`${n}px`,this.domNode.style.width=`${Math.ceil(.8*n)}px`};i(),this._register(this.editor.onDidChangeConfiguration(n=>{(n.hasChanged(52)||n.hasChanged(66))&&i()})),this._register(Y(this.domNode,he.CLICK,n=>{this.delegate.cancel()}))}getId(){return kD.baseId+"."+this.typeId}getDomNode(){return this.domNode}getPosition(){return{position:{lineNumber:this.range.startLineNumber,column:this.range.startColumn},preference:[0]}}dispose(){super.dispose(),this.editor.removeContentWidget(this)}}kD.baseId="editor.widget.inlineProgressWidget";let hL=class extends j{constructor(e,t,i){super(),this.id=e,this._editor=t,this._instantiationService=i,this._showDelay=500,this._showPromise=this._register(new En),this._currentWidget=new En,this._operationIdPool=0,this._currentDecorations=t.createDecorationsCollection()}async showWhile(e,t,i){const n=this._operationIdPool++;this._currentOperation=n,this.clear(),this._showPromise.value=Eu(()=>{const o=D.fromPositions(e);this._currentDecorations.set([{range:o,options:pwe}]).length>0&&(this._currentWidget.value=this._instantiationService.createInstance(kD,this.id,this._editor,o,t,i))},this._showDelay);try{return await i}finally{this._currentOperation===n&&(this.clear(),this._currentOperation=void 0)}}clear(){this._showPromise.clear(),this._currentDecorations.clear(),this._currentWidget.clear()}};hL=gwe([fwe(2,We)],hL);var $j=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},i0=function(s,e){return function(t,i){e(t,i,s)}},GM;let gL=GM=class extends j{constructor(e,t,i,n,o,r,a,l,d,c){super(),this.typeId=e,this.editor=t,this.showCommand=n,this.range=o,this.edits=r,this.onSelectNewEdit=a,this._contextMenuService=l,this._keybindingService=c,this.allowEditorOverflow=!0,this.suppressMouseDown=!0,this.create(),this.visibleContext=i.bindTo(d),this.visibleContext.set(!0),this._register(Fe(()=>this.visibleContext.reset())),this.editor.addContentWidget(this),this.editor.layoutContentWidget(this),this._register(Fe(()=>this.editor.removeContentWidget(this))),this._register(this.editor.onDidChangeCursorPosition(u=>{o.containsPosition(u.position)||this.dispose()})),this._register(ge.runAndSubscribe(c.onDidUpdateKeybindings,()=>{this._updateButtonTitle()}))}_updateButtonTitle(){var e;const t=(e=this._keybindingService.lookupKeybinding(this.showCommand.id))===null||e===void 0?void 0:e.getLabel();this.button.element.title=this.showCommand.label+(t?` (${t})`:"")}create(){this.domNode=se(".post-edit-widget"),this.button=this._register(new Vy(this.domNode,{supportIcons:!0})),this.button.label="$(insert)",this._register(Y(this.domNode,he.CLICK,()=>this.showSelector()))}getId(){return GM.baseId+"."+this.typeId}getDomNode(){return this.domNode}getPosition(){return{position:this.range.getEndPosition(),preference:[2]}}showSelector(){this._contextMenuService.showContextMenu({getAnchor:()=>{const e=ln(this.button.element);return{x:e.left+e.width,y:e.top+e.height}},getActions:()=>this.edits.allEdits.map((e,t)=>Rp({id:"",label:e.label,checked:t===this.edits.activeEditIndex,run:()=>{if(t!==this.edits.activeEditIndex)return this.onSelectNewEdit(t)}}))})}};gL.baseId="editor.widget.postEditWidget";gL=GM=$j([i0(7,Nr),i0(8,je),i0(9,qt)],gL);let fL=class extends j{constructor(e,t,i,n,o,r){super(),this._id=e,this._editor=t,this._visibleContext=i,this._showCommand=n,this._instantiationService=o,this._bulkEditService=r,this._currentWidget=this._register(new En),this._register(ge.any(t.onDidChangeModel,t.onDidChangeModelContent)(()=>this.clear()))}async applyEditAndShowIfNeeded(e,t,i,n){var o,r;const a=this._editor.getModel();if(!a||!e.length)return;const l=t.allEdits[t.activeEditIndex];if(!l)return;let d=[];(typeof l.insertText=="string"?l.insertText==="":l.insertText.snippet==="")?d=[]:d=e.map(_=>new qd(a.uri,typeof l.insertText=="string"?{range:_,text:l.insertText,insertAsSnippet:!1}:{range:_,text:l.insertText.snippet,insertAsSnippet:!0}));const u={edits:[...d,...(r=(o=l.additionalEdit)===null||o===void 0?void 0:o.edits)!==null&&r!==void 0?r:[]]},h=e[0],g=a.deltaDecorations([],[{range:h,options:{description:"paste-line-suffix",stickiness:0}}]);let f,m;try{f=await this._bulkEditService.apply(u,{editor:this._editor,token:n}),m=a.getDecorationRange(g[0])}finally{a.deltaDecorations(g,[])}i&&f.isApplied&&t.allEdits.length>1&&this.show(m??h,t,async _=>{const v=this._editor.getModel();v&&(await v.undo(),this.applyEditAndShowIfNeeded(e,{activeEditIndex:_,allEdits:t.allEdits},i,n))})}show(e,t,i){this.clear(),this._editor.hasModel()&&(this._currentWidget.value=this._instantiationService.createInstance(gL,this._id,this._editor,this._visibleContext,this._showCommand,e,t,i))}clear(){this._currentWidget.clear()}tryShowSelector(){var e;(e=this._currentWidget.value)===null||e===void 0||e.showSelector()}};fL=$j([i0(4,We),i0(5,bC)],fL);var mwe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Ff=function(s,e){return function(t,i){e(t,i,s)}},ZM;const jj="editor.changePasteType",Kj=new me("pasteWidgetVisible",!1,p("pasteWidgetVisible","Whether the paste widget is showing")),hE="application/vnd.code.copyMetadata";let Gg=ZM=class extends j{static get(e){return e.getContribution(ZM.ID)}constructor(e,t,i,n,o,r,a){super(),this._bulkEditService=i,this._clipboardService=n,this._languageFeaturesService=o,this._quickInputService=r,this._progressService=a,this._editor=e;const l=e.getContainerDomNode();this._register(Y(l,"copy",d=>this.handleCopy(d))),this._register(Y(l,"cut",d=>this.handleCopy(d))),this._register(Y(l,"paste",d=>this.handlePaste(d),!0)),this._pasteProgressManager=this._register(new hL("pasteIntoEditor",e,t)),this._postPasteWidgetManager=this._register(t.createInstance(fL,"pasteIntoEditor",e,Kj,{id:jj,label:p("postPasteWidgetTitle","Show paste options...")}))}changePasteType(){this._postPasteWidgetManager.tryShowSelector()}pasteAs(e){this._editor.focus();try{this._pasteAsActionContext={preferredId:e},i_().execCommand("paste")}finally{this._pasteAsActionContext=void 0}}isPasteAsEnabled(){return this._editor.getOption(84).enabled&&!this._editor.getOption(90)}handleCopy(e){var t,i;if(!this._editor.hasTextFocus()||(Ju&&this._clipboardService.writeResources([]),!e.clipboardData||!this.isPasteAsEnabled()))return;const n=this._editor.getModel(),o=this._editor.getSelections();if(!n||!(o!=null&&o.length))return;const r=this._editor.getOption(37);let a=o;const l=o.length===1&&o[0].isEmpty();if(l){if(!r)return;a=[new D(a[0].startLineNumber,1,a[0].startLineNumber,1+n.getLineLength(a[0].startLineNumber))]}const d=(t=this._editor._getViewModel())===null||t===void 0?void 0:t.getPlainTextToCopy(o,r,es),u={multicursorText:Array.isArray(d)?d:null,pasteOnNewLine:l,mode:null},h=this._languageFeaturesService.documentPasteEditProvider.ordered(n).filter(v=>!!v.prepareDocumentPaste);if(!h.length){this.setCopyMetadata(e.clipboardData,{defaultPastePayload:u});return}const g=Hj(e.clipboardData),f=h.flatMap(v=>{var b;return(b=v.copyMimeTypes)!==null&&b!==void 0?b:[]}),m=xD();this.setCopyMetadata(e.clipboardData,{id:m,providerCopyMimeTypes:f,defaultPastePayload:u});const _=gn(async v=>{const b=Ba(await Promise.all(h.map(async C=>{try{return await C.prepareDocumentPaste(n,a,g,v)}catch(w){console.error(w);return}})));b.reverse();for(const C of b)for(const[w,S]of C)g.replace(w,S);return g});(i=this._currentCopyOperation)===null||i===void 0||i.dataTransferPromise.cancel(),this._currentCopyOperation={handle:m,dataTransferPromise:_}}async handlePaste(e){var t,i;if(!e.clipboardData||!this._editor.hasTextFocus())return;(t=this._currentPasteOperation)===null||t===void 0||t.cancel(),this._currentPasteOperation=void 0;const n=this._editor.getModel(),o=this._editor.getSelections();if(!(o!=null&&o.length)||!n||!this.isPasteAsEnabled())return;const r=this.fetchCopyMetadata(e),a=zj(e.clipboardData);a.delete(hE);const l=[...e.clipboardData.types,...(i=r==null?void 0:r.providerCopyMimeTypes)!==null&&i!==void 0?i:[],Hi.uriList],d=this._languageFeaturesService.documentPasteEditProvider.ordered(n).filter(c=>{var u;return(u=c.pasteMimeTypes)===null||u===void 0?void 0:u.some(h=>Wj(h,l))});d.length&&(e.preventDefault(),e.stopImmediatePropagation(),this._pasteAsActionContext?this.showPasteAsPick(this._pasteAsActionContext.preferredId,d,o,a,r):this.doPasteInline(d,o,a,r))}doPasteInline(e,t,i,n){const o=gn(async r=>{const a=this._editor;if(!a.hasModel())return;const l=a.getModel(),d=new Hu(a,3,void 0,r);try{if(await this.mergeInDataFromCopy(i,n,d.token),d.token.isCancellationRequested)return;const c=e.filter(h=>Y8(h,i));if(!c.length||c.length===1&&c[0].id==="text"){await this.applyDefaultPasteHandler(i,n,d.token);return}const u=await this.getPasteEdits(c,i,l,t,d.token);if(d.token.isCancellationRequested)return;if(u.length===1&&u[0].providerId==="text"){await this.applyDefaultPasteHandler(i,n,d.token);return}if(u.length){const h=a.getOption(84).showPasteSelector==="afterPaste";return this._postPasteWidgetManager.applyEditAndShowIfNeeded(t,{activeEditIndex:0,allEdits:u},h,d.token)}await this.applyDefaultPasteHandler(i,n,d.token)}finally{d.dispose(),this._currentPasteOperation===o&&(this._currentPasteOperation=void 0)}});this._pasteProgressManager.showWhile(t[0].getEndPosition(),p("pasteIntoEditorProgress","Running paste handlers. Click to cancel"),o),this._currentPasteOperation=o}showPasteAsPick(e,t,i,n,o){const r=gn(async a=>{const l=this._editor;if(!l.hasModel())return;const d=l.getModel(),c=new Hu(l,3,void 0,a);try{if(await this.mergeInDataFromCopy(n,o,c.token),c.token.isCancellationRequested)return;let u=t.filter(m=>Y8(m,n));e&&(u=u.filter(m=>m.id===e));const h=await this.getPasteEdits(u,n,d,i,c.token);if(c.token.isCancellationRequested||!h.length)return;let g;if(e)g=h.at(0);else{const m=await this._quickInputService.pick(h.map(_=>({label:_.label,description:_.providerId,detail:_.detail,edit:_})),{placeHolder:p("pasteAsPickerPlaceholder","Select Paste Action")});g=m==null?void 0:m.edit}if(!g)return;const f=hwe(d.uri,i,g);await this._bulkEditService.apply(f,{editor:this._editor})}finally{c.dispose(),this._currentPasteOperation===r&&(this._currentPasteOperation=void 0)}});this._progressService.withProgress({location:10,title:p("pasteAsProgress","Running paste handlers")},()=>r)}setCopyMetadata(e,t){e.setData(hE,JSON.stringify(t))}fetchCopyMetadata(e){var t;if(!e.clipboardData)return;const i=e.clipboardData.getData(hE);if(i)try{return JSON.parse(i)}catch{return}const[n,o]=bT.getTextData(e.clipboardData);if(o)return{defaultPastePayload:{mode:o.mode,multicursorText:(t=o.multicursorText)!==null&&t!==void 0?t:null,pasteOnNewLine:!!o.isFromEmptySelection}}}async mergeInDataFromCopy(e,t,i){var n;if(t!=null&&t.id&&((n=this._currentCopyOperation)===null||n===void 0?void 0:n.handle)===t.id){const o=await this._currentCopyOperation.dataTransferPromise;if(i.isCancellationRequested)return;for(const[r,a]of o)e.replace(r,a)}if(!e.has(Hi.uriList)){const o=await this._clipboardService.readResources();if(i.isCancellationRequested)return;o.length&&e.append(Hi.uriList,f4(DD.create(o)))}}async getPasteEdits(e,t,i,n,o){const r=await sx(Promise.all(e.map(async l=>{var d;try{const c=await((d=l.provideDocumentPasteEdits)===null||d===void 0?void 0:d.call(l,i,n,t,o));if(c)return{...c,providerId:l.id}}catch(c){console.error(c)}})),o),a=Ba(r??[]);return Uj(a)}async applyDefaultPasteHandler(e,t,i){var n,o,r;const a=(n=e.get(Hi.text))!==null&&n!==void 0?n:e.get("text");if(!a)return;const l=await a.asString();if(i.isCancellationRequested)return;const d={text:l,pasteOnNewLine:(o=t==null?void 0:t.defaultPastePayload.pasteOnNewLine)!==null&&o!==void 0?o:!1,multicursorText:(r=t==null?void 0:t.defaultPastePayload.multicursorText)!==null&&r!==void 0?r:null,mode:null};this._editor.trigger("keyboard","paste",d)}};Gg.ID="editor.contrib.copyPasteActionController";Gg=ZM=mwe([Ff(1,We),Ff(2,bC),Ff(3,dc),Ff(4,xe),Ff(5,Ya),Ff(6,kz)],Gg);function Y8(s,e){var t;return!!(!((t=s.pasteMimeTypes)===null||t===void 0)&&t.some(i=>e.matches(i)))}var p4=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Eb=function(s,e){return function(t,i){e(t,i,s)}};const m4=p("builtIn","Built-in");class _4{async provideDocumentPasteEdits(e,t,i,n){const o=await this.getEdit(i,n);return o?{insertText:o.insertText,label:o.label,detail:o.detail,handledMimeType:o.handledMimeType,yieldTo:o.yieldTo}:void 0}async provideDocumentOnDropEdits(e,t,i,n){const o=await this.getEdit(i,n);return o?{insertText:o.insertText,label:o.label,handledMimeType:o.handledMimeType,yieldTo:o.yieldTo}:void 0}}class qj extends _4{constructor(){super(...arguments),this.id="text",this.dropMimeTypes=[Hi.text],this.pasteMimeTypes=[Hi.text]}async getEdit(e,t){const i=e.get(Hi.text);if(!i||e.has(Hi.uriList))return;const n=await i.asString();return{handledMimeType:Hi.text,label:p("text.label","Insert Plain Text"),detail:m4,insertText:n}}}class Gj extends _4{constructor(){super(...arguments),this.id="uri",this.dropMimeTypes=[Hi.uriList],this.pasteMimeTypes=[Hi.uriList]}async getEdit(e,t){const i=await Zj(e);if(!i.length||t.isCancellationRequested)return;let n=0;const o=i.map(({uri:a,originalText:l})=>a.scheme===it.file?a.fsPath:(n++,l)).join(" ");let r;return n>0?r=i.length>1?p("defaultDropProvider.uriList.uris","Insert Uris"):p("defaultDropProvider.uriList.uri","Insert Uri"):r=i.length>1?p("defaultDropProvider.uriList.paths","Insert Paths"):p("defaultDropProvider.uriList.path","Insert Path"),{handledMimeType:Hi.uriList,insertText:o,label:r,detail:m4}}}let pL=class extends _4{constructor(e){super(),this._workspaceContextService=e,this.id="relativePath",this.dropMimeTypes=[Hi.uriList],this.pasteMimeTypes=[Hi.uriList]}async getEdit(e,t){const i=await Zj(e);if(!i.length||t.isCancellationRequested)return;const n=Ba(i.map(({uri:o})=>{const r=this._workspaceContextService.getWorkspaceFolder(o);return r?Ble(r.uri,o):void 0}));if(n.length)return{handledMimeType:Hi.uriList,insertText:n.join(" "),label:i.length>1?p("defaultDropProvider.uriList.relativePaths","Insert Relative Paths"):p("defaultDropProvider.uriList.relativePath","Insert Relative Path"),detail:m4}}};pL=p4([Eb(0,Ag)],pL);async function Zj(s){const e=s.get(Hi.uriList);if(!e)return[];const t=await e.asString(),i=[];for(const n of DD.parse(t))try{i.push({uri:Pe.parse(n),originalText:n})}catch{}return i}let YM=class extends j{constructor(e,t){super(),this._register(e.documentOnDropEditProvider.register("*",new qj)),this._register(e.documentOnDropEditProvider.register("*",new Gj)),this._register(e.documentOnDropEditProvider.register("*",new pL(t)))}};YM=p4([Eb(0,xe),Eb(1,Ag)],YM);let XM=class extends j{constructor(e,t){super(),this._register(e.documentPasteEditProvider.register("*",new qj)),this._register(e.documentPasteEditProvider.register("*",new Gj)),this._register(e.documentPasteEditProvider.register("*",new pL(t)))}};XM=p4([Eb(0,xe),Eb(1,Ag)],XM);Lt(Gg.ID,Gg,0);tD(XM);ue(new class extends Nn{constructor(){super({id:jj,precondition:Kj,kbOpts:{weight:100,primary:2137}})}runEditorCommand(s,e,t){var i;return(i=Gg.get(e))===null||i===void 0?void 0:i.changePasteType()}});re(class extends we{constructor(){super({id:"editor.action.pasteAs",label:p("pasteAs","Paste As..."),alias:"Paste As...",precondition:void 0,metadata:{description:"Paste as",args:[{name:"args",schema:{type:"object",properties:{id:{type:"string",description:p("pasteAs.id","The id of the paste edit to try applying. If not provided, the editor will show a picker.")}}}}]}})}run(s,e,t){var i;const n=typeof(t==null?void 0:t.id)=="string"?t.id:void 0;return(i=Gg.get(e))===null||i===void 0?void 0:i.pasteAs(n)}});class _we{constructor(){this._dragOperations=new Map}removeDragOperationTransfer(e){if(e&&this._dragOperations.has(e)){const t=this._dragOperations.get(e);return this._dragOperations.delete(e),t}}}class X8{constructor(e){this.identifier=e}}const Yj=ut("treeViewsDndService");_t(Yj,_we,1);var vwe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},sw=function(s,e){return function(t,i){e(t,i,s)}},QM;const Xj="editor.experimental.dropIntoEditor.defaultProvider",Qj="editor.changeDropType",Jj=new me("dropWidgetVisible",!1,p("dropWidgetVisible","Whether the drop widget is showing"));let Hm=QM=class extends j{static get(e){return e.getContribution(QM.ID)}constructor(e,t,i,n,o){super(),this._configService=i,this._languageFeaturesService=n,this._treeViewsDragAndDropService=o,this.treeItemsTransfer=Ib.getInstance(),this._dropProgressManager=this._register(t.createInstance(hL,"dropIntoEditor",e)),this._postDropWidgetManager=this._register(t.createInstance(fL,"dropIntoEditor",e,Jj,{id:Qj,label:p("postDropWidgetTitle","Show drop options...")})),this._register(e.onDropIntoEditor(r=>this.onDropIntoEditor(e,r.position,r.event)))}changeDropType(){this._postDropWidgetManager.tryShowSelector()}async onDropIntoEditor(e,t,i){var n;if(!i.dataTransfer||!e.hasModel())return;(n=this._currentOperation)===null||n===void 0||n.cancel(),e.focus(),e.setPosition(t);const o=gn(async r=>{const a=new Hu(e,1,void 0,r);try{const l=await this.extractDataTransferData(i);if(l.size===0||a.token.isCancellationRequested)return;const d=e.getModel();if(!d)return;const c=this._languageFeaturesService.documentOnDropEditProvider.ordered(d).filter(h=>h.dropMimeTypes?h.dropMimeTypes.some(g=>l.matches(g)):!0),u=await this.getDropEdits(c,d,t,l,a);if(a.token.isCancellationRequested)return;if(u.length){const h=this.getInitialActiveEditIndex(d,u),g=e.getOption(36).showDropSelector==="afterDrop";await this._postDropWidgetManager.applyEditAndShowIfNeeded([D.fromPositions(t)],{activeEditIndex:h,allEdits:u},g,r)}}finally{a.dispose(),this._currentOperation===o&&(this._currentOperation=void 0)}});this._dropProgressManager.showWhile(t,p("dropIntoEditorProgress","Running drop handlers. Click to cancel"),o),this._currentOperation=o}async getDropEdits(e,t,i,n,o){const r=await sx(Promise.all(e.map(async l=>{try{const d=await l.provideDocumentOnDropEdits(t,i,n,o.token);if(d)return{...d,providerId:l.id}}catch(d){console.error(d)}})),o.token),a=Ba(r??[]);return Uj(a)}getInitialActiveEditIndex(e,t){const i=this._configService.getValue(Xj,{resource:e.uri});for(const[n,o]of Object.entries(i)){const r=t.findIndex(a=>o===a.providerId&&a.handledMimeType&&Wj(n,[a.handledMimeType]));if(r>=0)return r}return 0}async extractDataTransferData(e){if(!e.dataTransfer)return new Bj;const t=zj(e.dataTransfer);if(this.treeItemsTransfer.hasData(X8.prototype)){const i=this.treeItemsTransfer.getData(X8.prototype);if(Array.isArray(i))for(const n of i){const o=await this._treeViewsDragAndDropService.removeDragOperationTransfer(n.identifier);if(o)for(const[r,a]of o)t.replace(r,a)}}return t}};Hm.ID="editor.contrib.dropIntoEditorController";Hm=QM=vwe([sw(1,We),sw(2,mt),sw(3,xe),sw(4,Yj)],Hm);Lt(Hm.ID,Hm,2);ue(new class extends Nn{constructor(){super({id:Qj,precondition:Jj,kbOpts:{weight:100,primary:2137}})}runEditorCommand(s,e,t){var i;(i=Hm.get(e))===null||i===void 0||i.changeDropType()}});tD(YM);Si.as(Za.Configuration).registerConfiguration({...Px,properties:{[Xj]:{type:"object",scope:5,description:p("defaultProviderDescription","Configures the default drop provider to use for content of a given mime type."),default:{},additionalProperties:{type:"string"}}}});class vs{constructor(e){this._editor=e,this._decorations=[],this._overviewRulerApproximateDecorations=[],this._findScopeDecorationIds=[],this._rangeHighlightDecorationId=null,this._highlightedDecorationId=null,this._startPosition=this._editor.getPosition()}dispose(){this._editor.removeDecorations(this._allDecorations()),this._decorations=[],this._overviewRulerApproximateDecorations=[],this._findScopeDecorationIds=[],this._rangeHighlightDecorationId=null,this._highlightedDecorationId=null}reset(){this._decorations=[],this._overviewRulerApproximateDecorations=[],this._findScopeDecorationIds=[],this._rangeHighlightDecorationId=null,this._highlightedDecorationId=null}getCount(){return this._decorations.length}getFindScope(){return this._findScopeDecorationIds[0]?this._editor.getModel().getDecorationRange(this._findScopeDecorationIds[0]):null}getFindScopes(){if(this._findScopeDecorationIds.length){const e=this._findScopeDecorationIds.map(t=>this._editor.getModel().getDecorationRange(t)).filter(t=>!!t);if(e.length)return e}return null}getStartPosition(){return this._startPosition}setStartPosition(e){this._startPosition=e,this.setCurrentFindMatch(null)}_getDecorationIndex(e){const t=this._decorations.indexOf(e);return t>=0?t+1:1}getDecorationRangeAt(e){const t=e<this._decorations.length?this._decorations[e]:null;return t?this._editor.getModel().getDecorationRange(t):null}getCurrentMatchesPosition(e){const t=this._editor.getModel().getDecorationsInRange(e);for(const i of t){const n=i.options;if(n===vs._FIND_MATCH_DECORATION||n===vs._CURRENT_FIND_MATCH_DECORATION)return this._getDecorationIndex(i.id)}return 0}setCurrentFindMatch(e){let t=null,i=0;if(e)for(let n=0,o=this._decorations.length;n<o;n++){const r=this._editor.getModel().getDecorationRange(this._decorations[n]);if(e.equalsRange(r)){t=this._decorations[n],i=n+1;break}}return(this._highlightedDecorationId!==null||t!==null)&&this._editor.changeDecorations(n=>{if(this._highlightedDecorationId!==null&&(n.changeDecorationOptions(this._highlightedDecorationId,vs._FIND_MATCH_DECORATION),this._highlightedDecorationId=null),t!==null&&(this._highlightedDecorationId=t,n.changeDecorationOptions(this._highlightedDecorationId,vs._CURRENT_FIND_MATCH_DECORATION)),this._rangeHighlightDecorationId!==null&&(n.removeDecoration(this._rangeHighlightDecorationId),this._rangeHighlightDecorationId=null),t!==null){let o=this._editor.getModel().getDecorationRange(t);if(o.startLineNumber!==o.endLineNumber&&o.endColumn===1){const r=o.endLineNumber-1,a=this._editor.getModel().getLineMaxColumn(r);o=new D(o.startLineNumber,o.startColumn,r,a)}this._rangeHighlightDecorationId=n.addDecoration(o,vs._RANGE_HIGHLIGHT_DECORATION)}}),i}set(e,t){this._editor.changeDecorations(i=>{let n=vs._FIND_MATCH_DECORATION;const o=[];if(e.length>1e3){n=vs._FIND_MATCH_NO_OVERVIEW_DECORATION;const a=this._editor.getModel().getLineCount(),d=this._editor.getLayoutInfo().height/a,c=Math.max(2,Math.ceil(3/d));let u=e[0].range.startLineNumber,h=e[0].range.endLineNumber;for(let g=1,f=e.length;g<f;g++){const m=e[g].range;h+c>=m.startLineNumber?m.endLineNumber>h&&(h=m.endLineNumber):(o.push({range:new D(u,1,h,1),options:vs._FIND_MATCH_ONLY_OVERVIEW_DECORATION}),u=m.startLineNumber,h=m.endLineNumber)}o.push({range:new D(u,1,h,1),options:vs._FIND_MATCH_ONLY_OVERVIEW_DECORATION})}const r=new Array(e.length);for(let a=0,l=e.length;a<l;a++)r[a]={range:e[a].range,options:n};this._decorations=i.deltaDecorations(this._decorations,r),this._overviewRulerApproximateDecorations=i.deltaDecorations(this._overviewRulerApproximateDecorations,o),this._rangeHighlightDecorationId&&(i.removeDecoration(this._rangeHighlightDecorationId),this._rangeHighlightDecorationId=null),this._findScopeDecorationIds.length&&(this._findScopeDecorationIds.forEach(a=>i.removeDecoration(a)),this._findScopeDecorationIds=[]),t!=null&&t.length&&(this._findScopeDecorationIds=t.map(a=>i.addDecoration(a,vs._FIND_SCOPE_DECORATION)))})}matchBeforePosition(e){if(this._decorations.length===0)return null;for(let t=this._decorations.length-1;t>=0;t--){const i=this._decorations[t],n=this._editor.getModel().getDecorationRange(i);if(!(!n||n.endLineNumber>e.lineNumber)){if(n.endLineNumber<e.lineNumber)return n;if(!(n.endColumn>e.column))return n}}return this._editor.getModel().getDecorationRange(this._decorations[this._decorations.length-1])}matchAfterPosition(e){if(this._decorations.length===0)return null;for(let t=0,i=this._decorations.length;t<i;t++){const n=this._decorations[t],o=this._editor.getModel().getDecorationRange(n);if(!(!o||o.startLineNumber<e.lineNumber)){if(o.startLineNumber>e.lineNumber)return o;if(!(o.startColumn<e.column))return o}}return this._editor.getModel().getDecorationRange(this._decorations[0])}_allDecorations(){let e=[];return e=e.concat(this._decorations),e=e.concat(this._overviewRulerApproximateDecorations),this._findScopeDecorationIds.length&&e.push(...this._findScopeDecorationIds),this._rangeHighlightDecorationId&&e.push(this._rangeHighlightDecorationId),e}}vs._CURRENT_FIND_MATCH_DECORATION=tt.register({description:"current-find-match",stickiness:1,zIndex:13,className:"currentFindMatch",showIfCollapsed:!0,overviewRuler:{color:Di(SP),position:nr.Center},minimap:{color:Di(gp),position:bo.Inline}});vs._FIND_MATCH_DECORATION=tt.register({description:"find-match",stickiness:1,zIndex:10,className:"findMatch",showIfCollapsed:!0,overviewRuler:{color:Di(SP),position:nr.Center},minimap:{color:Di(gp),position:bo.Inline}});vs._FIND_MATCH_NO_OVERVIEW_DECORATION=tt.register({description:"find-match-no-overview",stickiness:1,className:"findMatch",showIfCollapsed:!0});vs._FIND_MATCH_ONLY_OVERVIEW_DECORATION=tt.register({description:"find-match-only-overview",stickiness:1,overviewRuler:{color:Di(SP),position:nr.Center}});vs._RANGE_HIGHLIGHT_DECORATION=tt.register({description:"find-range-highlight",stickiness:1,className:"rangeHighlight",isWholeLine:!0});vs._FIND_SCOPE_DECORATION=tt.register({description:"find-scope",className:"findScope",isWholeLine:!0});class bwe{constructor(e,t,i){this._editorSelection=e,this._ranges=t,this._replaceStrings=i,this._trackedEditorSelectionId=null}getEditOperations(e,t){if(this._ranges.length>0){const i=[];for(let r=0;r<this._ranges.length;r++)i.push({range:this._ranges[r],text:this._replaceStrings[r]});i.sort((r,a)=>D.compareRangesUsingStarts(r.range,a.range));const n=[];let o=i[0];for(let r=1;r<i.length;r++)o.range.endLineNumber===i[r].range.startLineNumber&&o.range.endColumn===i[r].range.startColumn?(o.range=o.range.plusRange(i[r].range),o.text=o.text+i[r].text):(n.push(o),o=i[r]);n.push(o);for(const r of n)t.addEditOperation(r.range,r.text)}this._trackedEditorSelectionId=t.trackSelection(this._editorSelection)}computeCursorState(e,t){return t.getTrackedSelection(this._trackedEditorSelectionId)}}function eK(s,e){if(s&&s[0]!==""){const t=Q8(s,e,"-"),i=Q8(s,e,"_");return t&&!i?J8(s,e,"-"):!t&&i?J8(s,e,"_"):s[0].toUpperCase()===s[0]?e.toUpperCase():s[0].toLowerCase()===s[0]?e.toLowerCase():cJ(s[0][0])&&e.length>0?e[0].toUpperCase()+e.substr(1):s[0][0].toUpperCase()!==s[0][0]&&e.length>0?e[0].toLowerCase()+e.substr(1):e}else return e}function Q8(s,e,t){return s[0].indexOf(t)!==-1&&e.indexOf(t)!==-1&&s[0].split(t).length===e.split(t).length}function J8(s,e,t){const i=e.split(t),n=s[0].split(t);let o="";return i.forEach((r,a)=>{o+=eK([n[a]],r)+t}),o.slice(0,-1)}class eB{constructor(e){this.staticValue=e,this.kind=0}}class Cwe{constructor(e){this.pieces=e,this.kind=1}}class zm{static fromStaticValue(e){return new zm([Sg.staticValue(e)])}get hasReplacementPatterns(){return this._state.kind===1}constructor(e){!e||e.length===0?this._state=new eB(""):e.length===1&&e[0].staticValue!==null?this._state=new eB(e[0].staticValue):this._state=new Cwe(e)}buildReplaceString(e,t){if(this._state.kind===0)return t?eK(e,this._state.staticValue):this._state.staticValue;let i="";for(let n=0,o=this._state.pieces.length;n<o;n++){const r=this._state.pieces[n];if(r.staticValue!==null){i+=r.staticValue;continue}let a=zm._substitute(r.matchIndex,e);if(r.caseOps!==null&&r.caseOps.length>0){const l=[],d=r.caseOps.length;let c=0;for(let u=0,h=a.length;u<h;u++){if(c>=d){l.push(a.slice(u));break}switch(r.caseOps[c]){case"U":l.push(a[u].toUpperCase());break;case"u":l.push(a[u].toUpperCase()),c++;break;case"L":l.push(a[u].toLowerCase());break;case"l":l.push(a[u].toLowerCase()),c++;break;default:l.push(a[u])}}a=l.join("")}i+=a}return i}static _substitute(e,t){if(t===null)return"";if(e===0)return t[0];let i="";for(;e>0;){if(e<t.length)return(t[e]||"")+i;i=String(e%10)+i,e=Math.floor(e/10)}return"$"+i}}class Sg{static staticValue(e){return new Sg(e,-1,null)}static caseOps(e,t){return new Sg(null,e,t)}constructor(e,t,i){this.staticValue=e,this.matchIndex=t,!i||i.length===0?this.caseOps=null:this.caseOps=i.slice(0)}}class wwe{constructor(e){this._source=e,this._lastCharIndex=0,this._result=[],this._resultLen=0,this._currentStaticPiece=""}emitUnchanged(e){this._emitStatic(this._source.substring(this._lastCharIndex,e)),this._lastCharIndex=e}emitStatic(e,t){this._emitStatic(e),this._lastCharIndex=t}_emitStatic(e){e.length!==0&&(this._currentStaticPiece+=e)}emitMatchIndex(e,t,i){this._currentStaticPiece.length!==0&&(this._result[this._resultLen++]=Sg.staticValue(this._currentStaticPiece),this._currentStaticPiece=""),this._result[this._resultLen++]=Sg.caseOps(e,i),this._lastCharIndex=t}finalize(){return this.emitUnchanged(this._source.length),this._currentStaticPiece.length!==0&&(this._result[this._resultLen++]=Sg.staticValue(this._currentStaticPiece),this._currentStaticPiece=""),new zm(this._result)}}function Swe(s){if(!s||s.length===0)return new zm(null);const e=[],t=new wwe(s);for(let i=0,n=s.length;i<n;i++){const o=s.charCodeAt(i);if(o===92){if(i++,i>=n)break;const r=s.charCodeAt(i);switch(r){case 92:t.emitUnchanged(i-1),t.emitStatic("\\",i+1);break;case 110:t.emitUnchanged(i-1),t.emitStatic(`
`,i+1);break;case 116:t.emitUnchanged(i-1),t.emitStatic("	",i+1);break;case 117:case 85:case 108:case 76:t.emitUnchanged(i-1),t.emitStatic("",i+1),e.push(String.fromCharCode(r));break}continue}if(o===36){if(i++,i>=n)break;const r=s.charCodeAt(i);if(r===36){t.emitUnchanged(i-1),t.emitStatic("$",i+1);continue}if(r===48||r===38){t.emitUnchanged(i-1),t.emitMatchIndex(0,i+1,e),e.length=0;continue}if(49<=r&&r<=57){let a=r-48;if(i+1<n){const l=s.charCodeAt(i+1);if(48<=l&&l<=57){i++,a=a*10+(l-48),t.emitUnchanged(i-2),t.emitMatchIndex(a,i+1,e),e.length=0;continue}}t.emitUnchanged(i-1),t.emitMatchIndex(a,i+1,e),e.length=0;continue}}}return t.finalize()}const uc=new me("findWidgetVisible",!1);uc.toNegated();const ID=new me("findInputFocussed",!1),v4=new me("replaceInputFocussed",!1),ow={primary:545,mac:{primary:2593}},rw={primary:565,mac:{primary:2613}},aw={primary:560,mac:{primary:2608}},lw={primary:554,mac:{primary:2602}},dw={primary:558,mac:{primary:2606}},ei={StartFindAction:"actions.find",StartFindWithSelection:"actions.findWithSelection",StartFindWithArgs:"editor.actions.findWithArgs",NextMatchFindAction:"editor.action.nextMatchFindAction",PreviousMatchFindAction:"editor.action.previousMatchFindAction",GoToMatchFindAction:"editor.action.goToMatchFindAction",NextSelectionMatchFindAction:"editor.action.nextSelectionMatchFindAction",PreviousSelectionMatchFindAction:"editor.action.previousSelectionMatchFindAction",StartFindReplaceAction:"editor.action.startFindReplaceAction",CloseFindWidgetCommand:"closeFindWidget",ToggleCaseSensitiveCommand:"toggleFindCaseSensitive",ToggleWholeWordCommand:"toggleFindWholeWord",ToggleRegexCommand:"toggleFindRegex",ToggleSearchScopeCommand:"toggleFindInSelection",TogglePreserveCaseCommand:"togglePreserveCase",ReplaceOneAction:"editor.action.replaceOne",ReplaceAllAction:"editor.action.replaceAll",SelectAllMatchesAction:"editor.action.selectAllMatches"},Jc=19999,ywe=240;class n0{constructor(e,t){this._toDispose=new ie,this._editor=e,this._state=t,this._isDisposed=!1,this._startSearchingTimer=new ea,this._decorations=new vs(e),this._toDispose.add(this._decorations),this._updateDecorationsScheduler=new jt(()=>this.research(!1),100),this._toDispose.add(this._updateDecorationsScheduler),this._toDispose.add(this._editor.onDidChangeCursorPosition(i=>{(i.reason===3||i.reason===5||i.reason===6)&&this._decorations.setStartPosition(this._editor.getPosition())})),this._ignoreModelContentChanged=!1,this._toDispose.add(this._editor.onDidChangeModelContent(i=>{this._ignoreModelContentChanged||(i.isFlush&&this._decorations.reset(),this._decorations.setStartPosition(this._editor.getPosition()),this._updateDecorationsScheduler.schedule())})),this._toDispose.add(this._state.onFindReplaceStateChange(i=>this._onStateChanged(i))),this.research(!1,this._state.searchScope)}dispose(){this._isDisposed=!0,Bt(this._startSearchingTimer),this._toDispose.dispose()}_onStateChanged(e){this._isDisposed||this._editor.hasModel()&&(e.searchString||e.isReplaceRevealed||e.isRegex||e.wholeWord||e.matchCase||e.searchScope)&&(this._editor.getModel().isTooLargeForSyncing()?(this._startSearchingTimer.cancel(),this._startSearchingTimer.setIfNotSet(()=>{e.searchScope?this.research(e.moveCursor,this._state.searchScope):this.research(e.moveCursor)},ywe)):e.searchScope?this.research(e.moveCursor,this._state.searchScope):this.research(e.moveCursor))}static _getSearchRange(e,t){return t||e.getFullModelRange()}research(e,t){let i=null;typeof t<"u"?t!==null&&(Array.isArray(t)?i=t:i=[t]):i=this._decorations.getFindScopes(),i!==null&&(i=i.map(a=>{if(a.startLineNumber!==a.endLineNumber){let l=a.endLineNumber;return a.endColumn===1&&(l=l-1),new D(a.startLineNumber,1,l,this._editor.getModel().getLineMaxColumn(l))}return a}));const n=this._findMatches(i,!1,Jc);this._decorations.set(n,i);const o=this._editor.getSelection();let r=this._decorations.getCurrentMatchesPosition(o);if(r===0&&n.length>0){const a=P0(n.map(l=>l.range),l=>D.compareRangesUsingStarts(l,o)>=0);r=a>0?a-1+1:r}this._state.changeMatchInfo(r,this._decorations.getCount(),void 0),e&&this._editor.getOption(41).cursorMoveOnType&&this._moveToNextMatch(this._decorations.getStartPosition())}_hasMatches(){return this._state.matchesCount>0}_cannotFind(){if(!this._hasMatches()){const e=this._decorations.getFindScope();return e&&this._editor.revealRangeInCenterIfOutsideViewport(e,0),!0}return!1}_setCurrentFindMatch(e){const t=this._decorations.setCurrentFindMatch(e);this._state.changeMatchInfo(t,this._decorations.getCount(),e),this._editor.setSelection(e),this._editor.revealRangeInCenterIfOutsideViewport(e,0)}_prevSearchPosition(e){const t=this._state.isRegex&&(this._state.searchString.indexOf("^")>=0||this._state.searchString.indexOf("$")>=0);let{lineNumber:i,column:n}=e;const o=this._editor.getModel();return t||n===1?(i===1?i=o.getLineCount():i--,n=o.getLineMaxColumn(i)):n--,new H(i,n)}_moveToPrevMatch(e,t=!1){if(!this._state.canNavigateBack()){const c=this._decorations.matchAfterPosition(e);c&&this._setCurrentFindMatch(c);return}if(this._decorations.getCount()<Jc){let c=this._decorations.matchBeforePosition(e);c&&c.isEmpty()&&c.getStartPosition().equals(e)&&(e=this._prevSearchPosition(e),c=this._decorations.matchBeforePosition(e)),c&&this._setCurrentFindMatch(c);return}if(this._cannotFind())return;const i=this._decorations.getFindScope(),n=n0._getSearchRange(this._editor.getModel(),i);n.getEndPosition().isBefore(e)&&(e=n.getEndPosition()),e.isBefore(n.getStartPosition())&&(e=n.getEndPosition());const{lineNumber:o,column:r}=e,a=this._editor.getModel();let l=new H(o,r),d=a.findPreviousMatch(this._state.searchString,l,this._state.isRegex,this._state.matchCase,this._state.wholeWord?this._editor.getOption(129):null,!1);if(d&&d.range.isEmpty()&&d.range.getStartPosition().equals(l)&&(l=this._prevSearchPosition(l),d=a.findPreviousMatch(this._state.searchString,l,this._state.isRegex,this._state.matchCase,this._state.wholeWord?this._editor.getOption(129):null,!1)),!!d){if(!t&&!n.containsRange(d.range))return this._moveToPrevMatch(d.range.getStartPosition(),!0);this._setCurrentFindMatch(d.range)}}moveToPrevMatch(){this._moveToPrevMatch(this._editor.getSelection().getStartPosition())}_nextSearchPosition(e){const t=this._state.isRegex&&(this._state.searchString.indexOf("^")>=0||this._state.searchString.indexOf("$")>=0);let{lineNumber:i,column:n}=e;const o=this._editor.getModel();return t||n===o.getLineMaxColumn(i)?(i===o.getLineCount()?i=1:i++,n=1):n++,new H(i,n)}_moveToNextMatch(e){if(!this._state.canNavigateForward()){const i=this._decorations.matchBeforePosition(e);i&&this._setCurrentFindMatch(i);return}if(this._decorations.getCount()<Jc){let i=this._decorations.matchAfterPosition(e);i&&i.isEmpty()&&i.getStartPosition().equals(e)&&(e=this._nextSearchPosition(e),i=this._decorations.matchAfterPosition(e)),i&&this._setCurrentFindMatch(i);return}const t=this._getNextMatch(e,!1,!0);t&&this._setCurrentFindMatch(t.range)}_getNextMatch(e,t,i,n=!1){if(this._cannotFind())return null;const o=this._decorations.getFindScope(),r=n0._getSearchRange(this._editor.getModel(),o);r.getEndPosition().isBefore(e)&&(e=r.getStartPosition()),e.isBefore(r.getStartPosition())&&(e=r.getStartPosition());const{lineNumber:a,column:l}=e,d=this._editor.getModel();let c=new H(a,l),u=d.findNextMatch(this._state.searchString,c,this._state.isRegex,this._state.matchCase,this._state.wholeWord?this._editor.getOption(129):null,t);return i&&u&&u.range.isEmpty()&&u.range.getStartPosition().equals(c)&&(c=this._nextSearchPosition(c),u=d.findNextMatch(this._state.searchString,c,this._state.isRegex,this._state.matchCase,this._state.wholeWord?this._editor.getOption(129):null,t)),u?!n&&!r.containsRange(u.range)?this._getNextMatch(u.range.getEndPosition(),t,i,!0):u:null}moveToNextMatch(){this._moveToNextMatch(this._editor.getSelection().getEndPosition())}_moveToMatch(e){const t=this._decorations.getDecorationRangeAt(e);t&&this._setCurrentFindMatch(t)}moveToMatch(e){this._moveToMatch(e)}_getReplacePattern(){return this._state.isRegex?Swe(this._state.replaceString):zm.fromStaticValue(this._state.replaceString)}replace(){if(!this._hasMatches())return;const e=this._getReplacePattern(),t=this._editor.getSelection(),i=this._getNextMatch(t.getStartPosition(),!0,!1);if(i)if(t.equalsRange(i.range)){const n=e.buildReplaceString(i.matches,this._state.preserveCase),o=new Kn(t,n);this._executeEditorCommand("replace",o),this._decorations.setStartPosition(new H(t.startLineNumber,t.startColumn+n.length)),this.research(!0)}else this._decorations.setStartPosition(this._editor.getPosition()),this._setCurrentFindMatch(i.range)}_findMatches(e,t,i){const n=(e||[null]).map(o=>n0._getSearchRange(this._editor.getModel(),o));return this._editor.getModel().findMatches(this._state.searchString,n,this._state.isRegex,this._state.matchCase,this._state.wholeWord?this._editor.getOption(129):null,t,i)}replaceAll(){if(!this._hasMatches())return;const e=this._decorations.getFindScopes();e===null&&this._state.matchesCount>=Jc?this._largeReplaceAll():this._regularReplaceAll(e),this.research(!1)}_largeReplaceAll(){const t=new Mh(this._state.searchString,this._state.isRegex,this._state.matchCase,this._state.wholeWord?this._editor.getOption(129):null).parseSearchRequest();if(!t)return;let i=t.regex;if(!i.multiline){let u="mu";i.ignoreCase&&(u+="i"),i.global&&(u+="g"),i=new RegExp(i.source,u)}const n=this._editor.getModel(),o=n.getValue(1),r=n.getFullModelRange(),a=this._getReplacePattern();let l;const d=this._state.preserveCase;a.hasReplacementPatterns||d?l=o.replace(i,function(){return a.buildReplaceString(arguments,d)}):l=o.replace(i,a.buildReplaceString(null,d));const c=new EP(r,l,this._editor.getSelection());this._executeEditorCommand("replaceAll",c)}_regularReplaceAll(e){const t=this._getReplacePattern(),i=this._findMatches(e,t.hasReplacementPatterns||this._state.preserveCase,1073741824),n=[];for(let r=0,a=i.length;r<a;r++)n[r]=t.buildReplaceString(i[r].matches,this._state.preserveCase);const o=new bwe(this._editor.getSelection(),i.map(r=>r.range),n);this._executeEditorCommand("replaceAll",o)}selectAllMatches(){if(!this._hasMatches())return;const e=this._decorations.getFindScopes();let i=this._findMatches(e,!1,1073741824).map(o=>new De(o.range.startLineNumber,o.range.startColumn,o.range.endLineNumber,o.range.endColumn));const n=this._editor.getSelection();for(let o=0,r=i.length;o<r;o++)if(i[o].equalsRange(n)){i=[n].concat(i.slice(0,o)).concat(i.slice(o+1));break}this._editor.setSelections(i)}_executeEditorCommand(e,t){try{this._ignoreModelContentChanged=!0,this._editor.pushUndoStop(),this._editor.executeCommand(e,t),this._editor.pushUndoStop()}finally{this._ignoreModelContentChanged=!1}}}class ED extends ta{constructor(e,t,i){super(),this._hideSoon=this._register(new jt(()=>this._hide(),2e3)),this._isVisible=!1,this._editor=e,this._state=t,this._keybindingService=i,this._domNode=document.createElement("div"),this._domNode.className="findOptionsWidget",this._domNode.style.display="none",this._domNode.style.top="10px",this._domNode.style.zIndex="12",this._domNode.setAttribute("role","presentation"),this._domNode.setAttribute("aria-hidden","true");const n={inputActiveOptionBorder:_e(bP),inputActiveOptionForeground:_e(CP),inputActiveOptionBackground:_e(Jh)};this.caseSensitive=this._register(new iU({appendTitle:this._keybindingLabelFor(ei.ToggleCaseSensitiveCommand),isChecked:this._state.matchCase,...n})),this._domNode.appendChild(this.caseSensitive.domNode),this._register(this.caseSensitive.onChange(()=>{this._state.change({matchCase:this.caseSensitive.checked},!1)})),this.wholeWords=this._register(new nU({appendTitle:this._keybindingLabelFor(ei.ToggleWholeWordCommand),isChecked:this._state.wholeWord,...n})),this._domNode.appendChild(this.wholeWords.domNode),this._register(this.wholeWords.onChange(()=>{this._state.change({wholeWord:this.wholeWords.checked},!1)})),this.regex=this._register(new sU({appendTitle:this._keybindingLabelFor(ei.ToggleRegexCommand),isChecked:this._state.isRegex,...n})),this._domNode.appendChild(this.regex.domNode),this._register(this.regex.onChange(()=>{this._state.change({isRegex:this.regex.checked},!1)})),this._editor.addOverlayWidget(this),this._register(this._state.onFindReplaceStateChange(o=>{let r=!1;o.isRegex&&(this.regex.checked=this._state.isRegex,r=!0),o.wholeWord&&(this.wholeWords.checked=this._state.wholeWord,r=!0),o.matchCase&&(this.caseSensitive.checked=this._state.matchCase,r=!0),!this._state.isRevealed&&r&&this._revealTemporarily()})),this._register(Y(this._domNode,he.MOUSE_LEAVE,o=>this._onMouseLeave())),this._register(Y(this._domNode,"mouseover",o=>this._onMouseOver()))}_keybindingLabelFor(e){const t=this._keybindingService.lookupKeybinding(e);return t?` (${t.getLabel()})`:""}dispose(){this._editor.removeOverlayWidget(this),super.dispose()}getId(){return ED.ID}getDomNode(){return this._domNode}getPosition(){return{preference:0}}highlightFindOptions(){this._revealTemporarily()}_revealTemporarily(){this._show(),this._hideSoon.schedule()}_onMouseLeave(){this._hideSoon.schedule()}_onMouseOver(){this._hideSoon.cancel()}_show(){this._isVisible||(this._isVisible=!0,this._domNode.style.display="block")}_hide(){this._isVisible&&(this._isVisible=!1,this._domNode.style.display="none")}}ED.ID="editor.contrib.findOptionsWidget";function cw(s,e){return s===1?!0:s===2?!1:e}class Lwe extends j{get searchString(){return this._searchString}get replaceString(){return this._replaceString}get isRevealed(){return this._isRevealed}get isReplaceRevealed(){return this._isReplaceRevealed}get isRegex(){return cw(this._isRegexOverride,this._isRegex)}get wholeWord(){return cw(this._wholeWordOverride,this._wholeWord)}get matchCase(){return cw(this._matchCaseOverride,this._matchCase)}get preserveCase(){return cw(this._preserveCaseOverride,this._preserveCase)}get actualIsRegex(){return this._isRegex}get actualWholeWord(){return this._wholeWord}get actualMatchCase(){return this._matchCase}get actualPreserveCase(){return this._preserveCase}get searchScope(){return this._searchScope}get matchesPosition(){return this._matchesPosition}get matchesCount(){return this._matchesCount}get currentMatch(){return this._currentMatch}constructor(){super(),this._onFindReplaceStateChange=this._register(new W),this.onFindReplaceStateChange=this._onFindReplaceStateChange.event,this._searchString="",this._replaceString="",this._isRevealed=!1,this._isReplaceRevealed=!1,this._isRegex=!1,this._isRegexOverride=0,this._wholeWord=!1,this._wholeWordOverride=0,this._matchCase=!1,this._matchCaseOverride=0,this._preserveCase=!1,this._preserveCaseOverride=0,this._searchScope=null,this._matchesPosition=0,this._matchesCount=0,this._currentMatch=null,this._loop=!0,this._isSearching=!1,this._filters=null}changeMatchInfo(e,t,i){const n={moveCursor:!1,updateHistory:!1,searchString:!1,replaceString:!1,isRevealed:!1,isReplaceRevealed:!1,isRegex:!1,wholeWord:!1,matchCase:!1,preserveCase:!1,searchScope:!1,matchesPosition:!1,matchesCount:!1,currentMatch:!1,loop:!1,isSearching:!1,filters:!1};let o=!1;t===0&&(e=0),e>t&&(e=t),this._matchesPosition!==e&&(this._matchesPosition=e,n.matchesPosition=!0,o=!0),this._matchesCount!==t&&(this._matchesCount=t,n.matchesCount=!0,o=!0),typeof i<"u"&&(D.equalsRange(this._currentMatch,i)||(this._currentMatch=i,n.currentMatch=!0,o=!0)),o&&this._onFindReplaceStateChange.fire(n)}change(e,t,i=!0){var n;const o={moveCursor:t,updateHistory:i,searchString:!1,replaceString:!1,isRevealed:!1,isReplaceRevealed:!1,isRegex:!1,wholeWord:!1,matchCase:!1,preserveCase:!1,searchScope:!1,matchesPosition:!1,matchesCount:!1,currentMatch:!1,loop:!1,isSearching:!1,filters:!1};let r=!1;const a=this.isRegex,l=this.wholeWord,d=this.matchCase,c=this.preserveCase;typeof e.searchString<"u"&&this._searchString!==e.searchString&&(this._searchString=e.searchString,o.searchString=!0,r=!0),typeof e.replaceString<"u"&&this._replaceString!==e.replaceString&&(this._replaceString=e.replaceString,o.replaceString=!0,r=!0),typeof e.isRevealed<"u"&&this._isRevealed!==e.isRevealed&&(this._isRevealed=e.isRevealed,o.isRevealed=!0,r=!0),typeof e.isReplaceRevealed<"u"&&this._isReplaceRevealed!==e.isReplaceRevealed&&(this._isReplaceRevealed=e.isReplaceRevealed,o.isReplaceRevealed=!0,r=!0),typeof e.isRegex<"u"&&(this._isRegex=e.isRegex),typeof e.wholeWord<"u"&&(this._wholeWord=e.wholeWord),typeof e.matchCase<"u"&&(this._matchCase=e.matchCase),typeof e.preserveCase<"u"&&(this._preserveCase=e.preserveCase),typeof e.searchScope<"u"&&(!((n=e.searchScope)===null||n===void 0)&&n.every(u=>{var h;return(h=this._searchScope)===null||h===void 0?void 0:h.some(g=>!D.equalsRange(g,u))})||(this._searchScope=e.searchScope,o.searchScope=!0,r=!0)),typeof e.loop<"u"&&this._loop!==e.loop&&(this._loop=e.loop,o.loop=!0,r=!0),typeof e.isSearching<"u"&&this._isSearching!==e.isSearching&&(this._isSearching=e.isSearching,o.isSearching=!0,r=!0),typeof e.filters<"u"&&(this._filters?this._filters.update(e.filters):this._filters=e.filters,o.filters=!0,r=!0),this._isRegexOverride=typeof e.isRegexOverride<"u"?e.isRegexOverride:0,this._wholeWordOverride=typeof e.wholeWordOverride<"u"?e.wholeWordOverride:0,this._matchCaseOverride=typeof e.matchCaseOverride<"u"?e.matchCaseOverride:0,this._preserveCaseOverride=typeof e.preserveCaseOverride<"u"?e.preserveCaseOverride:0,a!==this.isRegex&&(r=!0,o.isRegex=!0),l!==this.wholeWord&&(r=!0,o.wholeWord=!0),d!==this.matchCase&&(r=!0,o.matchCase=!0),c!==this.preserveCase&&(r=!0,o.preserveCase=!0),r&&this._onFindReplaceStateChange.fire(o)}canNavigateBack(){return this.canNavigateInLoop()||this.matchesPosition!==1}canNavigateForward(){return this.canNavigateInLoop()||this.matchesPosition<this.matchesCount}canNavigateInLoop(){return this._loop||this.matchesCount>=Jc}}const xwe=p("defaultLabel","input"),Dwe=p("label.preserveCaseToggle","Preserve Case");class kwe extends h_{constructor(e){super({icon:le.preserveCase,title:Dwe+e.appendTitle,isChecked:e.isChecked,inputActiveOptionBorder:e.inputActiveOptionBorder,inputActiveOptionForeground:e.inputActiveOptionForeground,inputActiveOptionBackground:e.inputActiveOptionBackground})}}class Iwe extends ta{constructor(e,t,i,n){super(),this._showOptionButtons=i,this.fixFocusOnOptionClickEnabled=!0,this.cachedOptionsWidth=0,this._onDidOptionChange=this._register(new W),this.onDidOptionChange=this._onDidOptionChange.event,this._onKeyDown=this._register(new W),this.onKeyDown=this._onKeyDown.event,this._onMouseDown=this._register(new W),this._onInput=this._register(new W),this._onKeyUp=this._register(new W),this._onPreserveCaseKeyDown=this._register(new W),this.onPreserveCaseKeyDown=this._onPreserveCaseKeyDown.event,this.contextViewProvider=t,this.placeholder=n.placeholder||"",this.validation=n.validation,this.label=n.label||xwe;const o=n.appendPreserveCaseLabel||"",r=n.history||[],a=!!n.flexibleHeight,l=!!n.flexibleWidth,d=n.flexibleMaxHeight;this.domNode=document.createElement("div"),this.domNode.classList.add("monaco-findInput"),this.inputBox=this._register(new oU(this.domNode,this.contextViewProvider,{ariaLabel:this.label||"",placeholder:this.placeholder||"",validationOptions:{validation:this.validation},history:r,showHistoryHint:n.showHistoryHint,flexibleHeight:a,flexibleWidth:l,flexibleMaxHeight:d,inputBoxStyles:n.inputBoxStyles})),this.preserveCase=this._register(new kwe({appendTitle:o,isChecked:!1,...n.toggleStyles})),this._register(this.preserveCase.onChange(h=>{this._onDidOptionChange.fire(h),!h&&this.fixFocusOnOptionClickEnabled&&this.inputBox.focus(),this.validate()})),this._register(this.preserveCase.onKeyDown(h=>{this._onPreserveCaseKeyDown.fire(h)})),this._showOptionButtons?this.cachedOptionsWidth=this.preserveCase.width():this.cachedOptionsWidth=0;const c=[this.preserveCase.domNode];this.onkeydown(this.domNode,h=>{if(h.equals(15)||h.equals(17)||h.equals(9)){const g=c.indexOf(this.domNode.ownerDocument.activeElement);if(g>=0){let f=-1;h.equals(17)?f=(g+1)%c.length:h.equals(15)&&(g===0?f=c.length-1:f=g-1),h.equals(9)?(c[g].blur(),this.inputBox.focus()):f>=0&&c[f].focus(),ot.stop(h,!0)}}});const u=document.createElement("div");u.className="controls",u.style.display=this._showOptionButtons?"block":"none",u.appendChild(this.preserveCase.domNode),this.domNode.appendChild(u),e==null||e.appendChild(this.domNode),this.onkeydown(this.inputBox.inputElement,h=>this._onKeyDown.fire(h)),this.onkeyup(this.inputBox.inputElement,h=>this._onKeyUp.fire(h)),this.oninput(this.inputBox.inputElement,h=>this._onInput.fire()),this.onmousedown(this.inputBox.inputElement,h=>this._onMouseDown.fire(h))}enable(){this.domNode.classList.remove("disabled"),this.inputBox.enable(),this.preserveCase.enable()}disable(){this.domNode.classList.add("disabled"),this.inputBox.disable(),this.preserveCase.disable()}setEnabled(e){e?this.enable():this.disable()}select(){this.inputBox.select()}focus(){this.inputBox.focus()}getPreserveCase(){return this.preserveCase.checked}setPreserveCase(e){this.preserveCase.checked=e}focusOnPreserve(){this.preserveCase.focus()}validate(){var e;(e=this.inputBox)===null||e===void 0||e.validate()}set width(e){this.inputBox.paddingRight=this.cachedOptionsWidth,this.domNode.style.width=e+"px"}dispose(){super.dispose()}}var tK=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},iK=function(s,e){return function(t,i){e(t,i,s)}};const b4=new me("suggestWidgetVisible",!1,p("suggestWidgetVisible","Whether suggestion are visible")),C4="historyNavigationWidgetFocus",nK="historyNavigationForwardsEnabled",sK="historyNavigationBackwardsEnabled";let Yd;const uw=[];function oK(s,e){if(uw.includes(e))throw new Error("Cannot register the same widget multiple times");uw.push(e);const t=new ie,i=new me(C4,!1).bindTo(s),n=new me(nK,!0).bindTo(s),o=new me(sK,!0).bindTo(s),r=()=>{i.set(!0),Yd=e},a=()=>{i.set(!1),Yd===e&&(Yd=void 0)};return dx(e.element)&&r(),t.add(e.onDidFocus(()=>r())),t.add(e.onDidBlur(()=>a())),t.add(Fe(()=>{uw.splice(uw.indexOf(e),1),a()})),{historyNavigationForwardsEnablement:n,historyNavigationBackwardsEnablement:o,dispose(){t.dispose()}}}let JM=class extends rU{constructor(e,t,i,n){super(e,t,i);const o=this._register(n.createScoped(this.inputBox.element));this._register(oK(o,this.inputBox))}};JM=tK([iK(3,je)],JM);let eR=class extends Iwe{constructor(e,t,i,n,o=!1){super(e,t,o,i);const r=this._register(n.createScoped(this.inputBox.element));this._register(oK(r,this.inputBox))}};eR=tK([iK(3,je)],eR);Js.registerCommandAndKeybindingRule({id:"history.showPrevious",weight:200,when:ee.and(ee.has(C4),ee.equals(sK,!0),ee.not("isComposing"),b4.isEqualTo(!1)),primary:16,secondary:[528],handler:s=>{Yd==null||Yd.showPreviousValue()}});Js.registerCommandAndKeybindingRule({id:"history.showNext",weight:200,when:ee.and(ee.has(C4),ee.equals(nK,!0),ee.not("isComposing"),b4.isEqualTo(!1)),primary:18,secondary:[530],handler:s=>{Yd==null||Yd.showNextValue()}});function tB(s){var e,t;return((e=s.lookupKeybinding("history.showPrevious"))===null||e===void 0?void 0:e.getElectronAccelerator())==="Up"&&((t=s.lookupKeybinding("history.showNext"))===null||t===void 0?void 0:t.getElectronAccelerator())==="Down"}const Ewe=Ui("find-selection",le.selection,p("findSelectionIcon","Icon for 'Find in Selection' in the editor find widget.")),iB=Ui("find-collapsed",le.chevronRight,p("findCollapsedIcon","Icon to indicate that the editor find widget is collapsed.")),nB=Ui("find-expanded",le.chevronDown,p("findExpandedIcon","Icon to indicate that the editor find widget is expanded.")),Nwe=Ui("find-replace",le.replace,p("findReplaceIcon","Icon for 'Replace' in the editor find widget.")),Twe=Ui("find-replace-all",le.replaceAll,p("findReplaceAllIcon","Icon for 'Replace All' in the editor find widget.")),Mwe=Ui("find-previous-match",le.arrowUp,p("findPreviousMatchIcon","Icon for 'Find Previous' in the editor find widget.")),Rwe=Ui("find-next-match",le.arrowDown,p("findNextMatchIcon","Icon for 'Find Next' in the editor find widget.")),Awe=p("label.findDialog","Find / Replace"),Pwe=p("label.find","Find"),Owe=p("placeholder.find","Find"),Fwe=p("label.previousMatchButton","Previous Match"),Bwe=p("label.nextMatchButton","Next Match"),Wwe=p("label.toggleSelectionFind","Find in Selection"),Vwe=p("label.closeButton","Close"),Hwe=p("label.replace","Replace"),zwe=p("placeholder.replace","Replace"),Uwe=p("label.replaceButton","Replace"),$we=p("label.replaceAllButton","Replace All"),jwe=p("label.toggleReplaceButton","Toggle Replace"),Kwe=p("title.matchesCountLimit","Only the first {0} results are highlighted, but all find operations work on the entire text.",Jc),qwe=p("label.matchesLocation","{0} of {1}"),sB=p("label.noResults","No results"),nl=419,Gwe=275,Zwe=Gwe-54;let Y_=69;const Ywe=33,oB="ctrlEnterReplaceAll.windows.donotask",rB=bt?256:2048;class gE{constructor(e){this.afterLineNumber=e,this.heightInPx=Ywe,this.suppressMouseDown=!1,this.domNode=document.createElement("div"),this.domNode.className="dock-find-viewzone"}}function aB(s,e,t){const i=!!e.match(/\n/);if(t&&i&&t.selectionStart>0){s.stopPropagation();return}}function lB(s,e,t){const i=!!e.match(/\n/);if(t&&i&&t.selectionEnd<t.value.length){s.stopPropagation();return}}class ND extends ta{constructor(e,t,i,n,o,r,a,l,d){super(),this._cachedHeight=null,this._revealTimeouts=[],this._codeEditor=e,this._controller=t,this._state=i,this._contextViewProvider=n,this._keybindingService=o,this._contextKeyService=r,this._storageService=l,this._notificationService=d,this._ctrlEnterReplaceAllWarningPrompted=!!l.getBoolean(oB,0),this._isVisible=!1,this._isReplaceVisible=!1,this._ignoreChangeEvent=!1,this._updateHistoryDelayer=new Qr(500),this._register(Fe(()=>this._updateHistoryDelayer.cancel())),this._register(this._state.onFindReplaceStateChange(c=>this._onStateChanged(c))),this._buildDomNode(),this._updateButtons(),this._tryUpdateWidgetWidth(),this._findInput.inputBox.layout(),this._register(this._codeEditor.onDidChangeConfiguration(c=>{if(c.hasChanged(90)&&(this._codeEditor.getOption(90)&&this._state.change({isReplaceRevealed:!1},!1),this._updateButtons()),c.hasChanged(143)&&this._tryUpdateWidgetWidth(),c.hasChanged(2)&&this.updateAccessibilitySupport(),c.hasChanged(41)){const u=this._codeEditor.getOption(41).loop;this._state.change({loop:u},!1);const h=this._codeEditor.getOption(41).addExtraSpaceOnTop;h&&!this._viewZone&&(this._viewZone=new gE(0),this._showViewZone()),!h&&this._viewZone&&this._removeViewZone()}})),this.updateAccessibilitySupport(),this._register(this._codeEditor.onDidChangeCursorSelection(()=>{this._isVisible&&this._updateToggleSelectionFindButton()})),this._register(this._codeEditor.onDidFocusEditorWidget(async()=>{if(this._isVisible){const c=await this._controller.getGlobalBufferTerm();c&&c!==this._state.searchString&&(this._state.change({searchString:c},!1),this._findInput.select())}})),this._findInputFocused=ID.bindTo(r),this._findFocusTracker=this._register(ql(this._findInput.inputBox.inputElement)),this._register(this._findFocusTracker.onDidFocus(()=>{this._findInputFocused.set(!0),this._updateSearchScope()})),this._register(this._findFocusTracker.onDidBlur(()=>{this._findInputFocused.set(!1)})),this._replaceInputFocused=v4.bindTo(r),this._replaceFocusTracker=this._register(ql(this._replaceInput.inputBox.inputElement)),this._register(this._replaceFocusTracker.onDidFocus(()=>{this._replaceInputFocused.set(!0),this._updateSearchScope()})),this._register(this._replaceFocusTracker.onDidBlur(()=>{this._replaceInputFocused.set(!1)})),this._codeEditor.addOverlayWidget(this),this._codeEditor.getOption(41).addExtraSpaceOnTop&&(this._viewZone=new gE(0)),this._register(this._codeEditor.onDidChangeModel(()=>{this._isVisible&&(this._viewZoneId=void 0)})),this._register(this._codeEditor.onDidScrollChange(c=>{if(c.scrollTopChanged){this._layoutViewZone();return}setTimeout(()=>{this._layoutViewZone()},0)}))}getId(){return ND.ID}getDomNode(){return this._domNode}getPosition(){return this._isVisible?{preference:0}:null}_onStateChanged(e){if(e.searchString){try{this._ignoreChangeEvent=!0,this._findInput.setValue(this._state.searchString)}finally{this._ignoreChangeEvent=!1}this._updateButtons()}if(e.replaceString&&(this._replaceInput.inputBox.value=this._state.replaceString),e.isRevealed&&(this._state.isRevealed?this._reveal():this._hide(!0)),e.isReplaceRevealed&&(this._state.isReplaceRevealed?!this._codeEditor.getOption(90)&&!this._isReplaceVisible&&(this._isReplaceVisible=!0,this._replaceInput.width=js(this._findInput.domNode),this._updateButtons(),this._replaceInput.inputBox.layout()):this._isReplaceVisible&&(this._isReplaceVisible=!1,this._updateButtons())),(e.isRevealed||e.isReplaceRevealed)&&(this._state.isRevealed||this._state.isReplaceRevealed)&&this._tryUpdateHeight()&&this._showViewZone(),e.isRegex&&this._findInput.setRegex(this._state.isRegex),e.wholeWord&&this._findInput.setWholeWords(this._state.wholeWord),e.matchCase&&this._findInput.setCaseSensitive(this._state.matchCase),e.preserveCase&&this._replaceInput.setPreserveCase(this._state.preserveCase),e.searchScope&&(this._state.searchScope?this._toggleSelectionFind.checked=!0:this._toggleSelectionFind.checked=!1,this._updateToggleSelectionFindButton()),e.searchString||e.matchesCount||e.matchesPosition){const t=this._state.searchString.length>0&&this._state.matchesCount===0;this._domNode.classList.toggle("no-results",t),this._updateMatchesCount(),this._updateButtons()}(e.searchString||e.currentMatch)&&this._layoutViewZone(),e.updateHistory&&this._delayedUpdateHistory(),e.loop&&this._updateButtons()}_delayedUpdateHistory(){this._updateHistoryDelayer.trigger(this._updateHistory.bind(this)).then(void 0,et)}_updateHistory(){this._state.searchString&&this._findInput.inputBox.addToHistory(),this._state.replaceString&&this._replaceInput.inputBox.addToHistory()}_updateMatchesCount(){this._matchesCount.style.minWidth=Y_+"px",this._state.matchesCount>=Jc?this._matchesCount.title=Kwe:this._matchesCount.title="",this._matchesCount.firstChild&&this._matchesCount.removeChild(this._matchesCount.firstChild);let e;if(this._state.matchesCount>0){let t=String(this._state.matchesCount);this._state.matchesCount>=Jc&&(t+="+");let i=String(this._state.matchesPosition);i==="0"&&(i="?"),e=xg(qwe,i,t)}else e=sB;this._matchesCount.appendChild(document.createTextNode(e)),Lo(this._getAriaLabel(e,this._state.currentMatch,this._state.searchString)),Y_=Math.max(Y_,this._matchesCount.clientWidth)}_getAriaLabel(e,t,i){if(e===sB)return i===""?p("ariaSearchNoResultEmpty","{0} found",e):p("ariaSearchNoResult","{0} found for '{1}'",e,i);if(t){const n=p("ariaSearchNoResultWithLineNum","{0} found for '{1}', at {2}",e,i,t.startLineNumber+":"+t.startColumn),o=this._codeEditor.getModel();return o&&t.startLineNumber<=o.getLineCount()&&t.startLineNumber>=1?`${o.getLineContent(t.startLineNumber)}, ${n}`:n}return p("ariaSearchNoResultWithLineNumNoCurrentMatch","{0} found for '{1}'",e,i)}_updateToggleSelectionFindButton(){const e=this._codeEditor.getSelection(),t=e?e.startLineNumber!==e.endLineNumber||e.startColumn!==e.endColumn:!1,i=this._toggleSelectionFind.checked;this._isVisible&&(i||t)?this._toggleSelectionFind.enable():this._toggleSelectionFind.disable()}_updateButtons(){this._findInput.setEnabled(this._isVisible),this._replaceInput.setEnabled(this._isVisible&&this._isReplaceVisible),this._updateToggleSelectionFindButton(),this._closeBtn.setEnabled(this._isVisible);const e=this._state.searchString.length>0,t=!!this._state.matchesCount;this._prevBtn.setEnabled(this._isVisible&&e&&t&&this._state.canNavigateBack()),this._nextBtn.setEnabled(this._isVisible&&e&&t&&this._state.canNavigateForward()),this._replaceBtn.setEnabled(this._isVisible&&this._isReplaceVisible&&e),this._replaceAllBtn.setEnabled(this._isVisible&&this._isReplaceVisible&&e),this._domNode.classList.toggle("replaceToggled",this._isReplaceVisible),this._toggleReplaceBtn.setExpanded(this._isReplaceVisible);const i=!this._codeEditor.getOption(90);this._toggleReplaceBtn.setEnabled(this._isVisible&&i)}_reveal(){if(this._revealTimeouts.forEach(e=>{clearTimeout(e)}),this._revealTimeouts=[],!this._isVisible){this._isVisible=!0;const e=this._codeEditor.getSelection();switch(this._codeEditor.getOption(41).autoFindInSelection){case"always":this._toggleSelectionFind.checked=!0;break;case"never":this._toggleSelectionFind.checked=!1;break;case"multiline":{const i=!!e&&e.startLineNumber!==e.endLineNumber;this._toggleSelectionFind.checked=i;break}}this._tryUpdateWidgetWidth(),this._updateButtons(),this._revealTimeouts.push(setTimeout(()=>{this._domNode.classList.add("visible"),this._domNode.setAttribute("aria-hidden","false")},0)),this._revealTimeouts.push(setTimeout(()=>{this._findInput.validate()},200)),this._codeEditor.layoutOverlayWidget(this);let t=!0;if(this._codeEditor.getOption(41).seedSearchStringFromSelection&&e){const i=this._codeEditor.getDomNode();if(i){const n=ln(i),o=this._codeEditor.getScrolledVisiblePosition(e.getStartPosition()),r=n.left+(o?o.left:0),a=o?o.top:0;if(this._viewZone&&a<this._viewZone.heightInPx){e.endLineNumber>e.startLineNumber&&(t=!1);const l=vV(this._domNode).left;r>l&&(t=!1);const d=this._codeEditor.getScrolledVisiblePosition(e.getEndPosition());n.left+(d?d.left:0)>l&&(t=!1)}}}this._showViewZone(t)}}_hide(e){this._revealTimeouts.forEach(t=>{clearTimeout(t)}),this._revealTimeouts=[],this._isVisible&&(this._isVisible=!1,this._updateButtons(),this._domNode.classList.remove("visible"),this._domNode.setAttribute("aria-hidden","true"),this._findInput.clearMessage(),e&&this._codeEditor.focus(),this._codeEditor.layoutOverlayWidget(this),this._removeViewZone())}_layoutViewZone(e){if(!this._codeEditor.getOption(41).addExtraSpaceOnTop){this._removeViewZone();return}if(!this._isVisible)return;const i=this._viewZone;this._viewZoneId!==void 0||!i||this._codeEditor.changeViewZones(n=>{i.heightInPx=this._getHeight(),this._viewZoneId=n.addZone(i),this._codeEditor.setScrollTop(e||this._codeEditor.getScrollTop()+i.heightInPx)})}_showViewZone(e=!0){if(!this._isVisible||!this._codeEditor.getOption(41).addExtraSpaceOnTop)return;this._viewZone===void 0&&(this._viewZone=new gE(0));const i=this._viewZone;this._codeEditor.changeViewZones(n=>{if(this._viewZoneId!==void 0){const o=this._getHeight();if(o===i.heightInPx)return;const r=o-i.heightInPx;i.heightInPx=o,n.layoutZone(this._viewZoneId),e&&this._codeEditor.setScrollTop(this._codeEditor.getScrollTop()+r);return}else{let o=this._getHeight();if(o-=this._codeEditor.getOption(83).top,o<=0)return;i.heightInPx=o,this._viewZoneId=n.addZone(i),e&&this._codeEditor.setScrollTop(this._codeEditor.getScrollTop()+o)}})}_removeViewZone(){this._codeEditor.changeViewZones(e=>{this._viewZoneId!==void 0&&(e.removeZone(this._viewZoneId),this._viewZoneId=void 0,this._viewZone&&(this._codeEditor.setScrollTop(this._codeEditor.getScrollTop()-this._viewZone.heightInPx),this._viewZone=void 0))})}_tryUpdateWidgetWidth(){if(!this._isVisible||!this._domNode.isConnected)return;const e=this._codeEditor.getLayoutInfo();if(e.contentWidth<=0){this._domNode.classList.add("hiddenEditor");return}else this._domNode.classList.contains("hiddenEditor")&&this._domNode.classList.remove("hiddenEditor");const i=e.width,n=e.minimap.minimapWidth;let o=!1,r=!1,a=!1;if(this._resized&&js(this._domNode)>nl){this._domNode.style.maxWidth=`${i-28-n-15}px`,this._replaceInput.width=js(this._findInput.domNode);return}if(nl+28+n>=i&&(r=!0),nl+28+n-Y_>=i&&(a=!0),nl+28+n-Y_>=i+50&&(o=!0),this._domNode.classList.toggle("collapsed-find-widget",o),this._domNode.classList.toggle("narrow-find-widget",a),this._domNode.classList.toggle("reduced-find-widget",r),!a&&!o&&(this._domNode.style.maxWidth=`${i-28-n-15}px`),this._findInput.layout({collapsedFindWidget:o,narrowFindWidget:a,reducedFindWidget:r}),this._resized){const l=this._findInput.inputBox.element.clientWidth;l>0&&(this._replaceInput.width=l)}else this._isReplaceVisible&&(this._replaceInput.width=js(this._findInput.domNode))}_getHeight(){let e=0;return e+=4,e+=this._findInput.inputBox.height+2,this._isReplaceVisible&&(e+=4,e+=this._replaceInput.inputBox.height+2),e+=4,e}_tryUpdateHeight(){const e=this._getHeight();return this._cachedHeight!==null&&this._cachedHeight===e?!1:(this._cachedHeight=e,this._domNode.style.height=`${e}px`,!0)}focusFindInput(){this._findInput.select(),this._findInput.focus()}focusReplaceInput(){this._replaceInput.select(),this._replaceInput.focus()}highlightFindOptions(){this._findInput.highlightFindOptions()}_updateSearchScope(){if(this._codeEditor.hasModel()&&this._toggleSelectionFind.checked){const e=this._codeEditor.getSelections();e.map(t=>{t.endColumn===1&&t.endLineNumber>t.startLineNumber&&(t=t.setEndPosition(t.endLineNumber-1,this._codeEditor.getModel().getLineMaxColumn(t.endLineNumber-1)));const i=this._state.currentMatch;return t.startLineNumber!==t.endLineNumber&&!D.equalsRange(t,i)?t:null}).filter(t=>!!t),e.length&&this._state.change({searchScope:e},!0)}}_onFindInputMouseDown(e){e.middleButton&&e.stopPropagation()}_onFindInputKeyDown(e){if(e.equals(rB|3))if(this._keybindingService.dispatchEvent(e,e.target)){e.preventDefault();return}else{this._findInput.inputBox.insertAtCursor(`
`),e.preventDefault();return}if(e.equals(2)){this._isReplaceVisible?this._replaceInput.focus():this._findInput.focusOnCaseSensitive(),e.preventDefault();return}if(e.equals(2066)){this._codeEditor.focus(),e.preventDefault();return}if(e.equals(16))return aB(e,this._findInput.getValue(),this._findInput.domNode.querySelector("textarea"));if(e.equals(18))return lB(e,this._findInput.getValue(),this._findInput.domNode.querySelector("textarea"))}_onReplaceInputKeyDown(e){if(e.equals(rB|3))if(this._keybindingService.dispatchEvent(e,e.target)){e.preventDefault();return}else{es&&Ra&&!this._ctrlEnterReplaceAllWarningPrompted&&(this._notificationService.info(p("ctrlEnter.keybindingChanged","Ctrl+Enter now inserts line break instead of replacing all. You can modify the keybinding for editor.action.replaceAll to override this behavior.")),this._ctrlEnterReplaceAllWarningPrompted=!0,this._storageService.store(oB,!0,0,0)),this._replaceInput.inputBox.insertAtCursor(`
`),e.preventDefault();return}if(e.equals(2)){this._findInput.focusOnCaseSensitive(),e.preventDefault();return}if(e.equals(1026)){this._findInput.focus(),e.preventDefault();return}if(e.equals(2066)){this._codeEditor.focus(),e.preventDefault();return}if(e.equals(16))return aB(e,this._replaceInput.inputBox.value,this._replaceInput.inputBox.element.querySelector("textarea"));if(e.equals(18))return lB(e,this._replaceInput.inputBox.value,this._replaceInput.inputBox.element.querySelector("textarea"))}getVerticalSashLeft(e){return 0}_keybindingLabelFor(e){const t=this._keybindingService.lookupKeybinding(e);return t?` (${t.getLabel()})`:""}_buildDomNode(){this._findInput=this._register(new JM(null,this._contextViewProvider,{width:Zwe,label:Pwe,placeholder:Owe,appendCaseSensitiveLabel:this._keybindingLabelFor(ei.ToggleCaseSensitiveCommand),appendWholeWordsLabel:this._keybindingLabelFor(ei.ToggleWholeWordCommand),appendRegexLabel:this._keybindingLabelFor(ei.ToggleRegexCommand),validation:l=>{if(l.length===0||!this._findInput.getRegex())return null;try{return new RegExp(l,"gu"),null}catch(d){return{content:d.message}}},flexibleHeight:!0,flexibleWidth:!0,flexibleMaxHeight:118,showCommonFindToggles:!0,showHistoryHint:()=>tB(this._keybindingService),inputBoxStyles:Dy,toggleStyles:xy},this._contextKeyService)),this._findInput.setRegex(!!this._state.isRegex),this._findInput.setCaseSensitive(!!this._state.matchCase),this._findInput.setWholeWords(!!this._state.wholeWord),this._register(this._findInput.onKeyDown(l=>this._onFindInputKeyDown(l))),this._register(this._findInput.inputBox.onDidChange(()=>{this._ignoreChangeEvent||this._state.change({searchString:this._findInput.getValue()},!0)})),this._register(this._findInput.onDidOptionChange(()=>{this._state.change({isRegex:this._findInput.getRegex(),wholeWord:this._findInput.getWholeWords(),matchCase:this._findInput.getCaseSensitive()},!0)})),this._register(this._findInput.onCaseSensitiveKeyDown(l=>{l.equals(1026)&&this._isReplaceVisible&&(this._replaceInput.focus(),l.preventDefault())})),this._register(this._findInput.onRegexKeyDown(l=>{l.equals(2)&&this._isReplaceVisible&&(this._replaceInput.focusOnPreserve(),l.preventDefault())})),this._register(this._findInput.inputBox.onDidHeightChange(l=>{this._tryUpdateHeight()&&this._showViewZone()})),Ss&&this._register(this._findInput.onMouseDown(l=>this._onFindInputMouseDown(l))),this._matchesCount=document.createElement("div"),this._matchesCount.className="matchesCount",this._updateMatchesCount(),this._prevBtn=this._register(new Bf({label:Fwe+this._keybindingLabelFor(ei.PreviousMatchFindAction),icon:Mwe,onTrigger:()=>{Vc(this._codeEditor.getAction(ei.PreviousMatchFindAction)).run().then(void 0,et)}})),this._nextBtn=this._register(new Bf({label:Bwe+this._keybindingLabelFor(ei.NextMatchFindAction),icon:Rwe,onTrigger:()=>{Vc(this._codeEditor.getAction(ei.NextMatchFindAction)).run().then(void 0,et)}}));const i=document.createElement("div");i.className="find-part",i.appendChild(this._findInput.domNode);const n=document.createElement("div");n.className="find-actions",i.appendChild(n),n.appendChild(this._matchesCount),n.appendChild(this._prevBtn.domNode),n.appendChild(this._nextBtn.domNode),this._toggleSelectionFind=this._register(new h_({icon:Ewe,title:Wwe+this._keybindingLabelFor(ei.ToggleSearchScopeCommand),isChecked:!1,inputActiveOptionBackground:_e(Jh),inputActiveOptionBorder:_e(bP),inputActiveOptionForeground:_e(CP)})),this._register(this._toggleSelectionFind.onChange(()=>{if(this._toggleSelectionFind.checked){if(this._codeEditor.hasModel()){const l=this._codeEditor.getSelections();l.map(d=>(d.endColumn===1&&d.endLineNumber>d.startLineNumber&&(d=d.setEndPosition(d.endLineNumber-1,this._codeEditor.getModel().getLineMaxColumn(d.endLineNumber-1))),d.isEmpty()?null:d)).filter(d=>!!d),l.length&&this._state.change({searchScope:l},!0)}}else this._state.change({searchScope:null},!0)})),n.appendChild(this._toggleSelectionFind.domNode),this._closeBtn=this._register(new Bf({label:Vwe+this._keybindingLabelFor(ei.CloseFindWidgetCommand),icon:EU,onTrigger:()=>{this._state.change({isRevealed:!1,searchScope:null},!1)},onKeyDown:l=>{l.equals(2)&&this._isReplaceVisible&&(this._replaceBtn.isEnabled()?this._replaceBtn.focus():this._codeEditor.focus(),l.preventDefault())}})),this._replaceInput=this._register(new eR(null,void 0,{label:Hwe,placeholder:zwe,appendPreserveCaseLabel:this._keybindingLabelFor(ei.TogglePreserveCaseCommand),history:[],flexibleHeight:!0,flexibleWidth:!0,flexibleMaxHeight:118,showHistoryHint:()=>tB(this._keybindingService),inputBoxStyles:Dy,toggleStyles:xy},this._contextKeyService,!0)),this._replaceInput.setPreserveCase(!!this._state.preserveCase),this._register(this._replaceInput.onKeyDown(l=>this._onReplaceInputKeyDown(l))),this._register(this._replaceInput.inputBox.onDidChange(()=>{this._state.change({replaceString:this._replaceInput.inputBox.value},!1)})),this._register(this._replaceInput.inputBox.onDidHeightChange(l=>{this._isReplaceVisible&&this._tryUpdateHeight()&&this._showViewZone()})),this._register(this._replaceInput.onDidOptionChange(()=>{this._state.change({preserveCase:this._replaceInput.getPreserveCase()},!0)})),this._register(this._replaceInput.onPreserveCaseKeyDown(l=>{l.equals(2)&&(this._prevBtn.isEnabled()?this._prevBtn.focus():this._nextBtn.isEnabled()?this._nextBtn.focus():this._toggleSelectionFind.enabled?this._toggleSelectionFind.focus():this._closeBtn.isEnabled()&&this._closeBtn.focus(),l.preventDefault())})),this._replaceBtn=this._register(new Bf({label:Uwe+this._keybindingLabelFor(ei.ReplaceOneAction),icon:Nwe,onTrigger:()=>{this._controller.replace()},onKeyDown:l=>{l.equals(1026)&&(this._closeBtn.focus(),l.preventDefault())}})),this._replaceAllBtn=this._register(new Bf({label:$we+this._keybindingLabelFor(ei.ReplaceAllAction),icon:Twe,onTrigger:()=>{this._controller.replaceAll()}}));const o=document.createElement("div");o.className="replace-part",o.appendChild(this._replaceInput.domNode);const r=document.createElement("div");r.className="replace-actions",o.appendChild(r),r.appendChild(this._replaceBtn.domNode),r.appendChild(this._replaceAllBtn.domNode),this._toggleReplaceBtn=this._register(new Bf({label:jwe,className:"codicon toggle left",onTrigger:()=>{this._state.change({isReplaceRevealed:!this._isReplaceVisible},!1),this._isReplaceVisible&&(this._replaceInput.width=js(this._findInput.domNode),this._replaceInput.inputBox.layout()),this._showViewZone()}})),this._toggleReplaceBtn.setExpanded(this._isReplaceVisible),this._domNode=document.createElement("div"),this._domNode.className="editor-widget find-widget",this._domNode.setAttribute("aria-hidden","true"),this._domNode.ariaLabel=Awe,this._domNode.role="dialog",this._domNode.style.width=`${nl}px`,this._domNode.appendChild(this._toggleReplaceBtn.domNode),this._domNode.appendChild(i),this._domNode.appendChild(this._closeBtn.domNode),this._domNode.appendChild(o),this._resizeSash=new ns(this._domNode,this,{orientation:0,size:2}),this._resized=!1;let a=nl;this._register(this._resizeSash.onDidStart(()=>{a=js(this._domNode)})),this._register(this._resizeSash.onDidChange(l=>{this._resized=!0;const d=a+l.startX-l.currentX;if(d<nl)return;const c=parseFloat(lx(this._domNode).maxWidth)||0;d>c||(this._domNode.style.width=`${d}px`,this._isReplaceVisible&&(this._replaceInput.width=js(this._findInput.domNode)),this._findInput.inputBox.layout(),this._tryUpdateHeight())})),this._register(this._resizeSash.onDidReset(()=>{const l=js(this._domNode);if(l<nl)return;let d=nl;if(!this._resized||l===nl){const c=this._codeEditor.getLayoutInfo();d=c.width-28-c.minimap.minimapWidth-15,this._resized=!0}this._domNode.style.width=`${d}px`,this._isReplaceVisible&&(this._replaceInput.width=js(this._findInput.domNode)),this._findInput.inputBox.layout()}))}updateAccessibilitySupport(){const e=this._codeEditor.getOption(2);this._findInput.setFocusInputOnOptionClick(e!==2)}}ND.ID="editor.contrib.findWidget";class Bf extends ta{constructor(e){super(),this._opts=e;let t="button";this._opts.className&&(t=t+" "+this._opts.className),this._opts.icon&&(t=t+" "+Oe.asClassName(this._opts.icon)),this._domNode=document.createElement("div"),this._domNode.title=this._opts.label,this._domNode.tabIndex=0,this._domNode.className=t,this._domNode.setAttribute("role","button"),this._domNode.setAttribute("aria-label",this._opts.label),this.onclick(this._domNode,i=>{this._opts.onTrigger(),i.preventDefault()}),this.onkeydown(this._domNode,i=>{var n,o;if(i.equals(10)||i.equals(3)){this._opts.onTrigger(),i.preventDefault();return}(o=(n=this._opts).onKeyDown)===null||o===void 0||o.call(n,i)})}get domNode(){return this._domNode}isEnabled(){return this._domNode.tabIndex>=0}focus(){this._domNode.focus()}setEnabled(e){this._domNode.classList.toggle("disabled",!e),this._domNode.setAttribute("aria-disabled",String(!e)),this._domNode.tabIndex=e?0:-1}setExpanded(e){this._domNode.setAttribute("aria-expanded",String(!!e)),e?(this._domNode.classList.remove(...Oe.asClassNameArray(iB)),this._domNode.classList.add(...Oe.asClassNameArray(nB))):(this._domNode.classList.remove(...Oe.asClassNameArray(nB)),this._domNode.classList.add(...Oe.asClassNameArray(iB)))}}ia((s,e)=>{const t=(m,_)=>{_&&e.addRule(`.monaco-editor ${m} { background-color: ${_}; }`)};t(".findMatch",s.getColor(Rl)),t(".currentFindMatch",s.getColor(kse)),t(".findScope",s.getColor(Ise));const i=s.getColor(Ri);t(".find-widget",i);const n=s.getColor(Il);n&&e.addRule(`.monaco-editor .find-widget { box-shadow: 0 0 8px 2px ${n}; }`);const o=s.getColor(vP);o&&e.addRule(`.monaco-editor .find-widget { border-left: 1px solid ${o}; border-right: 1px solid ${o}; border-bottom: 1px solid ${o}; }`);const r=s.getColor($c);r&&e.addRule(`.monaco-editor .findMatch { border: 1px ${Oa(s.type)?"dotted":"solid"} ${r}; box-sizing: border-box; }`);const a=s.getColor(Ese);a&&e.addRule(`.monaco-editor .currentFindMatch { border: 2px solid ${a}; padding: 1px; box-sizing: border-box; }`);const l=s.getColor(Nse);l&&e.addRule(`.monaco-editor .findScope { border: 1px ${Oa(s.type)?"dashed":"solid"} ${l}; }`);const d=s.getColor(pt);d&&e.addRule(`.monaco-editor .find-widget { border: 1px solid ${d}; }`);const c=s.getColor(Tl);c&&e.addRule(`.monaco-editor .find-widget { color: ${c}; }`);const u=s.getColor(Yne);u&&e.addRule(`.monaco-editor .find-widget.no-results .matchesCount { color: ${u}; }`);const h=s.getColor(vse);if(h)e.addRule(`.monaco-editor .find-widget .monaco-sash { background-color: ${h}; }`);else{const m=s.getColor(Ml);m&&e.addRule(`.monaco-editor .find-widget .monaco-sash { background-color: ${m}; }`)}const g=s.getColor(mT);g&&e.addRule(`
		.monaco-editor .find-widget .button:not(.disabled):hover,
		.monaco-editor .find-widget .codicon-find-selection:hover {
			background-color: ${g} !important;
		}
	`);const f=s.getColor(Zo);f&&e.addRule(`.monaco-editor .find-widget .monaco-inputbox.synthetic-focus { outline-color: ${f}; }`)});var rK=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},_a=function(s,e){return function(t,i){e(t,i,s)}},tR;const Xwe=524288;function iR(s,e="single",t=!1){if(!s.hasModel())return null;const i=s.getSelection();if(e==="single"&&i.startLineNumber===i.endLineNumber||e==="multiple"){if(i.isEmpty()){const n=s.getConfiguredWordAtPosition(i.getStartPosition());if(n&&t===!1)return n.word}else if(s.getModel().getValueLengthInRange(i)<Xwe)return s.getModel().getValueInRange(i)}return null}let Ws=tR=class extends j{get editor(){return this._editor}static get(e){return e.getContribution(tR.ID)}constructor(e,t,i,n,o){super(),this._editor=e,this._findWidgetVisible=uc.bindTo(t),this._contextKeyService=t,this._storageService=i,this._clipboardService=n,this._notificationService=o,this._updateHistoryDelayer=new Qr(500),this._state=this._register(new Lwe),this.loadQueryState(),this._register(this._state.onFindReplaceStateChange(r=>this._onStateChanged(r))),this._model=null,this._register(this._editor.onDidChangeModel(()=>{const r=this._editor.getModel()&&this._state.isRevealed;this.disposeModel(),this._state.change({searchScope:null,matchCase:this._storageService.getBoolean("editor.matchCase",1,!1),wholeWord:this._storageService.getBoolean("editor.wholeWord",1,!1),isRegex:this._storageService.getBoolean("editor.isRegex",1,!1),preserveCase:this._storageService.getBoolean("editor.preserveCase",1,!1)},!1),r&&this._start({forceRevealReplace:!1,seedSearchStringFromSelection:"none",seedSearchStringFromNonEmptySelection:!1,seedSearchStringFromGlobalClipboard:!1,shouldFocus:0,shouldAnimate:!1,updateSearchScope:!1,loop:this._editor.getOption(41).loop})}))}dispose(){this.disposeModel(),super.dispose()}disposeModel(){this._model&&(this._model.dispose(),this._model=null)}_onStateChanged(e){this.saveQueryState(e),e.isRevealed&&(this._state.isRevealed?this._findWidgetVisible.set(!0):(this._findWidgetVisible.reset(),this.disposeModel())),e.searchString&&this.setGlobalBufferTerm(this._state.searchString)}saveQueryState(e){e.isRegex&&this._storageService.store("editor.isRegex",this._state.actualIsRegex,1,1),e.wholeWord&&this._storageService.store("editor.wholeWord",this._state.actualWholeWord,1,1),e.matchCase&&this._storageService.store("editor.matchCase",this._state.actualMatchCase,1,1),e.preserveCase&&this._storageService.store("editor.preserveCase",this._state.actualPreserveCase,1,1)}loadQueryState(){this._state.change({matchCase:this._storageService.getBoolean("editor.matchCase",1,this._state.matchCase),wholeWord:this._storageService.getBoolean("editor.wholeWord",1,this._state.wholeWord),isRegex:this._storageService.getBoolean("editor.isRegex",1,this._state.isRegex),preserveCase:this._storageService.getBoolean("editor.preserveCase",1,this._state.preserveCase)},!1)}isFindInputFocused(){return!!ID.getValue(this._contextKeyService)}getState(){return this._state}closeFindWidget(){this._state.change({isRevealed:!1,searchScope:null},!1),this._editor.focus()}toggleCaseSensitive(){this._state.change({matchCase:!this._state.matchCase},!1),this._state.isRevealed||this.highlightFindOptions()}toggleWholeWords(){this._state.change({wholeWord:!this._state.wholeWord},!1),this._state.isRevealed||this.highlightFindOptions()}toggleRegex(){this._state.change({isRegex:!this._state.isRegex},!1),this._state.isRevealed||this.highlightFindOptions()}togglePreserveCase(){this._state.change({preserveCase:!this._state.preserveCase},!1),this._state.isRevealed||this.highlightFindOptions()}toggleSearchScope(){if(this._state.searchScope)this._state.change({searchScope:null},!0);else if(this._editor.hasModel()){const e=this._editor.getSelections();e.map(t=>(t.endColumn===1&&t.endLineNumber>t.startLineNumber&&(t=t.setEndPosition(t.endLineNumber-1,this._editor.getModel().getLineMaxColumn(t.endLineNumber-1))),t.isEmpty()?null:t)).filter(t=>!!t),e.length&&this._state.change({searchScope:e},!0)}}setSearchString(e){this._state.isRegex&&(e=ir(e)),this._state.change({searchString:e},!1)}highlightFindOptions(e=!1){}async _start(e,t){if(this.disposeModel(),!this._editor.hasModel())return;const i={...t,isRevealed:!0};if(e.seedSearchStringFromSelection==="single"){const n=iR(this._editor,e.seedSearchStringFromSelection,e.seedSearchStringFromNonEmptySelection);n&&(this._state.isRegex?i.searchString=ir(n):i.searchString=n)}else if(e.seedSearchStringFromSelection==="multiple"&&!e.updateSearchScope){const n=iR(this._editor,e.seedSearchStringFromSelection);n&&(i.searchString=n)}if(!i.searchString&&e.seedSearchStringFromGlobalClipboard){const n=await this.getGlobalBufferTerm();if(!this._editor.hasModel())return;n&&(i.searchString=n)}if(e.forceRevealReplace||i.isReplaceRevealed?i.isReplaceRevealed=!0:this._findWidgetVisible.get()||(i.isReplaceRevealed=!1),e.updateSearchScope){const n=this._editor.getSelections();n.some(o=>!o.isEmpty())&&(i.searchScope=n)}i.loop=e.loop,this._state.change(i,!1),this._model||(this._model=new n0(this._editor,this._state))}start(e,t){return this._start(e,t)}moveToNextMatch(){return this._model?(this._model.moveToNextMatch(),!0):!1}moveToPrevMatch(){return this._model?(this._model.moveToPrevMatch(),!0):!1}goToMatch(e){return this._model?(this._model.moveToMatch(e),!0):!1}replace(){return this._model?(this._model.replace(),!0):!1}replaceAll(){var e;return this._model?!((e=this._editor.getModel())===null||e===void 0)&&e.isTooLargeForHeapOperation()?(this._notificationService.warn(p("too.large.for.replaceall","The file is too large to perform a replace all operation.")),!1):(this._model.replaceAll(),!0):!1}selectAllMatches(){return this._model?(this._model.selectAllMatches(),this._editor.focus(),!0):!1}async getGlobalBufferTerm(){return this._editor.getOption(41).globalFindClipboard&&this._editor.hasModel()&&!this._editor.getModel().isTooLargeForSyncing()?this._clipboardService.readFindText():""}setGlobalBufferTerm(e){this._editor.getOption(41).globalFindClipboard&&this._editor.hasModel()&&!this._editor.getModel().isTooLargeForSyncing()&&this._clipboardService.writeFindText(e)}};Ws.ID="editor.contrib.findController";Ws=tR=rK([_a(1,je),_a(2,sa),_a(3,dc),_a(4,Qi)],Ws);let nR=class extends Ws{constructor(e,t,i,n,o,r,a,l){super(e,i,a,l,r),this._contextViewService=t,this._keybindingService=n,this._themeService=o,this._widget=null,this._findOptionsWidget=null}async _start(e,t){this._widget||this._createFindWidget();const i=this._editor.getSelection();let n=!1;switch(this._editor.getOption(41).autoFindInSelection){case"always":n=!0;break;case"never":n=!1;break;case"multiline":{n=!!i&&i.startLineNumber!==i.endLineNumber;break}}e.updateSearchScope=e.updateSearchScope||n,await super._start(e,t),this._widget&&(e.shouldFocus===2?this._widget.focusReplaceInput():e.shouldFocus===1&&this._widget.focusFindInput())}highlightFindOptions(e=!1){this._widget||this._createFindWidget(),this._state.isRevealed&&!e?this._widget.highlightFindOptions():this._findOptionsWidget.highlightFindOptions()}_createFindWidget(){this._widget=this._register(new ND(this._editor,this,this._state,this._contextViewService,this._keybindingService,this._contextKeyService,this._themeService,this._storageService,this._notificationService)),this._findOptionsWidget=this._register(new ED(this._editor,this._state,this._keybindingService))}};nR=rK([_a(1,rc),_a(2,je),_a(3,qt),_a(4,Cn),_a(5,Qi),_a(6,sa),_a(7,dc)],nR);const Qwe=IV(new kV({id:ei.StartFindAction,label:p("startFindAction","Find"),alias:"Find",precondition:ee.or(T.focus,ee.has("editorIsOpen")),kbOpts:{kbExpr:null,primary:2084,weight:100},menuOpts:{menuId:N.MenubarEditMenu,group:"3_find",title:p({key:"miFind",comment:["&& denotes a mnemonic"]},"&&Find"),order:1}}));Qwe.addImplementation(0,(s,e,t)=>{const i=Ws.get(e);return i?i.start({forceRevealReplace:!1,seedSearchStringFromSelection:e.getOption(41).seedSearchStringFromSelection!=="never"?"single":"none",seedSearchStringFromNonEmptySelection:e.getOption(41).seedSearchStringFromSelection==="selection",seedSearchStringFromGlobalClipboard:e.getOption(41).globalFindClipboard,shouldFocus:1,shouldAnimate:!0,updateSearchScope:!1,loop:e.getOption(41).loop}):!1});const Jwe={description:"Open a new In-Editor Find Widget.",args:[{name:"Open a new In-Editor Find Widget args",schema:{properties:{searchString:{type:"string"},replaceString:{type:"string"},regex:{type:"boolean"},regexOverride:{type:"number",description:p("actions.find.isRegexOverride",`Overrides "Use Regular Expression" flag.
The flag will not be saved for the future.
0: Do Nothing
1: True
2: False`)},wholeWord:{type:"boolean"},wholeWordOverride:{type:"number",description:p("actions.find.wholeWordOverride",`Overrides "Match Whole Word" flag.
The flag will not be saved for the future.
0: Do Nothing
1: True
2: False`)},matchCase:{type:"boolean"},matchCaseOverride:{type:"number",description:p("actions.find.matchCaseOverride",`Overrides "Math Case" flag.
The flag will not be saved for the future.
0: Do Nothing
1: True
2: False`)},preserveCase:{type:"boolean"},preserveCaseOverride:{type:"number",description:p("actions.find.preserveCaseOverride",`Overrides "Preserve Case" flag.
The flag will not be saved for the future.
0: Do Nothing
1: True
2: False`)},findInSelection:{type:"boolean"}}}}]};class eSe extends we{constructor(){super({id:ei.StartFindWithArgs,label:p("startFindWithArgsAction","Find With Arguments"),alias:"Find With Arguments",precondition:void 0,kbOpts:{kbExpr:null,primary:0,weight:100},metadata:Jwe})}async run(e,t,i){const n=Ws.get(t);if(n){const o=i?{searchString:i.searchString,replaceString:i.replaceString,isReplaceRevealed:i.replaceString!==void 0,isRegex:i.isRegex,wholeWord:i.matchWholeWord,matchCase:i.isCaseSensitive,preserveCase:i.preserveCase}:{};await n.start({forceRevealReplace:!1,seedSearchStringFromSelection:n.getState().searchString.length===0&&t.getOption(41).seedSearchStringFromSelection!=="never"?"single":"none",seedSearchStringFromNonEmptySelection:t.getOption(41).seedSearchStringFromSelection==="selection",seedSearchStringFromGlobalClipboard:!0,shouldFocus:1,shouldAnimate:!0,updateSearchScope:(i==null?void 0:i.findInSelection)||!1,loop:t.getOption(41).loop},o),n.setGlobalBufferTerm(n.getState().searchString)}}}class tSe extends we{constructor(){super({id:ei.StartFindWithSelection,label:p("startFindWithSelectionAction","Find With Selection"),alias:"Find With Selection",precondition:void 0,kbOpts:{kbExpr:null,primary:0,mac:{primary:2083},weight:100}})}async run(e,t){const i=Ws.get(t);i&&(await i.start({forceRevealReplace:!1,seedSearchStringFromSelection:"multiple",seedSearchStringFromNonEmptySelection:!1,seedSearchStringFromGlobalClipboard:!1,shouldFocus:0,shouldAnimate:!0,updateSearchScope:!1,loop:t.getOption(41).loop}),i.setGlobalBufferTerm(i.getState().searchString))}}class aK extends we{async run(e,t){const i=Ws.get(t);i&&!this._run(i)&&(await i.start({forceRevealReplace:!1,seedSearchStringFromSelection:i.getState().searchString.length===0&&t.getOption(41).seedSearchStringFromSelection!=="never"?"single":"none",seedSearchStringFromNonEmptySelection:t.getOption(41).seedSearchStringFromSelection==="selection",seedSearchStringFromGlobalClipboard:!0,shouldFocus:0,shouldAnimate:!0,updateSearchScope:!1,loop:t.getOption(41).loop}),this._run(i))}}class iSe extends aK{constructor(){super({id:ei.NextMatchFindAction,label:p("findNextMatchAction","Find Next"),alias:"Find Next",precondition:void 0,kbOpts:[{kbExpr:T.focus,primary:61,mac:{primary:2085,secondary:[61]},weight:100},{kbExpr:ee.and(T.focus,ID),primary:3,weight:100}]})}_run(e){return e.moveToNextMatch()?(e.editor.pushUndoStop(),!0):!1}}class nSe extends aK{constructor(){super({id:ei.PreviousMatchFindAction,label:p("findPreviousMatchAction","Find Previous"),alias:"Find Previous",precondition:void 0,kbOpts:[{kbExpr:T.focus,primary:1085,mac:{primary:3109,secondary:[1085]},weight:100},{kbExpr:ee.and(T.focus,ID),primary:1027,weight:100}]})}_run(e){return e.moveToPrevMatch()}}class sSe extends we{constructor(){super({id:ei.GoToMatchFindAction,label:p("findMatchAction.goToMatch","Go to Match..."),alias:"Go to Match...",precondition:uc}),this._highlightDecorations=[]}run(e,t,i){const n=Ws.get(t);if(!n)return;const o=n.getState().matchesCount;if(o<1){e.get(Qi).notify({severity:Rx.Warning,message:p("findMatchAction.noResults","No matches. Try searching for something else.")});return}const a=e.get(Ya).createInputBox();a.placeholder=p("findMatchAction.inputPlaceHolder","Type a number to go to a specific match (between 1 and {0})",o);const l=c=>{const u=parseInt(c);if(isNaN(u))return;const h=n.getState().matchesCount;if(u>0&&u<=h)return u-1;if(u<0&&u>=-h)return h+u},d=c=>{const u=l(c);if(typeof u=="number"){a.validationMessage=void 0,n.goToMatch(u);const h=n.getState().currentMatch;h&&this.addDecorations(t,h)}else a.validationMessage=p("findMatchAction.inputValidationMessage","Please type a number between 1 and {0}",n.getState().matchesCount),this.clearDecorations(t)};a.onDidChangeValue(c=>{d(c)}),a.onDidAccept(()=>{const c=l(a.value);typeof c=="number"?(n.goToMatch(c),a.hide()):a.validationMessage=p("findMatchAction.inputValidationMessage","Please type a number between 1 and {0}",n.getState().matchesCount)}),a.onDidHide(()=>{this.clearDecorations(t),a.dispose()}),a.show()}clearDecorations(e){e.changeDecorations(t=>{this._highlightDecorations=t.deltaDecorations(this._highlightDecorations,[])})}addDecorations(e,t){e.changeDecorations(i=>{this._highlightDecorations=i.deltaDecorations(this._highlightDecorations,[{range:t,options:{description:"find-match-quick-access-range-highlight",className:"rangeHighlight",isWholeLine:!0}},{range:t,options:{description:"find-match-quick-access-range-highlight-overview",overviewRuler:{color:Di(xH),position:nr.Full}}}])})}}class lK extends we{async run(e,t){const i=Ws.get(t);if(!i)return;const n=iR(t,"single",!1);n&&i.setSearchString(n),this._run(i)||(await i.start({forceRevealReplace:!1,seedSearchStringFromSelection:"none",seedSearchStringFromNonEmptySelection:!1,seedSearchStringFromGlobalClipboard:!1,shouldFocus:0,shouldAnimate:!0,updateSearchScope:!1,loop:t.getOption(41).loop}),this._run(i))}}class oSe extends lK{constructor(){super({id:ei.NextSelectionMatchFindAction,label:p("nextSelectionMatchFindAction","Find Next Selection"),alias:"Find Next Selection",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:2109,weight:100}})}_run(e){return e.moveToNextMatch()}}class rSe extends lK{constructor(){super({id:ei.PreviousSelectionMatchFindAction,label:p("previousSelectionMatchFindAction","Find Previous Selection"),alias:"Find Previous Selection",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:3133,weight:100}})}_run(e){return e.moveToPrevMatch()}}const aSe=IV(new kV({id:ei.StartFindReplaceAction,label:p("startReplace","Replace"),alias:"Replace",precondition:ee.or(T.focus,ee.has("editorIsOpen")),kbOpts:{kbExpr:null,primary:2086,mac:{primary:2596},weight:100},menuOpts:{menuId:N.MenubarEditMenu,group:"3_find",title:p({key:"miReplace",comment:["&& denotes a mnemonic"]},"&&Replace"),order:2}}));aSe.addImplementation(0,(s,e,t)=>{if(!e.hasModel()||e.getOption(90))return!1;const i=Ws.get(e);if(!i)return!1;const n=e.getSelection(),o=i.isFindInputFocused(),r=!n.isEmpty()&&n.startLineNumber===n.endLineNumber&&e.getOption(41).seedSearchStringFromSelection!=="never"&&!o,a=o||r?2:1;return i.start({forceRevealReplace:!0,seedSearchStringFromSelection:r?"single":"none",seedSearchStringFromNonEmptySelection:e.getOption(41).seedSearchStringFromSelection==="selection",seedSearchStringFromGlobalClipboard:e.getOption(41).seedSearchStringFromSelection!=="never",shouldFocus:a,shouldAnimate:!0,updateSearchScope:!1,loop:e.getOption(41).loop})});Lt(Ws.ID,nR,0);re(eSe);re(tSe);re(iSe);re(nSe);re(sSe);re(oSe);re(rSe);const Xa=Nn.bindToContribution(Ws.get);ue(new Xa({id:ei.CloseFindWidgetCommand,precondition:uc,handler:s=>s.closeFindWidget(),kbOpts:{weight:105,kbExpr:ee.and(T.focus,ee.not("isComposing")),primary:9,secondary:[1033]}}));ue(new Xa({id:ei.ToggleCaseSensitiveCommand,precondition:void 0,handler:s=>s.toggleCaseSensitive(),kbOpts:{weight:105,kbExpr:T.focus,primary:ow.primary,mac:ow.mac,win:ow.win,linux:ow.linux}}));ue(new Xa({id:ei.ToggleWholeWordCommand,precondition:void 0,handler:s=>s.toggleWholeWords(),kbOpts:{weight:105,kbExpr:T.focus,primary:rw.primary,mac:rw.mac,win:rw.win,linux:rw.linux}}));ue(new Xa({id:ei.ToggleRegexCommand,precondition:void 0,handler:s=>s.toggleRegex(),kbOpts:{weight:105,kbExpr:T.focus,primary:aw.primary,mac:aw.mac,win:aw.win,linux:aw.linux}}));ue(new Xa({id:ei.ToggleSearchScopeCommand,precondition:void 0,handler:s=>s.toggleSearchScope(),kbOpts:{weight:105,kbExpr:T.focus,primary:lw.primary,mac:lw.mac,win:lw.win,linux:lw.linux}}));ue(new Xa({id:ei.TogglePreserveCaseCommand,precondition:void 0,handler:s=>s.togglePreserveCase(),kbOpts:{weight:105,kbExpr:T.focus,primary:dw.primary,mac:dw.mac,win:dw.win,linux:dw.linux}}));ue(new Xa({id:ei.ReplaceOneAction,precondition:uc,handler:s=>s.replace(),kbOpts:{weight:105,kbExpr:T.focus,primary:3094}}));ue(new Xa({id:ei.ReplaceOneAction,precondition:uc,handler:s=>s.replace(),kbOpts:{weight:105,kbExpr:ee.and(T.focus,v4),primary:3}}));ue(new Xa({id:ei.ReplaceAllAction,precondition:uc,handler:s=>s.replaceAll(),kbOpts:{weight:105,kbExpr:T.focus,primary:2563}}));ue(new Xa({id:ei.ReplaceAllAction,precondition:uc,handler:s=>s.replaceAll(),kbOpts:{weight:105,kbExpr:ee.and(T.focus,v4),primary:void 0,mac:{primary:2051}}}));ue(new Xa({id:ei.SelectAllMatchesAction,precondition:uc,handler:s=>s.selectAllMatches(),kbOpts:{weight:105,kbExpr:T.focus,primary:515}}));const lSe={0:" ",1:"u",2:"r"},dB=65535,va=16777215,cB=4278190080;class fE{constructor(e){const t=Math.ceil(e/32);this._states=new Uint32Array(t)}get(e){const t=e/32|0,i=e%32;return(this._states[t]&1<<i)!==0}set(e,t){const i=e/32|0,n=e%32,o=this._states[i];t?this._states[i]=o|1<<n:this._states[i]=o&~(1<<n)}}class zo{constructor(e,t,i){if(e.length!==t.length||e.length>dB)throw new Error("invalid startIndexes or endIndexes size");this._startIndexes=e,this._endIndexes=t,this._collapseStates=new fE(e.length),this._userDefinedStates=new fE(e.length),this._recoveredStates=new fE(e.length),this._types=i,this._parentsComputed=!1}ensureParentIndices(){if(!this._parentsComputed){this._parentsComputed=!0;const e=[],t=(i,n)=>{const o=e[e.length-1];return this.getStartLineNumber(o)<=i&&this.getEndLineNumber(o)>=n};for(let i=0,n=this._startIndexes.length;i<n;i++){const o=this._startIndexes[i],r=this._endIndexes[i];if(o>va||r>va)throw new Error("startLineNumber or endLineNumber must not exceed "+va);for(;e.length>0&&!t(o,r);)e.pop();const a=e.length>0?e[e.length-1]:-1;e.push(i),this._startIndexes[i]=o+((a&255)<<24),this._endIndexes[i]=r+((a&65280)<<16)}}}get length(){return this._startIndexes.length}getStartLineNumber(e){return this._startIndexes[e]&va}getEndLineNumber(e){return this._endIndexes[e]&va}getType(e){return this._types?this._types[e]:void 0}hasTypes(){return!!this._types}isCollapsed(e){return this._collapseStates.get(e)}setCollapsed(e,t){this._collapseStates.set(e,t)}isUserDefined(e){return this._userDefinedStates.get(e)}setUserDefined(e,t){return this._userDefinedStates.set(e,t)}isRecovered(e){return this._recoveredStates.get(e)}setRecovered(e,t){return this._recoveredStates.set(e,t)}getSource(e){return this.isUserDefined(e)?1:this.isRecovered(e)?2:0}setSource(e,t){t===1?(this.setUserDefined(e,!0),this.setRecovered(e,!1)):t===2?(this.setUserDefined(e,!1),this.setRecovered(e,!0)):(this.setUserDefined(e,!1),this.setRecovered(e,!1))}setCollapsedAllOfType(e,t){let i=!1;if(this._types)for(let n=0;n<this._types.length;n++)this._types[n]===e&&(this.setCollapsed(n,t),i=!0);return i}toRegion(e){return new dSe(this,e)}getParentIndex(e){this.ensureParentIndices();const t=((this._startIndexes[e]&cB)>>>24)+((this._endIndexes[e]&cB)>>>16);return t===dB?-1:t}contains(e,t){return this.getStartLineNumber(e)<=t&&this.getEndLineNumber(e)>=t}findIndex(e){let t=0,i=this._startIndexes.length;if(i===0)return-1;for(;t<i;){const n=Math.floor((t+i)/2);e<this.getStartLineNumber(n)?i=n:t=n+1}return t-1}findRange(e){let t=this.findIndex(e);if(t>=0){if(this.getEndLineNumber(t)>=e)return t;for(t=this.getParentIndex(t);t!==-1;){if(this.contains(t,e))return t;t=this.getParentIndex(t)}}return-1}toString(){const e=[];for(let t=0;t<this.length;t++)e[t]=`[${lSe[this.getSource(t)]}${this.isCollapsed(t)?"+":"-"}] ${this.getStartLineNumber(t)}/${this.getEndLineNumber(t)}`;return e.join(", ")}toFoldRange(e){return{startLineNumber:this._startIndexes[e]&va,endLineNumber:this._endIndexes[e]&va,type:this._types?this._types[e]:void 0,isCollapsed:this.isCollapsed(e),source:this.getSource(e)}}static fromFoldRanges(e){const t=e.length,i=new Uint32Array(t),n=new Uint32Array(t);let o=[],r=!1;for(let l=0;l<t;l++){const d=e[l];i[l]=d.startLineNumber,n[l]=d.endLineNumber,o.push(d.type),d.type&&(r=!0)}r||(o=void 0);const a=new zo(i,n,o);for(let l=0;l<t;l++)e[l].isCollapsed&&a.setCollapsed(l,!0),a.setSource(l,e[l].source);return a}static sanitizeAndMerge(e,t,i){i=i??Number.MAX_VALUE;const n=(m,_)=>Array.isArray(m)?v=>v<_?m[v]:void 0:v=>v<_?m.toFoldRange(v):void 0,o=n(e,e.length),r=n(t,t.length);let a=0,l=0,d=o(0),c=r(0);const u=[];let h,g=0;const f=[];for(;d||c;){let m;if(c&&(!d||d.startLineNumber>=c.startLineNumber))d&&d.startLineNumber===c.startLineNumber?(c.source===1?m=c:(m=d,m.isCollapsed=c.isCollapsed&&d.endLineNumber===c.endLineNumber,m.source=0),d=o(++a)):(m=c,c.isCollapsed&&c.source===0&&(m.source=2)),c=r(++l);else{let _=l,v=c;for(;;){if(!v||v.startLineNumber>d.endLineNumber){m=d;break}if(v.source===1&&v.endLineNumber>d.endLineNumber)break;v=r(++_)}d=o(++a)}if(m){for(;h&&h.endLineNumber<m.startLineNumber;)h=u.pop();m.endLineNumber>m.startLineNumber&&m.startLineNumber>g&&m.endLineNumber<=i&&(!h||h.endLineNumber>=m.endLineNumber)&&(f.push(m),g=m.startLineNumber,h&&u.push(h),h=m)}}return f}}class dSe{constructor(e,t){this.ranges=e,this.index=t}get startLineNumber(){return this.ranges.getStartLineNumber(this.index)}get endLineNumber(){return this.ranges.getEndLineNumber(this.index)}get regionIndex(){return this.index}get parentIndex(){return this.ranges.getParentIndex(this.index)}get isCollapsed(){return this.ranges.isCollapsed(this.index)}containedBy(e){return e.startLineNumber<=this.startLineNumber&&e.endLineNumber>=this.endLineNumber}containsLine(e){return this.startLineNumber<=e&&e<=this.endLineNumber}}class cSe{get regions(){return this._regions}get textModel(){return this._textModel}constructor(e,t){this._updateEventEmitter=new W,this.onDidChange=this._updateEventEmitter.event,this._textModel=e,this._decorationProvider=t,this._regions=new zo(new Uint32Array(0),new Uint32Array(0)),this._editorDecorationIds=[]}toggleCollapseState(e){if(!e.length)return;e=e.sort((i,n)=>i.regionIndex-n.regionIndex);const t={};this._decorationProvider.changeDecorations(i=>{let n=0,o=-1,r=-1;const a=l=>{for(;n<l;){const d=this._regions.getEndLineNumber(n),c=this._regions.isCollapsed(n);if(d<=o){const u=this.regions.getSource(n)!==0;i.changeDecorationOptions(this._editorDecorationIds[n],this._decorationProvider.getDecorationOption(c,d<=r,u))}c&&d>r&&(r=d),n++}};for(const l of e){const d=l.regionIndex,c=this._editorDecorationIds[d];if(c&&!t[c]){t[c]=!0,a(d);const u=!this._regions.isCollapsed(d);this._regions.setCollapsed(d,u),o=Math.max(o,this._regions.getEndLineNumber(d))}}a(this._regions.length)}),this._updateEventEmitter.fire({model:this,collapseStateChanged:e})}removeManualRanges(e){const t=new Array,i=n=>{for(const o of e)if(!(o.startLineNumber>n.endLineNumber||n.startLineNumber>o.endLineNumber))return!0;return!1};for(let n=0;n<this._regions.length;n++){const o=this._regions.toFoldRange(n);(o.source===0||!i(o))&&t.push(o)}this.updatePost(zo.fromFoldRanges(t))}update(e,t=[]){const i=this._currentFoldedOrManualRanges(t),n=zo.sanitizeAndMerge(e,i,this._textModel.getLineCount());this.updatePost(zo.fromFoldRanges(n))}updatePost(e){const t=[];let i=-1;for(let n=0,o=e.length;n<o;n++){const r=e.getStartLineNumber(n),a=e.getEndLineNumber(n),l=e.isCollapsed(n),d=e.getSource(n)!==0,c={startLineNumber:r,startColumn:this._textModel.getLineMaxColumn(r),endLineNumber:a,endColumn:this._textModel.getLineMaxColumn(a)+1};t.push({range:c,options:this._decorationProvider.getDecorationOption(l,a<=i,d)}),l&&a>i&&(i=a)}this._decorationProvider.changeDecorations(n=>this._editorDecorationIds=n.deltaDecorations(this._editorDecorationIds,t)),this._regions=e,this._updateEventEmitter.fire({model:this})}_currentFoldedOrManualRanges(e=[]){const t=(n,o)=>{for(const r of e)if(n<r&&r<=o)return!0;return!1},i=[];for(let n=0,o=this._regions.length;n<o;n++){let r=this.regions.isCollapsed(n);const a=this.regions.getSource(n);if(r||a!==0){const l=this._regions.toFoldRange(n),d=this._textModel.getDecorationRange(this._editorDecorationIds[n]);d&&(r&&t(d.startLineNumber,d.endLineNumber)&&(r=!1),i.push({startLineNumber:d.startLineNumber,endLineNumber:d.endLineNumber,type:l.type,isCollapsed:r,source:a}))}}return i}getMemento(){const e=this._currentFoldedOrManualRanges(),t=[],i=this._textModel.getLineCount();for(let n=0,o=e.length;n<o;n++){const r=e[n];if(r.startLineNumber>=r.endLineNumber||r.startLineNumber<1||r.endLineNumber>i)continue;const a=this._getLinesChecksum(r.startLineNumber+1,r.endLineNumber);t.push({startLineNumber:r.startLineNumber,endLineNumber:r.endLineNumber,isCollapsed:r.isCollapsed,source:r.source,checksum:a})}return t.length>0?t:void 0}applyMemento(e){var t,i;if(!Array.isArray(e))return;const n=[],o=this._textModel.getLineCount();for(const a of e){if(a.startLineNumber>=a.endLineNumber||a.startLineNumber<1||a.endLineNumber>o)continue;const l=this._getLinesChecksum(a.startLineNumber+1,a.endLineNumber);(!a.checksum||l===a.checksum)&&n.push({startLineNumber:a.startLineNumber,endLineNumber:a.endLineNumber,type:void 0,isCollapsed:(t=a.isCollapsed)!==null&&t!==void 0?t:!0,source:(i=a.source)!==null&&i!==void 0?i:0})}const r=zo.sanitizeAndMerge(this._regions,n,o);this.updatePost(zo.fromFoldRanges(r))}_getLinesChecksum(e,t){return XA(this._textModel.getLineContent(e)+this._textModel.getLineContent(t))%1e6}dispose(){this._decorationProvider.removeDecorations(this._editorDecorationIds)}getAllRegionsAtLine(e,t){const i=[];if(this._regions){let n=this._regions.findRange(e),o=1;for(;n>=0;){const r=this._regions.toRegion(n);(!t||t(r,o))&&i.push(r),o++,n=r.parentIndex}}return i}getRegionAtLine(e){if(this._regions){const t=this._regions.findRange(e);if(t>=0)return this._regions.toRegion(t)}return null}getRegionsInside(e,t){const i=[],n=e?e.regionIndex+1:0,o=e?e.endLineNumber:Number.MAX_VALUE;if(t&&t.length===2){const r=[];for(let a=n,l=this._regions.length;a<l;a++){const d=this._regions.toRegion(a);if(this._regions.getStartLineNumber(a)<o){for(;r.length>0&&!d.containedBy(r[r.length-1]);)r.pop();r.push(d),t(d,r.length)&&i.push(d)}else break}}else for(let r=n,a=this._regions.length;r<a;r++){const l=this._regions.toRegion(r);if(this._regions.getStartLineNumber(r)<o)(!t||t(l))&&i.push(l);else break}return i}}function dK(s,e,t){const i=[];for(const n of t){const o=s.getRegionAtLine(n);if(o){const r=!o.isCollapsed;if(i.push(o),e>1){const a=s.getRegionsInside(o,(l,d)=>l.isCollapsed!==r&&d<e);i.push(...a)}}}s.toggleCollapseState(i)}function __(s,e,t=Number.MAX_VALUE,i){const n=[];if(i&&i.length>0)for(const o of i){const r=s.getRegionAtLine(o);if(r&&(r.isCollapsed!==e&&n.push(r),t>1)){const a=s.getRegionsInside(r,(l,d)=>l.isCollapsed!==e&&d<t);n.push(...a)}}else{const o=s.getRegionsInside(null,(r,a)=>r.isCollapsed!==e&&a<t);n.push(...o)}s.toggleCollapseState(n)}function cK(s,e,t,i){const n=[];for(const o of i){const r=s.getAllRegionsAtLine(o,(a,l)=>a.isCollapsed!==e&&l<=t);n.push(...r)}s.toggleCollapseState(n)}function uSe(s,e,t){const i=[];for(const n of t){const o=s.getAllRegionsAtLine(n,r=>r.isCollapsed!==e);o.length>0&&i.push(o[0])}s.toggleCollapseState(i)}function hSe(s,e,t,i){const n=(r,a)=>a===e&&r.isCollapsed!==t&&!i.some(l=>r.containsLine(l)),o=s.getRegionsInside(null,n);s.toggleCollapseState(o)}function uK(s,e,t){const i=[];for(const r of t){const a=s.getAllRegionsAtLine(r,void 0);a.length>0&&i.push(a[0])}const n=r=>i.every(a=>!a.containedBy(r)&&!r.containedBy(a))&&r.isCollapsed!==e,o=s.getRegionsInside(null,n);s.toggleCollapseState(o)}function w4(s,e,t){const i=s.textModel,n=s.regions,o=[];for(let r=n.length-1;r>=0;r--)if(t!==n.isCollapsed(r)){const a=n.getStartLineNumber(r);e.test(i.getLineContent(a))&&o.push(n.toRegion(r))}s.toggleCollapseState(o)}function S4(s,e,t){const i=s.regions,n=[];for(let o=i.length-1;o>=0;o--)t!==i.isCollapsed(o)&&e===i.getType(o)&&n.push(i.toRegion(o));s.toggleCollapseState(n)}function gSe(s,e){let t=null;const i=e.getRegionAtLine(s);if(i!==null&&(t=i.startLineNumber,s===t)){const n=i.parentIndex;n!==-1?t=e.regions.getStartLineNumber(n):t=null}return t}function fSe(s,e){let t=e.getRegionAtLine(s);if(t!==null&&t.startLineNumber===s){if(s!==t.startLineNumber)return t.startLineNumber;{const i=t.parentIndex;let n=0;for(i!==-1&&(n=e.regions.getStartLineNumber(t.parentIndex));t!==null;)if(t.regionIndex>0){if(t=e.regions.toRegion(t.regionIndex-1),t.startLineNumber<=n)return null;if(t.parentIndex===i)return t.startLineNumber}else return null}}else if(e.regions.length>0)for(t=e.regions.toRegion(e.regions.length-1);t!==null;){if(t.startLineNumber<s)return t.startLineNumber;t.regionIndex>0?t=e.regions.toRegion(t.regionIndex-1):t=null}return null}function pSe(s,e){let t=e.getRegionAtLine(s);if(t!==null&&t.startLineNumber===s){const i=t.parentIndex;let n=0;if(i!==-1)n=e.regions.getEndLineNumber(t.parentIndex);else{if(e.regions.length===0)return null;n=e.regions.getEndLineNumber(e.regions.length-1)}for(;t!==null;)if(t.regionIndex<e.regions.length){if(t=e.regions.toRegion(t.regionIndex+1),t.startLineNumber>=n)return null;if(t.parentIndex===i)return t.startLineNumber}else return null}else if(e.regions.length>0)for(t=e.regions.toRegion(0);t!==null;){if(t.startLineNumber>s)return t.startLineNumber;t.regionIndex<e.regions.length?t=e.regions.toRegion(t.regionIndex+1):t=null}return null}class mSe{get onDidChange(){return this._updateEventEmitter.event}get hiddenRanges(){return this._hiddenRanges}constructor(e){this._updateEventEmitter=new W,this._hasLineChanges=!1,this._foldingModel=e,this._foldingModelListener=e.onDidChange(t=>this.updateHiddenRanges()),this._hiddenRanges=[],e.regions.length&&this.updateHiddenRanges()}notifyChangeModelContent(e){this._hiddenRanges.length&&!this._hasLineChanges&&(this._hasLineChanges=e.changes.some(t=>t.range.endLineNumber!==t.range.startLineNumber||Ou(t.text)[0]!==0))}updateHiddenRanges(){let e=!1;const t=[];let i=0,n=0,o=Number.MAX_VALUE,r=-1;const a=this._foldingModel.regions;for(;i<a.length;i++){if(!a.isCollapsed(i))continue;const l=a.getStartLineNumber(i)+1,d=a.getEndLineNumber(i);o<=l&&d<=r||(!e&&n<this._hiddenRanges.length&&this._hiddenRanges[n].startLineNumber===l&&this._hiddenRanges[n].endLineNumber===d?(t.push(this._hiddenRanges[n]),n++):(e=!0,t.push(new D(l,1,d,1))),o=l,r=d)}(this._hasLineChanges||e||n<this._hiddenRanges.length)&&this.applyHiddenRanges(t)}applyHiddenRanges(e){this._hiddenRanges=e,this._hasLineChanges=!1,this._updateEventEmitter.fire(e)}hasRanges(){return this._hiddenRanges.length>0}isHidden(e){return uB(this._hiddenRanges,e)!==null}adjustSelections(e){let t=!1;const i=this._foldingModel.textModel;let n=null;const o=r=>((!n||!_Se(r,n))&&(n=uB(this._hiddenRanges,r)),n?n.startLineNumber-1:null);for(let r=0,a=e.length;r<a;r++){let l=e[r];const d=o(l.startLineNumber);d&&(l=l.setStartPosition(d,i.getLineMaxColumn(d)),t=!0);const c=o(l.endLineNumber);c&&(l=l.setEndPosition(c,i.getLineMaxColumn(c)),t=!0),e[r]=l}return t}dispose(){this.hiddenRanges.length>0&&(this._hiddenRanges=[],this._updateEventEmitter.fire(this._hiddenRanges)),this._foldingModelListener&&(this._foldingModelListener.dispose(),this._foldingModelListener=null)}}function _Se(s,e){return s>=e.startLineNumber&&s<=e.endLineNumber}function uB(s,e){const t=P0(s,i=>e<i.startLineNumber)-1;return t>=0&&s[t].endLineNumber>=e?s[t]:null}const vSe=5e3,bSe="indent";class y4{constructor(e,t,i){this.editorModel=e,this.languageConfigurationService=t,this.foldingRangesLimit=i,this.id=bSe}dispose(){}compute(e){const t=this.languageConfigurationService.getLanguageConfiguration(this.editorModel.getLanguageId()).foldingRules,i=t&&!!t.offSide,n=t&&t.markers;return Promise.resolve(SSe(this.editorModel,i,n,this.foldingRangesLimit))}}let CSe=class{constructor(e){this._startIndexes=[],this._endIndexes=[],this._indentOccurrences=[],this._length=0,this._foldingRangesLimit=e}insertFirst(e,t,i){if(e>va||t>va)return;const n=this._length;this._startIndexes[n]=e,this._endIndexes[n]=t,this._length++,i<1e3&&(this._indentOccurrences[i]=(this._indentOccurrences[i]||0)+1)}toIndentRanges(e){const t=this._foldingRangesLimit.limit;if(this._length<=t){this._foldingRangesLimit.update(this._length,!1);const i=new Uint32Array(this._length),n=new Uint32Array(this._length);for(let o=this._length-1,r=0;o>=0;o--,r++)i[r]=this._startIndexes[o],n[r]=this._endIndexes[o];return new zo(i,n)}else{this._foldingRangesLimit.update(this._length,t);let i=0,n=this._indentOccurrences.length;for(let l=0;l<this._indentOccurrences.length;l++){const d=this._indentOccurrences[l];if(d){if(d+i>t){n=l;break}i+=d}}const o=e.getOptions().tabSize,r=new Uint32Array(t),a=new Uint32Array(t);for(let l=this._length-1,d=0;l>=0;l--){const c=this._startIndexes[l],u=e.getLineContent(c),h=Ex(u,o);(h<n||h===n&&i++<t)&&(r[d]=c,a[d]=this._endIndexes[l],d++)}return new zo(r,a)}}};const wSe={limit:vSe,update:()=>{}};function SSe(s,e,t,i=wSe){const n=s.getOptions().tabSize,o=new CSe(i);let r;t&&(r=new RegExp(`(${t.start.source})|(?:${t.end.source})`));const a=[],l=s.getLineCount()+1;a.push({indent:-1,endAbove:l,line:l});for(let d=s.getLineCount();d>0;d--){const c=s.getLineContent(d),u=Ex(c,n);let h=a[a.length-1];if(u===-1){e&&(h.endAbove=d);continue}let g;if(r&&(g=c.match(r)))if(g[1]){let f=a.length-1;for(;f>0&&a[f].indent!==-2;)f--;if(f>0){a.length=f+1,h=a[f],o.insertFirst(d,h.line,u),h.line=d,h.indent=u,h.endAbove=d;continue}}else{a.push({indent:-2,endAbove:d,line:d});continue}if(h.indent>u){do a.pop(),h=a[a.length-1];while(h.indent>u);const f=h.endAbove-1;f-d>=1&&o.insertFirst(d,f,u)}h.indent===u?h.endAbove=d:a.push({indent:u,endAbove:d,line:d})}return o.toIndentRanges(s)}const ySe=R("editor.foldBackground",{light:Me(Uc,.3),dark:Me(Uc,.3),hcDark:null,hcLight:null},p("foldBackgroundBackground","Background color behind folded ranges. The color must not be opaque so as not to hide underlying decorations."),!0);R("editorGutter.foldingControlForeground",{dark:Ur,light:Ur,hcDark:Ur,hcLight:Ur},p("editorGutter.foldingControlForeground","Color of the folding control in the editor gutter."));const TD=Ui("folding-expanded",le.chevronDown,p("foldingExpandedIcon","Icon for expanded ranges in the editor glyph margin.")),MD=Ui("folding-collapsed",le.chevronRight,p("foldingCollapsedIcon","Icon for collapsed ranges in the editor glyph margin.")),hK=Ui("folding-manual-collapsed",MD,p("foldingManualCollapedIcon","Icon for manually collapsed ranges in the editor glyph margin.")),gK=Ui("folding-manual-expanded",TD,p("foldingManualExpandedIcon","Icon for manually expanded ranges in the editor glyph margin.")),L4={color:Di(ySe),position:bo.Inline};class en{constructor(e){this.editor=e,this.showFoldingControls="mouseover",this.showFoldingHighlights=!0}getDecorationOption(e,t,i){return t?en.HIDDEN_RANGE_DECORATION:this.showFoldingControls==="never"?e?this.showFoldingHighlights?en.NO_CONTROLS_COLLAPSED_HIGHLIGHTED_RANGE_DECORATION:en.NO_CONTROLS_COLLAPSED_RANGE_DECORATION:en.NO_CONTROLS_EXPANDED_RANGE_DECORATION:e?i?this.showFoldingHighlights?en.MANUALLY_COLLAPSED_HIGHLIGHTED_VISUAL_DECORATION:en.MANUALLY_COLLAPSED_VISUAL_DECORATION:this.showFoldingHighlights?en.COLLAPSED_HIGHLIGHTED_VISUAL_DECORATION:en.COLLAPSED_VISUAL_DECORATION:this.showFoldingControls==="mouseover"?i?en.MANUALLY_EXPANDED_AUTO_HIDE_VISUAL_DECORATION:en.EXPANDED_AUTO_HIDE_VISUAL_DECORATION:i?en.MANUALLY_EXPANDED_VISUAL_DECORATION:en.EXPANDED_VISUAL_DECORATION}changeDecorations(e){return this.editor.changeDecorations(e)}removeDecorations(e){this.editor.removeDecorations(e)}}en.COLLAPSED_VISUAL_DECORATION=tt.register({description:"folding-collapsed-visual-decoration",stickiness:0,afterContentClassName:"inline-folded",isWholeLine:!0,firstLineDecorationClassName:Oe.asClassName(MD)});en.COLLAPSED_HIGHLIGHTED_VISUAL_DECORATION=tt.register({description:"folding-collapsed-highlighted-visual-decoration",stickiness:0,afterContentClassName:"inline-folded",className:"folded-background",minimap:L4,isWholeLine:!0,firstLineDecorationClassName:Oe.asClassName(MD)});en.MANUALLY_COLLAPSED_VISUAL_DECORATION=tt.register({description:"folding-manually-collapsed-visual-decoration",stickiness:0,afterContentClassName:"inline-folded",isWholeLine:!0,firstLineDecorationClassName:Oe.asClassName(hK)});en.MANUALLY_COLLAPSED_HIGHLIGHTED_VISUAL_DECORATION=tt.register({description:"folding-manually-collapsed-highlighted-visual-decoration",stickiness:0,afterContentClassName:"inline-folded",className:"folded-background",minimap:L4,isWholeLine:!0,firstLineDecorationClassName:Oe.asClassName(hK)});en.NO_CONTROLS_COLLAPSED_RANGE_DECORATION=tt.register({description:"folding-no-controls-range-decoration",stickiness:0,afterContentClassName:"inline-folded",isWholeLine:!0});en.NO_CONTROLS_COLLAPSED_HIGHLIGHTED_RANGE_DECORATION=tt.register({description:"folding-no-controls-range-decoration",stickiness:0,afterContentClassName:"inline-folded",className:"folded-background",minimap:L4,isWholeLine:!0});en.EXPANDED_VISUAL_DECORATION=tt.register({description:"folding-expanded-visual-decoration",stickiness:1,isWholeLine:!0,firstLineDecorationClassName:"alwaysShowFoldIcons "+Oe.asClassName(TD)});en.EXPANDED_AUTO_HIDE_VISUAL_DECORATION=tt.register({description:"folding-expanded-auto-hide-visual-decoration",stickiness:1,isWholeLine:!0,firstLineDecorationClassName:Oe.asClassName(TD)});en.MANUALLY_EXPANDED_VISUAL_DECORATION=tt.register({description:"folding-manually-expanded-visual-decoration",stickiness:0,isWholeLine:!0,firstLineDecorationClassName:"alwaysShowFoldIcons "+Oe.asClassName(gK)});en.MANUALLY_EXPANDED_AUTO_HIDE_VISUAL_DECORATION=tt.register({description:"folding-manually-expanded-auto-hide-visual-decoration",stickiness:0,isWholeLine:!0,firstLineDecorationClassName:Oe.asClassName(gK)});en.NO_CONTROLS_EXPANDED_RANGE_DECORATION=tt.register({description:"folding-no-controls-range-decoration",stickiness:0,isWholeLine:!0});en.HIDDEN_RANGE_DECORATION=tt.register({description:"folding-hidden-range-decoration",stickiness:1});const LSe={},xSe="syntax";class x4{constructor(e,t,i,n,o){this.editorModel=e,this.providers=t,this.handleFoldingRangesChange=i,this.foldingRangesLimit=n,this.fallbackRangeProvider=o,this.id=xSe,this.disposables=new ie,o&&this.disposables.add(o);for(const r of t)typeof r.onDidChange=="function"&&this.disposables.add(r.onDidChange(i))}compute(e){return DSe(this.providers,this.editorModel,e).then(t=>{var i,n;return t?ISe(t,this.foldingRangesLimit):(n=(i=this.fallbackRangeProvider)===null||i===void 0?void 0:i.compute(e))!==null&&n!==void 0?n:null})}dispose(){this.disposables.dispose()}}function DSe(s,e,t){let i=null;const n=s.map((o,r)=>Promise.resolve(o.provideFoldingRanges(e,LSe,t)).then(a=>{if(!t.isCancellationRequested&&Array.isArray(a)){Array.isArray(i)||(i=[]);const l=e.getLineCount();for(const d of a)d.start>0&&d.end>d.start&&d.end<=l&&i.push({start:d.start,end:d.end,rank:r,kind:d.kind})}},Zi));return Promise.all(n).then(o=>i)}class kSe{constructor(e){this._startIndexes=[],this._endIndexes=[],this._nestingLevels=[],this._nestingLevelCounts=[],this._types=[],this._length=0,this._foldingRangesLimit=e}add(e,t,i,n){if(e>va||t>va)return;const o=this._length;this._startIndexes[o]=e,this._endIndexes[o]=t,this._nestingLevels[o]=n,this._types[o]=i,this._length++,n<30&&(this._nestingLevelCounts[n]=(this._nestingLevelCounts[n]||0)+1)}toIndentRanges(){const e=this._foldingRangesLimit.limit;if(this._length<=e){this._foldingRangesLimit.update(this._length,!1);const t=new Uint32Array(this._length),i=new Uint32Array(this._length);for(let n=0;n<this._length;n++)t[n]=this._startIndexes[n],i[n]=this._endIndexes[n];return new zo(t,i,this._types)}else{this._foldingRangesLimit.update(this._length,e);let t=0,i=this._nestingLevelCounts.length;for(let a=0;a<this._nestingLevelCounts.length;a++){const l=this._nestingLevelCounts[a];if(l){if(l+t>e){i=a;break}t+=l}}const n=new Uint32Array(e),o=new Uint32Array(e),r=[];for(let a=0,l=0;a<this._length;a++){const d=this._nestingLevels[a];(d<i||d===i&&t++<e)&&(n[l]=this._startIndexes[a],o[l]=this._endIndexes[a],r[l]=this._types[a],l++)}return new zo(n,o,r)}}}function ISe(s,e){const t=s.sort((r,a)=>{let l=r.start-a.start;return l===0&&(l=r.rank-a.rank),l}),i=new kSe(e);let n;const o=[];for(const r of t)if(!n)n=r,i.add(r.start,r.end,r.kind&&r.kind.value,o.length);else if(r.start>n.start)if(r.end<=n.end)o.push(n),n=r,i.add(r.start,r.end,r.kind&&r.kind.value,o.length);else{if(r.start>n.end){do n=o.pop();while(n&&r.start>n.end);n&&o.push(n),n=r}i.add(r.start,r.end,r.kind&&r.kind.value,o.length)}return i.toIndentRanges()}var ESe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},X_=function(s,e){return function(t,i){e(t,i,s)}},Yf;const hs=new me("foldingEnabled",!1);let id=Yf=class extends j{static get(e){return e.getContribution(Yf.ID)}static getFoldingRangeProviders(e,t){var i,n;const o=e.foldingRangeProvider.ordered(t);return(n=(i=Yf._foldingRangeSelector)===null||i===void 0?void 0:i.call(Yf,o,t))!==null&&n!==void 0?n:o}constructor(e,t,i,n,o,r){super(),this.contextKeyService=t,this.languageConfigurationService=i,this.languageFeaturesService=r,this.localToDispose=this._register(new ie),this.editor=e,this._foldingLimitReporter=new fK(e);const a=this.editor.getOptions();this._isEnabled=a.get(43),this._useFoldingProviders=a.get(44)!=="indentation",this._unfoldOnClickAfterEndOfLine=a.get(48),this._restoringViewState=!1,this._currentModelHasFoldedImports=!1,this._foldingImportsByDefault=a.get(46),this.updateDebounceInfo=o.for(r.foldingRangeProvider,"Folding",{min:200}),this.foldingModel=null,this.hiddenRangeModel=null,this.rangeProvider=null,this.foldingRegionPromise=null,this.foldingModelPromise=null,this.updateScheduler=null,this.cursorChangedScheduler=null,this.mouseDownInfo=null,this.foldingDecorationProvider=new en(e),this.foldingDecorationProvider.showFoldingControls=a.get(109),this.foldingDecorationProvider.showFoldingHighlights=a.get(45),this.foldingEnabled=hs.bindTo(this.contextKeyService),this.foldingEnabled.set(this._isEnabled),this._register(this.editor.onDidChangeModel(()=>this.onModelChanged())),this._register(this.editor.onDidChangeConfiguration(l=>{if(l.hasChanged(43)&&(this._isEnabled=this.editor.getOptions().get(43),this.foldingEnabled.set(this._isEnabled),this.onModelChanged()),l.hasChanged(47)&&this.onModelChanged(),l.hasChanged(109)||l.hasChanged(45)){const d=this.editor.getOptions();this.foldingDecorationProvider.showFoldingControls=d.get(109),this.foldingDecorationProvider.showFoldingHighlights=d.get(45),this.triggerFoldingModelChanged()}l.hasChanged(44)&&(this._useFoldingProviders=this.editor.getOptions().get(44)!=="indentation",this.onFoldingStrategyChanged()),l.hasChanged(48)&&(this._unfoldOnClickAfterEndOfLine=this.editor.getOptions().get(48)),l.hasChanged(46)&&(this._foldingImportsByDefault=this.editor.getOptions().get(46))})),this.onModelChanged()}saveViewState(){const e=this.editor.getModel();if(!e||!this._isEnabled||e.isTooLargeForTokenization())return{};if(this.foldingModel){const t=this.foldingModel.getMemento(),i=this.rangeProvider?this.rangeProvider.id:void 0;return{collapsedRegions:t,lineCount:e.getLineCount(),provider:i,foldedImports:this._currentModelHasFoldedImports}}}restoreViewState(e){const t=this.editor.getModel();if(!(!t||!this._isEnabled||t.isTooLargeForTokenization()||!this.hiddenRangeModel)&&e&&(this._currentModelHasFoldedImports=!!e.foldedImports,e.collapsedRegions&&e.collapsedRegions.length>0&&this.foldingModel)){this._restoringViewState=!0;try{this.foldingModel.applyMemento(e.collapsedRegions)}finally{this._restoringViewState=!1}}}onModelChanged(){this.localToDispose.clear();const e=this.editor.getModel();!this._isEnabled||!e||e.isTooLargeForTokenization()||(this._currentModelHasFoldedImports=!1,this.foldingModel=new cSe(e,this.foldingDecorationProvider),this.localToDispose.add(this.foldingModel),this.hiddenRangeModel=new mSe(this.foldingModel),this.localToDispose.add(this.hiddenRangeModel),this.localToDispose.add(this.hiddenRangeModel.onDidChange(t=>this.onHiddenRangesChanges(t))),this.updateScheduler=new Qr(this.updateDebounceInfo.get(e)),this.cursorChangedScheduler=new jt(()=>this.revealCursor(),200),this.localToDispose.add(this.cursorChangedScheduler),this.localToDispose.add(this.languageFeaturesService.foldingRangeProvider.onDidChange(()=>this.onFoldingStrategyChanged())),this.localToDispose.add(this.editor.onDidChangeModelLanguageConfiguration(()=>this.onFoldingStrategyChanged())),this.localToDispose.add(this.editor.onDidChangeModelContent(t=>this.onDidChangeModelContent(t))),this.localToDispose.add(this.editor.onDidChangeCursorPosition(()=>this.onCursorPositionChanged())),this.localToDispose.add(this.editor.onMouseDown(t=>this.onEditorMouseDown(t))),this.localToDispose.add(this.editor.onMouseUp(t=>this.onEditorMouseUp(t))),this.localToDispose.add({dispose:()=>{var t,i;this.foldingRegionPromise&&(this.foldingRegionPromise.cancel(),this.foldingRegionPromise=null),(t=this.updateScheduler)===null||t===void 0||t.cancel(),this.updateScheduler=null,this.foldingModel=null,this.foldingModelPromise=null,this.hiddenRangeModel=null,this.cursorChangedScheduler=null,(i=this.rangeProvider)===null||i===void 0||i.dispose(),this.rangeProvider=null}}),this.triggerFoldingModelChanged())}onFoldingStrategyChanged(){var e;(e=this.rangeProvider)===null||e===void 0||e.dispose(),this.rangeProvider=null,this.triggerFoldingModelChanged()}getRangeProvider(e){if(this.rangeProvider)return this.rangeProvider;const t=new y4(e,this.languageConfigurationService,this._foldingLimitReporter);if(this.rangeProvider=t,this._useFoldingProviders&&this.foldingModel){const i=Yf.getFoldingRangeProviders(this.languageFeaturesService,e);i.length>0&&(this.rangeProvider=new x4(e,i,()=>this.triggerFoldingModelChanged(),this._foldingLimitReporter,t))}return this.rangeProvider}getFoldingModel(){return this.foldingModelPromise}onDidChangeModelContent(e){var t;(t=this.hiddenRangeModel)===null||t===void 0||t.notifyChangeModelContent(e),this.triggerFoldingModelChanged()}triggerFoldingModelChanged(){this.updateScheduler&&(this.foldingRegionPromise&&(this.foldingRegionPromise.cancel(),this.foldingRegionPromise=null),this.foldingModelPromise=this.updateScheduler.trigger(()=>{const e=this.foldingModel;if(!e)return null;const t=new cs,i=this.getRangeProvider(e.textModel),n=this.foldingRegionPromise=gn(o=>i.compute(o));return n.then(o=>{if(o&&n===this.foldingRegionPromise){let r;if(this._foldingImportsByDefault&&!this._currentModelHasFoldedImports){const c=o.setCollapsedAllOfType(Rs.Imports.value,!0);c&&(r=$a.capture(this.editor),this._currentModelHasFoldedImports=c)}const a=this.editor.getSelections(),l=a?a.map(c=>c.startLineNumber):[];e.update(o,l),r==null||r.restore(this.editor);const d=this.updateDebounceInfo.update(e.textModel,t.elapsed());this.updateScheduler&&(this.updateScheduler.defaultDelay=d)}return e})}).then(void 0,e=>(et(e),null)))}onHiddenRangesChanges(e){if(this.hiddenRangeModel&&e.length&&!this._restoringViewState){const t=this.editor.getSelections();t&&this.hiddenRangeModel.adjustSelections(t)&&this.editor.setSelections(t)}this.editor.setHiddenAreas(e,this)}onCursorPositionChanged(){this.hiddenRangeModel&&this.hiddenRangeModel.hasRanges()&&this.cursorChangedScheduler.schedule()}revealCursor(){const e=this.getFoldingModel();e&&e.then(t=>{if(t){const i=this.editor.getSelections();if(i&&i.length>0){const n=[];for(const o of i){const r=o.selectionStartLineNumber;this.hiddenRangeModel&&this.hiddenRangeModel.isHidden(r)&&n.push(...t.getAllRegionsAtLine(r,a=>a.isCollapsed&&r>a.startLineNumber))}n.length&&(t.toggleCollapseState(n),this.reveal(i[0].getPosition()))}}}).then(void 0,et)}onEditorMouseDown(e){if(this.mouseDownInfo=null,!this.hiddenRangeModel||!e.target||!e.target.range||!e.event.leftButton&&!e.event.middleButton)return;const t=e.target.range;let i=!1;switch(e.target.type){case 4:{const n=e.target.detail,o=e.target.element.offsetLeft;if(n.offsetX-o<4)return;i=!0;break}case 7:{if(this._unfoldOnClickAfterEndOfLine&&this.hiddenRangeModel.hasRanges()&&!e.target.detail.isAfterLines)break;return}case 6:{if(this.hiddenRangeModel.hasRanges()){const n=this.editor.getModel();if(n&&t.startColumn===n.getLineMaxColumn(t.startLineNumber))break}return}default:return}this.mouseDownInfo={lineNumber:t.startLineNumber,iconClicked:i}}onEditorMouseUp(e){const t=this.foldingModel;if(!t||!this.mouseDownInfo||!e.target)return;const i=this.mouseDownInfo.lineNumber,n=this.mouseDownInfo.iconClicked,o=e.target.range;if(!o||o.startLineNumber!==i)return;if(n){if(e.target.type!==4)return}else{const a=this.editor.getModel();if(!a||o.startColumn!==a.getLineMaxColumn(i))return}const r=t.getRegionAtLine(i);if(r&&r.startLineNumber===i){const a=r.isCollapsed;if(n||a){const l=e.event.altKey;let d=[];if(l){const c=h=>!h.containedBy(r)&&!r.containedBy(h),u=t.getRegionsInside(null,c);for(const h of u)h.isCollapsed&&d.push(h);d.length===0&&(d=u)}else{const c=e.event.middleButton||e.event.shiftKey;if(c)for(const u of t.getRegionsInside(r))u.isCollapsed===a&&d.push(u);(a||!c||d.length===0)&&d.push(r)}t.toggleCollapseState(d),this.reveal({lineNumber:i,column:1})}}}reveal(e){this.editor.revealPositionInCenterIfOutsideViewport(e,0)}};id.ID="editor.contrib.folding";id=Yf=ESe([X_(1,je),X_(2,Jt),X_(3,Qi),X_(4,Er),X_(5,xe)],id);class fK{constructor(e){this.editor=e,this._onDidChange=new W,this._computed=0,this._limited=!1}get limit(){return this.editor.getOptions().get(47)}update(e,t){(e!==this._computed||t!==this._limited)&&(this._computed=e,this._limited=t,this._onDidChange.fire())}}class ys extends we{runEditorCommand(e,t,i){const n=e.get(Jt),o=id.get(t);if(!o)return;const r=o.getFoldingModel();if(r)return this.reportTelemetry(e,t),r.then(a=>{if(a){this.invoke(o,a,t,i,n);const l=t.getSelection();l&&o.reveal(l.getStartPosition())}})}getSelectedLines(e){const t=e.getSelections();return t?t.map(i=>i.startLineNumber):[]}getLineNumbers(e,t){return e&&e.selectionLines?e.selectionLines.map(i=>i+1):this.getSelectedLines(t)}run(e,t){}}function pK(s){if(!fo(s)){if(!Ts(s))return!1;const e=s;if(!fo(e.levels)&&!xu(e.levels)||!fo(e.direction)&&!Ps(e.direction)||!fo(e.selectionLines)&&(!Array.isArray(e.selectionLines)||!e.selectionLines.every(xu)))return!1}return!0}class NSe extends ys{constructor(){super({id:"editor.unfold",label:p("unfoldAction.label","Unfold"),alias:"Unfold",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:3166,mac:{primary:2654},weight:100},metadata:{description:"Unfold the content in the editor",args:[{name:"Unfold editor argument",description:`Property-value pairs that can be passed through this argument:
						* 'levels': Number of levels to unfold. If not set, defaults to 1.
						* 'direction': If 'up', unfold given number of levels up otherwise unfolds down.
						* 'selectionLines': Array of the start lines (0-based) of the editor selections to apply the unfold action to. If not set, the active selection(s) will be used.
						`,constraint:pK,schema:{type:"object",properties:{levels:{type:"number",default:1},direction:{type:"string",enum:["up","down"],default:"down"},selectionLines:{type:"array",items:{type:"number"}}}}}]}})}invoke(e,t,i,n){const o=n&&n.levels||1,r=this.getLineNumbers(n,i);n&&n.direction==="up"?cK(t,!1,o,r):__(t,!1,o,r)}}class TSe extends ys{constructor(){super({id:"editor.unfoldRecursively",label:p("unFoldRecursivelyAction.label","Unfold Recursively"),alias:"Unfold Recursively",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2142),weight:100}})}invoke(e,t,i,n){__(t,!1,Number.MAX_VALUE,this.getSelectedLines(i))}}class MSe extends ys{constructor(){super({id:"editor.fold",label:p("foldAction.label","Fold"),alias:"Fold",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:3164,mac:{primary:2652},weight:100},metadata:{description:"Fold the content in the editor",args:[{name:"Fold editor argument",description:`Property-value pairs that can be passed through this argument:
							* 'levels': Number of levels to fold.
							* 'direction': If 'up', folds given number of levels up otherwise folds down.
							* 'selectionLines': Array of the start lines (0-based) of the editor selections to apply the fold action to. If not set, the active selection(s) will be used.
							If no levels or direction is set, folds the region at the locations or if already collapsed, the first uncollapsed parent instead.
						`,constraint:pK,schema:{type:"object",properties:{levels:{type:"number"},direction:{type:"string",enum:["up","down"]},selectionLines:{type:"array",items:{type:"number"}}}}}]}})}invoke(e,t,i,n){const o=this.getLineNumbers(n,i),r=n&&n.levels,a=n&&n.direction;typeof r!="number"&&typeof a!="string"?uSe(t,!0,o):a==="up"?cK(t,!0,r||1,o):__(t,!0,r||1,o)}}class RSe extends ys{constructor(){super({id:"editor.toggleFold",label:p("toggleFoldAction.label","Toggle Fold"),alias:"Toggle Fold",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2090),weight:100}})}invoke(e,t,i){const n=this.getSelectedLines(i);dK(t,1,n)}}class ASe extends ys{constructor(){super({id:"editor.foldRecursively",label:p("foldRecursivelyAction.label","Fold Recursively"),alias:"Fold Recursively",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2140),weight:100}})}invoke(e,t,i){const n=this.getSelectedLines(i);__(t,!0,Number.MAX_VALUE,n)}}class PSe extends ys{constructor(){super({id:"editor.foldAllBlockComments",label:p("foldAllBlockComments.label","Fold All Block Comments"),alias:"Fold All Block Comments",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2138),weight:100}})}invoke(e,t,i,n,o){if(t.regions.hasTypes())S4(t,Rs.Comment.value,!0);else{const r=i.getModel();if(!r)return;const a=o.getLanguageConfiguration(r.getLanguageId()).comments;if(a&&a.blockCommentStartToken){const l=new RegExp("^\\s*"+ir(a.blockCommentStartToken));w4(t,l,!0)}}}}class OSe extends ys{constructor(){super({id:"editor.foldAllMarkerRegions",label:p("foldAllMarkerRegions.label","Fold All Regions"),alias:"Fold All Regions",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2077),weight:100}})}invoke(e,t,i,n,o){if(t.regions.hasTypes())S4(t,Rs.Region.value,!0);else{const r=i.getModel();if(!r)return;const a=o.getLanguageConfiguration(r.getLanguageId()).foldingRules;if(a&&a.markers&&a.markers.start){const l=new RegExp(a.markers.start);w4(t,l,!0)}}}}class FSe extends ys{constructor(){super({id:"editor.unfoldAllMarkerRegions",label:p("unfoldAllMarkerRegions.label","Unfold All Regions"),alias:"Unfold All Regions",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2078),weight:100}})}invoke(e,t,i,n,o){if(t.regions.hasTypes())S4(t,Rs.Region.value,!1);else{const r=i.getModel();if(!r)return;const a=o.getLanguageConfiguration(r.getLanguageId()).foldingRules;if(a&&a.markers&&a.markers.start){const l=new RegExp(a.markers.start);w4(t,l,!1)}}}}class BSe extends ys{constructor(){super({id:"editor.foldAllExcept",label:p("foldAllExcept.label","Fold All Except Selected"),alias:"Fold All Except Selected",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2136),weight:100}})}invoke(e,t,i){const n=this.getSelectedLines(i);uK(t,!0,n)}}class WSe extends ys{constructor(){super({id:"editor.unfoldAllExcept",label:p("unfoldAllExcept.label","Unfold All Except Selected"),alias:"Unfold All Except Selected",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2134),weight:100}})}invoke(e,t,i){const n=this.getSelectedLines(i);uK(t,!1,n)}}class VSe extends ys{constructor(){super({id:"editor.foldAll",label:p("foldAllAction.label","Fold All"),alias:"Fold All",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2069),weight:100}})}invoke(e,t,i){__(t,!0)}}class HSe extends ys{constructor(){super({id:"editor.unfoldAll",label:p("unfoldAllAction.label","Unfold All"),alias:"Unfold All",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2088),weight:100}})}invoke(e,t,i){__(t,!1)}}class Zg extends ys{getFoldingLevel(){return parseInt(this.id.substr(Zg.ID_PREFIX.length))}invoke(e,t,i){hSe(t,this.getFoldingLevel(),!0,this.getSelectedLines(i))}}Zg.ID_PREFIX="editor.foldLevel";Zg.ID=s=>Zg.ID_PREFIX+s;class zSe extends ys{constructor(){super({id:"editor.gotoParentFold",label:p("gotoParentFold.label","Go to Parent Fold"),alias:"Go to Parent Fold",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,weight:100}})}invoke(e,t,i){const n=this.getSelectedLines(i);if(n.length>0){const o=gSe(n[0],t);o!==null&&i.setSelection({startLineNumber:o,startColumn:1,endLineNumber:o,endColumn:1})}}}class USe extends ys{constructor(){super({id:"editor.gotoPreviousFold",label:p("gotoPreviousFold.label","Go to Previous Folding Range"),alias:"Go to Previous Folding Range",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,weight:100}})}invoke(e,t,i){const n=this.getSelectedLines(i);if(n.length>0){const o=fSe(n[0],t);o!==null&&i.setSelection({startLineNumber:o,startColumn:1,endLineNumber:o,endColumn:1})}}}class $Se extends ys{constructor(){super({id:"editor.gotoNextFold",label:p("gotoNextFold.label","Go to Next Folding Range"),alias:"Go to Next Folding Range",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,weight:100}})}invoke(e,t,i){const n=this.getSelectedLines(i);if(n.length>0){const o=pSe(n[0],t);o!==null&&i.setSelection({startLineNumber:o,startColumn:1,endLineNumber:o,endColumn:1})}}}class jSe extends ys{constructor(){super({id:"editor.createFoldingRangeFromSelection",label:p("createManualFoldRange.label","Create Folding Range from Selection"),alias:"Create Folding Range from Selection",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2135),weight:100}})}invoke(e,t,i){var n;const o=[],r=i.getSelections();if(r){for(const a of r){let l=a.endLineNumber;a.endColumn===1&&--l,l>a.startLineNumber&&(o.push({startLineNumber:a.startLineNumber,endLineNumber:l,type:void 0,isCollapsed:!0,source:1}),i.setSelection({startLineNumber:a.startLineNumber,startColumn:1,endLineNumber:a.startLineNumber,endColumn:1}))}if(o.length>0){o.sort((l,d)=>l.startLineNumber-d.startLineNumber);const a=zo.sanitizeAndMerge(t.regions,o,(n=i.getModel())===null||n===void 0?void 0:n.getLineCount());t.updatePost(zo.fromFoldRanges(a))}}}}class KSe extends ys{constructor(){super({id:"editor.removeManualFoldingRanges",label:p("removeManualFoldingRanges.label","Remove Manual Folding Ranges"),alias:"Remove Manual Folding Ranges",precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2137),weight:100}})}invoke(e,t,i){const n=i.getSelections();if(n){const o=[];for(const r of n){const{startLineNumber:a,endLineNumber:l}=r;o.push(l>=a?{startLineNumber:a,endLineNumber:l}:{endLineNumber:l,startLineNumber:a})}t.removeManualRanges(o),e.triggerFoldingModelChanged()}}}Lt(id.ID,id,0);re(NSe);re(TSe);re(MSe);re(ASe);re(VSe);re(HSe);re(PSe);re(OSe);re(FSe);re(BSe);re(WSe);re(RSe);re(zSe);re(USe);re($Se);re(jSe);re(KSe);for(let s=1;s<=7;s++)rte(new Zg({id:Zg.ID(s),label:p("foldLevelAction.label","Fold Level {0}",s),alias:`Fold Level ${s}`,precondition:hs,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2048|21+s),weight:100}}));Ct.registerCommand("_executeFoldingRangeProvider",async function(s,...e){const[t]=e;if(!(t instanceof Pe))throw Cr();const i=s.get(xe),n=s.get(vi).getModel(t);if(!n)throw Cr();const o=s.get(mt);if(!o.getValue("editor.folding",{resource:t}))return[];const r=s.get(Jt),a=o.getValue("editor.foldingStrategy",{resource:t}),l={get limit(){return o.getValue("editor.foldingMaximumRegions",{resource:t})},update:(g,f)=>{}},d=new y4(n,r,l);let c=d;if(a!=="indentation"){const g=id.getFoldingRangeProviders(i,n);g.length&&(c=new x4(n,g,()=>{},l,d))}const u=await c.compute(ct.None),h=[];try{if(u)for(let g=0;g<u.length;g++){const f=u.getType(g);h.push({start:u.getStartLineNumber(g),end:u.getEndLineNumber(g),kind:f?Rs.fromValue(f):void 0})}return h}finally{c.dispose()}});class qSe extends we{constructor(){super({id:"editor.action.fontZoomIn",label:p("EditorFontZoomIn.label","Editor Font Zoom In"),alias:"Editor Font Zoom In",precondition:void 0})}run(e,t){fr.setZoomLevel(fr.getZoomLevel()+1)}}class GSe extends we{constructor(){super({id:"editor.action.fontZoomOut",label:p("EditorFontZoomOut.label","Editor Font Zoom Out"),alias:"Editor Font Zoom Out",precondition:void 0})}run(e,t){fr.setZoomLevel(fr.getZoomLevel()-1)}}class ZSe extends we{constructor(){super({id:"editor.action.fontZoomReset",label:p("EditorFontZoomReset.label","Editor Font Zoom Reset"),alias:"Editor Font Zoom Reset",precondition:void 0})}run(e,t){fr.setZoomLevel(0)}}re(qSe);re(GSe);re(ZSe);var mK=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},s0=function(s,e){return function(t,i){e(t,i,s)}};let Nb=class{constructor(e,t,i,n){this._editor=e,this._languageFeaturesService=t,this._workerService=i,this._accessibleNotificationService=n,this._disposables=new ie,this._sessionDisposables=new ie,this._disposables.add(t.onTypeFormattingEditProvider.onDidChange(this._update,this)),this._disposables.add(e.onDidChangeModel(()=>this._update())),this._disposables.add(e.onDidChangeModelLanguage(()=>this._update())),this._disposables.add(e.onDidChangeConfiguration(o=>{o.hasChanged(56)&&this._update()})),this._update()}dispose(){this._disposables.dispose(),this._sessionDisposables.dispose()}_update(){if(this._sessionDisposables.clear(),!this._editor.getOption(56)||!this._editor.hasModel())return;const e=this._editor.getModel(),[t]=this._languageFeaturesService.onTypeFormattingEditProvider.ordered(e);if(!t||!t.autoFormatTriggerCharacters)return;const i=new US;for(const n of t.autoFormatTriggerCharacters)i.add(n.charCodeAt(0));this._sessionDisposables.add(this._editor.onDidType(n=>{const o=n.charCodeAt(n.length-1);i.has(o)&&this._trigger(String.fromCharCode(o))}))}_trigger(e){if(!this._editor.hasModel()||this._editor.getSelections().length>1||!this._editor.getSelection().isEmpty())return;const t=this._editor.getModel(),i=this._editor.getPosition(),n=new Yi,o=this._editor.onDidChangeModelContent(r=>{if(r.isFlush){n.cancel(),o.dispose();return}for(let a=0,l=r.changes.length;a<l;a++)if(r.changes[a].range.endLineNumber<=i.lineNumber){n.cancel(),o.dispose();return}});s$(this._workerService,this._languageFeaturesService,t,i,e,t.getFormattingOptions(),n.token).then(r=>{n.token.isCancellationRequested||as(r)&&(this._accessibleNotificationService.notify("format",!1),Pm.execute(this._editor,r,!0))}).finally(()=>{o.dispose()})}};Nb.ID="editor.contrib.autoFormat";Nb=mK([s0(1,xe),s0(2,oa),s0(3,bx)],Nb);let Tb=class{constructor(e,t,i){this.editor=e,this._languageFeaturesService=t,this._instantiationService=i,this._callOnDispose=new ie,this._callOnModel=new ie,this._callOnDispose.add(e.onDidChangeConfiguration(()=>this._update())),this._callOnDispose.add(e.onDidChangeModel(()=>this._update())),this._callOnDispose.add(e.onDidChangeModelLanguage(()=>this._update())),this._callOnDispose.add(t.documentRangeFormattingEditProvider.onDidChange(this._update,this))}dispose(){this._callOnDispose.dispose(),this._callOnModel.dispose()}_update(){this._callOnModel.clear(),this.editor.getOption(55)&&this.editor.hasModel()&&this._languageFeaturesService.documentRangeFormattingEditProvider.has(this.editor.getModel())&&this._callOnModel.add(this.editor.onDidPaste(({range:e})=>this._trigger(e)))}_trigger(e){this.editor.hasModel()&&(this.editor.getSelections().length>1||this._instantiationService.invokeFunction(n$,this.editor,e,2,Gd.None,ct.None,!1).catch(et))}};Tb.ID="editor.contrib.formatOnPaste";Tb=mK([s0(1,xe),s0(2,We)],Tb);class YSe extends we{constructor(){super({id:"editor.action.formatDocument",label:p("formatDocument.label","Format Document"),alias:"Format Document",precondition:ee.and(T.notInCompositeEditor,T.writable,T.hasDocumentFormattingProvider),kbOpts:{kbExpr:T.editorTextFocus,primary:1572,linux:{primary:3111},weight:100},contextMenuOpts:{group:"1_modification",order:1.3}})}async run(e,t){if(t.hasModel()){const i=e.get(We);await e.get(rh).showWhile(i.invokeFunction(w0e,t,1,Gd.None,ct.None,!0),250)}}}class XSe extends we{constructor(){super({id:"editor.action.formatSelection",label:p("formatSelection.label","Format Selection"),alias:"Format Selection",precondition:ee.and(T.writable,T.hasDocumentSelectionFormattingProvider),kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2084),weight:100},contextMenuOpts:{when:T.hasNonEmptySelection,group:"1_modification",order:1.31}})}async run(e,t){if(!t.hasModel())return;const i=e.get(We),n=t.getModel(),o=t.getSelections().map(a=>a.isEmpty()?new D(a.startLineNumber,1,a.startLineNumber,n.getLineMaxColumn(a.startLineNumber)):a);await e.get(rh).showWhile(i.invokeFunction(n$,t,o,1,Gd.None,ct.None,!0),250)}}Lt(Nb.ID,Nb,2);Lt(Tb.ID,Tb,2);re(YSe);re(XSe);Ct.registerCommand("editor.action.format",async s=>{const e=s.get(It).getFocusedCodeEditor();if(!e||!e.hasModel())return;const t=s.get(Ei);e.getSelection().isEmpty()?await t.executeCommand("editor.action.formatDocument"):await t.executeCommand("editor.action.formatSelection")});var QSe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},pE=function(s,e){return function(t,i){e(t,i,s)}};class Lp{remove(){var e;(e=this.parent)===null||e===void 0||e.children.delete(this.id)}static findId(e,t){let i;typeof e=="string"?i=`${t.id}/${e}`:(i=`${t.id}/${e.name}`,t.children.get(i)!==void 0&&(i=`${t.id}/${e.name}_${e.range.startLineNumber}_${e.range.startColumn}`));let n=i;for(let o=0;t.children.get(n)!==void 0;o++)n=`${i}_${o}`;return n}static empty(e){return e.children.size===0}}class sR extends Lp{constructor(e,t,i){super(),this.id=e,this.parent=t,this.symbol=i,this.children=new Map}}class _K extends Lp{constructor(e,t,i,n){super(),this.id=e,this.parent=t,this.label=i,this.order=n,this.children=new Map}}class kd extends Lp{static create(e,t,i){const n=new Yi(i),o=new kd(t.uri),r=e.ordered(t),a=r.map((d,c)=>{var u;const h=Lp.findId(`provider_${c}`,o),g=new _K(h,o,(u=d.displayName)!==null&&u!==void 0?u:"Unknown Outline Provider",c);return Promise.resolve(d.provideDocumentSymbols(t,n.token)).then(f=>{for(const m of f||[])kd._makeOutlineElement(m,g);return g},f=>(Zi(f),g)).then(f=>{Lp.empty(f)?f.remove():o._groups.set(h,f)})}),l=e.onDidChange(()=>{const d=e.ordered(t);Ai(d,r)||n.cancel()});return Promise.all(a).then(()=>n.token.isCancellationRequested&&!i.isCancellationRequested?kd.create(e,t,i):o._compact()).finally(()=>{n.dispose(),l.dispose(),n.dispose()})}static _makeOutlineElement(e,t){const i=Lp.findId(e,t),n=new sR(i,t,e);if(e.children)for(const o of e.children)kd._makeOutlineElement(o,n);t.children.set(n.id,n)}constructor(e){super(),this.uri=e,this.id="root",this.parent=void 0,this._groups=new Map,this.children=new Map,this.id="root",this.parent=void 0}_compact(){let e=0;for(const[t,i]of this._groups)i.children.size===0?this._groups.delete(t):e+=1;if(e!==1)this.children=this._groups;else{const t=ht.first(this._groups.values());for(const[,i]of t.children)i.parent=this,this.children.set(i.id,i)}return this}getTopLevelSymbols(){const e=[];for(const t of this.children.values())t instanceof sR?e.push(t.symbol):e.push(...ht.map(t.children.values(),i=>i.symbol));return e.sort((t,i)=>D.compareRangesUsingStarts(t.range,i.range))}asListOfDocumentSymbols(){const e=this.getTopLevelSymbols(),t=[];return kd._flattenDocumentSymbols(t,e,""),t.sort((i,n)=>H.compare(D.getStartPosition(i.range),D.getStartPosition(n.range))||H.compare(D.getEndPosition(n.range),D.getEndPosition(i.range)))}static _flattenDocumentSymbols(e,t,i){for(const n of t)e.push({kind:n.kind,tags:n.tags,name:n.name,detail:n.detail,containerName:n.containerName||i,range:n.range,selectionRange:n.selectionRange,children:void 0}),n.children&&kd._flattenDocumentSymbols(e,n.children,n.name)}}const RD=ut("IOutlineModelService");let oR=class{constructor(e,t,i){this._languageFeaturesService=e,this._disposables=new ie,this._cache=new nh(10,.7),this._debounceInformation=t.for(e.documentSymbolProvider,"DocumentSymbols",{min:350}),this._disposables.add(i.onModelRemoved(n=>{this._cache.delete(n.id)}))}dispose(){this._disposables.dispose()}async getOrCreate(e,t){const i=this._languageFeaturesService.documentSymbolProvider,n=i.ordered(e);let o=this._cache.get(e.id);if(!o||o.versionId!==e.getVersionId()||!Ai(o.provider,n)){const a=new Yi;o={versionId:e.getVersionId(),provider:n,promiseCnt:0,source:a,promise:kd.create(i,e,a.token),model:void 0},this._cache.set(e.id,o);const l=Date.now();o.promise.then(d=>{o.model=d,this._debounceInformation.update(e,Date.now()-l)}).catch(d=>{this._cache.delete(e.id)})}if(o.model)return o.model;o.promiseCnt+=1;const r=t.onCancellationRequested(()=>{--o.promiseCnt===0&&(o.source.cancel(),this._cache.delete(e.id))});try{return await o.promise}finally{r.dispose()}}};oR=QSe([pE(0,xe),pE(1,Er),pE(2,vi)],oR);_t(RD,oR,1);Ct.registerCommand("_executeDocumentSymbolProvider",async function(s,...e){const[t]=e;zt(Pe.isUri(t));const i=s.get(RD),o=await s.get(io).createModelReference(t);try{return(await i.getOrCreate(o.object.textEditorModel,ct.None)).getTopLevelSymbols()}finally{o.dispose()}});class kn extends j{constructor(e,t){super(),this.contextKeyService=e,this.model=t,this.inlineCompletionVisible=kn.inlineSuggestionVisible.bindTo(this.contextKeyService),this.inlineCompletionSuggestsIndentation=kn.inlineSuggestionHasIndentation.bindTo(this.contextKeyService),this.inlineCompletionSuggestsIndentationLessThanTabSize=kn.inlineSuggestionHasIndentationLessThanTabSize.bindTo(this.contextKeyService),this.suppressSuggestions=kn.suppressSuggestions.bindTo(this.contextKeyService),this._register(Rt(i=>{const n=this.model.read(i),o=n==null?void 0:n.state.read(i),r=!!(o!=null&&o.inlineCompletion)&&(o==null?void 0:o.ghostText)!==void 0&&!(o!=null&&o.ghostText.isEmpty());this.inlineCompletionVisible.set(r),o!=null&&o.ghostText&&(o!=null&&o.inlineCompletion)&&this.suppressSuggestions.set(o.inlineCompletion.inlineCompletion.source.inlineCompletions.suppressSuggestions)})),this._register(Rt(i=>{const n=this.model.read(i);let o=!1,r=!0;const a=n==null?void 0:n.ghostText.read(i);if(n!=null&&n.selectedSuggestItem&&a&&a.parts.length>0){const{column:l,lines:d}=a.parts[0],c=d[0],u=n.textModel.getLineIndentColumn(a.lineNumber);if(l<=u){let g=ws(c);g===-1&&(g=c.length-1),o=g>0;const f=n.textModel.getOptions().tabSize;r=hn.visibleColumnFromColumn(c,g+1,f)<f}}this.inlineCompletionSuggestsIndentation.set(o),this.inlineCompletionSuggestsIndentationLessThanTabSize.set(r)}))}}kn.inlineSuggestionVisible=new me("inlineSuggestionVisible",!1,p("inlineSuggestionVisible","Whether an inline suggestion is visible"));kn.inlineSuggestionHasIndentation=new me("inlineSuggestionHasIndentation",!1,p("inlineSuggestionHasIndentation","Whether the inline suggestion starts with whitespace"));kn.inlineSuggestionHasIndentationLessThanTabSize=new me("inlineSuggestionHasIndentationLessThanTabSize",!0,p("inlineSuggestionHasIndentationLessThanTabSize","Whether the inline suggestion starts with whitespace that is less than what would be inserted by tab"));kn.suppressSuggestions=new me("inlineSuggestionSuppressSuggestions",void 0,p("suppressSuggestions","Whether suggestions should be suppressed for the current suggestion"));function JSe(s,e){const t=new eye(s),i=e.map(n=>{const o=D.lift(n.range);return{startOffset:t.getOffset(o.getStartPosition()),endOffset:t.getOffset(o.getEndPosition()),text:n.text}});i.sort((n,o)=>o.startOffset-n.startOffset);for(const n of i)s=s.substring(0,n.startOffset)+n.text+s.substring(n.endOffset);return s}class eye{constructor(e){this.lineStartOffsetByLineIdx=[],this.lineStartOffsetByLineIdx.push(0);for(let t=0;t<e.length;t++)e.charAt(t)===`
`&&this.lineStartOffsetByLineIdx.push(t+1)}getOffset(e){return this.lineStartOffsetByLineIdx[e.lineNumber-1]+e.column-1}}const tye=[];function iye(){return tye}class nye{constructor(e,t){if(this.startColumn=e,this.endColumnExclusive=t,e>t)throw new pi(`startColumn ${e} cannot be after endColumnExclusive ${t}`)}toRange(e){return new D(e,this.startColumn,e,this.endColumnExclusive)}equals(e){return this.startColumn===e.startColumn&&this.endColumnExclusive===e.endColumnExclusive}}function sye(s,e){const t=new ie,i=s.createDecorationsCollection();return t.add(sD({debugName:()=>`Apply decorations from ${e.debugName}`},n=>{const o=e.read(n);i.set(o)})),t.add({dispose:()=>{i.clear()}}),t}function rR(s,e){return new H(s.lineNumber+e.lineNumber-1,e.lineNumber===1?s.column+e.column-1:e.column)}function aR(s){let e=1,t=1;for(const i of s)i===`
`?(e++,t=1):t++;return new H(e,t)}class mL{constructor(e,t){this.lineNumber=e,this.parts=t}equals(e){return this.lineNumber===e.lineNumber&&this.parts.length===e.parts.length&&this.parts.every((t,i)=>t.equals(e.parts[i]))}renderForScreenReader(e){if(this.parts.length===0)return"";const t=this.parts[this.parts.length-1],i=e.substr(0,t.column-1);return JSe(i,this.parts.map(o=>({range:{startLineNumber:1,endLineNumber:1,startColumn:o.column,endColumn:o.column},text:o.lines.join(`
`)}))).substring(this.parts[0].column-1)}isEmpty(){return this.parts.every(e=>e.lines.length===0)}get lineCount(){return 1+this.parts.reduce((e,t)=>e+t.lines.length-1,0)}}class lR{constructor(e,t,i){this.column=e,this.lines=t,this.preview=i}equals(e){return this.column===e.column&&this.lines.length===e.lines.length&&this.lines.every((t,i)=>t===e.lines[i])}}class dR{constructor(e,t,i,n=0){this.lineNumber=e,this.columnRange=t,this.newLines=i,this.additionalReservedLineCount=n,this.parts=[new lR(this.columnRange.endColumnExclusive,this.newLines,!1)]}renderForScreenReader(e){return this.newLines.join(`
`)}get lineCount(){return this.newLines.length}isEmpty(){return this.parts.every(e=>e.lines.length===0)}equals(e){return this.lineNumber===e.lineNumber&&this.columnRange.equals(e.columnRange)&&this.newLines.length===e.newLines.length&&this.newLines.every((t,i)=>t===e.newLines[i])&&this.additionalReservedLineCount===e.additionalReservedLineCount}}function hB(s,e){return s===e?!0:!s||!e?!1:s instanceof mL&&e instanceof mL||s instanceof dR&&e instanceof dR?s.equals(e):!1}var oye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},rye=function(s,e){return function(t,i){e(t,i,s)}};const gB="ghost-text";let cR=class extends j{constructor(e,t,i){super(),this.editor=e,this.model=t,this.languageService=i,this.isDisposed=kt(this,!1),this.currentTextModel=Mi(this.editor.onDidChangeModel,()=>this.editor.getModel()),this.uiState=nt(this,n=>{if(this.isDisposed.read(n))return;const o=this.currentTextModel.read(n);if(o!==this.model.targetTextModel.read(n))return;const r=this.model.ghostText.read(n);if(!r)return;const a=r instanceof dR?r.columnRange:void 0,l=[],d=[];function c(m,_){if(d.length>0){const v=d[d.length-1];_&&v.decorations.push(new mo(v.content.length+1,v.content.length+1+m[0].length,_,0)),v.content+=m[0],m=m.slice(1)}for(const v of m)d.push({content:v,decorations:_?[new mo(1,v.length+1,_,0)]:[]})}const u=o.getLineContent(r.lineNumber);let h,g=0;for(const m of r.parts){let _=m.lines;h===void 0?(l.push({column:m.column,text:_[0],preview:m.preview}),_=_.slice(1)):c([u.substring(g,m.column-1)],void 0),_.length>0&&(c(_,gB),h===void 0&&m.column<=u.length&&(h=m.column)),g=m.column-1}h!==void 0&&c([u.substring(g)],void 0);const f=h!==void 0?new nye(h,u.length+1):void 0;return{replacedRange:a,inlineTexts:l,additionalLines:d,hiddenRange:f,lineNumber:r.lineNumber,additionalReservedLineCount:this.model.minReservedLineCount.read(n),targetTextModel:o}}),this.decorations=nt(this,n=>{const o=this.uiState.read(n);if(!o)return[];const r=[];o.replacedRange&&r.push({range:o.replacedRange.toRange(o.lineNumber),options:{inlineClassName:"inline-completion-text-to-replace",description:"GhostTextReplacement"}}),o.hiddenRange&&r.push({range:o.hiddenRange.toRange(o.lineNumber),options:{inlineClassName:"ghost-text-hidden",description:"ghost-text-hidden"}});for(const a of o.inlineTexts)r.push({range:D.fromPositions(new H(o.lineNumber,a.column)),options:{description:gB,after:{content:a.text,inlineClassName:a.preview?"ghost-text-decoration-preview":"ghost-text-decoration",cursorStops:Na.Left},showIfCollapsed:!0}});return r}),this.additionalLinesWidget=this._register(new aye(this.editor,this.languageService.languageIdCodec,nt(n=>{const o=this.uiState.read(n);return o?{lineNumber:o.lineNumber,additionalLines:o.additionalLines,minReservedLineCount:o.additionalReservedLineCount,targetTextModel:o.targetTextModel}:void 0}))),this._register(Fe(()=>{this.isDisposed.set(!0,void 0)})),this._register(sye(this.editor,this.decorations))}ownsViewZone(e){return this.additionalLinesWidget.viewZoneId===e}};cR=oye([rye(2,fi)],cR);class aye extends j{get viewZoneId(){return this._viewZoneId}constructor(e,t,i){super(),this.editor=e,this.languageIdCodec=t,this.lines=i,this._viewZoneId=void 0,this.editorOptionsChanged=Ko("editorOptionChanged",ge.filter(this.editor.onDidChangeConfiguration,n=>n.hasChanged(33)||n.hasChanged(116)||n.hasChanged(98)||n.hasChanged(93)||n.hasChanged(51)||n.hasChanged(50)||n.hasChanged(66))),this._register(Rt(n=>{const o=this.lines.read(n);this.editorOptionsChanged.read(n),o?this.updateLines(o.lineNumber,o.additionalLines,o.minReservedLineCount):this.clear()}))}dispose(){super.dispose(),this.clear()}clear(){this.editor.changeViewZones(e=>{this._viewZoneId&&(e.removeZone(this._viewZoneId),this._viewZoneId=void 0)})}updateLines(e,t,i){const n=this.editor.getModel();if(!n)return;const{tabSize:o}=n.getOptions();this.editor.changeViewZones(r=>{this._viewZoneId&&(r.removeZone(this._viewZoneId),this._viewZoneId=void 0);const a=Math.max(t.length,i);if(a>0){const l=document.createElement("div");lye(l,o,t,this.editor.getOptions(),this.languageIdCodec),this._viewZoneId=r.addZone({afterLineNumber:e,heightInLines:a,domNode:l,afterColumnAffinity:1})}})}}function lye(s,e,t,i,n){const o=i.get(33),r=i.get(116),a="none",l=i.get(93),d=i.get(51),c=i.get(50),u=i.get(66),h=new s_(1e4);h.appendString('<div class="suggest-preview-text">');for(let m=0,_=t.length;m<_;m++){const v=t[m],b=v.content;h.appendString('<div class="view-line'),h.appendString('" style="top:'),h.appendString(String(m*u)),h.appendString('px;width:1000000px;">');const C=sC(b),w=dm(b),S=vn.createEmpty(b,n);lC(new sh(c.isMonospace&&!o,c.canUseHalfwidthRightwardsArrow,b,!1,C,w,0,S,v.decorations,e,0,c.spaceWidth,c.middotWidth,c.wsmiddotWidth,r,a,l,d!==$o.OFF,null),h),h.appendString("</div>")}h.appendString("</div>"),Xn(s,c);const g=h.build(),f=fB?fB.createHTML(g):g;s.innerHTML=f}const fB=oc("editorGhostText",{createHTML:s=>s});function dye(s,e){const t=new jH,i=new qH(t,d=>e.getLanguageConfiguration(d)),n=new KH(new cye([s]),i),o=DT(n,[],void 0,!0);let r="";const a=s.getLineContent();function l(d,c){if(d.kind===2)if(l(d.openingBracket,c),c=ki(c,d.openingBracket.length),d.child&&(l(d.child,c),c=ki(c,d.child.length)),d.closingBracket)l(d.closingBracket,c),c=ki(c,d.closingBracket.length);else{const h=i.getSingleLanguageBracketTokens(d.openingBracket.languageId).findClosingTokenText(d.openingBracket.bracketIds);r+=h}else if(d.kind!==3){if(d.kind===0||d.kind===1)r+=a.substring(c,ki(c,d.length));else if(d.kind===4)for(const u of d.children)l(u,c),c=ki(c,u.length)}}return l(o,As),r}class cye{constructor(e){this.lines=e,this.tokenization={getLineTokens:t=>this.lines[t-1]}}getLineCount(){return this.lines.length}getLineLength(e){return this.lines[e-1].getLineContent().length}}class Br{constructor(){this.value="",this.pos=0}static isDigitCharacter(e){return e>=48&&e<=57}static isVariableCharacter(e){return e===95||e>=97&&e<=122||e>=65&&e<=90}text(e){this.value=e,this.pos=0}tokenText(e){return this.value.substr(e.pos,e.len)}next(){if(this.pos>=this.value.length)return{type:14,pos:this.pos,len:0};const e=this.pos;let t=0,i=this.value.charCodeAt(e),n;if(n=Br._table[i],typeof n=="number")return this.pos+=1,{type:n,pos:e,len:1};if(Br.isDigitCharacter(i)){n=8;do t+=1,i=this.value.charCodeAt(e+t);while(Br.isDigitCharacter(i));return this.pos+=t,{type:n,pos:e,len:t}}if(Br.isVariableCharacter(i)){n=9;do i=this.value.charCodeAt(e+ ++t);while(Br.isVariableCharacter(i)||Br.isDigitCharacter(i));return this.pos+=t,{type:n,pos:e,len:t}}n=10;do t+=1,i=this.value.charCodeAt(e+t);while(!isNaN(i)&&typeof Br._table[i]>"u"&&!Br.isDigitCharacter(i)&&!Br.isVariableCharacter(i));return this.pos+=t,{type:n,pos:e,len:t}}}Br._table={36:0,58:1,44:2,123:3,125:4,92:5,47:6,124:7,43:11,45:12,63:13};class v_{constructor(){this._children=[]}appendChild(e){return e instanceof Es&&this._children[this._children.length-1]instanceof Es?this._children[this._children.length-1].value+=e.value:(e.parent=this,this._children.push(e)),this}replace(e,t){const{parent:i}=e,n=i.children.indexOf(e),o=i.children.slice(0);o.splice(n,1,...t),i._children=o,function r(a,l){for(const d of a)d.parent=l,r(d.children,d)}(t,i)}get children(){return this._children}get rightMostDescendant(){return this._children.length>0?this._children[this._children.length-1].rightMostDescendant:this}get snippet(){let e=this;for(;;){if(!e)return;if(e instanceof HC)return e;e=e.parent}}toString(){return this.children.reduce((e,t)=>e+t.toString(),"")}len(){return 0}}class Es extends v_{constructor(e){super(),this.value=e}toString(){return this.value}len(){return this.value.length}clone(){return new Es(this.value)}}class vK extends v_{}class gr extends vK{static compareByIndex(e,t){return e.index===t.index?0:e.isFinalTabstop?1:t.isFinalTabstop||e.index<t.index?-1:e.index>t.index?1:0}constructor(e){super(),this.index=e}get isFinalTabstop(){return this.index===0}get choice(){return this._children.length===1&&this._children[0]instanceof b_?this._children[0]:void 0}clone(){const e=new gr(this.index);return this.transform&&(e.transform=this.transform.clone()),e._children=this.children.map(t=>t.clone()),e}}class b_ extends v_{constructor(){super(...arguments),this.options=[]}appendChild(e){return e instanceof Es&&(e.parent=this,this.options.push(e)),this}toString(){return this.options[0].value}len(){return this.options[0].len()}clone(){const e=new b_;return this.options.forEach(e.appendChild,e),e}}class D4 extends v_{constructor(){super(...arguments),this.regexp=new RegExp("")}resolve(e){const t=this;let i=!1,n=e.replace(this.regexp,function(){return i=!0,t._replace(Array.prototype.slice.call(arguments,0,-2))});return!i&&this._children.some(o=>o instanceof ba&&!!o.elseValue)&&(n=this._replace([])),n}_replace(e){let t="";for(const i of this._children)if(i instanceof ba){let n=e[i.index]||"";n=i.resolve(n),t+=n}else t+=i.toString();return t}toString(){return""}clone(){const e=new D4;return e.regexp=new RegExp(this.regexp.source,(this.regexp.ignoreCase?"i":"")+(this.regexp.global?"g":"")),e._children=this.children.map(t=>t.clone()),e}}class ba extends v_{constructor(e,t,i,n){super(),this.index=e,this.shorthandName=t,this.ifValue=i,this.elseValue=n}resolve(e){return this.shorthandName==="upcase"?e?e.toLocaleUpperCase():"":this.shorthandName==="downcase"?e?e.toLocaleLowerCase():"":this.shorthandName==="capitalize"?e?e[0].toLocaleUpperCase()+e.substr(1):"":this.shorthandName==="pascalcase"?e?this._toPascalCase(e):"":this.shorthandName==="camelcase"?e?this._toCamelCase(e):"":e&&typeof this.ifValue=="string"?this.ifValue:!e&&typeof this.elseValue=="string"?this.elseValue:e||""}_toPascalCase(e){const t=e.match(/[a-z0-9]+/gi);return t?t.map(i=>i.charAt(0).toUpperCase()+i.substr(1)).join(""):e}_toCamelCase(e){const t=e.match(/[a-z0-9]+/gi);return t?t.map((i,n)=>n===0?i.charAt(0).toLowerCase()+i.substr(1):i.charAt(0).toUpperCase()+i.substr(1)).join(""):e}clone(){return new ba(this.index,this.shorthandName,this.ifValue,this.elseValue)}}class Mb extends vK{constructor(e){super(),this.name=e}resolve(e){let t=e.resolve(this);return this.transform&&(t=this.transform.resolve(t||"")),t!==void 0?(this._children=[new Es(t)],!0):!1}clone(){const e=new Mb(this.name);return this.transform&&(e.transform=this.transform.clone()),e._children=this.children.map(t=>t.clone()),e}}function pB(s,e){const t=[...s];for(;t.length>0;){const i=t.shift();if(!e(i))break;t.unshift(...i.children)}}class HC extends v_{get placeholderInfo(){if(!this._placeholders){const e=[];let t;this.walk(function(i){return i instanceof gr&&(e.push(i),t=!t||t.index<i.index?i:t),!0}),this._placeholders={all:e,last:t}}return this._placeholders}get placeholders(){const{all:e}=this.placeholderInfo;return e}offset(e){let t=0,i=!1;return this.walk(n=>n===e?(i=!0,!1):(t+=n.len(),!0)),i?t:-1}fullLen(e){let t=0;return pB([e],i=>(t+=i.len(),!0)),t}enclosingPlaceholders(e){const t=[];let{parent:i}=e;for(;i;)i instanceof gr&&t.push(i),i=i.parent;return t}resolveVariables(e){return this.walk(t=>(t instanceof Mb&&t.resolve(e)&&(this._placeholders=void 0),!0)),this}appendChild(e){return this._placeholders=void 0,super.appendChild(e)}replace(e,t){return this._placeholders=void 0,super.replace(e,t)}clone(){const e=new HC;return this._children=this.children.map(t=>t.clone()),e}walk(e){pB(this.children,e)}}class Um{constructor(){this._scanner=new Br,this._token={type:14,pos:0,len:0}}static escape(e){return e.replace(/\$|}|\\/g,"\\$&")}static guessNeedsClipboard(e){return/\${?CLIPBOARD/.test(e)}parse(e,t,i){const n=new HC;return this.parseFragment(e,n),this.ensureFinalTabstop(n,i??!1,t??!1),n}parseFragment(e,t){const i=t.children.length;for(this._scanner.text(e),this._token=this._scanner.next();this._parse(t););const n=new Map,o=[];t.walk(l=>(l instanceof gr&&(l.isFinalTabstop?n.set(0,void 0):!n.has(l.index)&&l.children.length>0?n.set(l.index,l.children):o.push(l)),!0));const r=(l,d)=>{const c=n.get(l.index);if(!c)return;const u=new gr(l.index);u.transform=l.transform;for(const h of c){const g=h.clone();u.appendChild(g),g instanceof gr&&n.has(g.index)&&!d.has(g.index)&&(d.add(g.index),r(g,d),d.delete(g.index))}t.replace(l,[u])},a=new Set;for(const l of o)r(l,a);return t.children.slice(i)}ensureFinalTabstop(e,t,i){(t||i&&e.placeholders.length>0)&&(e.placeholders.find(o=>o.index===0)||e.appendChild(new gr(0)))}_accept(e,t){if(e===void 0||this._token.type===e){const i=t?this._scanner.tokenText(this._token):!0;return this._token=this._scanner.next(),i}return!1}_backTo(e){return this._scanner.pos=e.pos+e.len,this._token=e,!1}_until(e){const t=this._token;for(;this._token.type!==e;){if(this._token.type===14)return!1;if(this._token.type===5){const n=this._scanner.next();if(n.type!==0&&n.type!==4&&n.type!==5)return!1}this._token=this._scanner.next()}const i=this._scanner.value.substring(t.pos,this._token.pos).replace(/\\(\$|}|\\)/g,"$1");return this._token=this._scanner.next(),i}_parse(e){return this._parseEscaped(e)||this._parseTabstopOrVariableName(e)||this._parseComplexPlaceholder(e)||this._parseComplexVariable(e)||this._parseAnything(e)}_parseEscaped(e){let t;return(t=this._accept(5,!0))?(t=this._accept(0,!0)||this._accept(4,!0)||this._accept(5,!0)||t,e.appendChild(new Es(t)),!0):!1}_parseTabstopOrVariableName(e){let t;const i=this._token;return this._accept(0)&&(t=this._accept(9,!0)||this._accept(8,!0))?(e.appendChild(/^\d+$/.test(t)?new gr(Number(t)):new Mb(t)),!0):this._backTo(i)}_parseComplexPlaceholder(e){let t;const i=this._token;if(!(this._accept(0)&&this._accept(3)&&(t=this._accept(8,!0))))return this._backTo(i);const o=new gr(Number(t));if(this._accept(1))for(;;){if(this._accept(4))return e.appendChild(o),!0;if(!this._parse(o))return e.appendChild(new Es("${"+t+":")),o.children.forEach(e.appendChild,e),!0}else if(o.index>0&&this._accept(7)){const r=new b_;for(;;){if(this._parseChoiceElement(r)){if(this._accept(2))continue;if(this._accept(7)&&(o.appendChild(r),this._accept(4)))return e.appendChild(o),!0}return this._backTo(i),!1}}else return this._accept(6)?this._parseTransform(o)?(e.appendChild(o),!0):(this._backTo(i),!1):this._accept(4)?(e.appendChild(o),!0):this._backTo(i)}_parseChoiceElement(e){const t=this._token,i=[];for(;!(this._token.type===2||this._token.type===7);){let n;if((n=this._accept(5,!0))?n=this._accept(2,!0)||this._accept(7,!0)||this._accept(5,!0)||n:n=this._accept(void 0,!0),!n)return this._backTo(t),!1;i.push(n)}return i.length===0?(this._backTo(t),!1):(e.appendChild(new Es(i.join(""))),!0)}_parseComplexVariable(e){let t;const i=this._token;if(!(this._accept(0)&&this._accept(3)&&(t=this._accept(9,!0))))return this._backTo(i);const o=new Mb(t);if(this._accept(1))for(;;){if(this._accept(4))return e.appendChild(o),!0;if(!this._parse(o))return e.appendChild(new Es("${"+t+":")),o.children.forEach(e.appendChild,e),!0}else return this._accept(6)?this._parseTransform(o)?(e.appendChild(o),!0):(this._backTo(i),!1):this._accept(4)?(e.appendChild(o),!0):this._backTo(i)}_parseTransform(e){const t=new D4;let i="",n="";for(;!this._accept(6);){let o;if(o=this._accept(5,!0)){o=this._accept(6,!0)||o,i+=o;continue}if(this._token.type!==14){i+=this._accept(void 0,!0);continue}return!1}for(;!this._accept(6);){let o;if(o=this._accept(5,!0)){o=this._accept(5,!0)||this._accept(6,!0)||o,t.appendChild(new Es(o));continue}if(!(this._parseFormatString(t)||this._parseAnything(t)))return!1}for(;!this._accept(4);){if(this._token.type!==14){n+=this._accept(void 0,!0);continue}return!1}try{t.regexp=new RegExp(i,n)}catch{return!1}return e.transform=t,!0}_parseFormatString(e){const t=this._token;if(!this._accept(0))return!1;let i=!1;this._accept(3)&&(i=!0);const n=this._accept(8,!0);if(n)if(i){if(this._accept(4))return e.appendChild(new ba(Number(n))),!0;if(!this._accept(1))return this._backTo(t),!1}else return e.appendChild(new ba(Number(n))),!0;else return this._backTo(t),!1;if(this._accept(6)){const o=this._accept(9,!0);return!o||!this._accept(4)?(this._backTo(t),!1):(e.appendChild(new ba(Number(n),o)),!0)}else if(this._accept(11)){const o=this._until(4);if(o)return e.appendChild(new ba(Number(n),void 0,o,void 0)),!0}else if(this._accept(12)){const o=this._until(4);if(o)return e.appendChild(new ba(Number(n),void 0,void 0,o)),!0}else if(this._accept(13)){const o=this._until(1);if(o){const r=this._until(4);if(r)return e.appendChild(new ba(Number(n),void 0,o,r)),!0}}else{const o=this._until(4);if(o)return e.appendChild(new ba(Number(n),void 0,void 0,o)),!0}return this._backTo(t),!1}_parseAnything(e){return this._token.type!==14?(e.appendChild(new Es(this._scanner.tokenText(this._token))),this._accept(void 0),!0):!1}}async function uye(s,e,t,i,n=ct.None,o){const r=fye(e,t),a=s.all(t),l=new lP;for(const v of a)v.groupId&&l.add(v.groupId,v);function d(v){if(!v.yieldsToGroupIds)return[];const b=[];for(const C of v.yieldsToGroupIds||[]){const w=l.get(C);for(const S of w)b.push(S)}return b}const c=new Map,u=new Set;function h(v,b){if(b=[...b,v],u.has(v))return b;u.add(v);try{const C=d(v);for(const w of C){const S=h(w,b);if(S)return S}}finally{u.delete(v)}}function g(v){const b=c.get(v);if(b)return b;const C=h(v,[]);C&&Zi(new Error(`Inline completions: cyclic yield-to dependency detected. Path: ${C.map(S=>S.toString?S.toString():""+S).join(" -> ")}`));const w=new ox;return c.set(v,w.p),(async()=>{if(!C){const S=d(v);for(const x of S){const L=await g(x);if(L&&L.items.length>0)return}}try{return await v.provideInlineCompletions(t,e,i,n)}catch(S){Zi(S);return}})().then(S=>w.complete(S),S=>w.error(S)),w.p}const f=await Promise.all(a.map(async v=>({provider:v,completions:await g(v)}))),m=new Map,_=[];for(const v of f){const b=v.completions;if(!b)continue;const C=new gye(b,v.provider);_.push(C);for(const w of b.items){const S=_L.from(w,C,r,t,o);m.set(S.hash(),S)}}return new hye(Array.from(m.values()),new Set(m.keys()),_)}class hye{constructor(e,t,i){this.completions=e,this.hashs=t,this.providerResults=i}has(e){return this.hashs.has(e.hash())}dispose(){for(const e of this.providerResults)e.removeRef()}}class gye{constructor(e,t){this.inlineCompletions=e,this.provider=t,this.refCount=1}addRef(){this.refCount++}removeRef(){this.refCount--,this.refCount===0&&this.provider.freeInlineCompletions(this.inlineCompletions)}}class _L{static from(e,t,i,n,o){let r,a,l=e.range?D.lift(e.range):i;if(typeof e.insertText=="string"){if(r=e.insertText,o&&e.completeBracketPairs){r=mB(r,l.getStartPosition(),n,o);const d=r.length-e.insertText.length;d!==0&&(l=new D(l.startLineNumber,l.startColumn,l.endLineNumber,l.endColumn+d))}a=void 0}else if("snippet"in e.insertText){const d=e.insertText.snippet.length;if(o&&e.completeBracketPairs){e.insertText.snippet=mB(e.insertText.snippet,l.getStartPosition(),n,o);const u=e.insertText.snippet.length-d;u!==0&&(l=new D(l.startLineNumber,l.startColumn,l.endLineNumber,l.endColumn+u))}const c=new Um().parse(e.insertText.snippet);c.children.length===1&&c.children[0]instanceof Es?(r=c.children[0].value,a=void 0):(r=c.toString(),a={snippet:e.insertText.snippet,range:l})}else nx(e.insertText);return new _L(r,e.command,l,r,a,e.additionalTextEdits||iye(),e,t)}constructor(e,t,i,n,o,r,a,l){this.filterText=e,this.command=t,this.range=i,this.insertText=n,this.snippetInfo=o,this.additionalTextEdits=r,this.sourceInlineCompletion=a,this.source=l,e=e.replace(/\r\n|\r/g,`
`),n=e.replace(/\r\n|\r/g,`
`)}withRange(e){return new _L(this.filterText,this.command,e,this.insertText,this.snippetInfo,this.additionalTextEdits,this.sourceInlineCompletion,this.source)}hash(){return JSON.stringify({insertText:this.insertText,range:this.range.toString()})}}function fye(s,e){const t=e.getWordAtPosition(s),i=e.getLineMaxColumn(s.lineNumber);return t?new D(s.lineNumber,t.startColumn,s.lineNumber,i):D.fromPositions(s,s.with(void 0,i))}function mB(s,e,t,i){const o=t.getLineContent(e.lineNumber).substring(0,e.column-1)+s,r=t.tokenization.tokenizeLineWithEdit(e,o.length-(e.column-1),s),a=r==null?void 0:r.sliceAndInflate(e.column-1,o.length,0);return a?dye(a,i):s}class $m{constructor(e,t){this.range=e,this.text=t}removeCommonPrefix(e,t){const i=t?this.range.intersectRanges(t):this.range;if(!i)return this;const n=e.getValueInRange(i,1),o=Dg(n,this.text),r=rR(this.range.getStartPosition(),aR(n.substring(0,o))),a=this.text.substring(o),l=D.fromPositions(r,this.range.getEndPosition());return new $m(l,a)}augments(e){return this.text.startsWith(e.text)&&pye(this.range,e.range)}computeGhostText(e,t,i,n=0){let o=this.removeCommonPrefix(e);if(o.range.endLineNumber!==o.range.startLineNumber)return;const r=e.getLineContent(o.range.startLineNumber),a=Zt(r).length;if(o.range.startColumn-1<=a){const f=Zt(o.text).length,m=r.substring(o.range.startColumn-1,a),[_,v]=[o.range.getStartPosition(),o.range.getEndPosition()],b=_.column+m.length<=v.column?_.delta(0,m.length):v,C=D.fromPositions(b,v),w=o.text.startsWith(m)?o.text.substring(m.length):o.text.substring(f);o=new $m(C,w)}const d=e.getValueInRange(o.range),c=mye(d,o.text);if(!c)return;const u=o.range.startLineNumber,h=new Array;if(t==="prefix"){const f=c.filter(m=>m.originalLength===0);if(f.length>1||f.length===1&&f[0].originalStart!==d.length)return}const g=o.text.length-n;for(const f of c){const m=o.range.startColumn+f.originalStart+f.originalLength;if(t==="subwordSmart"&&i&&i.lineNumber===o.range.startLineNumber&&m<i.column||f.originalLength>0)return;if(f.modifiedLength===0)continue;const _=f.modifiedStart+f.modifiedLength,v=Math.max(f.modifiedStart,Math.min(_,g)),b=o.text.substring(f.modifiedStart,v),C=o.text.substring(v,Math.max(f.modifiedStart,_));if(b.length>0){const w=Kl(b);h.push(new lR(m,w,!1))}if(C.length>0){const w=Kl(C);h.push(new lR(m,w,!0))}}return new mL(u,h)}}function pye(s,e){return e.getStartPosition().equals(s.getStartPosition())&&e.getEndPosition().isBeforeOrEqual(s.getEndPosition())}let sl;function mye(s,e){if((sl==null?void 0:sl.originalValue)===s&&(sl==null?void 0:sl.newValue)===e)return sl==null?void 0:sl.changes;{let t=vB(s,e,!0);if(t){const i=_B(t);if(i>0){const n=vB(s,e,!1);n&&_B(n)<i&&(t=n)}}return sl={originalValue:s,newValue:e,changes:t},t}}function _B(s){let e=0;for(const t of s)e+=t.originalLength;return e}function vB(s,e,t){if(s.length>5e3||e.length>5e3)return;function i(d){let c=0;for(let u=0,h=d.length;u<h;u++){const g=d.charCodeAt(u);g>c&&(c=g)}return c}const n=Math.max(i(s),i(e));function o(d){if(d<0)throw new Error("unexpected");return n+d+1}function r(d){let c=0,u=0;const h=new Int32Array(d.length);for(let g=0,f=d.length;g<f;g++)if(t&&d[g]==="("){const m=u*100+c;h[g]=o(2*m),c++}else if(t&&d[g]===")"){c=Math.max(c-1,0);const m=u*100+c;h[g]=o(2*m+1),c===0&&u++}else h[g]=d.charCodeAt(g);return h}const a=r(s),l=r(e);return new vl({getElements:()=>a},{getElements:()=>l}).ComputeDiff(!1).changes}var _ye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},bB=function(s,e){return function(t,i){e(t,i,s)}};let uR=class extends j{constructor(e,t,i,n,o){super(),this.textModel=e,this.versionId=t,this._debounceValue=i,this.languageFeaturesService=n,this.languageConfigurationService=o,this._updateOperation=this._register(new En),this.inlineCompletions=jy("inlineCompletions",void 0),this.suggestWidgetInlineCompletions=jy("suggestWidgetInlineCompletions",void 0),this._register(this.textModel.onDidChangeContent(()=>{this._updateOperation.clear()}))}fetch(e,t,i){var n,o;const r=new bye(e,t,this.textModel.getVersionId()),a=t.selectedSuggestionInfo?this.suggestWidgetInlineCompletions:this.inlineCompletions;if(!((n=this._updateOperation.value)===null||n===void 0)&&n.request.satisfies(r))return this._updateOperation.value.promise;if(!((o=a.get())===null||o===void 0)&&o.request.satisfies(r))return Promise.resolve(!0);const l=!!this._updateOperation.value;this._updateOperation.clear();const d=new Yi,c=(async()=>{if((l||t.triggerKind===jd.Automatic)&&await vye(this._debounceValue.get(this.textModel)),d.token.isCancellationRequested||this.textModel.getVersionId()!==r.versionId)return!1;const g=new Date,f=await uye(this.languageFeaturesService.inlineCompletionsProvider,e,this.textModel,t,d.token,this.languageConfigurationService);if(d.token.isCancellationRequested||this.textModel.getVersionId()!==r.versionId)return!1;const m=new Date;this._debounceValue.update(this.textModel,m.getTime()-g.getTime());const _=new Sye(f,r,this.textModel,this.versionId);if(i){const v=i.toInlineCompletion(void 0);i.canBeReused(this.textModel,e)&&!f.has(v)&&_.prepend(i.inlineCompletion,v.range,!0)}return this._updateOperation.clear(),mi(v=>{a.set(_,v)}),!0})(),u=new wye(r,d,c);return this._updateOperation.value=u,c}clear(e){this._updateOperation.clear(),this.inlineCompletions.set(void 0,e),this.suggestWidgetInlineCompletions.set(void 0,e)}clearSuggestWidgetInlineCompletions(e){var t;!((t=this._updateOperation.value)===null||t===void 0)&&t.request.context.selectedSuggestionInfo&&this._updateOperation.clear(),this.suggestWidgetInlineCompletions.set(void 0,e)}cancelUpdate(){this._updateOperation.clear()}};uR=_ye([bB(3,xe),bB(4,Jt)],uR);function vye(s,e){return new Promise(t=>{let i;const n=setTimeout(()=>{i&&i.dispose(),t()},s);e&&(i=e.onCancellationRequested(()=>{clearTimeout(n),i&&i.dispose(),t()}))})}class bye{constructor(e,t,i){this.position=e,this.context=t,this.versionId=i}satisfies(e){return this.position.equals(e.position)&&Cye(this.context.selectedSuggestionInfo,e.context.selectedSuggestionInfo,(t,i)=>t.equals(i))&&(e.context.triggerKind===jd.Automatic||this.context.triggerKind===jd.Explicit)&&this.versionId===e.versionId}}function Cye(s,e,t){return!s||!e?s===e:t(s,e)}class wye{constructor(e,t,i){this.request=e,this.cancellationTokenSource=t,this.promise=i}dispose(){this.cancellationTokenSource.cancel()}}class Sye{get inlineCompletions(){return this._inlineCompletions}constructor(e,t,i,n){this.inlineCompletionProviderResult=e,this.request=t,this.textModel=i,this.versionId=n,this._refCount=1,this._prependedInlineCompletionItems=[],this._rangeVersionIdValue=0,this._rangeVersionId=nt(this,r=>{this.versionId.read(r);let a=!1;for(const l of this._inlineCompletions)a=a||l._updateRange(this.textModel);return a&&this._rangeVersionIdValue++,this._rangeVersionIdValue});const o=i.deltaDecorations([],e.completions.map(r=>({range:r.range,options:{description:"inline-completion-tracking-range"}})));this._inlineCompletions=e.completions.map((r,a)=>new CB(r,o[a],this._rangeVersionId))}clone(){return this._refCount++,this}dispose(){if(this._refCount--,this._refCount===0){setTimeout(()=>{this.textModel.isDisposed()||this.textModel.deltaDecorations(this._inlineCompletions.map(e=>e.decorationId),[])},0),this.inlineCompletionProviderResult.dispose();for(const e of this._prependedInlineCompletionItems)e.source.removeRef()}}prepend(e,t,i){i&&e.source.addRef();const n=this.textModel.deltaDecorations([],[{range:t,options:{description:"inline-completion-tracking-range"}}])[0];this._inlineCompletions.unshift(new CB(e,n,this._rangeVersionId,t)),this._prependedInlineCompletionItems.push(e)}}class CB{get forwardStable(){var e;return(e=this.inlineCompletion.source.inlineCompletions.enableForwardStability)!==null&&e!==void 0?e:!1}constructor(e,t,i,n){this.inlineCompletion=e,this.decorationId=t,this.rangeVersion=i,this.semanticId=JSON.stringify([this.inlineCompletion.filterText,this.inlineCompletion.insertText,this.inlineCompletion.range.getStartPosition().toString()]),this._isValid=!0,this._updatedRange=n??e.range}toInlineCompletion(e){return this.inlineCompletion.withRange(this._getUpdatedRange(e))}toSingleTextEdit(e){return new $m(this._getUpdatedRange(e),this.inlineCompletion.insertText)}isVisible(e,t,i){const n=this._toFilterTextReplacement(i).removeCommonPrefix(e);if(!this._isValid||!this.inlineCompletion.range.getStartPosition().equals(this._getUpdatedRange(i).getStartPosition())||t.lineNumber!==n.range.startLineNumber)return!1;const o=e.getValueInRange(n.range,1),r=n.text,a=Math.max(0,t.column-n.range.startColumn);let l=r.substring(0,a),d=r.substring(a),c=o.substring(0,a),u=o.substring(a);const h=e.getLineIndentColumn(n.range.startLineNumber);return n.range.startColumn<=h&&(c=c.trimStart(),c.length===0&&(u=u.trimStart()),l=l.trimStart(),l.length===0&&(d=d.trimStart())),l.startsWith(c)&&!!Rz(u,d)}canBeReused(e,t){return this._isValid&&this._getUpdatedRange(void 0).containsPosition(t)&&this.isVisible(e,t,void 0)&&!this._isSmallerThanOriginal(void 0)}_toFilterTextReplacement(e){return new $m(this._getUpdatedRange(e),this.inlineCompletion.filterText)}_isSmallerThanOriginal(e){return wB(this._getUpdatedRange(e)).isBefore(wB(this.inlineCompletion.range))}_getUpdatedRange(e){return this.rangeVersion.read(e),this._updatedRange}_updateRange(e){const t=e.getDecorationRange(this.decorationId);return t?this._updatedRange.equalsRange(t)?!1:(this._updatedRange=t,!0):(this._isValid=!1,!0)}}function wB(s){return s.startLineNumber===s.endLineNumber?new H(1,1+s.endColumn-s.startColumn):new H(1+s.endLineNumber-s.startLineNumber,s.endColumn)}const st={Visible:b4,HasFocusedSuggestion:new me("suggestWidgetHasFocusedSuggestion",!1,p("suggestWidgetHasSelection","Whether any suggestion is focused")),DetailsVisible:new me("suggestWidgetDetailsVisible",!1,p("suggestWidgetDetailsVisible","Whether suggestion details are visible")),MultipleSuggestions:new me("suggestWidgetMultipleSuggestions",!1,p("suggestWidgetMultipleSuggestions","Whether there are multiple suggestions to pick from")),MakesTextEdit:new me("suggestionMakesTextEdit",!0,p("suggestionMakesTextEdit","Whether inserting the current suggestion yields in a change or has everything already been typed")),AcceptSuggestionsOnEnter:new me("acceptSuggestionOnEnter",!0,p("acceptSuggestionOnEnter","Whether suggestions are inserted when pressing Enter")),HasInsertAndReplaceRange:new me("suggestionHasInsertAndReplaceRange",!1,p("suggestionHasInsertAndReplaceRange","Whether the current suggestion has insert and replace behaviour")),InsertMode:new me("suggestionInsertMode",void 0,{type:"string",description:p("suggestionInsertMode","Whether the default behaviour is to insert or replace")}),CanResolve:new me("suggestionCanResolve",!1,p("suggestionCanResolve","Whether the current suggestion supports to resolve further details"))},bu=new N("suggestWidgetStatusBar");class yye{constructor(e,t,i,n){var o;this.position=e,this.completion=t,this.container=i,this.provider=n,this.isInvalid=!1,this.score=Fa.Default,this.distance=0,this.textLabel=typeof t.label=="string"?t.label:(o=t.label)===null||o===void 0?void 0:o.label,this.labelLow=this.textLabel.toLowerCase(),this.isInvalid=!this.textLabel,this.sortTextLow=t.sortText&&t.sortText.toLowerCase(),this.filterTextLow=t.filterText&&t.filterText.toLowerCase(),this.extensionId=t.extensionId,D.isIRange(t.range)?(this.editStart=new H(t.range.startLineNumber,t.range.startColumn),this.editInsertEnd=new H(t.range.endLineNumber,t.range.endColumn),this.editReplaceEnd=new H(t.range.endLineNumber,t.range.endColumn),this.isInvalid=this.isInvalid||D.spansMultipleLines(t.range)||t.range.startLineNumber!==e.lineNumber):(this.editStart=new H(t.range.insert.startLineNumber,t.range.insert.startColumn),this.editInsertEnd=new H(t.range.insert.endLineNumber,t.range.insert.endColumn),this.editReplaceEnd=new H(t.range.replace.endLineNumber,t.range.replace.endColumn),this.isInvalid=this.isInvalid||D.spansMultipleLines(t.range.insert)||D.spansMultipleLines(t.range.replace)||t.range.insert.startLineNumber!==e.lineNumber||t.range.replace.startLineNumber!==e.lineNumber||t.range.insert.startColumn!==t.range.replace.startColumn),typeof n.resolveCompletionItem!="function"&&(this._resolveCache=Promise.resolve(),this._resolveDuration=0)}get isResolved(){return this._resolveDuration!==void 0}get resolveDuration(){return this._resolveDuration!==void 0?this._resolveDuration:-1}async resolve(e){if(!this._resolveCache){const t=e.onCancellationRequested(()=>{this._resolveCache=void 0,this._resolveDuration=void 0}),i=new cs(!0);this._resolveCache=Promise.resolve(this.provider.resolveCompletionItem(this.completion,e)).then(n=>{Object.assign(this.completion,n),this._resolveDuration=i.elapsed()},n=>{Ka(n)&&(this._resolveCache=void 0,this._resolveDuration=void 0)}).finally(()=>{t.dispose()})}return this._resolveCache}}class Rb{constructor(e=2,t=new Set,i=new Set,n=new Map,o=!0){this.snippetSortOrder=e,this.kindFilter=t,this.providerFilter=i,this.providerItemsToReuse=n,this.showDeprecated=o}}Rb.default=new Rb;let Lye;function xye(){return Lye}class Dye{constructor(e,t,i,n){this.items=e,this.needsClipboard=t,this.durations=i,this.disposable=n}}async function k4(s,e,t,i=Rb.default,n={triggerKind:0},o=ct.None){const r=new cs;t=t.clone();const a=e.getWordAtPosition(t),l=a?new D(t.lineNumber,a.startColumn,t.lineNumber,a.endColumn):D.fromPositions(t),d={replace:l,insert:l.setEndPosition(t.lineNumber,t.column)},c=[],u=new ie,h=[];let g=!1;const f=(_,v,b)=>{var C,w,S;let x=!1;if(!v)return x;for(const L of v.suggestions)if(!i.kindFilter.has(L.kind)){if(!i.showDeprecated&&(!((C=L==null?void 0:L.tags)===null||C===void 0)&&C.includes(1)))continue;L.range||(L.range=d),L.sortText||(L.sortText=typeof L.label=="string"?L.label:L.label.label),!g&&L.insertTextRules&&L.insertTextRules&4&&(g=Um.guessNeedsClipboard(L.insertText)),c.push(new yye(t,L,v,_)),x=!0}return EA(v)&&u.add(v),h.push({providerName:(w=_._debugDisplayName)!==null&&w!==void 0?w:"unknown_provider",elapsedProvider:(S=v.duration)!==null&&S!==void 0?S:-1,elapsedOverall:b.elapsed()}),x},m=(async()=>{})();for(const _ of s.orderedGroups(e)){let v=!1;if(await Promise.all(_.map(async b=>{if(i.providerItemsToReuse.has(b)){const C=i.providerItemsToReuse.get(b);C.forEach(w=>c.push(w)),v=v||C.length>0;return}if(!(i.providerFilter.size>0&&!i.providerFilter.has(b)))try{const C=new cs,w=await b.provideCompletionItems(e,t,n,o);v=f(b,w,C)||v}catch(C){Zi(C)}})),v||o.isCancellationRequested)break}return await m,o.isCancellationRequested?(u.dispose(),Promise.reject(new eh)):new Dye(c.sort(Eye(i.snippetSortOrder)),g,{entries:h,elapsed:r.elapsed()},u)}function I4(s,e){if(s.sortTextLow&&e.sortTextLow){if(s.sortTextLow<e.sortTextLow)return-1;if(s.sortTextLow>e.sortTextLow)return 1}return s.textLabel<e.textLabel?-1:s.textLabel>e.textLabel?1:s.completion.kind-e.completion.kind}function kye(s,e){if(s.completion.kind!==e.completion.kind){if(s.completion.kind===27)return-1;if(e.completion.kind===27)return 1}return I4(s,e)}function Iye(s,e){if(s.completion.kind!==e.completion.kind){if(s.completion.kind===27)return 1;if(e.completion.kind===27)return-1}return I4(s,e)}const AD=new Map;AD.set(0,kye);AD.set(2,Iye);AD.set(1,I4);function Eye(s){return AD.get(s)}Ct.registerCommand("_executeCompletionItemProvider",async(s,...e)=>{const[t,i,n,o]=e;zt(Pe.isUri(t)),zt(H.isIPosition(i)),zt(typeof n=="string"||!n),zt(typeof o=="number"||!o);const{completionProvider:r}=s.get(xe),a=await s.get(io).createModelReference(t);try{const l={incomplete:!1,suggestions:[]},d=[],c=a.object.textEditorModel.validatePosition(i),u=await k4(r,a.object.textEditorModel,c,void 0,{triggerCharacter:n??void 0,triggerKind:n?1:0});for(const h of u.items)d.length<(o??0)&&d.push(h.resolve(ct.None)),l.incomplete=l.incomplete||h.container.incomplete,l.suggestions.push(h.completion);try{return await Promise.all(d),l}finally{setTimeout(()=>u.disposable.dispose(),100)}}finally{a.dispose()}});function Nye(s,e){var t;(t=s.getContribution("editor.contrib.suggestController"))===null||t===void 0||t.triggerSuggest(new Set().add(e),void 0,!0)}class xp{static isAllOff(e){return e.other==="off"&&e.comments==="off"&&e.strings==="off"}static isAllOn(e){return e.other==="on"&&e.comments==="on"&&e.strings==="on"}static valueFor(e,t){switch(t){case 1:return e.comments;case 2:return e.strings;default:return e.other}}}function SB(s,e=es){return Mle(s,e)?s.charAt(0).toUpperCase()+s.slice(1):s}var Tye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Mye=function(s,e){return function(t,i){e(t,i,s)}};class yB{constructor(e){this._delegates=e}resolve(e){for(const t of this._delegates){const i=t.resolve(e);if(i!==void 0)return i}}}class LB{constructor(e,t,i,n){this._model=e,this._selection=t,this._selectionIdx=i,this._overtypingCapturer=n}resolve(e){const{name:t}=e;if(t==="SELECTION"||t==="TM_SELECTED_TEXT"){let i=this._model.getValueInRange(this._selection)||void 0,n=this._selection.startLineNumber!==this._selection.endLineNumber;if(!i&&this._overtypingCapturer){const o=this._overtypingCapturer.getLastOvertypedInfo(this._selectionIdx);o&&(i=o.value,n=o.multiline)}if(i&&n&&e.snippet){const o=this._model.getLineContent(this._selection.startLineNumber),r=Zt(o,0,this._selection.startColumn-1);let a=r;e.snippet.walk(d=>d===e?!1:(d instanceof Es&&(a=Zt(Kl(d.value).pop())),!0));const l=Dg(a,r);i=i.replace(/(\r\n|\r|\n)(.*)/g,(d,c,u)=>`${c}${a.substr(l)}${u}`)}return i}else{if(t==="TM_CURRENT_LINE")return this._model.getLineContent(this._selection.positionLineNumber);if(t==="TM_CURRENT_WORD"){const i=this._model.getWordAtPosition({lineNumber:this._selection.positionLineNumber,column:this._selection.positionColumn});return i&&i.word||void 0}else{if(t==="TM_LINE_INDEX")return String(this._selection.positionLineNumber-1);if(t==="TM_LINE_NUMBER")return String(this._selection.positionLineNumber);if(t==="CURSOR_INDEX")return String(this._selectionIdx);if(t==="CURSOR_NUMBER")return String(this._selectionIdx+1)}}}}class xB{constructor(e,t){this._labelService=e,this._model=t}resolve(e){const{name:t}=e;if(t==="TM_FILENAME")return ru(this._model.uri.fsPath);if(t==="TM_FILENAME_BASE"){const i=ru(this._model.uri.fsPath),n=i.lastIndexOf(".");return n<=0?i:i.slice(0,n)}else{if(t==="TM_DIRECTORY")return RW(this._model.uri.fsPath)==="."?"":this._labelService.getUriLabel(Tx(this._model.uri));if(t==="TM_FILEPATH")return this._labelService.getUriLabel(this._model.uri);if(t==="RELATIVE_FILEPATH")return this._labelService.getUriLabel(this._model.uri,{relative:!0,noPrefix:!0})}}}class DB{constructor(e,t,i,n){this._readClipboardText=e,this._selectionIdx=t,this._selectionCount=i,this._spread=n}resolve(e){if(e.name!=="CLIPBOARD")return;const t=this._readClipboardText();if(t){if(this._spread){const i=t.split(/\r\n|\n|\r/).filter(n=>!VW(n));if(i.length===this._selectionCount)return i[this._selectionIdx]}return t}}}let vL=class{constructor(e,t,i){this._model=e,this._selection=t,this._languageConfigurationService=i}resolve(e){const{name:t}=e,i=this._model.getLanguageIdAtPosition(this._selection.selectionStartLineNumber,this._selection.selectionStartColumn),n=this._languageConfigurationService.getLanguageConfiguration(i).comments;if(n){if(t==="LINE_COMMENT")return n.lineCommentToken||void 0;if(t==="BLOCK_COMMENT_START")return n.blockCommentStartToken||void 0;if(t==="BLOCK_COMMENT_END")return n.blockCommentEndToken||void 0}}};vL=Tye([Mye(2,Jt)],vL);class Ta{constructor(){this._date=new Date}resolve(e){const{name:t}=e;if(t==="CURRENT_YEAR")return String(this._date.getFullYear());if(t==="CURRENT_YEAR_SHORT")return String(this._date.getFullYear()).slice(-2);if(t==="CURRENT_MONTH")return String(this._date.getMonth().valueOf()+1).padStart(2,"0");if(t==="CURRENT_DATE")return String(this._date.getDate().valueOf()).padStart(2,"0");if(t==="CURRENT_HOUR")return String(this._date.getHours().valueOf()).padStart(2,"0");if(t==="CURRENT_MINUTE")return String(this._date.getMinutes().valueOf()).padStart(2,"0");if(t==="CURRENT_SECOND")return String(this._date.getSeconds().valueOf()).padStart(2,"0");if(t==="CURRENT_DAY_NAME")return Ta.dayNames[this._date.getDay()];if(t==="CURRENT_DAY_NAME_SHORT")return Ta.dayNamesShort[this._date.getDay()];if(t==="CURRENT_MONTH_NAME")return Ta.monthNames[this._date.getMonth()];if(t==="CURRENT_MONTH_NAME_SHORT")return Ta.monthNamesShort[this._date.getMonth()];if(t==="CURRENT_SECONDS_UNIX")return String(Math.floor(this._date.getTime()/1e3));if(t==="CURRENT_TIMEZONE_OFFSET"){const i=this._date.getTimezoneOffset(),n=i>0?"-":"+",o=Math.trunc(Math.abs(i/60)),r=o<10?"0"+o:o,a=Math.abs(i)-o*60,l=a<10?"0"+a:a;return n+r+":"+l}}}Ta.dayNames=[p("Sunday","Sunday"),p("Monday","Monday"),p("Tuesday","Tuesday"),p("Wednesday","Wednesday"),p("Thursday","Thursday"),p("Friday","Friday"),p("Saturday","Saturday")];Ta.dayNamesShort=[p("SundayShort","Sun"),p("MondayShort","Mon"),p("TuesdayShort","Tue"),p("WednesdayShort","Wed"),p("ThursdayShort","Thu"),p("FridayShort","Fri"),p("SaturdayShort","Sat")];Ta.monthNames=[p("January","January"),p("February","February"),p("March","March"),p("April","April"),p("May","May"),p("June","June"),p("July","July"),p("August","August"),p("September","September"),p("October","October"),p("November","November"),p("December","December")];Ta.monthNamesShort=[p("JanuaryShort","Jan"),p("FebruaryShort","Feb"),p("MarchShort","Mar"),p("AprilShort","Apr"),p("MayShort","May"),p("JuneShort","Jun"),p("JulyShort","Jul"),p("AugustShort","Aug"),p("SeptemberShort","Sep"),p("OctoberShort","Oct"),p("NovemberShort","Nov"),p("DecemberShort","Dec")];class kB{constructor(e){this._workspaceService=e}resolve(e){if(!this._workspaceService)return;const t=zue(this._workspaceService.getWorkspace());if(!Wue(t)){if(e.name==="WORKSPACE_NAME")return this._resolveWorkspaceName(t);if(e.name==="WORKSPACE_FOLDER")return this._resoveWorkspacePath(t)}}_resolveWorkspaceName(e){if(GT(e))return ru(e.uri.path);let t=ru(e.configPath.path);return t.endsWith(ZT)&&(t=t.substr(0,t.length-ZT.length-1)),t}_resoveWorkspacePath(e){if(GT(e))return SB(e.uri.fsPath);const t=ru(e.configPath.path);let i=e.configPath.fsPath;return i.endsWith(t)&&(i=i.substr(0,i.length-t.length-1)),i?SB(i):"/"}}class IB{resolve(e){const{name:t}=e;if(t==="RANDOM")return Math.random().toString().slice(-6);if(t==="RANDOM_HEX")return Math.random().toString(16).slice(-6);if(t==="UUID")return xD()}}var Rye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Aye=function(s,e){return function(t,i){e(t,i,s)}},ha;class hr{constructor(e,t,i){this._editor=e,this._snippet=t,this._snippetLineLeadingWhitespace=i,this._offset=-1,this._nestingLevel=1,this._placeholderGroups=qF(t.placeholders,gr.compareByIndex),this._placeholderGroupsIdx=-1}initialize(e){this._offset=e.newPosition}dispose(){this._placeholderDecorations&&this._editor.removeDecorations([...this._placeholderDecorations.values()]),this._placeholderGroups.length=0}_initDecorations(){if(this._offset===-1)throw new Error("Snippet not initialized!");if(this._placeholderDecorations)return;this._placeholderDecorations=new Map;const e=this._editor.getModel();this._editor.changeDecorations(t=>{for(const i of this._snippet.placeholders){const n=this._snippet.offset(i),o=this._snippet.fullLen(i),r=D.fromPositions(e.getPositionAt(this._offset+n),e.getPositionAt(this._offset+n+o)),a=i.isFinalTabstop?hr._decor.inactiveFinal:hr._decor.inactive,l=t.addDecoration(r,a);this._placeholderDecorations.set(i,l)}})}move(e){if(!this._editor.hasModel())return[];if(this._initDecorations(),this._placeholderGroupsIdx>=0){const n=[];for(const o of this._placeholderGroups[this._placeholderGroupsIdx])if(o.transform){const r=this._placeholderDecorations.get(o),a=this._editor.getModel().getDecorationRange(r),l=this._editor.getModel().getValueInRange(a),d=o.transform.resolve(l).split(/\r\n|\r|\n/);for(let c=1;c<d.length;c++)d[c]=this._editor.getModel().normalizeIndentation(this._snippetLineLeadingWhitespace+d[c]);n.push(_i.replace(a,d.join(this._editor.getModel().getEOL())))}n.length>0&&this._editor.executeEdits("snippet.placeholderTransform",n)}let t=!1;e===!0&&this._placeholderGroupsIdx<this._placeholderGroups.length-1?(this._placeholderGroupsIdx+=1,t=!0):e===!1&&this._placeholderGroupsIdx>0&&(this._placeholderGroupsIdx-=1,t=!0);const i=this._editor.getModel().changeDecorations(n=>{const o=new Set,r=[];for(const a of this._placeholderGroups[this._placeholderGroupsIdx]){const l=this._placeholderDecorations.get(a),d=this._editor.getModel().getDecorationRange(l);r.push(new De(d.startLineNumber,d.startColumn,d.endLineNumber,d.endColumn)),t=t&&this._hasPlaceholderBeenCollapsed(a),n.changeDecorationOptions(l,a.isFinalTabstop?hr._decor.activeFinal:hr._decor.active),o.add(a);for(const c of this._snippet.enclosingPlaceholders(a)){const u=this._placeholderDecorations.get(c);n.changeDecorationOptions(u,c.isFinalTabstop?hr._decor.activeFinal:hr._decor.active),o.add(c)}}for(const[a,l]of this._placeholderDecorations)o.has(a)||n.changeDecorationOptions(l,a.isFinalTabstop?hr._decor.inactiveFinal:hr._decor.inactive);return r});return t?this.move(e):i??[]}_hasPlaceholderBeenCollapsed(e){let t=e;for(;t;){if(t instanceof gr){const i=this._placeholderDecorations.get(t);if(this._editor.getModel().getDecorationRange(i).isEmpty()&&t.toString().length>0)return!0}t=t.parent}return!1}get isAtFirstPlaceholder(){return this._placeholderGroupsIdx<=0||this._placeholderGroups.length===0}get isAtLastPlaceholder(){return this._placeholderGroupsIdx===this._placeholderGroups.length-1}get hasPlaceholder(){return this._snippet.placeholders.length>0}get isTrivialSnippet(){if(this._snippet.placeholders.length===0)return!0;if(this._snippet.placeholders.length===1){const[e]=this._snippet.placeholders;if(e.isFinalTabstop&&this._snippet.rightMostDescendant===e)return!0}return!1}computePossibleSelections(){const e=new Map;for(const t of this._placeholderGroups){let i;for(const n of t){if(n.isFinalTabstop)break;i||(i=[],e.set(n.index,i));const o=this._placeholderDecorations.get(n),r=this._editor.getModel().getDecorationRange(o);if(!r){e.delete(n.index);break}i.push(r)}}return e}get activeChoice(){if(!this._placeholderDecorations)return;const e=this._placeholderGroups[this._placeholderGroupsIdx][0];if(!(e!=null&&e.choice))return;const t=this._placeholderDecorations.get(e);if(!t)return;const i=this._editor.getModel().getDecorationRange(t);if(i)return{range:i,choice:e.choice}}get hasChoice(){let e=!1;return this._snippet.walk(t=>(e=t instanceof b_,!e)),e}merge(e){const t=this._editor.getModel();this._nestingLevel*=10,this._editor.changeDecorations(i=>{for(const n of this._placeholderGroups[this._placeholderGroupsIdx]){const o=e.shift();console.assert(o._offset!==-1),console.assert(!o._placeholderDecorations);const r=o._snippet.placeholderInfo.last.index;for(const l of o._snippet.placeholderInfo.all)l.isFinalTabstop?l.index=n.index+(r+1)/this._nestingLevel:l.index=n.index+l.index/this._nestingLevel;this._snippet.replace(n,o._snippet.children);const a=this._placeholderDecorations.get(n);i.removeDecoration(a),this._placeholderDecorations.delete(n);for(const l of o._snippet.placeholders){const d=o._snippet.offset(l),c=o._snippet.fullLen(l),u=D.fromPositions(t.getPositionAt(o._offset+d),t.getPositionAt(o._offset+d+c)),h=i.addDecoration(u,hr._decor.inactive);this._placeholderDecorations.set(l,h)}}this._placeholderGroups=qF(this._snippet.placeholders,gr.compareByIndex)})}}hr._decor={active:tt.register({description:"snippet-placeholder-1",stickiness:0,className:"snippet-placeholder"}),inactive:tt.register({description:"snippet-placeholder-2",stickiness:1,className:"snippet-placeholder"}),activeFinal:tt.register({description:"snippet-placeholder-3",stickiness:1,className:"finish-snippet-placeholder"}),inactiveFinal:tt.register({description:"snippet-placeholder-4",stickiness:1,className:"finish-snippet-placeholder"})};const EB={overwriteBefore:0,overwriteAfter:0,adjustWhitespace:!0,clipboardText:void 0,overtypingCapturer:void 0};let bL=ha=class{static adjustWhitespace(e,t,i,n,o){const r=e.getLineContent(t.lineNumber),a=Zt(r,0,t.column-1);let l;return n.walk(d=>{if(!(d instanceof Es)||d.parent instanceof b_||o&&!o.has(d))return!0;const c=d.value.split(/\r\n|\r|\n/);if(i){const h=n.offset(d);if(h===0)c[0]=e.normalizeIndentation(c[0]);else{l=l??n.toString();const g=l.charCodeAt(h-1);(g===10||g===13)&&(c[0]=e.normalizeIndentation(a+c[0]))}for(let g=1;g<c.length;g++)c[g]=e.normalizeIndentation(a+c[g])}const u=c.join(e.getEOL());return u!==d.value&&(d.parent.replace(d,[new Es(u)]),l=void 0),!0}),a}static adjustSelection(e,t,i,n){if(i!==0||n!==0){const{positionLineNumber:o,positionColumn:r}=t,a=r-i,l=r+n,d=e.validateRange({startLineNumber:o,startColumn:a,endLineNumber:o,endColumn:l});t=De.createWithDirection(d.startLineNumber,d.startColumn,d.endLineNumber,d.endColumn,t.getDirection())}return t}static createEditsAndSnippetsFromSelections(e,t,i,n,o,r,a,l,d){const c=[],u=[];if(!e.hasModel())return{edits:c,snippets:u};const h=e.getModel(),g=e.invokeWithinContext(w=>w.get(Ag)),f=e.invokeWithinContext(w=>new xB(w.get(xm),h)),m=()=>a,_=h.getValueInRange(ha.adjustSelection(h,e.getSelection(),i,0)),v=h.getValueInRange(ha.adjustSelection(h,e.getSelection(),0,n)),b=h.getLineFirstNonWhitespaceColumn(e.getSelection().positionLineNumber),C=e.getSelections().map((w,S)=>({selection:w,idx:S})).sort((w,S)=>D.compareRangesUsingStarts(w.selection,S.selection));for(const{selection:w,idx:S}of C){let x=ha.adjustSelection(h,w,i,0),L=ha.adjustSelection(h,w,0,n);_!==h.getValueInRange(x)&&(x=w),v!==h.getValueInRange(L)&&(L=w);const k=w.setStartPosition(x.startLineNumber,x.startColumn).setEndPosition(L.endLineNumber,L.endColumn),I=new Um().parse(t,!0,o),P=k.getStartPosition(),$=ha.adjustWhitespace(h,P,r||S>0&&b!==h.getLineFirstNonWhitespaceColumn(w.positionLineNumber),I);I.resolveVariables(new yB([f,new DB(m,S,C.length,e.getOption(78)==="spread"),new LB(h,w,S,l),new vL(h,w,d),new Ta,new kB(g),new IB])),c[S]=_i.replace(k,I.toString()),c[S].identifier={major:S,minor:0},c[S]._isTracked=!0,u[S]=new hr(e,I,$)}return{edits:c,snippets:u}}static createEditsAndSnippetsFromEdits(e,t,i,n,o,r,a){if(!e.hasModel()||t.length===0)return{edits:[],snippets:[]};const l=[],d=e.getModel(),c=new Um,u=new HC,h=new yB([e.invokeWithinContext(f=>new xB(f.get(xm),d)),new DB(()=>o,0,e.getSelections().length,e.getOption(78)==="spread"),new LB(d,e.getSelection(),0,r),new vL(d,e.getSelection(),a),new Ta,new kB(e.invokeWithinContext(f=>f.get(Ag))),new IB]);t=t.sort((f,m)=>D.compareRangesUsingStarts(f.range,m.range));let g=0;for(let f=0;f<t.length;f++){const{range:m,template:_}=t[f];if(f>0){const S=t[f-1].range,x=D.fromPositions(S.getEndPosition(),m.getStartPosition()),L=new Es(d.getValueInRange(x));u.appendChild(L),g+=L.value.length}const v=c.parseFragment(_,u);ha.adjustWhitespace(d,m.getStartPosition(),!0,u,new Set(v)),u.resolveVariables(h);const b=u.toString(),C=b.slice(g);g=b.length;const w=_i.replace(m,C);w.identifier={major:f,minor:0},w._isTracked=!0,l.push(w)}return c.ensureFinalTabstop(u,i,!0),{edits:l,snippets:[new hr(e,u,"")]}}constructor(e,t,i=EB,n){this._editor=e,this._template=t,this._options=i,this._languageConfigurationService=n,this._templateMerges=[],this._snippets=[]}dispose(){Bt(this._snippets)}_logInfo(){return`template="${this._template}", merged_templates="${this._templateMerges.join(" -> ")}"`}insert(){if(!this._editor.hasModel())return;const{edits:e,snippets:t}=typeof this._template=="string"?ha.createEditsAndSnippetsFromSelections(this._editor,this._template,this._options.overwriteBefore,this._options.overwriteAfter,!1,this._options.adjustWhitespace,this._options.clipboardText,this._options.overtypingCapturer,this._languageConfigurationService):ha.createEditsAndSnippetsFromEdits(this._editor,this._template,!1,this._options.adjustWhitespace,this._options.clipboardText,this._options.overtypingCapturer,this._languageConfigurationService);this._snippets=t,this._editor.executeEdits("snippet",e,i=>{const n=i.filter(o=>!!o.identifier);for(let o=0;o<t.length;o++)t[o].initialize(n[o].textChange);return this._snippets[0].hasPlaceholder?this._move(!0):n.map(o=>De.fromPositions(o.range.getEndPosition()))}),this._editor.revealRange(this._editor.getSelections()[0])}merge(e,t=EB){if(!this._editor.hasModel())return;this._templateMerges.push([this._snippets[0]._nestingLevel,this._snippets[0]._placeholderGroupsIdx,e]);const{edits:i,snippets:n}=ha.createEditsAndSnippetsFromSelections(this._editor,e,t.overwriteBefore,t.overwriteAfter,!0,t.adjustWhitespace,t.clipboardText,t.overtypingCapturer,this._languageConfigurationService);this._editor.executeEdits("snippet",i,o=>{const r=o.filter(l=>!!l.identifier);for(let l=0;l<n.length;l++)n[l].initialize(r[l].textChange);const a=n[0].isTrivialSnippet;if(!a){for(const l of this._snippets)l.merge(n);console.assert(n.length===0)}return this._snippets[0].hasPlaceholder&&!a?this._move(void 0):r.map(l=>De.fromPositions(l.range.getEndPosition()))})}next(){const e=this._move(!0);this._editor.setSelections(e),this._editor.revealPositionInCenterIfOutsideViewport(e[0].getPosition())}prev(){const e=this._move(!1);this._editor.setSelections(e),this._editor.revealPositionInCenterIfOutsideViewport(e[0].getPosition())}_move(e){const t=[];for(const i of this._snippets){const n=i.move(e);t.push(...n)}return t}get isAtFirstPlaceholder(){return this._snippets[0].isAtFirstPlaceholder}get isAtLastPlaceholder(){return this._snippets[0].isAtLastPlaceholder}get hasPlaceholder(){return this._snippets[0].hasPlaceholder}get hasChoice(){return this._snippets[0].hasChoice}get activeChoice(){return this._snippets[0].activeChoice}isSelectionWithinPlaceholders(){if(!this.hasPlaceholder)return!1;const e=this._editor.getSelections();if(e.length<this._snippets.length)return!1;const t=new Map;for(const i of this._snippets){const n=i.computePossibleSelections();if(t.size===0)for(const[o,r]of n){r.sort(D.compareRangesUsingStarts);for(const a of e)if(r[0].containsRange(a)){t.set(o,[]);break}}if(t.size===0)return!1;t.forEach((o,r)=>{o.push(...n.get(r))})}e.sort(D.compareRangesUsingStarts);for(const[i,n]of t){if(n.length!==e.length){t.delete(i);continue}n.sort(D.compareRangesUsingStarts);for(let o=0;o<n.length;o++)if(!n[o].containsRange(e[o])){t.delete(i);continue}}return t.size>0}};bL=ha=Rye([Aye(3,Jt)],bL);var Pye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},hw=function(s,e){return function(t,i){e(t,i,s)}},Xf;const NB={overwriteBefore:0,overwriteAfter:0,undoStopBefore:!0,undoStopAfter:!0,adjustWhitespace:!0,clipboardText:void 0,overtypingCapturer:void 0};let Hn=Xf=class{static get(e){return e.getContribution(Xf.ID)}constructor(e,t,i,n,o){this._editor=e,this._logService=t,this._languageFeaturesService=i,this._languageConfigurationService=o,this._snippetListener=new ie,this._modelVersionId=-1,this._inSnippet=Xf.InSnippetMode.bindTo(n),this._hasNextTabstop=Xf.HasNextTabstop.bindTo(n),this._hasPrevTabstop=Xf.HasPrevTabstop.bindTo(n)}dispose(){var e;this._inSnippet.reset(),this._hasPrevTabstop.reset(),this._hasNextTabstop.reset(),(e=this._session)===null||e===void 0||e.dispose(),this._snippetListener.dispose()}insert(e,t){try{this._doInsert(e,typeof t>"u"?NB:{...NB,...t})}catch(i){this.cancel(),this._logService.error(i),this._logService.error("snippet_error"),this._logService.error("insert_template=",e),this._logService.error("existing_template=",this._session?this._session._logInfo():"<no_session>")}}_doInsert(e,t){var i;if(this._editor.hasModel()){if(this._snippetListener.clear(),t.undoStopBefore&&this._editor.getModel().pushStackElement(),this._session&&typeof e!="string"&&this.cancel(),this._session?(zt(typeof e=="string"),this._session.merge(e,t)):(this._modelVersionId=this._editor.getModel().getAlternativeVersionId(),this._session=new bL(this._editor,e,t,this._languageConfigurationService),this._session.insert()),t.undoStopAfter&&this._editor.getModel().pushStackElement(),!((i=this._session)===null||i===void 0)&&i.hasChoice){const n={_debugDisplayName:"snippetChoiceCompletions",provideCompletionItems:(c,u)=>{if(!this._session||c!==this._editor.getModel()||!H.equals(this._editor.getPosition(),u))return;const{activeChoice:h}=this._session;if(!h||h.choice.options.length===0)return;const g=c.getValueInRange(h.range),f=!!h.choice.options.find(_=>_.value===g),m=[];for(let _=0;_<h.choice.options.length;_++){const v=h.choice.options[_];m.push({kind:13,label:v.value,insertText:v.value,sortText:"a".repeat(_+1),range:h.range,filterText:f?`${g}_${v.value}`:void 0,command:{id:"jumpToNextSnippetPlaceholder",title:p("next","Go to next placeholder...")}})}return{suggestions:m}}},o=this._editor.getModel();let r,a=!1;const l=()=>{r==null||r.dispose(),a=!1},d=()=>{a||(r=this._languageFeaturesService.completionProvider.register({language:o.getLanguageId(),pattern:o.uri.fsPath,scheme:o.uri.scheme,exclusive:!0},n),this._snippetListener.add(r),a=!0)};this._choiceCompletions={provider:n,enable:d,disable:l}}this._updateState(),this._snippetListener.add(this._editor.onDidChangeModelContent(n=>n.isFlush&&this.cancel())),this._snippetListener.add(this._editor.onDidChangeModel(()=>this.cancel())),this._snippetListener.add(this._editor.onDidChangeCursorSelection(()=>this._updateState()))}}_updateState(){if(!(!this._session||!this._editor.hasModel())){if(this._modelVersionId===this._editor.getModel().getAlternativeVersionId())return this.cancel();if(!this._session.hasPlaceholder)return this.cancel();if(this._session.isAtLastPlaceholder||!this._session.isSelectionWithinPlaceholders())return this._editor.getModel().pushStackElement(),this.cancel();this._inSnippet.set(!0),this._hasPrevTabstop.set(!this._session.isAtFirstPlaceholder),this._hasNextTabstop.set(!this._session.isAtLastPlaceholder),this._handleChoice()}}_handleChoice(){var e;if(!this._session||!this._editor.hasModel()){this._currentChoice=void 0;return}const{activeChoice:t}=this._session;if(!t||!this._choiceCompletions){(e=this._choiceCompletions)===null||e===void 0||e.disable(),this._currentChoice=void 0;return}this._currentChoice!==t.choice&&(this._currentChoice=t.choice,this._choiceCompletions.enable(),queueMicrotask(()=>{Nye(this._editor,this._choiceCompletions.provider)}))}finish(){for(;this._inSnippet.get();)this.next()}cancel(e=!1){var t;this._inSnippet.reset(),this._hasPrevTabstop.reset(),this._hasNextTabstop.reset(),this._snippetListener.clear(),this._currentChoice=void 0,(t=this._session)===null||t===void 0||t.dispose(),this._session=void 0,this._modelVersionId=-1,e&&this._editor.setSelections([this._editor.getSelection()])}prev(){var e;(e=this._session)===null||e===void 0||e.prev(),this._updateState()}next(){var e;(e=this._session)===null||e===void 0||e.next(),this._updateState()}isInSnippet(){return!!this._inSnippet.get()}};Hn.ID="snippetController2";Hn.InSnippetMode=new me("inSnippetMode",!1,p("inSnippetMode","Whether the editor in current in snippet mode"));Hn.HasNextTabstop=new me("hasNextTabstop",!1,p("hasNextTabstop","Whether there is a next tab stop when in snippet mode"));Hn.HasPrevTabstop=new me("hasPrevTabstop",!1,p("hasPrevTabstop","Whether there is a previous tab stop when in snippet mode"));Hn=Xf=Pye([hw(1,ko),hw(2,xe),hw(3,je),hw(4,Jt)],Hn);Lt(Hn.ID,Hn,4);const PD=Nn.bindToContribution(Hn.get);ue(new PD({id:"jumpToNextSnippetPlaceholder",precondition:ee.and(Hn.InSnippetMode,Hn.HasNextTabstop),handler:s=>s.next(),kbOpts:{weight:130,kbExpr:T.editorTextFocus,primary:2}}));ue(new PD({id:"jumpToPrevSnippetPlaceholder",precondition:ee.and(Hn.InSnippetMode,Hn.HasPrevTabstop),handler:s=>s.prev(),kbOpts:{weight:130,kbExpr:T.editorTextFocus,primary:1026}}));ue(new PD({id:"leaveSnippet",precondition:Hn.InSnippetMode,handler:s=>s.cancel(!0),kbOpts:{weight:130,kbExpr:T.editorTextFocus,primary:9,secondary:[1033]}}));ue(new PD({id:"acceptSnippet",precondition:Hn.InSnippetMode,handler:s=>s.finish()}));var Oye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},mE=function(s,e){return function(t,i){e(t,i,s)}},Bo;(function(s){s[s.Undo=0]="Undo",s[s.Redo=1]="Redo",s[s.AcceptWord=2]="AcceptWord",s[s.Other=3]="Other"})(Bo||(Bo={}));let hR=class extends j{get isAcceptingPartially(){return this._isAcceptingPartially}constructor(e,t,i,n,o,r,a,l,d,c,u,h){super(),this.textModel=e,this.selectedSuggestItem=t,this.cursorPosition=i,this.textModelVersionId=n,this._debounceValue=o,this._suggestPreviewEnabled=r,this._suggestPreviewMode=a,this._inlineSuggestMode=l,this._enabled=d,this._instantiationService=c,this._commandService=u,this._languageConfigurationService=h,this._source=this._register(this._instantiationService.createInstance(uR,this.textModel,this.textModelVersionId,this._debounceValue)),this._isActive=kt(this,!1),this._forceUpdateSignal=BO("forceUpdate"),this._selectedInlineCompletionId=kt(this,void 0),this._isAcceptingPartially=!1,this._preserveCurrentCompletionReasons=new Set([Bo.Redo,Bo.Undo,Bo.AcceptWord]),this._fetchInlineCompletions=Hme({owner:this,createEmptyChangeSummary:()=>({preserveCurrentCompletion:!1,inlineCompletionTriggerKind:jd.Automatic}),handleChange:(f,m)=>(f.didChange(this.textModelVersionId)&&this._preserveCurrentCompletionReasons.has(f.change)?m.preserveCurrentCompletion=!0:f.didChange(this._forceUpdateSignal)&&(m.inlineCompletionTriggerKind=f.change),!0)},(f,m)=>{if(this._forceUpdateSignal.read(f),!(this._enabled.read(f)&&this.selectedSuggestItem.read(f)||this._isActive.read(f))){this._source.cancelUpdate();return}this.textModelVersionId.read(f);const v=this.selectedInlineCompletion.get(),b=m.preserveCurrentCompletion||v!=null&&v.forwardStable?v:void 0,C=this._source.suggestWidgetInlineCompletions.get(),w=this.selectedSuggestItem.read(f);if(C&&!w){const L=this._source.inlineCompletions.get();mi(k=>{(!L||C.request.versionId>L.request.versionId)&&this._source.inlineCompletions.set(C.clone(),k),this._source.clearSuggestWidgetInlineCompletions(k)})}const S=this.cursorPosition.read(f),x={triggerKind:m.inlineCompletionTriggerKind,selectedSuggestionInfo:w==null?void 0:w.toSelectedSuggestionInfo()};return this._source.fetch(S,x,b)}),this._filteredInlineCompletionItems=nt(this,f=>{const m=this._source.inlineCompletions.read(f);if(!m)return[];const _=this.cursorPosition.read(f);return m.inlineCompletions.filter(b=>b.isVisible(this.textModel,_,f))}),this.selectedInlineCompletionIndex=nt(this,f=>{const m=this._selectedInlineCompletionId.read(f),_=this._filteredInlineCompletionItems.read(f),v=this._selectedInlineCompletionId===void 0?-1:_.findIndex(b=>b.semanticId===m);return v===-1?(this._selectedInlineCompletionId.set(void 0,void 0),0):v}),this.selectedInlineCompletion=nt(this,f=>{const m=this._filteredInlineCompletionItems.read(f),_=this.selectedInlineCompletionIndex.read(f);return m[_]}),this.lastTriggerKind=this._source.inlineCompletions.map(this,f=>f==null?void 0:f.request.context.triggerKind),this.inlineCompletionsCount=nt(this,f=>{if(this.lastTriggerKind.read(f)===jd.Explicit)return this._filteredInlineCompletionItems.read(f).length}),this.state=X2({owner:this,equalityComparer:(f,m)=>!f||!m?f===m:hB(f.ghostText,m.ghostText)&&f.inlineCompletion===m.inlineCompletion&&f.suggestItem===m.suggestItem},f=>{var m;const _=this.textModel,v=this.selectedSuggestItem.read(f);if(v){const b=v.toSingleTextEdit().removeCommonPrefix(_),C=this._computeAugmentedCompletion(b,f);if(!this._suggestPreviewEnabled.read(f)&&!C)return;const S=(m=C==null?void 0:C.edit)!==null&&m!==void 0?m:b,x=C?C.edit.text.length-b.text.length:0,L=this._suggestPreviewMode.read(f),k=this.cursorPosition.read(f),I=S.computeGhostText(_,L,k,x);return{ghostText:I??new mL(S.range.endLineNumber,[]),inlineCompletion:C==null?void 0:C.completion,suggestItem:v}}else{if(!this._isActive.read(f))return;const b=this.selectedInlineCompletion.read(f);if(!b)return;const C=b.toSingleTextEdit(f),w=this._inlineSuggestMode.read(f),S=this.cursorPosition.read(f),x=C.computeGhostText(_,w,S);return x?{ghostText:x,inlineCompletion:b,suggestItem:void 0}:void 0}}),this.ghostText=X2({owner:this,equalityComparer:hB},f=>{const m=this.state.read(f);if(m)return m.ghostText}),this._register(TC(this._fetchInlineCompletions));let g;this._register(Rt(f=>{var m,_;const v=this.state.read(f),b=v==null?void 0:v.inlineCompletion;if((b==null?void 0:b.semanticId)!==(g==null?void 0:g.semanticId)&&(g=b,b)){const C=b.inlineCompletion,w=C.source;(_=(m=w.provider).handleItemDidShow)===null||_===void 0||_.call(m,w.inlineCompletions,C.sourceInlineCompletion,C.insertText)}}))}async trigger(e){this._isActive.set(!0,e),await this._fetchInlineCompletions.get()}async triggerExplicitly(e){Cb(e,t=>{this._isActive.set(!0,t),this._forceUpdateSignal.trigger(t,jd.Explicit)}),await this._fetchInlineCompletions.get()}stop(e){Cb(e,t=>{this._isActive.set(!1,t),this._source.clear(t)})}_computeAugmentedCompletion(e,t){const i=this.textModel,n=this._source.suggestWidgetInlineCompletions.read(t),o=n?n.inlineCompletions:[this.selectedInlineCompletion.read(t)].filter(b0);return kie(o,a=>{let l=a.toSingleTextEdit(t);return l=l.removeCommonPrefix(i,D.fromPositions(l.range.getStartPosition(),e.range.getEndPosition())),l.augments(e)?{edit:l,completion:a}:void 0})}async _deltaSelectedInlineCompletionIndex(e){await this.triggerExplicitly();const t=this._filteredInlineCompletionItems.get()||[];if(t.length>0){const i=(this.selectedInlineCompletionIndex.get()+e+t.length)%t.length;this._selectedInlineCompletionId.set(t[i].semanticId,void 0)}else this._selectedInlineCompletionId.set(void 0,void 0)}async next(){await this._deltaSelectedInlineCompletionIndex(1)}async previous(){await this._deltaSelectedInlineCompletionIndex(-1)}async accept(e){var t;if(e.getModel()!==this.textModel)throw new pi;const i=this.state.get();if(!i||i.ghostText.isEmpty()||!i.inlineCompletion)return;const n=i.inlineCompletion.toInlineCompletion(void 0);e.pushUndoStop(),n.snippetInfo?(e.executeEdits("inlineSuggestion.accept",[_i.replaceMove(n.range,""),...n.additionalTextEdits]),e.setPosition(n.snippetInfo.range.getStartPosition()),(t=Hn.get(e))===null||t===void 0||t.insert(n.snippetInfo.snippet,{undoStopBefore:!1})):e.executeEdits("inlineSuggestion.accept",[_i.replaceMove(n.range,n.insertText),...n.additionalTextEdits]),n.command&&n.source.addRef(),mi(o=>{this._source.clear(o),this._isActive.set(!1,o)}),n.command&&(await this._commandService.executeCommand(n.command.id,...n.command.arguments||[]).then(void 0,Zi),n.source.removeRef())}async acceptNextWord(e){await this._acceptNext(e,(t,i)=>{const n=this.textModel.getLanguageIdAtPosition(t.lineNumber,t.column),o=this._languageConfigurationService.getLanguageConfiguration(n),r=new RegExp(o.wordDefinition.source,o.wordDefinition.flags.replace("g","")),a=i.match(r);let l=0;a&&a.index!==void 0?a.index===0?l=a[0].length:l=a.index:l=i.length;const c=/\s+/g.exec(i);return c&&c.index!==void 0&&c.index+c[0].length<l&&(l=c.index+c[0].length),l})}async acceptNextLine(e){await this._acceptNext(e,(t,i)=>{const n=i.match(/\n/);return n&&n.index!==void 0?n.index+1:i.length})}async _acceptNext(e,t){if(e.getModel()!==this.textModel)throw new pi;const i=this.state.get();if(!i||i.ghostText.isEmpty()||!i.inlineCompletion)return;const n=i.ghostText,o=i.inlineCompletion.toInlineCompletion(void 0);if(o.snippetInfo||o.filterText!==o.insertText){await this.accept(e);return}const r=n.parts[0],a=new H(n.lineNumber,r.column),l=r.lines.join(`
`),d=t(a,l);if(d===l.length&&n.parts.length===1){this.accept(e);return}const c=l.substring(0,d);o.source.addRef();try{this._isAcceptingPartially=!0;try{e.pushUndoStop(),e.executeEdits("inlineSuggestion.accept",[_i.replace(D.fromPositions(a),c)]);const u=aR(c);e.setPosition(rR(a,u))}finally{this._isAcceptingPartially=!1}if(o.source.provider.handlePartialAccept){const u=D.fromPositions(o.range.getStartPosition(),rR(a,aR(c))),h=e.getModel().getValueInRange(u,1);o.source.provider.handlePartialAccept(o.source.inlineCompletions,o.sourceInlineCompletion,h.length)}}finally{o.source.removeRef()}}handleSuggestAccepted(e){var t,i;const n=e.toSingleTextEdit().removeCommonPrefix(this.textModel),o=this._computeAugmentedCompletion(n,void 0);if(!o)return;const r=o.completion.inlineCompletion;(i=(t=r.source.provider).handlePartialAccept)===null||i===void 0||i.call(t,r.source.inlineCompletions,r.sourceInlineCompletion,n.text.length)}};hR=Oye([mE(9,We),mE(10,Ei),mE(11,Jt)],hR);var Fye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},TB=function(s,e){return function(t,i){e(t,i,s)}},Lv;class E4{constructor(e){this.name=e}select(e,t,i){if(i.length===0)return 0;const n=i[0].score[0];for(let o=0;o<i.length;o++){const{score:r,completion:a}=i[o];if(r[0]!==n)break;if(a.preselect)return o}return 0}}class bK extends E4{constructor(){super("first")}memorize(e,t,i){}toJSON(){}fromJSON(){}}class Bye extends E4{constructor(){super("recentlyUsed"),this._cache=new nh(300,.66),this._seq=0}memorize(e,t,i){const n=`${e.getLanguageId()}/${i.textLabel}`;this._cache.set(n,{touch:this._seq++,type:i.completion.kind,insertText:i.completion.insertText})}select(e,t,i){if(i.length===0)return 0;const n=e.getLineContent(t.lineNumber).substr(t.column-10,t.column-1);if(/\s$/.test(n))return super.select(e,t,i);const o=i[0].score[0];let r=-1,a=-1,l=-1;for(let d=0;d<i.length&&i[d].score[0]===o;d++){const c=`${e.getLanguageId()}/${i[d].textLabel}`,u=this._cache.peek(c);if(u&&u.touch>l&&u.type===i[d].completion.kind&&u.insertText===i[d].completion.insertText&&(l=u.touch,a=d),i[d].completion.preselect&&r===-1)return r=d}return a!==-1?a:r!==-1?r:0}toJSON(){return this._cache.toJSON()}fromJSON(e){this._cache.clear();const t=0;for(const[i,n]of e)n.touch=t,n.type=typeof n.type=="number"?n.type:y0.fromString(n.type),this._cache.set(i,n);this._seq=this._cache.size}}class Wye extends E4{constructor(){super("recentlyUsedByPrefix"),this._trie=Gp.forStrings(),this._seq=0}memorize(e,t,i){const{word:n}=e.getWordUntilPosition(t),o=`${e.getLanguageId()}/${n}`;this._trie.set(o,{type:i.completion.kind,insertText:i.completion.insertText,touch:this._seq++})}select(e,t,i){const{word:n}=e.getWordUntilPosition(t);if(!n)return super.select(e,t,i);const o=`${e.getLanguageId()}/${n}`;let r=this._trie.get(o);if(r||(r=this._trie.findSubstr(o)),r)for(let a=0;a<i.length;a++){const{kind:l,insertText:d}=i[a].completion;if(l===r.type&&d===r.insertText)return a}return super.select(e,t,i)}toJSON(){const e=[];return this._trie.forEach((t,i)=>e.push([i,t])),e.sort((t,i)=>-(t[1].touch-i[1].touch)).forEach((t,i)=>t[1].touch=i),e.slice(0,200)}fromJSON(e){if(this._trie.clear(),e.length>0){this._seq=e[0][1].touch+1;for(const[t,i]of e)i.type=typeof i.type=="number"?i.type:y0.fromString(i.type),this._trie.set(t,i)}}}let Ab=Lv=class{constructor(e,t){this._storageService=e,this._configService=t,this._disposables=new ie,this._persistSoon=new jt(()=>this._saveState(),500),this._disposables.add(e.onWillSaveState(i=>{i.reason===db.SHUTDOWN&&this._saveState()}))}dispose(){this._disposables.dispose(),this._persistSoon.dispose()}memorize(e,t,i){this._withStrategy(e,t).memorize(e,t,i),this._persistSoon.schedule()}select(e,t,i){return this._withStrategy(e,t).select(e,t,i)}_withStrategy(e,t){var i;const n=this._configService.getValue("editor.suggestSelection",{overrideIdentifier:e.getLanguageIdAtPosition(t.lineNumber,t.column),resource:e.uri});if(((i=this._strategy)===null||i===void 0?void 0:i.name)!==n){this._saveState();const o=Lv._strategyCtors.get(n)||bK;this._strategy=new o;try{const a=this._configService.getValue("editor.suggest.shareSuggestSelections")?0:1,l=this._storageService.get(`${Lv._storagePrefix}/${n}`,a);l&&this._strategy.fromJSON(JSON.parse(l))}catch{}}return this._strategy}_saveState(){if(this._strategy){const t=this._configService.getValue("editor.suggest.shareSuggestSelections")?0:1,i=JSON.stringify(this._strategy);this._storageService.store(`${Lv._storagePrefix}/${this._strategy.name}`,i,t,1)}}};Ab._strategyCtors=new Map([["recentlyUsedByPrefix",Wye],["recentlyUsed",Bye],["first",bK]]);Ab._storagePrefix="suggest/memories";Ab=Lv=Fye([TB(0,sa),TB(1,mt)],Ab);const OD=ut("ISuggestMemories");_t(OD,Ab,1);var Vye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Hye=function(s,e){return function(t,i){e(t,i,s)}},gR;let Pb=gR=class{constructor(e,t){this._editor=e,this._enabled=!1,this._ckAtEnd=gR.AtEnd.bindTo(t),this._configListener=this._editor.onDidChangeConfiguration(i=>i.hasChanged(122)&&this._update()),this._update()}dispose(){var e;this._configListener.dispose(),(e=this._selectionListener)===null||e===void 0||e.dispose(),this._ckAtEnd.reset()}_update(){const e=this._editor.getOption(122)==="on";if(this._enabled!==e)if(this._enabled=e,this._enabled){const t=()=>{if(!this._editor.hasModel()){this._ckAtEnd.set(!1);return}const i=this._editor.getModel(),n=this._editor.getSelection(),o=i.getWordAtPosition(n.getStartPosition());if(!o){this._ckAtEnd.set(!1);return}this._ckAtEnd.set(o.endColumn===n.getStartPosition().column)};this._selectionListener=this._editor.onDidChangeCursorSelection(t),t()}else this._selectionListener&&(this._ckAtEnd.reset(),this._selectionListener.dispose(),this._selectionListener=void 0)}};Pb.AtEnd=new me("atEndOfWord",!1);Pb=gR=Vye([Hye(1,je)],Pb);var zye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Uye=function(s,e){return function(t,i){e(t,i,s)}},xv;let Yg=xv=class{constructor(e,t){this._editor=e,this._index=0,this._ckOtherSuggestions=xv.OtherSuggestions.bindTo(t)}dispose(){this.reset()}reset(){var e;this._ckOtherSuggestions.reset(),(e=this._listener)===null||e===void 0||e.dispose(),this._model=void 0,this._acceptNext=void 0,this._ignore=!1}set({model:e,index:t},i){if(e.items.length===0){this.reset();return}if(xv._moveIndex(!0,e,t)===t){this.reset();return}this._acceptNext=i,this._model=e,this._index=t,this._listener=this._editor.onDidChangeCursorPosition(()=>{this._ignore||this.reset()}),this._ckOtherSuggestions.set(!0)}static _moveIndex(e,t,i){let n=i;for(let o=t.items.length;o>0&&(n=(n+t.items.length+(e?1:-1))%t.items.length,!(n===i||!t.items[n].completion.additionalTextEdits));o--);return n}next(){this._move(!0)}prev(){this._move(!1)}_move(e){if(this._model)try{this._ignore=!0,this._index=xv._moveIndex(e,this._model,this._index),this._acceptNext({index:this._index,item:this._model.items[this._index],model:this._model})}finally{this._ignore=!1}}};Yg.OtherSuggestions=new me("hasOtherSuggestions",!1);Yg=xv=zye([Uye(1,je)],Yg);class $ye{constructor(e,t,i,n){this._disposables=new ie,this._disposables.add(i.onDidSuggest(o=>{o.completionModel.items.length===0&&this.reset()})),this._disposables.add(i.onDidCancel(o=>{this.reset()})),this._disposables.add(t.onDidShow(()=>this._onItem(t.getFocusedItem()))),this._disposables.add(t.onDidFocus(this._onItem,this)),this._disposables.add(t.onDidHide(this.reset,this)),this._disposables.add(e.onWillType(o=>{if(this._active&&!t.isFrozen()&&i.state!==0){const r=o.charCodeAt(o.length-1);this._active.acceptCharacters.has(r)&&e.getOption(0)&&n(this._active.item)}}))}_onItem(e){if(!e||!as(e.item.completion.commitCharacters)){this.reset();return}if(this._active&&this._active.item.item===e.item)return;const t=new US;for(const i of e.item.completion.commitCharacters)i.length>0&&t.add(i.charCodeAt(0));this._active={acceptCharacters:t,item:e}}reset(){this._active=void 0}dispose(){this._disposables.dispose()}}class Wo{async provideSelectionRanges(e,t){const i=[];for(const n of t){const o=[];i.push(o);const r=new Map;await new Promise(a=>Wo._bracketsRightYield(a,0,e,n,r)),await new Promise(a=>Wo._bracketsLeftYield(a,0,e,n,r,o))}return i}static _bracketsRightYield(e,t,i,n,o){const r=new Map,a=Date.now();for(;;){if(t>=Wo._maxRounds){e();break}if(!n){e();break}const l=i.bracketPairs.findNextBracket(n);if(!l){e();break}if(Date.now()-a>Wo._maxDuration){setTimeout(()=>Wo._bracketsRightYield(e,t+1,i,n,o));break}if(l.bracketInfo.isOpeningBracket){const c=l.bracketInfo.bracketText,u=r.has(c)?r.get(c):0;r.set(c,u+1)}else{const c=l.bracketInfo.getOpeningBrackets()[0].bracketText;let u=r.has(c)?r.get(c):0;if(u-=1,r.set(c,Math.max(0,u)),u<0){let h=o.get(c);h||(h=new Ms,o.set(c,h)),h.push(l.range)}}n=l.range.getEndPosition()}}static _bracketsLeftYield(e,t,i,n,o,r){const a=new Map,l=Date.now();for(;;){if(t>=Wo._maxRounds&&o.size===0){e();break}if(!n){e();break}const d=i.bracketPairs.findPrevBracket(n);if(!d){e();break}if(Date.now()-l>Wo._maxDuration){setTimeout(()=>Wo._bracketsLeftYield(e,t+1,i,n,o,r));break}if(d.bracketInfo.isOpeningBracket){const u=d.bracketInfo.bracketText;let h=a.has(u)?a.get(u):0;if(h-=1,a.set(u,Math.max(0,h)),h<0){const g=o.get(u);if(g){const f=g.shift();g.size===0&&o.delete(u);const m=D.fromPositions(d.range.getEndPosition(),f.getStartPosition()),_=D.fromPositions(d.range.getStartPosition(),f.getEndPosition());r.push({range:m}),r.push({range:_}),Wo._addBracketLeading(i,_,r)}}}else{const u=d.bracketInfo.getOpeningBrackets()[0].bracketText,h=a.has(u)?a.get(u):0;a.set(u,h+1)}n=d.range.getStartPosition()}}static _addBracketLeading(e,t,i){if(t.startLineNumber===t.endLineNumber)return;const n=t.startLineNumber,o=e.getLineFirstNonWhitespaceColumn(n);o!==0&&o!==t.startColumn&&(i.push({range:D.fromPositions(new H(n,o),t.getEndPosition())}),i.push({range:D.fromPositions(new H(n,1),t.getEndPosition())}));const r=n-1;if(r>0){const a=e.getLineFirstNonWhitespaceColumn(r);a===t.startColumn&&a!==e.getLineLastNonWhitespaceColumn(r)&&(i.push({range:D.fromPositions(new H(r,a),t.getEndPosition())}),i.push({range:D.fromPositions(new H(r,1),t.getEndPosition())}))}}}Wo._maxDuration=30;Wo._maxRounds=2;class ya{static async create(e,t){if(!t.getOption(117).localityBonus||!t.hasModel())return ya.None;const i=t.getModel(),n=t.getPosition();if(!e.canComputeWordRanges(i.uri))return ya.None;const[o]=await new Wo().provideSelectionRanges(i,[n]);if(o.length===0)return ya.None;const r=await e.computeWordRanges(i.uri,o[0].range);if(!r)return ya.None;const a=i.getWordUntilPosition(n);return delete r[a.word],new class extends ya{distance(l,d){if(!n.equals(t.getPosition()))return 0;if(d.kind===17)return 2<<20;const c=typeof d.label=="string"?d.label:d.label.label,u=r[c];if(dW(u))return 2<<20;const h=_0(u,D.fromPositions(l),D.compareRangesUsingStarts),g=h>=0?u[h]:u[Math.max(0,~h-1)];let f=o.length;for(const m of o){if(!D.containsRange(m.range,g))break;f-=1}return f}}}}ya.None=new class extends ya{distance(){return 0}};let MB=class{constructor(e,t){this.leadingLineContent=e,this.characterCountDelta=t}};class Wc{constructor(e,t,i,n,o,r,a=Wx.default,l=void 0){this.clipboardText=l,this._snippetCompareFn=Wc._compareCompletionItems,this._items=e,this._column=t,this._wordDistance=n,this._options=o,this._refilterKind=1,this._lineContext=i,this._fuzzyScoreOptions=a,r==="top"?this._snippetCompareFn=Wc._compareCompletionItemsSnippetsUp:r==="bottom"&&(this._snippetCompareFn=Wc._compareCompletionItemsSnippetsDown)}get lineContext(){return this._lineContext}set lineContext(e){(this._lineContext.leadingLineContent!==e.leadingLineContent||this._lineContext.characterCountDelta!==e.characterCountDelta)&&(this._refilterKind=this._lineContext.characterCountDelta<e.characterCountDelta&&this._filteredItems?2:1,this._lineContext=e)}get items(){return this._ensureCachedState(),this._filteredItems}getItemsByProvider(){return this._ensureCachedState(),this._itemsByProvider}getIncompleteProvider(){this._ensureCachedState();const e=new Set;for(const[t,i]of this.getItemsByProvider())i.length>0&&i[0].container.incomplete&&e.add(t);return e}get stats(){return this._ensureCachedState(),this._stats}_ensureCachedState(){this._refilterKind!==0&&this._createCachedState()}_createCachedState(){this._itemsByProvider=new Map;const e=[],{leadingLineContent:t,characterCountDelta:i}=this._lineContext;let n="",o="";const r=this._refilterKind===1?this._items:this._filteredItems,a=[],l=!this._options.filterGraceful||r.length>2e3?Pg:vhe;for(let d=0;d<r.length;d++){const c=r[d];if(c.isInvalid)continue;const u=this._itemsByProvider.get(c.provider);u?u.push(c):this._itemsByProvider.set(c.provider,[c]);const h=c.position.column-c.editStart.column,g=h+i-(c.position.column-this._column);if(n.length!==g&&(n=g===0?"":t.slice(-g),o=n.toLowerCase()),c.word=n,g===0)c.score=Fa.Default;else{let f=0;for(;f<h;){const m=n.charCodeAt(f);if(m===32||m===9)f+=1;else break}if(f>=g)c.score=Fa.Default;else if(typeof c.completion.filterText=="string"){const m=l(n,o,f,c.completion.filterText,c.filterTextLow,0,this._fuzzyScoreOptions);if(!m)continue;WN(c.completion.filterText,c.textLabel)===0?c.score=m:(c.score=fhe(n,o,f,c.textLabel,c.labelLow,0),c.score[0]=m[0])}else{const m=l(n,o,f,c.textLabel,c.labelLow,0,this._fuzzyScoreOptions);if(!m)continue;c.score=m}}c.idx=d,c.distance=this._wordDistance.distance(c.position,c.completion),a.push(c),e.push(c.textLabel.length)}this._filteredItems=a.sort(this._snippetCompareFn),this._refilterKind=0,this._stats={pLabelLen:e.length?UE(e.length-.85,e,(d,c)=>d-c):0}}static _compareCompletionItems(e,t){return e.score[0]>t.score[0]?-1:e.score[0]<t.score[0]?1:e.distance<t.distance?-1:e.distance>t.distance?1:e.idx<t.idx?-1:e.idx>t.idx?1:0}static _compareCompletionItemsSnippetsDown(e,t){if(e.completion.kind!==t.completion.kind){if(e.completion.kind===27)return 1;if(t.completion.kind===27)return-1}return Wc._compareCompletionItems(e,t)}static _compareCompletionItemsSnippetsUp(e,t){if(e.completion.kind!==t.completion.kind){if(e.completion.kind===27)return-1;if(t.completion.kind===27)return 1}return Wc._compareCompletionItems(e,t)}}var jye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},_c=function(s,e){return function(t,i){e(t,i,s)}},fR;class Ih{static shouldAutoTrigger(e){if(!e.hasModel())return!1;const t=e.getModel(),i=e.getPosition();t.tokenization.tokenizeIfCheap(i.lineNumber);const n=t.getWordAtPosition(i);return!(!n||n.endColumn!==i.column&&n.startColumn+1!==i.column||!isNaN(Number(n.word)))}constructor(e,t,i){this.leadingLineContent=e.getLineContent(t.lineNumber).substr(0,t.column-1),this.leadingWord=e.getWordUntilPosition(t),this.lineNumber=t.lineNumber,this.column=t.column,this.triggerOptions=i}}function Kye(s,e,t){if(!e.getContextKeyValue(kn.inlineSuggestionVisible.key))return!0;const i=e.getContextKeyValue(kn.suppressSuggestions.key);return i!==void 0?!i:!s.getOption(62).suppressSuggestions}function qye(s,e,t){if(!e.getContextKeyValue("inlineSuggestionVisible"))return!0;const i=e.getContextKeyValue(kn.suppressSuggestions.key);return i!==void 0?!i:!s.getOption(62).suppressSuggestions}let pR=fR=class{constructor(e,t,i,n,o,r,a,l,d){this._editor=e,this._editorWorkerService=t,this._clipboardService=i,this._telemetryService=n,this._logService=o,this._contextKeyService=r,this._configurationService=a,this._languageFeaturesService=l,this._envService=d,this._toDispose=new ie,this._triggerCharacterListener=new ie,this._triggerQuickSuggest=new ea,this._triggerState=void 0,this._completionDisposables=new ie,this._onDidCancel=new W,this._onDidTrigger=new W,this._onDidSuggest=new W,this.onDidCancel=this._onDidCancel.event,this.onDidTrigger=this._onDidTrigger.event,this.onDidSuggest=this._onDidSuggest.event,this._telemetryGate=0,this._currentSelection=this._editor.getSelection()||new De(1,1,1,1),this._toDispose.add(this._editor.onDidChangeModel(()=>{this._updateTriggerCharacters(),this.cancel()})),this._toDispose.add(this._editor.onDidChangeModelLanguage(()=>{this._updateTriggerCharacters(),this.cancel()})),this._toDispose.add(this._editor.onDidChangeConfiguration(()=>{this._updateTriggerCharacters()})),this._toDispose.add(this._languageFeaturesService.completionProvider.onDidChange(()=>{this._updateTriggerCharacters(),this._updateActiveSuggestSession()}));let c=!1;this._toDispose.add(this._editor.onDidCompositionStart(()=>{c=!0})),this._toDispose.add(this._editor.onDidCompositionEnd(()=>{c=!1,this._onCompositionEnd()})),this._toDispose.add(this._editor.onDidChangeCursorSelection(u=>{c||this._onCursorChange(u)})),this._toDispose.add(this._editor.onDidChangeModelContent(()=>{!c&&this._triggerState!==void 0&&this._refilterCompletionItems()})),this._updateTriggerCharacters()}dispose(){Bt(this._triggerCharacterListener),Bt([this._onDidCancel,this._onDidSuggest,this._onDidTrigger,this._triggerQuickSuggest]),this._toDispose.dispose(),this._completionDisposables.dispose(),this.cancel()}_updateTriggerCharacters(){if(this._triggerCharacterListener.clear(),this._editor.getOption(90)||!this._editor.hasModel()||!this._editor.getOption(120))return;const e=new Map;for(const i of this._languageFeaturesService.completionProvider.all(this._editor.getModel()))for(const n of i.triggerCharacters||[]){let o=e.get(n);o||(o=new Set,o.add(xye()),e.set(n,o)),o.add(i)}const t=i=>{var n;if(!qye(this._editor,this._contextKeyService,this._configurationService)||Ih.shouldAutoTrigger(this._editor))return;if(!i){const a=this._editor.getPosition();i=this._editor.getModel().getLineContent(a.lineNumber).substr(0,a.column-1)}let o="";kg(i.charCodeAt(i.length-1))?_n(i.charCodeAt(i.length-2))&&(o=i.substr(i.length-2)):o=i.charAt(i.length-1);const r=e.get(o);if(r){const a=new Map;if(this._completionModel)for(const[l,d]of this._completionModel.getItemsByProvider())r.has(l)||a.set(l,d);this.trigger({auto:!0,triggerKind:1,triggerCharacter:o,retrigger:!!this._completionModel,clipboardText:(n=this._completionModel)===null||n===void 0?void 0:n.clipboardText,completionOptions:{providerFilter:r,providerItemsToReuse:a}})}};this._triggerCharacterListener.add(this._editor.onDidType(t)),this._triggerCharacterListener.add(this._editor.onDidCompositionEnd(()=>t()))}get state(){return this._triggerState?this._triggerState.auto?2:1:0}cancel(e=!1){var t;this._triggerState!==void 0&&(this._triggerQuickSuggest.cancel(),(t=this._requestToken)===null||t===void 0||t.cancel(),this._requestToken=void 0,this._triggerState=void 0,this._completionModel=void 0,this._context=void 0,this._onDidCancel.fire({retrigger:e}))}clear(){this._completionDisposables.clear()}_updateActiveSuggestSession(){this._triggerState!==void 0&&(!this._editor.hasModel()||!this._languageFeaturesService.completionProvider.has(this._editor.getModel())?this.cancel():this.trigger({auto:this._triggerState.auto,retrigger:!0}))}_onCursorChange(e){if(!this._editor.hasModel())return;const t=this._currentSelection;if(this._currentSelection=this._editor.getSelection(),!e.selection.isEmpty()||e.reason!==0&&e.reason!==3||e.source!=="keyboard"&&e.source!=="deleteLeft"){this.cancel();return}this._triggerState===void 0&&e.reason===0?(t.containsRange(this._currentSelection)||t.getEndPosition().isBeforeOrEqual(this._currentSelection.getPosition()))&&this._doTriggerQuickSuggest():this._triggerState!==void 0&&e.reason===3&&this._refilterCompletionItems()}_onCompositionEnd(){this._triggerState===void 0?this._doTriggerQuickSuggest():this._refilterCompletionItems()}_doTriggerQuickSuggest(){var e;xp.isAllOff(this._editor.getOption(88))||this._editor.getOption(117).snippetsPreventQuickSuggestions&&(!((e=Hn.get(this._editor))===null||e===void 0)&&e.isInSnippet())||(this.cancel(),this._triggerQuickSuggest.cancelAndSet(()=>{if(this._triggerState!==void 0||!Ih.shouldAutoTrigger(this._editor)||!this._editor.hasModel()||!this._editor.hasWidgetFocus())return;const t=this._editor.getModel(),i=this._editor.getPosition(),n=this._editor.getOption(88);if(!xp.isAllOff(n)){if(!xp.isAllOn(n)){t.tokenization.tokenizeIfCheap(i.lineNumber);const o=t.tokenization.getLineTokens(i.lineNumber),r=o.getStandardTokenType(o.findTokenIndexAtOffset(Math.max(i.column-1-1,0)));if(xp.valueFor(n,r)!=="on")return}Kye(this._editor,this._contextKeyService,this._configurationService)&&this._languageFeaturesService.completionProvider.has(t)&&this.trigger({auto:!0})}},this._editor.getOption(89)))}_refilterCompletionItems(){zt(this._editor.hasModel()),zt(this._triggerState!==void 0);const e=this._editor.getModel(),t=this._editor.getPosition(),i=new Ih(e,t,{...this._triggerState,refilter:!0});this._onNewContext(i)}trigger(e){var t,i,n,o,r,a;if(!this._editor.hasModel())return;const l=this._editor.getModel(),d=new Ih(l,this._editor.getPosition(),e);this.cancel(e.retrigger),this._triggerState=e,this._onDidTrigger.fire({auto:e.auto,shy:(t=e.shy)!==null&&t!==void 0?t:!1,position:this._editor.getPosition()}),this._context=d;let c={triggerKind:(i=e.triggerKind)!==null&&i!==void 0?i:0};e.triggerCharacter&&(c={triggerKind:1,triggerCharacter:e.triggerCharacter}),this._requestToken=new Yi;const u=this._editor.getOption(111);let h=1;switch(u){case"top":h=0;break;case"bottom":h=2;break}const{itemKind:g,showDeprecated:f}=fR._createSuggestFilter(this._editor),m=new Rb(h,(o=(n=e.completionOptions)===null||n===void 0?void 0:n.kindFilter)!==null&&o!==void 0?o:g,(r=e.completionOptions)===null||r===void 0?void 0:r.providerFilter,(a=e.completionOptions)===null||a===void 0?void 0:a.providerItemsToReuse,f),_=ya.create(this._editorWorkerService,this._editor),v=k4(this._languageFeaturesService.completionProvider,l,this._editor.getPosition(),m,c,this._requestToken.token);Promise.all([v,_]).then(async([b,C])=>{var w;if((w=this._requestToken)===null||w===void 0||w.dispose(),!this._editor.hasModel())return;let S=e==null?void 0:e.clipboardText;if(!S&&b.needsClipboard&&(S=await this._clipboardService.readText()),this._triggerState===void 0)return;const x=this._editor.getModel(),L=new Ih(x,this._editor.getPosition(),e),k={...Wx.default,firstMatchCanBeWeak:!this._editor.getOption(117).matchOnWordStartOnly};if(this._completionModel=new Wc(b.items,this._context.column,{leadingLineContent:L.leadingLineContent,characterCountDelta:L.column-this._context.column},C,this._editor.getOption(117),this._editor.getOption(111),k,S),this._completionDisposables.add(b.disposable),this._onNewContext(L),this._reportDurationsTelemetry(b.durations),!this._envService.isBuilt||this._envService.isExtensionDevelopment)for(const I of b.items)I.isInvalid&&this._logService.warn(`[suggest] did IGNORE invalid completion item from ${I.provider._debugDisplayName}`,I.completion)}).catch(et)}_reportDurationsTelemetry(e){this._telemetryGate++%230===0&&setTimeout(()=>{this._telemetryService.publicLog2("suggest.durations.json",{data:JSON.stringify(e)}),this._logService.debug("suggest.durations.json",e)})}static _createSuggestFilter(e){const t=new Set;e.getOption(111)==="none"&&t.add(27);const n=e.getOption(117);return n.showMethods||t.add(0),n.showFunctions||t.add(1),n.showConstructors||t.add(2),n.showFields||t.add(3),n.showVariables||t.add(4),n.showClasses||t.add(5),n.showStructs||t.add(6),n.showInterfaces||t.add(7),n.showModules||t.add(8),n.showProperties||t.add(9),n.showEvents||t.add(10),n.showOperators||t.add(11),n.showUnits||t.add(12),n.showValues||t.add(13),n.showConstants||t.add(14),n.showEnums||t.add(15),n.showEnumMembers||t.add(16),n.showKeywords||t.add(17),n.showWords||t.add(18),n.showColors||t.add(19),n.showFiles||t.add(20),n.showReferences||t.add(21),n.showColors||t.add(22),n.showFolders||t.add(23),n.showTypeParameters||t.add(24),n.showSnippets||t.add(27),n.showUsers||t.add(25),n.showIssues||t.add(26),{itemKind:t,showDeprecated:n.showDeprecated}}_onNewContext(e){if(this._context){if(e.lineNumber!==this._context.lineNumber){this.cancel();return}if(Zt(e.leadingLineContent)!==Zt(this._context.leadingLineContent)){this.cancel();return}if(e.column<this._context.column){e.leadingWord.word?this.trigger({auto:this._context.triggerOptions.auto,retrigger:!0}):this.cancel();return}if(this._completionModel){if(e.leadingWord.word.length!==0&&e.leadingWord.startColumn>this._context.leadingWord.startColumn){if(Ih.shouldAutoTrigger(this._editor)&&this._context){const i=this._completionModel.getItemsByProvider();this.trigger({auto:this._context.triggerOptions.auto,retrigger:!0,clipboardText:this._completionModel.clipboardText,completionOptions:{providerItemsToReuse:i}})}return}if(e.column>this._context.column&&this._completionModel.getIncompleteProvider().size>0&&e.leadingWord.word.length!==0){const t=new Map,i=new Set;for(const[n,o]of this._completionModel.getItemsByProvider())o.length>0&&o[0].container.incomplete?i.add(n):t.set(n,o);this.trigger({auto:this._context.triggerOptions.auto,triggerKind:2,retrigger:!0,clipboardText:this._completionModel.clipboardText,completionOptions:{providerFilter:i,providerItemsToReuse:t}})}else{const t=this._completionModel.lineContext;let i=!1;if(this._completionModel.lineContext={leadingLineContent:e.leadingLineContent,characterCountDelta:e.column-this._context.column},this._completionModel.items.length===0){const n=Ih.shouldAutoTrigger(this._editor);if(!this._context){this.cancel();return}if(n&&this._context.leadingWord.endColumn<e.leadingWord.startColumn){this.trigger({auto:this._context.triggerOptions.auto,retrigger:!0});return}if(this._context.triggerOptions.auto){this.cancel();return}else if(this._completionModel.lineContext=t,i=this._completionModel.items.length>0,i&&e.leadingWord.word.length===0){this.cancel();return}}this._onDidSuggest.fire({completionModel:this._completionModel,triggerOptions:e.triggerOptions,isFrozen:i})}}}}};pR=fR=jye([_c(1,oa),_c(2,dc),_c(3,Do),_c(4,ko),_c(5,je),_c(6,mt),_c(7,xe),_c(8,YP)],pR);class FD{constructor(e,t){this._disposables=new ie,this._lastOvertyped=[],this._locked=!1,this._disposables.add(e.onWillType(()=>{if(this._locked||!e.hasModel())return;const i=e.getSelections(),n=i.length;let o=!1;for(let a=0;a<n;a++)if(!i[a].isEmpty()){o=!0;break}if(!o){this._lastOvertyped.length!==0&&(this._lastOvertyped.length=0);return}this._lastOvertyped=[];const r=e.getModel();for(let a=0;a<n;a++){const l=i[a];if(r.getValueLengthInRange(l)>FD._maxSelectionLength)return;this._lastOvertyped[a]={value:r.getValueInRange(l),multiline:l.startLineNumber!==l.endLineNumber}}})),this._disposables.add(t.onDidTrigger(i=>{this._locked=!0})),this._disposables.add(t.onDidCancel(i=>{this._locked=!1}))}getLastOvertypedInfo(e){if(e>=0&&e<this._lastOvertyped.length)return this._lastOvertyped[e]}dispose(){this._disposables.dispose()}}FD._maxSelectionLength=51200;var Gye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},_E=function(s,e){return function(t,i){e(t,i,s)}};class N4 extends Og{updateLabel(){const e=this._keybindingService.lookupKeybinding(this._action.id,this._contextKeyService);if(!e)return super.updateLabel();this.label&&(this.label.textContent=p({key:"content",comment:["A label","A keybinding"]},"{0} ({1})",this._action.label,N4.symbolPrintEnter(e)))}static symbolPrintEnter(e){var t;return(t=e.getLabel())===null||t===void 0?void 0:t.replace(/\benter\b/gi,"⏎")}}let mR=class{constructor(e,t,i,n,o){this._menuId=t,this._menuService=n,this._contextKeyService=o,this._menuDisposables=new ie,this.element=te(e,se(".suggest-status-bar"));const r=a=>a instanceof Xr?i.createInstance(N4,a,void 0):void 0;this._leftActions=new Ir(this.element,{actionViewItemProvider:r}),this._rightActions=new Ir(this.element,{actionViewItemProvider:r}),this._leftActions.domNode.classList.add("left"),this._rightActions.domNode.classList.add("right")}dispose(){this._menuDisposables.dispose(),this._leftActions.dispose(),this._rightActions.dispose(),this.element.remove()}show(){const e=this._menuService.createMenu(this._menuId,this._contextKeyService),t=()=>{const i=[],n=[];for(const[o,r]of e.getActions())o==="left"?i.push(...r):n.push(...r);this._leftActions.clear(),this._leftActions.push(i),this._rightActions.clear(),this._rightActions.push(n)};this._menuDisposables.add(e.onDidChange(()=>t())),this._menuDisposables.add(e)}hide(){this._menuDisposables.clear()}};mR=Gye([_E(2,We),_E(3,qa),_E(4,je)],mR);var Zye=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Yye=function(s,e){return function(t,i){e(t,i,s)}};function T4(s){return!!s&&!!(s.completion.documentation||s.completion.detail&&s.completion.detail!==s.completion.label)}let _R=class{constructor(e,t){this._editor=e,this._onDidClose=new W,this.onDidClose=this._onDidClose.event,this._onDidChangeContents=new W,this.onDidChangeContents=this._onDidChangeContents.event,this._disposables=new ie,this._renderDisposeable=new ie,this._borderWidth=1,this._size=new Dt(330,0),this.domNode=se(".suggest-details"),this.domNode.classList.add("no-docs"),this._markdownRenderer=t.createInstance(ic,{editor:e}),this._body=se(".body"),this._scrollbar=new hC(this._body,{alwaysConsumeMouseWheel:!0}),te(this.domNode,this._scrollbar.getDomNode()),this._disposables.add(this._scrollbar),this._header=te(this._body,se(".header")),this._close=te(this._header,se("span"+Oe.asCSSSelector(le.close))),this._close.title=p("details.close","Close"),this._type=te(this._header,se("p.type")),this._docs=te(this._body,se("p.docs")),this._configureFont(),this._disposables.add(this._editor.onDidChangeConfiguration(i=>{i.hasChanged(50)&&this._configureFont()}))}dispose(){this._disposables.dispose(),this._renderDisposeable.dispose()}_configureFont(){const e=this._editor.getOptions(),t=e.get(50),i=t.getMassagedFontFamily(),n=e.get(118)||t.fontSize,o=e.get(119)||t.lineHeight,r=t.fontWeight,a=`${n}px`,l=`${o}px`;this.domNode.style.fontSize=a,this.domNode.style.lineHeight=`${o/n}`,this.domNode.style.fontWeight=r,this.domNode.style.fontFeatureSettings=t.fontFeatureSettings,this._type.style.fontFamily=i,this._close.style.height=l,this._close.style.width=l}getLayoutInfo(){const e=this._editor.getOption(119)||this._editor.getOption(50).lineHeight,t=this._borderWidth,i=t*2;return{lineHeight:e,borderWidth:t,borderHeight:i,verticalPadding:22,horizontalPadding:14}}renderLoading(){this._type.textContent=p("loading","Loading..."),this._docs.textContent="",this.domNode.classList.remove("no-docs","no-type"),this.layout(this.size.width,this.getLayoutInfo().lineHeight*2),this._onDidChangeContents.fire(this)}renderItem(e,t){var i,n;this._renderDisposeable.clear();let{detail:o,documentation:r}=e.completion;if(t){let a="";a+=`score: ${e.score[0]}
`,a+=`prefix: ${(i=e.word)!==null&&i!==void 0?i:"(no prefix)"}
`,a+=`word: ${e.completion.filterText?e.completion.filterText+" (filterText)":e.textLabel}
`,a+=`distance: ${e.distance} (localityBonus-setting)
`,a+=`index: ${e.idx}, based on ${e.completion.sortText&&`sortText: "${e.completion.sortText}"`||"label"}
`,a+=`commit_chars: ${(n=e.completion.commitCharacters)===null||n===void 0?void 0:n.join("")}
`,r=new rs().appendCodeblock("empty",a),o=`Provider: ${e.provider._debugDisplayName}`}if(!t&&!T4(e)){this.clearContents();return}if(this.domNode.classList.remove("no-docs","no-type"),o){const a=o.length>1e5?`${o.substr(0,1e5)}…`:o;this._type.textContent=a,this._type.title=a,go(this._type),this._type.classList.toggle("auto-wrap",!/\r?\n^\s+/gmi.test(a))}else Vn(this._type),this._type.title="",ks(this._type),this.domNode.classList.add("no-type");if(Vn(this._docs),typeof r=="string")this._docs.classList.remove("markdown-docs"),this._docs.textContent=r;else if(r){this._docs.classList.add("markdown-docs"),Vn(this._docs);const a=this._markdownRenderer.render(r);this._docs.appendChild(a.element),this._renderDisposeable.add(a),this._renderDisposeable.add(this._markdownRenderer.onDidRenderAsync(()=>{this.layout(this._size.width,this._type.clientHeight+this._docs.clientHeight),this._onDidChangeContents.fire(this)}))}this.domNode.style.userSelect="text",this.domNode.tabIndex=-1,this._close.onmousedown=a=>{a.preventDefault(),a.stopPropagation()},this._close.onclick=a=>{a.preventDefault(),a.stopPropagation(),this._onDidClose.fire()},this._body.scrollTop=0,this.layout(this._size.width,this._type.clientHeight+this._docs.clientHeight),this._onDidChangeContents.fire(this)}clearContents(){this.domNode.classList.add("no-docs"),this._type.textContent="",this._docs.textContent=""}get size(){return this._size}layout(e,t){const i=new Dt(e,t);Dt.equals(i,this._size)||(this._size=i,Vee(this.domNode,e,t)),this._scrollbar.scanDomNode()}scrollDown(e=8){this._body.scrollTop+=e}scrollUp(e=8){this._body.scrollTop-=e}scrollTop(){this._body.scrollTop=0}scrollBottom(){this._body.scrollTop=this._body.scrollHeight}pageDown(){this.scrollDown(80)}pageUp(){this.scrollUp(80)}set borderWidth(e){this._borderWidth=e}get borderWidth(){return this._borderWidth}};_R=Zye([Yye(1,We)],_R);class Xye{constructor(e,t){this.widget=e,this._editor=t,this._disposables=new ie,this._added=!1,this._preferAlignAtTop=!0,this._resizable=new d4,this._resizable.domNode.classList.add("suggest-details-container"),this._resizable.domNode.appendChild(e.domNode),this._resizable.enableSashes(!1,!0,!0,!1);let i,n,o=0,r=0;this._disposables.add(this._resizable.onDidWillResize(()=>{i=this._topLeft,n=this._resizable.size})),this._disposables.add(this._resizable.onDidResize(a=>{if(i&&n){this.widget.layout(a.dimension.width,a.dimension.height);let l=!1;a.west&&(r=n.width-a.dimension.width,l=!0),a.north&&(o=n.height-a.dimension.height,l=!0),l&&this._applyTopLeft({top:i.top+o,left:i.left+r})}a.done&&(i=void 0,n=void 0,o=0,r=0,this._userSize=a.dimension)})),this._disposables.add(this.widget.onDidChangeContents(()=>{var a;this._anchorBox&&this._placeAtAnchor(this._anchorBox,(a=this._userSize)!==null&&a!==void 0?a:this.widget.size,this._preferAlignAtTop)}))}dispose(){this._resizable.dispose(),this._disposables.dispose(),this.hide()}getId(){return"suggest.details"}getDomNode(){return this._resizable.domNode}getPosition(){return null}show(){this._added||(this._editor.addOverlayWidget(this),this.getDomNode().style.position="fixed",this._added=!0)}hide(e=!1){this._resizable.clearSashHoverState(),this._added&&(this._editor.removeOverlayWidget(this),this._added=!1,this._anchorBox=void 0,this._topLeft=void 0),e&&(this._userSize=void 0,this.widget.clearContents())}placeAtAnchor(e,t){var i;const n=e.getBoundingClientRect();this._anchorBox=n,this._preferAlignAtTop=t,this._placeAtAnchor(this._anchorBox,(i=this._userSize)!==null&&i!==void 0?i:this.widget.size,t)}_placeAtAnchor(e,t,i){var n;const o=Nu(this.getDomNode().ownerDocument.body),r=this.widget.getLayoutInfo(),a=new Dt(220,2*r.lineHeight),l=e.top,d=function(){const C=o.width-(e.left+e.width+r.borderWidth+r.horizontalPadding),w=-r.borderWidth+e.left+e.width,S=new Dt(C,o.height-e.top-r.borderHeight-r.verticalPadding),x=S.with(void 0,e.top+e.height-r.borderHeight-r.verticalPadding);return{top:l,left:w,fit:C-t.width,maxSizeTop:S,maxSizeBottom:x,minSize:a.with(Math.min(C,a.width))}}(),c=function(){const C=e.left-r.borderWidth-r.horizontalPadding,w=Math.max(r.horizontalPadding,e.left-t.width-r.borderWidth),S=new Dt(C,o.height-e.top-r.borderHeight-r.verticalPadding),x=S.with(void 0,e.top+e.height-r.borderHeight-r.verticalPadding);return{top:l,left:w,fit:C-t.width,maxSizeTop:S,maxSizeBottom:x,minSize:a.with(Math.min(C,a.width))}}(),u=function(){const C=e.left,w=-r.borderWidth+e.top+e.height,S=new Dt(e.width-r.borderHeight,o.height-e.top-e.height-r.verticalPadding);return{top:w,left:C,fit:S.height-t.height,maxSizeBottom:S,maxSizeTop:S,minSize:a.with(S.width)}}(),h=[d,c,u],g=(n=h.find(C=>C.fit>=0))!==null&&n!==void 0?n:h.sort((C,w)=>w.fit-C.fit)[0],f=e.top+e.height-r.borderHeight;let m,_=t.height;const v=Math.max(g.maxSizeTop.height,g.maxSizeBottom.height);_>v&&(_=v);let b;i?_<=g.maxSizeTop.height?(m=!0,b=g.maxSizeTop):(m=!1,b=g.maxSizeBottom):_<=g.maxSizeBottom.height?(m=!1,b=g.maxSizeBottom):(m=!0,b=g.maxSizeTop),this._applyTopLeft({left:g.left,top:m?g.top:f-_}),this.getDomNode().style.position="fixed",this._resizable.enableSashes(!m,g===d,m,g!==d),this._resizable.minSize=g.minSize,this._resizable.maxSize=b,this._resizable.layout(_,Math.min(b.width,t.width)),this.widget.layout(this._resizable.size.width,this._resizable.size.height)}_applyTopLeft(e){this._topLeft=e,this.getDomNode().style.left=`${this._topLeft.left}px`,this.getDomNode().style.top=`${this._topLeft.top}px`}}var Ol;(function(s){s[s.FILE=0]="FILE",s[s.FOLDER=1]="FOLDER",s[s.ROOT_FOLDER=2]="ROOT_FOLDER"})(Ol||(Ol={}));const Qye=/(?:\/|^)(?:([^\/]+)\/)?([^\/]+)$/;function gw(s,e,t,i){const n=i===Ol.ROOT_FOLDER?["rootfolder-icon"]:i===Ol.FOLDER?["folder-icon"]:["file-icon"];if(t){let o;if(t.scheme===it.data)o=Fu.parseMetaData(t).get(Fu.META_DATA_LABEL);else{const r=t.path.match(Qye);r?(o=fw(r[2].toLowerCase()),r[1]&&n.push(`${fw(r[1].toLowerCase())}-name-dir-icon`)):o=fw(t.authority.toLowerCase())}if(i===Ol.ROOT_FOLDER)n.push(`${o}-root-name-folder-icon`);else if(i===Ol.FOLDER)n.push(`${o}-name-folder-icon`);else{if(o){if(n.push(`${o}-name-file-icon`),n.push("name-file-icon"),o.length<=255){const a=o.split(".");for(let l=1;l<a.length;l++)n.push(`${a.slice(l).join(".")}-ext-file-icon`)}n.push("ext-file-icon")}const r=Jye(s,e,t);r&&n.push(`${fw(r)}-lang-file-icon`)}}return n}function Jye(s,e,t){if(!t)return null;let i=null;if(t.scheme===it.data){const o=Fu.parseMetaData(t).get(Fu.META_DATA_MIME);o&&(i=e.getLanguageIdByMimeType(o))}else{const n=s.getModel(t);n&&(i=n.getLanguageId())}return i&&i!==er?i:e.guessLanguageIdByFilepathOrFirstLine(t)}function fw(s){return s.replace(/[\11\12\14\15\40]/g,"/")}var eLe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},vE=function(s,e){return function(t,i){e(t,i,s)}},vc;function CK(s){return`suggest-aria-id:${s}`}const tLe=Ui("suggest-more-info",le.chevronRight,p("suggestMoreInfoIcon","Icon for more information in the suggest widget.")),iLe=new(vc=class{extract(e,t){if(e.textLabel.match(vc._regexStrict))return t[0]=e.textLabel,!0;if(e.completion.detail&&e.completion.detail.match(vc._regexStrict))return t[0]=e.completion.detail,!0;if(typeof e.completion.documentation=="string"){const i=vc._regexRelaxed.exec(e.completion.documentation);if(i&&(i.index===0||i.index+i[0].length===e.completion.documentation.length))return t[0]=i[0],!0}return!1}},vc._regexRelaxed=/(#([\da-fA-F]{3}){1,2}|(rgb|hsl)a\(\s*(\d{1,3}%?\s*,\s*){3}(1|0?\.\d+)\)|(rgb|hsl)\(\s*\d{1,3}%?(\s*,\s*\d{1,3}%?){2}\s*\))/,vc._regexStrict=new RegExp(`^${vc._regexRelaxed.source}$`,"i"),vc);let vR=class{constructor(e,t,i,n){this._editor=e,this._modelService=t,this._languageService=i,this._themeService=n,this._onDidToggleDetails=new W,this.onDidToggleDetails=this._onDidToggleDetails.event,this.templateId="suggestion"}dispose(){this._onDidToggleDetails.dispose()}renderTemplate(e){const t=new ie,i=e;i.classList.add("show-file-icons");const n=te(e,se(".icon")),o=te(n,se("span.colorspan")),r=te(e,se(".contents")),a=te(r,se(".main")),l=te(a,se(".icon-label.codicon")),d=te(a,se("span.left")),c=te(a,se("span.right")),u=new Hy(d,{supportHighlights:!0,supportIcons:!0});t.add(u);const h=te(d,se("span.signature-label")),g=te(d,se("span.qualifier-label")),f=te(c,se("span.details-label")),m=te(c,se("span.readMore"+Oe.asCSSSelector(tLe)));m.title=p("readMore","Read More");const _=()=>{const v=this._editor.getOptions(),b=v.get(50),C=b.getMassagedFontFamily(),w=b.fontFeatureSettings,S=v.get(118)||b.fontSize,x=v.get(119)||b.lineHeight,L=b.fontWeight,k=b.letterSpacing,I=`${S}px`,P=`${x}px`,$=`${k}px`;i.style.fontSize=I,i.style.fontWeight=L,i.style.letterSpacing=$,a.style.fontFamily=C,a.style.fontFeatureSettings=w,a.style.lineHeight=P,n.style.height=P,n.style.width=P,m.style.height=P,m.style.width=P};return _(),t.add(this._editor.onDidChangeConfiguration(v=>{(v.hasChanged(50)||v.hasChanged(118)||v.hasChanged(119))&&_()})),{root:i,left:d,right:c,icon:n,colorspan:o,iconLabel:u,iconContainer:l,parametersLabel:h,qualifierLabel:g,detailsLabel:f,readMore:m,disposables:t}}renderElement(e,t,i){const{completion:n}=e;i.root.id=CK(t),i.colorspan.style.backgroundColor="";const o={labelEscapeNewLines:!0,matches:CC(e.score)},r=[];if(n.kind===19&&iLe.extract(e,r))i.icon.className="icon customcolor",i.iconContainer.className="icon hide",i.colorspan.style.backgroundColor=r[0];else if(n.kind===20&&this._themeService.getFileIconTheme().hasFileIcons){i.icon.className="icon hide",i.iconContainer.className="icon hide";const a=gw(this._modelService,this._languageService,Pe.from({scheme:"fake",path:e.textLabel}),Ol.FILE),l=gw(this._modelService,this._languageService,Pe.from({scheme:"fake",path:n.detail}),Ol.FILE);o.extraClasses=a.length>l.length?a:l}else n.kind===23&&this._themeService.getFileIconTheme().hasFolderIcons?(i.icon.className="icon hide",i.iconContainer.className="icon hide",o.extraClasses=[gw(this._modelService,this._languageService,Pe.from({scheme:"fake",path:e.textLabel}),Ol.FOLDER),gw(this._modelService,this._languageService,Pe.from({scheme:"fake",path:n.detail}),Ol.FOLDER)].flat()):(i.icon.className="icon hide",i.iconContainer.className="",i.iconContainer.classList.add("suggest-icon",...Oe.asClassNameArray(y0.toIcon(n.kind))));n.tags&&n.tags.indexOf(1)>=0&&(o.extraClasses=(o.extraClasses||[]).concat(["deprecated"]),o.matches=[]),i.iconLabel.setLabel(e.textLabel,void 0,o),typeof n.label=="string"?(i.parametersLabel.textContent="",i.detailsLabel.textContent=bE(n.detail||""),i.root.classList.add("string-label")):(i.parametersLabel.textContent=bE(n.label.detail||""),i.detailsLabel.textContent=bE(n.label.description||""),i.root.classList.remove("string-label")),this._editor.getOption(117).showInlineDetails?go(i.detailsLabel):ks(i.detailsLabel),T4(e)?(i.right.classList.add("can-expand-details"),go(i.readMore),i.readMore.onmousedown=a=>{a.stopPropagation(),a.preventDefault()},i.readMore.onclick=a=>{a.stopPropagation(),a.preventDefault(),this._onDidToggleDetails.fire()}):(i.right.classList.remove("can-expand-details"),ks(i.readMore),i.readMore.onmousedown=null,i.readMore.onclick=null)}disposeTemplate(e){e.disposables.dispose()}};vR=eLe([vE(1,vi),vE(2,fi),vE(3,Cn)],vR);function bE(s){return s.replace(/\r\n|\r|\n/g,"")}var nLe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},pw=function(s,e){return function(t,i){e(t,i,s)}},Qf;R("editorSuggestWidget.background",{dark:Ri,light:Ri,hcDark:Ri,hcLight:Ri},p("editorSuggestWidgetBackground","Background color of the suggest widget."));R("editorSuggestWidget.border",{dark:Ml,light:Ml,hcDark:Ml,hcLight:Ml},p("editorSuggestWidgetBorder","Border color of the suggest widget."));const mw=R("editorSuggestWidget.foreground",{dark:$r,light:$r,hcDark:$r,hcLight:$r},p("editorSuggestWidgetForeground","Foreground color of the suggest widget."));R("editorSuggestWidget.selectedForeground",{dark:eg,light:eg,hcDark:eg,hcLight:eg},p("editorSuggestWidgetSelectedForeground","Foreground color of the selected entry in the suggest widget."));R("editorSuggestWidget.selectedIconForeground",{dark:dp,light:dp,hcDark:dp,hcLight:dp},p("editorSuggestWidgetSelectedIconForeground","Icon foreground color of the selected entry in the suggest widget."));const sLe=R("editorSuggestWidget.selectedBackground",{dark:tg,light:tg,hcDark:tg,hcLight:tg},p("editorSuggestWidgetSelectedBackground","Background color of the selected entry in the suggest widget."));R("editorSuggestWidget.highlightForeground",{dark:jr,light:jr,hcDark:jr,hcLight:jr},p("editorSuggestWidgetHighlightForeground","Color of the match highlights in the suggest widget."));R("editorSuggestWidget.focusHighlightForeground",{dark:h1,light:h1,hcDark:h1,hcLight:h1},p("editorSuggestWidgetFocusHighlightForeground","Color of the match highlights in the suggest widget when an item is focused."));R("editorSuggestWidgetStatus.foreground",{dark:Me(mw,.5),light:Me(mw,.5),hcDark:Me(mw,.5),hcLight:Me(mw,.5)},p("editorSuggestWidgetStatusForeground","Foreground color of the suggest widget status."));class oLe{constructor(e,t){this._service=e,this._key=`suggestWidget.size/${t.getEditorType()}/${t instanceof $u}`}restore(){var e;const t=(e=this._service.get(this._key,0))!==null&&e!==void 0?e:"";try{const i=JSON.parse(t);if(Dt.is(i))return Dt.lift(i)}catch{}}store(e){this._service.store(this._key,JSON.stringify(e),0,1)}reset(){this._service.remove(this._key,0)}}let Ob=Qf=class{constructor(e,t,i,n,o){this.editor=e,this._storageService=t,this._state=0,this._isAuto=!1,this._pendingLayout=new En,this._pendingShowDetails=new En,this._ignoreFocusEvents=!1,this._forceRenderingAbove=!1,this._explainMode=!1,this._showTimeout=new ea,this._disposables=new ie,this._onDidSelect=new Lg,this._onDidFocus=new Lg,this._onDidHide=new W,this._onDidShow=new W,this.onDidSelect=this._onDidSelect.event,this.onDidFocus=this._onDidFocus.event,this.onDidHide=this._onDidHide.event,this.onDidShow=this._onDidShow.event,this._onDetailsKeydown=new W,this.onDetailsKeyDown=this._onDetailsKeydown.event,this.element=new d4,this.element.domNode.classList.add("editor-widget","suggest-widget"),this._contentWidget=new rLe(this,e),this._persistedSize=new oLe(t,e);class r{constructor(g,f,m=!1,_=!1){this.persistedSize=g,this.currentSize=f,this.persistHeight=m,this.persistWidth=_}}let a;this._disposables.add(this.element.onDidWillResize(()=>{this._contentWidget.lockPreference(),a=new r(this._persistedSize.restore(),this.element.size)})),this._disposables.add(this.element.onDidResize(h=>{var g,f,m,_;if(this._resize(h.dimension.width,h.dimension.height),a&&(a.persistHeight=a.persistHeight||!!h.north||!!h.south,a.persistWidth=a.persistWidth||!!h.east||!!h.west),!!h.done){if(a){const{itemHeight:v,defaultSize:b}=this.getLayoutInfo(),C=Math.round(v/2);let{width:w,height:S}=this.element.size;(!a.persistHeight||Math.abs(a.currentSize.height-S)<=C)&&(S=(f=(g=a.persistedSize)===null||g===void 0?void 0:g.height)!==null&&f!==void 0?f:b.height),(!a.persistWidth||Math.abs(a.currentSize.width-w)<=C)&&(w=(_=(m=a.persistedSize)===null||m===void 0?void 0:m.width)!==null&&_!==void 0?_:b.width),this._persistedSize.store(new Dt(w,S))}this._contentWidget.unlockPreference(),a=void 0}})),this._messageElement=te(this.element.domNode,se(".message")),this._listElement=te(this.element.domNode,se(".tree"));const l=this._disposables.add(o.createInstance(_R,this.editor));l.onDidClose(this.toggleDetails,this,this._disposables),this._details=new Xye(l,this.editor);const d=()=>this.element.domNode.classList.toggle("no-icons",!this.editor.getOption(117).showIcons);d();const c=o.createInstance(vR,this.editor);this._disposables.add(c),this._disposables.add(c.onDidToggleDetails(()=>this.toggleDetails())),this._list=new na("SuggestWidget",this._listElement,{getHeight:h=>this.getLayoutInfo().itemHeight,getTemplateId:h=>"suggestion"},[c],{alwaysConsumeMouseWheel:!0,useShadows:!1,mouseSupport:!1,multipleSelectionSupport:!1,accessibilityProvider:{getRole:()=>"option",getWidgetAriaLabel:()=>p("suggest","Suggest"),getWidgetRole:()=>"listbox",getAriaLabel:h=>{let g=h.textLabel;if(typeof h.completion.label!="string"){const{detail:v,description:b}=h.completion.label;v&&b?g=p("label.full","{0} {1}, {2}",g,v,b):v?g=p("label.detail","{0} {1}",g,v):b&&(g=p("label.desc","{0}, {1}",g,b))}if(!h.isResolved||!this._isDetailsVisible())return g;const{documentation:f,detail:m}=h.completion,_=xg("{0}{1}",m||"",f?typeof f=="string"?f:f.value:"");return p("ariaCurrenttSuggestionReadDetails","{0}, docs: {1}",g,_)}}}),this._list.style(c_({listInactiveFocusBackground:sLe,listInactiveFocusOutline:ai})),this._status=o.createInstance(mR,this.element.domNode,bu);const u=()=>this.element.domNode.classList.toggle("with-status-bar",this.editor.getOption(117).showStatusBar);u(),this._disposables.add(n.onDidColorThemeChange(h=>this._onThemeChange(h))),this._onThemeChange(n.getColorTheme()),this._disposables.add(this._list.onMouseDown(h=>this._onListMouseDownOrTap(h))),this._disposables.add(this._list.onTap(h=>this._onListMouseDownOrTap(h))),this._disposables.add(this._list.onDidChangeSelection(h=>this._onListSelection(h))),this._disposables.add(this._list.onDidChangeFocus(h=>this._onListFocus(h))),this._disposables.add(this.editor.onDidChangeCursorSelection(()=>this._onCursorSelectionChanged())),this._disposables.add(this.editor.onDidChangeConfiguration(h=>{h.hasChanged(117)&&(u(),d())})),this._ctxSuggestWidgetVisible=st.Visible.bindTo(i),this._ctxSuggestWidgetDetailsVisible=st.DetailsVisible.bindTo(i),this._ctxSuggestWidgetMultipleSuggestions=st.MultipleSuggestions.bindTo(i),this._ctxSuggestWidgetHasFocusedSuggestion=st.HasFocusedSuggestion.bindTo(i),this._disposables.add(Pi(this._details.widget.domNode,"keydown",h=>{this._onDetailsKeydown.fire(h)})),this._disposables.add(this.editor.onMouseDown(h=>this._onEditorMouseDown(h)))}dispose(){var e;this._details.widget.dispose(),this._details.dispose(),this._list.dispose(),this._status.dispose(),this._disposables.dispose(),(e=this._loadingTimeout)===null||e===void 0||e.dispose(),this._pendingLayout.dispose(),this._pendingShowDetails.dispose(),this._showTimeout.dispose(),this._contentWidget.dispose(),this.element.dispose()}_onEditorMouseDown(e){this._details.widget.domNode.contains(e.target.element)?this._details.widget.domNode.focus():this.element.domNode.contains(e.target.element)&&this.editor.focus()}_onCursorSelectionChanged(){this._state!==0&&this._contentWidget.layout()}_onListMouseDownOrTap(e){typeof e.element>"u"||typeof e.index>"u"||(e.browserEvent.preventDefault(),e.browserEvent.stopPropagation(),this._select(e.element,e.index))}_onListSelection(e){e.elements.length&&this._select(e.elements[0],e.indexes[0])}_select(e,t){const i=this._completionModel;i&&(this._onDidSelect.fire({item:e,index:t,model:i}),this.editor.focus())}_onThemeChange(e){this._details.widget.borderWidth=Oa(e.type)?2:1}_onListFocus(e){var t;if(this._ignoreFocusEvents)return;if(!e.elements.length){this._currentSuggestionDetails&&(this._currentSuggestionDetails.cancel(),this._currentSuggestionDetails=void 0,this._focusedItem=void 0),this.editor.setAriaOptions({activeDescendant:void 0}),this._ctxSuggestWidgetHasFocusedSuggestion.set(!1);return}if(!this._completionModel)return;this._ctxSuggestWidgetHasFocusedSuggestion.set(!0);const i=e.elements[0],n=e.indexes[0];i!==this._focusedItem&&((t=this._currentSuggestionDetails)===null||t===void 0||t.cancel(),this._currentSuggestionDetails=void 0,this._focusedItem=i,this._list.reveal(n),this._currentSuggestionDetails=gn(async o=>{const r=Eu(()=>{this._isDetailsVisible()&&this.showDetails(!0)},250),a=o.onCancellationRequested(()=>r.dispose());try{return await i.resolve(o)}finally{r.dispose(),a.dispose()}}),this._currentSuggestionDetails.then(()=>{n>=this._list.length||i!==this._list.element(n)||(this._ignoreFocusEvents=!0,this._list.splice(n,1,[i]),this._list.setFocus([n]),this._ignoreFocusEvents=!1,this._isDetailsVisible()?this.showDetails(!1):this.element.domNode.classList.remove("docs-side"),this.editor.setAriaOptions({activeDescendant:CK(n)}))}).catch(et)),this._onDidFocus.fire({item:i,index:n,model:this._completionModel})}_setState(e){if(this._state!==e)switch(this._state=e,this.element.domNode.classList.toggle("frozen",e===4),this.element.domNode.classList.remove("message"),e){case 0:ks(this._messageElement,this._listElement,this._status.element),this._details.hide(!0),this._status.hide(),this._contentWidget.hide(),this._ctxSuggestWidgetVisible.reset(),this._ctxSuggestWidgetMultipleSuggestions.reset(),this._ctxSuggestWidgetHasFocusedSuggestion.reset(),this._showTimeout.cancel(),this.element.domNode.classList.remove("visible"),this._list.splice(0,this._list.length),this._focusedItem=void 0,this._cappedHeight=void 0,this._explainMode=!1;break;case 1:this.element.domNode.classList.add("message"),this._messageElement.textContent=Qf.LOADING_MESSAGE,ks(this._listElement,this._status.element),go(this._messageElement),this._details.hide(),this._show(),this._focusedItem=void 0,Au(Qf.LOADING_MESSAGE);break;case 2:this.element.domNode.classList.add("message"),this._messageElement.textContent=Qf.NO_SUGGESTIONS_MESSAGE,ks(this._listElement,this._status.element),go(this._messageElement),this._details.hide(),this._show(),this._focusedItem=void 0,Au(Qf.NO_SUGGESTIONS_MESSAGE);break;case 3:ks(this._messageElement),go(this._listElement,this._status.element),this._show();break;case 4:ks(this._messageElement),go(this._listElement,this._status.element),this._show();break;case 5:ks(this._messageElement),go(this._listElement,this._status.element),this._details.show(),this._show();break}}_show(){this._status.show(),this._contentWidget.show(),this._layout(this._persistedSize.restore()),this._ctxSuggestWidgetVisible.set(!0),this._showTimeout.cancelAndSet(()=>{this.element.domNode.classList.add("visible"),this._onDidShow.fire(this)},100)}showTriggered(e,t){this._state===0&&(this._contentWidget.setPosition(this.editor.getPosition()),this._isAuto=!!e,this._isAuto||(this._loadingTimeout=Eu(()=>this._setState(1),t)))}showSuggestions(e,t,i,n,o){var r,a;if(this._contentWidget.setPosition(this.editor.getPosition()),(r=this._loadingTimeout)===null||r===void 0||r.dispose(),(a=this._currentSuggestionDetails)===null||a===void 0||a.cancel(),this._currentSuggestionDetails=void 0,this._completionModel!==e&&(this._completionModel=e),i&&this._state!==2&&this._state!==0){this._setState(4);return}const l=this._completionModel.items.length,d=l===0;if(this._ctxSuggestWidgetMultipleSuggestions.set(l>1),d){this._setState(n?0:2),this._completionModel=void 0;return}this._focusedItem=void 0,this._onDidFocus.pause(),this._onDidSelect.pause();try{this._list.splice(0,this._list.length,this._completionModel.items),this._setState(i?4:3),this._list.reveal(t,0),this._list.setFocus(o?[]:[t])}finally{this._onDidFocus.resume(),this._onDidSelect.resume()}this._pendingLayout.value=OS(Xe(this.element.domNode),()=>{this._pendingLayout.clear(),this._layout(this.element.size),this._details.widget.domNode.classList.remove("focused")})}focusSelected(){this._list.length>0&&this._list.setFocus([0])}selectNextPage(){switch(this._state){case 0:return!1;case 5:return this._details.widget.pageDown(),!0;case 1:return!this._isAuto;default:return this._list.focusNextPage(),!0}}selectNext(){switch(this._state){case 0:return!1;case 1:return!this._isAuto;default:return this._list.focusNext(1,!0),!0}}selectLast(){switch(this._state){case 0:return!1;case 5:return this._details.widget.scrollBottom(),!0;case 1:return!this._isAuto;default:return this._list.focusLast(),!0}}selectPreviousPage(){switch(this._state){case 0:return!1;case 5:return this._details.widget.pageUp(),!0;case 1:return!this._isAuto;default:return this._list.focusPreviousPage(),!0}}selectPrevious(){switch(this._state){case 0:return!1;case 1:return!this._isAuto;default:return this._list.focusPrevious(1,!0),!1}}selectFirst(){switch(this._state){case 0:return!1;case 5:return this._details.widget.scrollTop(),!0;case 1:return!this._isAuto;default:return this._list.focusFirst(),!0}}getFocusedItem(){if(this._state!==0&&this._state!==2&&this._state!==1&&this._completionModel&&this._list.getFocus().length>0)return{item:this._list.getFocusedElements()[0],index:this._list.getFocus()[0],model:this._completionModel}}toggleDetailsFocus(){this._state===5?(this._setState(3),this._details.widget.domNode.classList.remove("focused")):this._state===3&&this._isDetailsVisible()&&(this._setState(5),this._details.widget.domNode.classList.add("focused"))}toggleDetails(){this._isDetailsVisible()?(this._pendingShowDetails.clear(),this._ctxSuggestWidgetDetailsVisible.set(!1),this._setDetailsVisible(!1),this._details.hide(),this.element.domNode.classList.remove("shows-details")):(T4(this._list.getFocusedElements()[0])||this._explainMode)&&(this._state===3||this._state===5||this._state===4)&&(this._ctxSuggestWidgetDetailsVisible.set(!0),this._setDetailsVisible(!0),this.showDetails(!1))}showDetails(e){this._pendingShowDetails.value=OS(Xe(this.element.domNode),()=>{this._pendingShowDetails.clear(),this._details.show(),e?this._details.widget.renderLoading():this._details.widget.renderItem(this._list.getFocusedElements()[0],this._explainMode),this._positionDetails(),this.editor.focus(),this.element.domNode.classList.add("shows-details")})}toggleExplainMode(){this._list.getFocusedElements()[0]&&(this._explainMode=!this._explainMode,this._isDetailsVisible()?this.showDetails(!1):this.toggleDetails())}resetPersistedSize(){this._persistedSize.reset()}hideWidget(){var e;this._pendingLayout.clear(),this._pendingShowDetails.clear(),(e=this._loadingTimeout)===null||e===void 0||e.dispose(),this._setState(0),this._onDidHide.fire(this),this.element.clearSashHoverState();const t=this._persistedSize.restore(),i=Math.ceil(this.getLayoutInfo().itemHeight*4.3);t&&t.height<i&&this._persistedSize.store(t.with(void 0,i))}isFrozen(){return this._state===4}_afterRender(e){if(e===null){this._isDetailsVisible()&&this._details.hide();return}this._state===2||this._state===1||(this._isDetailsVisible()&&this._details.show(),this._positionDetails())}_layout(e){var t,i,n;if(!this.editor.hasModel()||!this.editor.getDomNode())return;const o=Nu(this.element.domNode.ownerDocument.body),r=this.getLayoutInfo();e||(e=r.defaultSize);let a=e.height,l=e.width;if(this._status.element.style.height=`${r.itemHeight}px`,this._state===2||this._state===1)a=r.itemHeight+r.borderHeight,l=r.defaultSize.width/2,this.element.enableSashes(!1,!1,!1,!1),this.element.minSize=this.element.maxSize=new Dt(l,a),this._contentWidget.setPreference(2);else{const d=o.width-r.borderHeight-2*r.horizontalPadding;l>d&&(l=d);const c=this._completionModel?this._completionModel.stats.pLabelLen*r.typicalHalfwidthCharacterWidth:l,u=r.statusBarHeight+this._list.contentHeight+r.borderHeight,h=r.itemHeight+r.statusBarHeight,g=ln(this.editor.getDomNode()),f=this.editor.getScrolledVisiblePosition(this.editor.getPosition()),m=g.top+f.top+f.height,_=Math.min(o.height-m-r.verticalPadding,u),v=g.top+f.top-r.verticalPadding,b=Math.min(v,u);let C=Math.min(Math.max(b,_)+r.borderHeight,u);a===((t=this._cappedHeight)===null||t===void 0?void 0:t.capped)&&(a=this._cappedHeight.wanted),a<h&&(a=h),a>C&&(a=C),a>_||this._forceRenderingAbove&&v>150?(this._contentWidget.setPreference(1),this.element.enableSashes(!0,!0,!1,!1),C=b):(this._contentWidget.setPreference(2),this.element.enableSashes(!1,!0,!0,!1),C=_),this.element.preferredSize=new Dt(c,r.defaultSize.height),this.element.maxSize=new Dt(d,C),this.element.minSize=new Dt(220,h),this._cappedHeight=a===u?{wanted:(n=(i=this._cappedHeight)===null||i===void 0?void 0:i.wanted)!==null&&n!==void 0?n:e.height,capped:a}:void 0}this._resize(l,a)}_resize(e,t){const{width:i,height:n}=this.element.maxSize;e=Math.min(i,e),t=Math.min(n,t);const{statusBarHeight:o}=this.getLayoutInfo();this._list.layout(t-o,e),this._listElement.style.height=`${t-o}px`,this.element.layout(t,e),this._contentWidget.layout(),this._positionDetails()}_positionDetails(){var e;this._isDetailsVisible()&&this._details.placeAtAnchor(this.element.domNode,((e=this._contentWidget.getPosition())===null||e===void 0?void 0:e.preference[0])===2)}getLayoutInfo(){const e=this.editor.getOption(50),t=co(this.editor.getOption(119)||e.lineHeight,8,1e3),i=!this.editor.getOption(117).showStatusBar||this._state===2||this._state===1?0:t,n=this._details.widget.borderWidth,o=2*n;return{itemHeight:t,statusBarHeight:i,borderWidth:n,borderHeight:o,typicalHalfwidthCharacterWidth:e.typicalHalfwidthCharacterWidth,verticalPadding:22,horizontalPadding:14,defaultSize:new Dt(430,i+12*t+o)}}_isDetailsVisible(){return this._storageService.getBoolean("expandSuggestionDocs",0,!1)}_setDetailsVisible(e){this._storageService.store("expandSuggestionDocs",e,0,0)}forceRenderingAbove(){this._forceRenderingAbove||(this._forceRenderingAbove=!0,this._layout(this._persistedSize.restore()))}stopForceRenderingAbove(){this._forceRenderingAbove=!1}};Ob.LOADING_MESSAGE=p("suggestWidget.loading","Loading...");Ob.NO_SUGGESTIONS_MESSAGE=p("suggestWidget.noSuggestions","No suggestions.");Ob=Qf=nLe([pw(1,sa),pw(2,je),pw(3,Cn),pw(4,We)],Ob);class rLe{constructor(e,t){this._widget=e,this._editor=t,this.allowEditorOverflow=!0,this.suppressMouseDown=!1,this._preferenceLocked=!1,this._added=!1,this._hidden=!1}dispose(){this._added&&(this._added=!1,this._editor.removeContentWidget(this))}getId(){return"editor.widget.suggestWidget"}getDomNode(){return this._widget.element.domNode}show(){this._hidden=!1,this._added||(this._added=!0,this._editor.addContentWidget(this))}hide(){this._hidden||(this._hidden=!0,this.layout())}layout(){this._editor.layoutContentWidget(this)}getPosition(){return this._hidden||!this._position||!this._preference?null:{position:this._position,preference:[this._preference]}}beforeRender(){const{height:e,width:t}=this._widget.element.size,{borderWidth:i,horizontalPadding:n}=this._widget.getLayoutInfo();return new Dt(t+2*i+n,e+2*i)}afterRender(e){this._widget._afterRender(e)}setPreference(e){this._preferenceLocked||(this._preference=e)}lockPreference(){this._preferenceLocked=!0}unlockPreference(){this._preferenceLocked=!1}setPosition(e){this._position=e}}var aLe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Wf=function(s,e){return function(t,i){e(t,i,s)}},bR;class lLe{constructor(e,t){if(this._model=e,this._position=t,e.getLineMaxColumn(t.lineNumber)!==t.column){const n=e.getOffsetAt(t),o=e.getPositionAt(n+1);this._marker=e.deltaDecorations([],[{range:D.fromPositions(t,o),options:{description:"suggest-line-suffix",stickiness:1}}])}}dispose(){this._marker&&!this._model.isDisposed()&&this._model.deltaDecorations(this._marker,[])}delta(e){if(this._model.isDisposed()||this._position.lineNumber!==e.lineNumber)return 0;if(this._marker){const t=this._model.getDecorationRange(this._marker[0]);return this._model.getOffsetAt(t.getStartPosition())-this._model.getOffsetAt(e)}else return this._model.getLineMaxColumn(e.lineNumber)-e.column}}let qr=bR=class{static get(e){return e.getContribution(bR.ID)}constructor(e,t,i,n,o,r,a){this._memoryService=t,this._commandService=i,this._contextKeyService=n,this._instantiationService=o,this._logService=r,this._telemetryService=a,this._lineSuffix=new En,this._toDispose=new ie,this._selectors=new dLe(u=>u.priority),this._onWillInsertSuggestItem=new W,this.onWillInsertSuggestItem=this._onWillInsertSuggestItem.event,this.editor=e,this.model=o.createInstance(pR,this.editor),this._selectors.register({priority:0,select:(u,h,g)=>this._memoryService.select(u,h,g)});const l=st.InsertMode.bindTo(n);l.set(e.getOption(117).insertMode),this._toDispose.add(this.model.onDidTrigger(()=>l.set(e.getOption(117).insertMode))),this.widget=this._toDispose.add(new Wk(Xe(e.getDomNode()),()=>{const u=this._instantiationService.createInstance(Ob,this.editor);this._toDispose.add(u),this._toDispose.add(u.onDidSelect(_=>this._insertSuggestion(_,0),this));const h=new $ye(this.editor,u,this.model,_=>this._insertSuggestion(_,2));this._toDispose.add(h);const g=st.MakesTextEdit.bindTo(this._contextKeyService),f=st.HasInsertAndReplaceRange.bindTo(this._contextKeyService),m=st.CanResolve.bindTo(this._contextKeyService);return this._toDispose.add(Fe(()=>{g.reset(),f.reset(),m.reset()})),this._toDispose.add(u.onDidFocus(({item:_})=>{const v=this.editor.getPosition(),b=_.editStart.column,C=v.column;let w=!0;this.editor.getOption(1)==="smart"&&this.model.state===2&&!_.completion.additionalTextEdits&&!(_.completion.insertTextRules&4)&&C-b===_.completion.insertText.length&&(w=this.editor.getModel().getValueInRange({startLineNumber:v.lineNumber,startColumn:b,endLineNumber:v.lineNumber,endColumn:C})!==_.completion.insertText),g.set(w),f.set(!H.equals(_.editInsertEnd,_.editReplaceEnd)),m.set(!!_.provider.resolveCompletionItem||!!_.completion.documentation||_.completion.detail!==_.completion.label)})),this._toDispose.add(u.onDetailsKeyDown(_=>{if(_.toKeyCodeChord().equals(new ec(!0,!1,!1,!1,33))||bt&&_.toKeyCodeChord().equals(new ec(!1,!1,!1,!0,33))){_.stopPropagation();return}_.toKeyCodeChord().isModifierKey()||this.editor.focus()})),u})),this._overtypingCapturer=this._toDispose.add(new Wk(Xe(e.getDomNode()),()=>this._toDispose.add(new FD(this.editor,this.model)))),this._alternatives=this._toDispose.add(new Wk(Xe(e.getDomNode()),()=>this._toDispose.add(new Yg(this.editor,this._contextKeyService)))),this._toDispose.add(o.createInstance(Pb,e)),this._toDispose.add(this.model.onDidTrigger(u=>{this.widget.value.showTriggered(u.auto,u.shy?250:50),this._lineSuffix.value=new lLe(this.editor.getModel(),u.position)})),this._toDispose.add(this.model.onDidSuggest(u=>{if(u.triggerOptions.shy)return;let h=-1;for(const f of this._selectors.itemsOrderedByPriorityDesc)if(h=f.select(this.editor.getModel(),this.editor.getPosition(),u.completionModel.items),h!==-1)break;h===-1&&(h=0);let g=!1;if(u.triggerOptions.auto){const f=this.editor.getOption(117);f.selectionMode==="never"||f.selectionMode==="always"?g=f.selectionMode==="never":f.selectionMode==="whenTriggerCharacter"?g=u.triggerOptions.triggerKind!==1:f.selectionMode==="whenQuickSuggestion"&&(g=u.triggerOptions.triggerKind===1&&!u.triggerOptions.refilter)}this.widget.value.showSuggestions(u.completionModel,h,u.isFrozen,u.triggerOptions.auto,g)})),this._toDispose.add(this.model.onDidCancel(u=>{u.retrigger||this.widget.value.hideWidget()})),this._toDispose.add(this.editor.onDidBlurEditorWidget(()=>{this.model.cancel(),this.model.clear()}));const d=st.AcceptSuggestionsOnEnter.bindTo(n),c=()=>{const u=this.editor.getOption(1);d.set(u==="on"||u==="smart")};this._toDispose.add(this.editor.onDidChangeConfiguration(()=>c())),c()}dispose(){this._alternatives.dispose(),this._toDispose.dispose(),this.widget.dispose(),this.model.dispose(),this._lineSuffix.dispose(),this._onWillInsertSuggestItem.dispose()}_insertSuggestion(e,t){if(!e||!e.item){this._alternatives.value.reset(),this.model.cancel(),this.model.clear();return}if(!this.editor.hasModel())return;const i=Hn.get(this.editor);if(!i)return;this._onWillInsertSuggestItem.fire({item:e.item});const n=this.editor.getModel(),o=n.getAlternativeVersionId(),{item:r}=e,a=[],l=new Yi;t&1||this.editor.pushUndoStop();const d=this.getOverwriteInfo(r,!!(t&8));this._memoryService.memorize(n,this.editor.getPosition(),r);const c=r.isResolved;let u=-1,h=-1;if(Array.isArray(r.completion.additionalTextEdits)){this.model.cancel();const f=$a.capture(this.editor);this.editor.executeEdits("suggestController.additionalTextEdits.sync",r.completion.additionalTextEdits.map(m=>_i.replaceMove(D.lift(m.range),m.text))),f.restoreRelativeVerticalPositionOfCursor(this.editor)}else if(!c){const f=new cs;let m;const _=n.onDidChangeContent(w=>{if(w.isFlush){l.cancel(),_.dispose();return}for(const S of w.changes){const x=D.getEndPosition(S.range);(!m||H.isBefore(x,m))&&(m=x)}}),v=t;t|=2;let b=!1;const C=this.editor.onWillType(()=>{C.dispose(),b=!0,v&2||this.editor.pushUndoStop()});a.push(r.resolve(l.token).then(()=>{if(!r.completion.additionalTextEdits||l.token.isCancellationRequested)return;if(m&&r.completion.additionalTextEdits.some(S=>H.isBefore(m,D.getStartPosition(S.range))))return!1;b&&this.editor.pushUndoStop();const w=$a.capture(this.editor);return this.editor.executeEdits("suggestController.additionalTextEdits.async",r.completion.additionalTextEdits.map(S=>_i.replaceMove(D.lift(S.range),S.text))),w.restoreRelativeVerticalPositionOfCursor(this.editor),(b||!(v&2))&&this.editor.pushUndoStop(),!0}).then(w=>{this._logService.trace("[suggest] async resolving of edits DONE (ms, applied?)",f.elapsed(),w),h=w===!0?1:w===!1?0:-2}).finally(()=>{_.dispose(),C.dispose()}))}let{insertText:g}=r.completion;if(r.completion.insertTextRules&4||(g=Um.escape(g)),this.model.cancel(),i.insert(g,{overwriteBefore:d.overwriteBefore,overwriteAfter:d.overwriteAfter,undoStopBefore:!1,undoStopAfter:!1,adjustWhitespace:!(r.completion.insertTextRules&1),clipboardText:e.model.clipboardText,overtypingCapturer:this._overtypingCapturer.value}),t&2||this.editor.pushUndoStop(),r.completion.command)if(r.completion.command.id===zC.id)this.model.trigger({auto:!0,retrigger:!0});else{const f=new cs;a.push(this._commandService.executeCommand(r.completion.command.id,...r.completion.command.arguments?[...r.completion.command.arguments]:[]).catch(m=>{r.completion.extensionId?Zi(m):et(m)}).finally(()=>{u=f.elapsed()}))}t&4&&this._alternatives.value.set(e,f=>{for(l.cancel();n.canUndo();){o!==n.getAlternativeVersionId()&&n.undo(),this._insertSuggestion(f,3|(t&8?8:0));break}}),this._alertCompletionItem(r),Promise.all(a).finally(()=>{this._reportSuggestionAcceptedTelemetry(r,n,c,u,h),this.model.clear(),l.dispose()})}_reportSuggestionAcceptedTelemetry(e,t,i,n,o){var r,a,l;Math.floor(Math.random()*100)!==0&&this._telemetryService.publicLog2("suggest.acceptedSuggestion",{extensionId:(a=(r=e.extensionId)===null||r===void 0?void 0:r.value)!==null&&a!==void 0?a:"unknown",providerId:(l=e.provider._debugDisplayName)!==null&&l!==void 0?l:"unknown",kind:e.completion.kind,basenameHash:XA(kr(t.uri)).toString(16),languageId:t.getLanguageId(),fileExtension:Ple(t.uri),resolveInfo:e.provider.resolveCompletionItem?i?1:0:-1,resolveDuration:e.resolveDuration,commandDuration:n,additionalEditsAsync:o})}getOverwriteInfo(e,t){zt(this.editor.hasModel());let i=this.editor.getOption(117).insertMode==="replace";t&&(i=!i);const n=e.position.column-e.editStart.column,o=(i?e.editReplaceEnd.column:e.editInsertEnd.column)-e.position.column,r=this.editor.getPosition().column-e.position.column,a=this._lineSuffix.value?this._lineSuffix.value.delta(this.editor.getPosition()):0;return{overwriteBefore:n+r,overwriteAfter:o+a}}_alertCompletionItem(e){if(as(e.completion.additionalTextEdits)){const t=p("aria.alert.snippet","Accepting '{0}' made {1} additional edits",e.textLabel,e.completion.additionalTextEdits.length);Lo(t)}}triggerSuggest(e,t,i){this.editor.hasModel()&&(this.model.trigger({auto:t??!1,completionOptions:{providerFilter:e,kindFilter:i?new Set:void 0}}),this.editor.revealPosition(this.editor.getPosition(),0),this.editor.focus())}triggerSuggestAndAcceptBest(e){if(!this.editor.hasModel())return;const t=this.editor.getPosition(),i=()=>{t.equals(this.editor.getPosition())&&this._commandService.executeCommand(e.fallback)},n=o=>{if(o.completion.insertTextRules&4||o.completion.additionalTextEdits)return!0;const r=this.editor.getPosition(),a=o.editStart.column,l=r.column;return l-a!==o.completion.insertText.length?!0:this.editor.getModel().getValueInRange({startLineNumber:r.lineNumber,startColumn:a,endLineNumber:r.lineNumber,endColumn:l})!==o.completion.insertText};ge.once(this.model.onDidTrigger)(o=>{const r=[];ge.any(this.model.onDidTrigger,this.model.onDidCancel)(()=>{Bt(r),i()},void 0,r),this.model.onDidSuggest(({completionModel:a})=>{if(Bt(r),a.items.length===0){i();return}const l=this._memoryService.select(this.editor.getModel(),this.editor.getPosition(),a.items),d=a.items[l];if(!n(d)){i();return}this.editor.pushUndoStop(),this._insertSuggestion({index:l,item:d,model:a},7)},void 0,r)}),this.model.trigger({auto:!1,shy:!0}),this.editor.revealPosition(t,0),this.editor.focus()}acceptSelectedSuggestion(e,t){const i=this.widget.value.getFocusedItem();let n=0;e&&(n|=4),t&&(n|=8),this._insertSuggestion(i,n)}acceptNextSuggestion(){this._alternatives.value.next()}acceptPrevSuggestion(){this._alternatives.value.prev()}cancelSuggestWidget(){this.model.cancel(),this.model.clear(),this.widget.value.hideWidget()}focusSuggestion(){this.widget.value.focusSelected()}selectNextSuggestion(){this.widget.value.selectNext()}selectNextPageSuggestion(){this.widget.value.selectNextPage()}selectLastSuggestion(){this.widget.value.selectLast()}selectPrevSuggestion(){this.widget.value.selectPrevious()}selectPrevPageSuggestion(){this.widget.value.selectPreviousPage()}selectFirstSuggestion(){this.widget.value.selectFirst()}toggleSuggestionDetails(){this.widget.value.toggleDetails()}toggleExplainMode(){this.widget.value.toggleExplainMode()}toggleSuggestionFocus(){this.widget.value.toggleDetailsFocus()}resetWidgetSize(){this.widget.value.resetPersistedSize()}forceRenderingAbove(){this.widget.value.forceRenderingAbove()}stopForceRenderingAbove(){this.widget.isInitialized&&this.widget.value.stopForceRenderingAbove()}registerSelector(e){return this._selectors.register(e)}};qr.ID="editor.contrib.suggestController";qr=bR=aLe([Wf(1,OD),Wf(2,Ei),Wf(3,je),Wf(4,We),Wf(5,ko),Wf(6,Do)],qr);class dLe{constructor(e){this.prioritySelector=e,this._items=new Array}register(e){if(this._items.indexOf(e)!==-1)throw new Error("Value is already registered");return this._items.push(e),this._items.sort((t,i)=>this.prioritySelector(i)-this.prioritySelector(t)),{dispose:()=>{const t=this._items.indexOf(e);t>=0&&this._items.splice(t,1)}}}get itemsOrderedByPriorityDesc(){return this._items}}class zC extends we{constructor(){super({id:zC.id,label:p("suggest.trigger.label","Trigger Suggest"),alias:"Trigger Suggest",precondition:ee.and(T.writable,T.hasCompletionItemProvider,st.Visible.toNegated()),kbOpts:{kbExpr:T.textInputFocus,primary:2058,secondary:[2087],mac:{primary:266,secondary:[521,2087]},weight:100}})}run(e,t,i){const n=qr.get(t);if(!n)return;let o;i&&typeof i=="object"&&i.auto===!0&&(o=!0),n.triggerSuggest(void 0,o,void 0)}}zC.id="editor.action.triggerSuggest";Lt(qr.ID,qr,2);re(zC);const or=190,zs=Nn.bindToContribution(qr.get);ue(new zs({id:"acceptSelectedSuggestion",precondition:ee.and(st.Visible,st.HasFocusedSuggestion),handler(s){s.acceptSelectedSuggestion(!0,!1)},kbOpts:[{primary:2,kbExpr:ee.and(st.Visible,T.textInputFocus),weight:or},{primary:3,kbExpr:ee.and(st.Visible,T.textInputFocus,st.AcceptSuggestionsOnEnter,st.MakesTextEdit),weight:or}],menuOpts:[{menuId:bu,title:p("accept.insert","Insert"),group:"left",order:1,when:st.HasInsertAndReplaceRange.toNegated()},{menuId:bu,title:p("accept.insert","Insert"),group:"left",order:1,when:ee.and(st.HasInsertAndReplaceRange,st.InsertMode.isEqualTo("insert"))},{menuId:bu,title:p("accept.replace","Replace"),group:"left",order:1,when:ee.and(st.HasInsertAndReplaceRange,st.InsertMode.isEqualTo("replace"))}]}));ue(new zs({id:"acceptAlternativeSelectedSuggestion",precondition:ee.and(st.Visible,T.textInputFocus,st.HasFocusedSuggestion),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:1027,secondary:[1026]},handler(s){s.acceptSelectedSuggestion(!1,!0)},menuOpts:[{menuId:bu,group:"left",order:2,when:ee.and(st.HasInsertAndReplaceRange,st.InsertMode.isEqualTo("insert")),title:p("accept.replace","Replace")},{menuId:bu,group:"left",order:2,when:ee.and(st.HasInsertAndReplaceRange,st.InsertMode.isEqualTo("replace")),title:p("accept.insert","Insert")}]}));Ct.registerCommandAlias("acceptSelectedSuggestionOnEnter","acceptSelectedSuggestion");ue(new zs({id:"hideSuggestWidget",precondition:st.Visible,handler:s=>s.cancelSuggestWidget(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:9,secondary:[1033]}}));ue(new zs({id:"selectNextSuggestion",precondition:ee.and(st.Visible,ee.or(st.MultipleSuggestions,st.HasFocusedSuggestion.negate())),handler:s=>s.selectNextSuggestion(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:18,secondary:[2066],mac:{primary:18,secondary:[2066,300]}}}));ue(new zs({id:"selectNextPageSuggestion",precondition:ee.and(st.Visible,ee.or(st.MultipleSuggestions,st.HasFocusedSuggestion.negate())),handler:s=>s.selectNextPageSuggestion(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:12,secondary:[2060]}}));ue(new zs({id:"selectLastSuggestion",precondition:ee.and(st.Visible,ee.or(st.MultipleSuggestions,st.HasFocusedSuggestion.negate())),handler:s=>s.selectLastSuggestion()}));ue(new zs({id:"selectPrevSuggestion",precondition:ee.and(st.Visible,ee.or(st.MultipleSuggestions,st.HasFocusedSuggestion.negate())),handler:s=>s.selectPrevSuggestion(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:16,secondary:[2064],mac:{primary:16,secondary:[2064,302]}}}));ue(new zs({id:"selectPrevPageSuggestion",precondition:ee.and(st.Visible,ee.or(st.MultipleSuggestions,st.HasFocusedSuggestion.negate())),handler:s=>s.selectPrevPageSuggestion(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:11,secondary:[2059]}}));ue(new zs({id:"selectFirstSuggestion",precondition:ee.and(st.Visible,ee.or(st.MultipleSuggestions,st.HasFocusedSuggestion.negate())),handler:s=>s.selectFirstSuggestion()}));ue(new zs({id:"focusSuggestion",precondition:ee.and(st.Visible,st.HasFocusedSuggestion.negate()),handler:s=>s.focusSuggestion(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:2058,secondary:[2087],mac:{primary:266,secondary:[2087]}}}));ue(new zs({id:"focusAndAcceptSuggestion",precondition:ee.and(st.Visible,st.HasFocusedSuggestion.negate()),handler:s=>{s.focusSuggestion(),s.acceptSelectedSuggestion(!0,!1)}}));ue(new zs({id:"toggleSuggestionDetails",precondition:ee.and(st.Visible,st.HasFocusedSuggestion),handler:s=>s.toggleSuggestionDetails(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:2058,secondary:[2087],mac:{primary:266,secondary:[2087]}},menuOpts:[{menuId:bu,group:"right",order:1,when:ee.and(st.DetailsVisible,st.CanResolve),title:p("detail.more","show less")},{menuId:bu,group:"right",order:1,when:ee.and(st.DetailsVisible.toNegated(),st.CanResolve),title:p("detail.less","show more")}]}));ue(new zs({id:"toggleExplainMode",precondition:st.Visible,handler:s=>s.toggleExplainMode(),kbOpts:{weight:100,primary:2138}}));ue(new zs({id:"toggleSuggestionFocus",precondition:st.Visible,handler:s=>s.toggleSuggestionFocus(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:2570,mac:{primary:778}}}));ue(new zs({id:"insertBestCompletion",precondition:ee.and(T.textInputFocus,ee.equals("config.editor.tabCompletion","on"),Pb.AtEnd,st.Visible.toNegated(),Yg.OtherSuggestions.toNegated(),Hn.InSnippetMode.toNegated()),handler:(s,e)=>{s.triggerSuggestAndAcceptBest(Ts(e)?{fallback:"tab",...e}:{fallback:"tab"})},kbOpts:{weight:or,primary:2}}));ue(new zs({id:"insertNextSuggestion",precondition:ee.and(T.textInputFocus,ee.equals("config.editor.tabCompletion","on"),Yg.OtherSuggestions,st.Visible.toNegated(),Hn.InSnippetMode.toNegated()),handler:s=>s.acceptNextSuggestion(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:2}}));ue(new zs({id:"insertPrevSuggestion",precondition:ee.and(T.textInputFocus,ee.equals("config.editor.tabCompletion","on"),Yg.OtherSuggestions,st.Visible.toNegated(),Hn.InSnippetMode.toNegated()),handler:s=>s.acceptPrevSuggestion(),kbOpts:{weight:or,kbExpr:T.textInputFocus,primary:1026}}));re(class extends we{constructor(){super({id:"editor.action.resetSuggestSize",label:p("suggest.reset.label","Reset Suggest Widget Size"),alias:"Reset Suggest Widget Size",precondition:void 0})}run(s,e){var t;(t=qr.get(e))===null||t===void 0||t.resetWidgetSize()}});class cLe extends j{get selectedItem(){return this._selectedItem}constructor(e,t,i,n){super(),this.editor=e,this.suggestControllerPreselector=t,this.checkModelVersion=i,this.onWillAccept=n,this.isSuggestWidgetVisible=!1,this.isShiftKeyPressed=!1,this._isActive=!1,this._currentSuggestItemInfo=void 0,this._selectedItem=kt(this,void 0),this._register(e.onKeyDown(r=>{r.shiftKey&&!this.isShiftKeyPressed&&(this.isShiftKeyPressed=!0,this.update(this._isActive))})),this._register(e.onKeyUp(r=>{r.shiftKey&&this.isShiftKeyPressed&&(this.isShiftKeyPressed=!1,this.update(this._isActive))}));const o=qr.get(this.editor);if(o){this._register(o.registerSelector({priority:100,select:(l,d,c)=>{var u;mi(v=>this.checkModelVersion(v));const h=this.editor.getModel();if(!h)return-1;const g=(u=this.suggestControllerPreselector())===null||u===void 0?void 0:u.removeCommonPrefix(h);if(!g)return-1;const f=H.lift(d),m=c.map((v,b)=>{const w=o0.fromSuggestion(o,h,f,v,this.isShiftKeyPressed).toSingleTextEdit().removeCommonPrefix(h),S=g.augments(w);return{index:b,valid:S,prefixLength:w.text.length,suggestItem:v}}).filter(v=>v&&v.valid&&v.prefixLength>0),_=aP(m,br(v=>v.prefixLength,Ud));return _?_.index:-1}}));let r=!1;const a=()=>{r||(r=!0,this._register(o.widget.value.onDidShow(()=>{this.isSuggestWidgetVisible=!0,this.update(!0)})),this._register(o.widget.value.onDidHide(()=>{this.isSuggestWidgetVisible=!1,this.update(!1)})),this._register(o.widget.value.onDidFocus(()=>{this.isSuggestWidgetVisible=!0,this.update(!0)})))};this._register(ge.once(o.model.onDidTrigger)(l=>{a()})),this._register(o.onWillInsertSuggestItem(l=>{const d=this.editor.getPosition(),c=this.editor.getModel();if(!d||!c)return;const u=o0.fromSuggestion(o,c,d,l.item,this.isShiftKeyPressed);this.onWillAccept(u)}))}this.update(this._isActive)}update(e){const t=this.getSuggestItemInfo();(this._isActive!==e||!uLe(this._currentSuggestItemInfo,t))&&(this._isActive=e,this._currentSuggestItemInfo=t,mi(i=>{this.checkModelVersion(i),this._selectedItem.set(this._isActive?this._currentSuggestItemInfo:void 0,i)}))}getSuggestItemInfo(){const e=qr.get(this.editor);if(!e||!this.isSuggestWidgetVisible)return;const t=e.widget.value.getFocusedItem(),i=this.editor.getPosition(),n=this.editor.getModel();if(!(!t||!i||!n))return o0.fromSuggestion(e,n,i,t.item,this.isShiftKeyPressed)}stopForceRenderingAbove(){const e=qr.get(this.editor);e==null||e.stopForceRenderingAbove()}forceRenderingAbove(){const e=qr.get(this.editor);e==null||e.forceRenderingAbove()}}class o0{static fromSuggestion(e,t,i,n,o){let{insertText:r}=n.completion,a=!1;if(n.completion.insertTextRules&4){const d=new Um().parse(r);d.children.length<100&&bL.adjustWhitespace(t,i,!0,d),r=d.toString(),a=!0}const l=e.getOverwriteInfo(n,o);return new o0(D.fromPositions(i.delta(0,-l.overwriteBefore),i.delta(0,Math.max(l.overwriteAfter,0))),r,n.completion.kind,a)}constructor(e,t,i,n){this.range=e,this.insertText=t,this.completionItemKind=i,this.isSnippetText=n}equals(e){return this.range.equalsRange(e.range)&&this.insertText===e.insertText&&this.completionItemKind===e.completionItemKind&&this.isSnippetText===e.isSnippetText}toSelectedSuggestionInfo(){return new BW(this.range,this.insertText,this.completionItemKind,this.isSnippetText)}toSingleTextEdit(){return new $m(this.range,this.insertText)}}function uLe(s,e){return s===e?!0:!s||!e?!1:s.equals(e)}var hLe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},bc=function(s,e){return function(t,i){e(t,i,s)}},CR;let rr=CR=class extends j{static get(e){return e.getContribution(CR.ID)}constructor(e,t,i,n,o,r,a,l,d){super(),this.editor=e,this._instantiationService=t,this._contextKeyService=i,this._configurationService=n,this._commandService=o,this._debounceService=r,this._languageFeaturesService=a,this._audioCueService=l,this._keybindingService=d,this.model=jy("inlineCompletionModel",void 0),this._textModelVersionId=kt(this,-1),this._cursorPosition=kt(this,new H(1,1)),this._suggestWidgetAdaptor=this._register(new cLe(this.editor,()=>{var h,g;return(g=(h=this.model.get())===null||h===void 0?void 0:h.selectedInlineCompletion.get())===null||g===void 0?void 0:g.toSingleTextEdit(void 0)},h=>this.updateObservables(h,Bo.Other),h=>{mi(g=>{var f;this.updateObservables(g,Bo.Other),(f=this.model.get())===null||f===void 0||f.handleSuggestAccepted(h)})})),this._enabled=Mi(this.editor.onDidChangeConfiguration,()=>this.editor.getOption(62).enabled),this._ghostTextWidget=this._register(this._instantiationService.createInstance(cR,this.editor,{ghostText:this.model.map((h,g)=>h==null?void 0:h.ghostText.read(g)),minReservedLineCount:Ky(0),targetTextModel:this.model.map(h=>h==null?void 0:h.textModel)})),this._debounceValue=this._debounceService.for(this._languageFeaturesService.inlineCompletionsProvider,"InlineCompletionsDebounce",{min:50,max:50}),this._playAudioCueSignal=BO(this),this._isReadonly=Mi(this.editor.onDidChangeConfiguration,()=>this.editor.getOption(90)),this._textModel=Mi(this.editor.onDidChangeModel,()=>this.editor.getModel()),this._textModelIfWritable=nt(h=>this._isReadonly.read(h)?void 0:this._textModel.read(h)),this._register(new kn(this._contextKeyService,this.model)),this._register(Rt(h=>{const g=this._textModelIfWritable.read(h);mi(f=>{if(this.model.set(void 0,f),this.updateObservables(f,Bo.Other),g){const m=t.createInstance(hR,g,this._suggestWidgetAdaptor.selectedItem,this._cursorPosition,this._textModelVersionId,this._debounceValue,Mi(e.onDidChangeConfiguration,()=>e.getOption(117).preview),Mi(e.onDidChangeConfiguration,()=>e.getOption(117).previewMode),Mi(e.onDidChangeConfiguration,()=>e.getOption(62).mode),this._enabled);this.model.set(m,f)}})}));const c=h=>{var g;return h.isUndoing?Bo.Undo:h.isRedoing?Bo.Redo:!((g=this.model.get())===null||g===void 0)&&g.isAcceptingPartially?Bo.AcceptWord:Bo.Other};this._register(e.onDidChangeModelContent(h=>mi(g=>this.updateObservables(g,c(h))))),this._register(e.onDidChangeCursorPosition(h=>mi(g=>{var f;this.updateObservables(g,Bo.Other),(h.reason===3||h.source==="api")&&((f=this.model.get())===null||f===void 0||f.stop(g))}))),this._register(e.onDidType(()=>mi(h=>{var g;this.updateObservables(h,Bo.Other),this._enabled.get()&&((g=this.model.get())===null||g===void 0||g.trigger(h))}))),this._register(this._commandService.onDidExecuteCommand(h=>{new Set([zp.Tab.id,zp.DeleteLeft.id,zp.DeleteRight.id,Aj,"acceptSelectedSuggestion"]).has(h.commandId)&&e.hasTextFocus()&&this._enabled.get()&&mi(f=>{var m;(m=this.model.get())===null||m===void 0||m.trigger(f)})})),this._register(this.editor.onDidBlurEditorWidget(()=>{this._contextKeyService.getContextKeyValue("accessibleViewIsShown")||this._configurationService.getValue("editor.inlineSuggest.keepOnBlur")||e.getOption(62).keepOnBlur||Gu.dropDownVisible||mi(h=>{var g;(g=this.model.get())===null||g===void 0||g.stop(h)})})),this._register(Rt(h=>{var g;const f=(g=this.model.read(h))===null||g===void 0?void 0:g.state.read(h);f!=null&&f.suggestItem?f.ghostText.lineCount>=2&&this._suggestWidgetAdaptor.forceRenderingAbove():this._suggestWidgetAdaptor.stopForceRenderingAbove()})),this._register(Fe(()=>{this._suggestWidgetAdaptor.stopForceRenderingAbove()}));let u;this._register(NC({handleChange:(h,g)=>(h.didChange(this._playAudioCueSignal)&&(u=void 0),!0)},async h=>{this._playAudioCueSignal.read(h);const g=this.model.read(h),f=g==null?void 0:g.state.read(h);if(!g||!f||!f.inlineCompletion){u=void 0;return}if(f.inlineCompletion.semanticId!==u){u=f.inlineCompletion.semanticId;const m=g.textModel.getLineContent(f.ghostText.lineNumber);this._audioCueService.playAudioCue(at.inlineSuggestion).then(()=>{this.editor.getOption(8)&&this.provideScreenReaderUpdate(f.ghostText.renderForScreenReader(m))})}})),this._register(new HM(this.editor,this.model,this._instantiationService)),this._register(this._configurationService.onDidChangeConfiguration(h=>{h.affectsConfiguration("accessibility.verbosity.inlineCompletions")&&this.editor.updateOptions({inlineCompletionsAccessibilityVerbose:this._configurationService.getValue("accessibility.verbosity.inlineCompletions")})})),this.editor.updateOptions({inlineCompletionsAccessibilityVerbose:this._configurationService.getValue("accessibility.verbosity.inlineCompletions")})}playAudioCue(e){this._playAudioCueSignal.trigger(e)}provideScreenReaderUpdate(e){const t=this._contextKeyService.getContextKeyValue("accessibleViewIsShown"),i=this._keybindingService.lookupKeybinding("editor.action.accessibleView");let n;!t&&i&&this.editor.getOption(147)&&(n=p("showAccessibleViewHint","Inspect this in the accessible view ({0})",i.getAriaLabel())),Lo(n?e+", "+n:e)}updateObservables(e,t){var i,n;const o=this.editor.getModel();this._textModelVersionId.set((i=o==null?void 0:o.getVersionId())!==null&&i!==void 0?i:-1,e,t),this._cursorPosition.set((n=this.editor.getPosition())!==null&&n!==void 0?n:new H(1,1),e)}shouldShowHoverAt(e){var t;const i=(t=this.model.get())===null||t===void 0?void 0:t.ghostText.get();return i?i.parts.some(n=>e.containsPosition(new H(i.lineNumber,n.column))):!1}shouldShowHoverAtViewZone(e){return this._ghostTextWidget.ownsViewZone(e)}};rr.ID="editor.contrib.inlineCompletionsController";rr=CR=hLe([bc(1,We),bc(2,je),bc(3,mt),bc(4,Ei),bc(5,Er),bc(6,xe),bc(7,IC),bc(8,qt)],rr);class BD extends we{constructor(){super({id:BD.ID,label:p("action.inlineSuggest.showNext","Show Next Inline Suggestion"),alias:"Show Next Inline Suggestion",precondition:ee.and(T.writable,kn.inlineSuggestionVisible),kbOpts:{weight:100,primary:606}})}async run(e,t){var i;const n=rr.get(t);(i=n==null?void 0:n.model.get())===null||i===void 0||i.next()}}BD.ID=Oj;class WD extends we{constructor(){super({id:WD.ID,label:p("action.inlineSuggest.showPrevious","Show Previous Inline Suggestion"),alias:"Show Previous Inline Suggestion",precondition:ee.and(T.writable,kn.inlineSuggestionVisible),kbOpts:{weight:100,primary:604}})}async run(e,t){var i;const n=rr.get(t);(i=n==null?void 0:n.model.get())===null||i===void 0||i.previous()}}WD.ID=Pj;class gLe extends we{constructor(){super({id:"editor.action.inlineSuggest.trigger",label:p("action.inlineSuggest.trigger","Trigger Inline Suggestion"),alias:"Trigger Inline Suggestion",precondition:T.writable})}async run(e,t){const i=rr.get(t);await Fme(async n=>{var o;await((o=i==null?void 0:i.model.get())===null||o===void 0?void 0:o.triggerExplicitly(n)),i==null||i.playAudioCue(n)})}}class fLe extends we{constructor(){super({id:"editor.action.inlineSuggest.acceptNextWord",label:p("action.inlineSuggest.acceptNextWord","Accept Next Word Of Inline Suggestion"),alias:"Accept Next Word Of Inline Suggestion",precondition:ee.and(T.writable,kn.inlineSuggestionVisible),kbOpts:{weight:101,primary:2065,kbExpr:ee.and(T.writable,kn.inlineSuggestionVisible)},menuOpts:[{menuId:N.InlineSuggestionToolbar,title:p("acceptWord","Accept Word"),group:"primary",order:2}]})}async run(e,t){var i;const n=rr.get(t);await((i=n==null?void 0:n.model.get())===null||i===void 0?void 0:i.acceptNextWord(n.editor))}}class pLe extends we{constructor(){super({id:"editor.action.inlineSuggest.acceptNextLine",label:p("action.inlineSuggest.acceptNextLine","Accept Next Line Of Inline Suggestion"),alias:"Accept Next Line Of Inline Suggestion",precondition:ee.and(T.writable,kn.inlineSuggestionVisible),kbOpts:{weight:101},menuOpts:[{menuId:N.InlineSuggestionToolbar,title:p("acceptLine","Accept Line"),group:"secondary",order:2}]})}async run(e,t){var i;const n=rr.get(t);await((i=n==null?void 0:n.model.get())===null||i===void 0?void 0:i.acceptNextLine(n.editor))}}class mLe extends we{constructor(){super({id:Aj,label:p("action.inlineSuggest.accept","Accept Inline Suggestion"),alias:"Accept Inline Suggestion",precondition:kn.inlineSuggestionVisible,menuOpts:[{menuId:N.InlineSuggestionToolbar,title:p("accept","Accept"),group:"primary",order:1}],kbOpts:{primary:2,weight:200,kbExpr:ee.and(kn.inlineSuggestionVisible,T.tabMovesFocus.toNegated(),kn.inlineSuggestionHasIndentationLessThanTabSize,st.Visible.toNegated(),T.hoverFocused.toNegated())}})}async run(e,t){var i;const n=rr.get(t);n&&((i=n.model.get())===null||i===void 0||i.accept(n.editor),n.editor.focus())}}class VD extends we{constructor(){super({id:VD.ID,label:p("action.inlineSuggest.hide","Hide Inline Suggestion"),alias:"Hide Inline Suggestion",precondition:kn.inlineSuggestionVisible,kbOpts:{weight:100,primary:9}})}async run(e,t){const i=rr.get(t);mi(n=>{var o;(o=i==null?void 0:i.model.get())===null||o===void 0||o.stop(n)})}}VD.ID="editor.action.inlineSuggest.hide";class HD extends ar{constructor(){super({id:HD.ID,title:p("action.inlineSuggest.alwaysShowToolbar","Always Show Toolbar"),f1:!1,precondition:void 0,menu:[{id:N.InlineSuggestionToolbar,group:"secondary",order:10}],toggled:ee.equals("config.editor.inlineSuggest.showToolbar","always")})}async run(e,t){const i=e.get(mt),o=i.getValue("editor.inlineSuggest.showToolbar")==="always"?"onHover":"always";i.updateValue("editor.inlineSuggest.showToolbar",o)}}HD.ID="editor.action.inlineSuggest.toggleAlwaysShowToolbar";var _Le=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Q_=function(s,e){return function(t,i){e(t,i,s)}};class vLe{constructor(e,t,i){this.owner=e,this.range=t,this.controller=i}isValidForHoverAnchor(e){return e.type===1&&this.range.startColumn<=e.range.startColumn&&this.range.endColumn>=e.range.endColumn}}let wR=class{constructor(e,t,i,n,o,r){this._editor=e,this._languageService=t,this._openerService=i,this.accessibilityService=n,this._instantiationService=o,this._telemetryService=r,this.hoverOrdinal=4}suggestHoverAnchor(e){const t=rr.get(this._editor);if(!t)return null;const i=e.target;if(i.type===8){const n=i.detail;if(t.shouldShowHoverAtViewZone(n.viewZoneId))return new sS(1e3,this,D.fromPositions(this._editor.getModel().validatePosition(n.positionBefore||n.position)),e.event.posx,e.event.posy,!1)}return i.type===7&&t.shouldShowHoverAt(i.range)?new sS(1e3,this,i.range,e.event.posx,e.event.posy,!1):i.type===6&&i.detail.mightBeForeignElement&&t.shouldShowHoverAt(i.range)?new sS(1e3,this,i.range,e.event.posx,e.event.posy,!1):null}computeSync(e,t){if(this._editor.getOption(62).showToolbar!=="onHover")return[];const i=rr.get(this._editor);return i&&i.shouldShowHoverAt(e.range)?[new vLe(this,e.range,i)]:[]}renderHoverParts(e,t){const i=new ie,n=t[0];this._telemetryService.publicLog2("inlineCompletionHover.shown"),this.accessibilityService.isScreenReaderOptimized()&&!this._editor.getOption(8)&&this.renderScreenReaderText(e,n,i);const o=n.controller.model.get(),r=this._instantiationService.createInstance(Gu,this._editor,!1,Ky(null),o.selectedInlineCompletionIndex,o.inlineCompletionsCount,o.selectedInlineCompletion.map(a=>{var l;return(l=a==null?void 0:a.inlineCompletion.source.inlineCompletions.commands)!==null&&l!==void 0?l:[]}));return e.fragment.appendChild(r.getDomNode()),o.triggerExplicitly(),i.add(r),i}renderScreenReaderText(e,t,i){const n=se,o=n("div.hover-row.markdown-hover"),r=te(o,n("div.hover-contents",{"aria-live":"assertive"})),a=i.add(new ic({editor:this._editor},this._languageService,this._openerService)),l=d=>{i.add(a.onDidRenderAsync(()=>{r.className="hover-contents code-hover-contents",e.onContentsChanged()}));const c=p("inlineSuggestionFollows","Suggestion:"),u=i.add(a.render(new rs().appendText(c).appendCodeblock("text",d)));r.replaceChildren(u.element)};i.add(Rt(d=>{var c;const u=(c=t.controller.model.read(d))===null||c===void 0?void 0:c.ghostText.read(d);if(u){const h=this._editor.getModel().getLineContent(u.lineNumber);l(u.renderForScreenReader(h))}else Qn(r)})),e.fragment.appendChild(o)}};wR=_Le([Q_(1,fi),Q_(2,No),Q_(3,ad),Q_(4,We),Q_(5,Do)],wR);Lt(rr.ID,rr,3);re(gLe);re(BD);re(WD);re(fLe);re(pLe);re(mLe);re(VD);di(HD);wf.register(wR);function lo(s,e){let t=0;for(let i=0;i<s.length;i++)s.charAt(i)==="	"?t+=e:t++;return t}function r0(s,e,t){s=s<0?0:s;let i="";if(!t){const n=Math.floor(s/e);s=s%e;for(let o=0;o<n;o++)i+="	"}for(let n=0;n<s;n++)i+=" ";return i}var bLe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},CLe=function(s,e){return function(t,i){e(t,i,s)}};function wK(s,e,t,i,n){if(s.getLineCount()===1&&s.getLineMaxColumn(1)===1)return[];const o=e.getLanguageConfiguration(s.getLanguageId()).indentationRules;if(!o)return[];for(i=Math.min(i,s.getLineCount());t<=i&&o.unIndentedLinePattern;){const _=s.getLineContent(t);if(!o.unIndentedLinePattern.test(_))break;t++}if(t>i-1)return[];const{tabSize:r,indentSize:a,insertSpaces:l}=s.getOptions(),d=(_,v)=>(v=v||1,mr.shiftIndent(_,_.length+v,r,a,l)),c=(_,v)=>(v=v||1,mr.unshiftIndent(_,_.length+v,r,a,l)),u=[];let h;const g=s.getLineContent(t);let f=g;if(n!=null){h=n;const _=Zt(g);f=h+g.substring(_.length),o.decreaseIndentPattern&&o.decreaseIndentPattern.test(f)&&(h=c(h),f=h+g.substring(_.length)),g!==f&&u.push(_i.replaceMove(new De(t,1,t,_.length+1),JS(h,a,l)))}else h=Zt(g);let m=h;o.increaseIndentPattern&&o.increaseIndentPattern.test(f)?(m=d(m),h=d(h)):o.indentNextLinePattern&&o.indentNextLinePattern.test(f)&&(m=d(m)),t++;for(let _=t;_<=i;_++){const v=s.getLineContent(_),b=Zt(v),C=m+v.substring(b.length);o.decreaseIndentPattern&&o.decreaseIndentPattern.test(C)&&(m=c(m),h=c(h)),b!==m&&u.push(_i.replaceMove(new De(_,1,_,b.length+1),JS(m,a,l))),!(o.unIndentedLinePattern&&o.unIndentedLinePattern.test(v))&&(o.increaseIndentPattern&&o.increaseIndentPattern.test(C)?(h=d(h),m=h):o.indentNextLinePattern&&o.indentNextLinePattern.test(C)?m=d(m):m=h)}return u}class zD extends we{constructor(){super({id:zD.ID,label:p("indentationToSpaces","Convert Indentation to Spaces"),alias:"Convert Indentation to Spaces",precondition:T.writable})}run(e,t){const i=t.getModel();if(!i)return;const n=i.getOptions(),o=t.getSelection();if(!o)return;const r=new LLe(o,n.tabSize);t.pushUndoStop(),t.executeCommands(this.id,[r]),t.pushUndoStop(),i.updateOptions({insertSpaces:!0})}}zD.ID="editor.action.indentationToSpaces";class UD extends we{constructor(){super({id:UD.ID,label:p("indentationToTabs","Convert Indentation to Tabs"),alias:"Convert Indentation to Tabs",precondition:T.writable})}run(e,t){const i=t.getModel();if(!i)return;const n=i.getOptions(),o=t.getSelection();if(!o)return;const r=new xLe(o,n.tabSize);t.pushUndoStop(),t.executeCommands(this.id,[r]),t.pushUndoStop(),i.updateOptions({insertSpaces:!1})}}UD.ID="editor.action.indentationToTabs";class M4 extends we{constructor(e,t,i){super(i),this.insertSpaces=e,this.displaySizeOnly=t}run(e,t){const i=e.get(Ya),n=e.get(vi),o=t.getModel();if(!o)return;const r=n.getCreationOptions(o.getLanguageId(),o.uri,o.isForSimpleWidget),a=o.getOptions(),l=[1,2,3,4,5,6,7,8].map(c=>({id:c.toString(),label:c.toString(),description:c===r.tabSize&&c===a.tabSize?p("configuredTabSize","Configured Tab Size"):c===r.tabSize?p("defaultTabSize","Default Tab Size"):c===a.tabSize?p("currentTabSize","Current Tab Size"):void 0})),d=Math.min(o.getOptions().tabSize-1,7);setTimeout(()=>{i.pick(l,{placeHolder:p({key:"selectTabWidth",comment:["Tab corresponds to the tab key"]},"Select Tab Size for Current File"),activeItem:l[d]}).then(c=>{if(c&&o&&!o.isDisposed()){const u=parseInt(c.label,10);this.displaySizeOnly?o.updateOptions({tabSize:u}):o.updateOptions({tabSize:u,indentSize:u,insertSpaces:this.insertSpaces})}})},50)}}class $D extends M4{constructor(){super(!1,!1,{id:$D.ID,label:p("indentUsingTabs","Indent Using Tabs"),alias:"Indent Using Tabs",precondition:void 0})}}$D.ID="editor.action.indentUsingTabs";class jD extends M4{constructor(){super(!0,!1,{id:jD.ID,label:p("indentUsingSpaces","Indent Using Spaces"),alias:"Indent Using Spaces",precondition:void 0})}}jD.ID="editor.action.indentUsingSpaces";class KD extends M4{constructor(){super(!0,!0,{id:KD.ID,label:p("changeTabDisplaySize","Change Tab Display Size"),alias:"Change Tab Display Size",precondition:void 0})}}KD.ID="editor.action.changeTabDisplaySize";class qD extends we{constructor(){super({id:qD.ID,label:p("detectIndentation","Detect Indentation from Content"),alias:"Detect Indentation from Content",precondition:void 0})}run(e,t){const i=e.get(vi),n=t.getModel();if(!n)return;const o=i.getCreationOptions(n.getLanguageId(),n.uri,n.isForSimpleWidget);n.detectIndentation(o.insertSpaces,o.tabSize)}}qD.ID="editor.action.detectIndentation";class wLe extends we{constructor(){super({id:"editor.action.reindentlines",label:p("editor.reindentlines","Reindent Lines"),alias:"Reindent Lines",precondition:T.writable})}run(e,t){const i=e.get(Jt),n=t.getModel();if(!n)return;const o=wK(n,i,1,n.getLineCount());o.length>0&&(t.pushUndoStop(),t.executeEdits(this.id,o),t.pushUndoStop())}}class SLe extends we{constructor(){super({id:"editor.action.reindentselectedlines",label:p("editor.reindentselectedlines","Reindent Selected Lines"),alias:"Reindent Selected Lines",precondition:T.writable})}run(e,t){const i=e.get(Jt),n=t.getModel();if(!n)return;const o=t.getSelections();if(o===null)return;const r=[];for(const a of o){let l=a.startLineNumber,d=a.endLineNumber;if(l!==d&&a.endColumn===1&&d--,l===1){if(l===d)continue}else l--;const c=wK(n,i,l,d);r.push(...c)}r.length>0&&(t.pushUndoStop(),t.executeEdits(this.id,r),t.pushUndoStop())}}class yLe{constructor(e,t){this._initialSelection=t,this._edits=[],this._selectionId=null;for(const i of e)i.range&&typeof i.text=="string"&&this._edits.push(i)}getEditOperations(e,t){for(const n of this._edits)t.addEditOperation(D.lift(n.range),n.text);let i=!1;Array.isArray(this._edits)&&this._edits.length===1&&this._initialSelection.isEmpty()&&(this._edits[0].range.startColumn===this._initialSelection.endColumn&&this._edits[0].range.startLineNumber===this._initialSelection.endLineNumber?(i=!0,this._selectionId=t.trackSelection(this._initialSelection,!0)):this._edits[0].range.endColumn===this._initialSelection.startColumn&&this._edits[0].range.endLineNumber===this._initialSelection.startLineNumber&&(i=!0,this._selectionId=t.trackSelection(this._initialSelection,!1))),i||(this._selectionId=t.trackSelection(this._initialSelection))}computeCursorState(e,t){return t.getTrackedSelection(this._selectionId)}}let Fb=class{constructor(e,t){this.editor=e,this._languageConfigurationService=t,this.callOnDispose=new ie,this.callOnModel=new ie,this.callOnDispose.add(e.onDidChangeConfiguration(()=>this.update())),this.callOnDispose.add(e.onDidChangeModel(()=>this.update())),this.callOnDispose.add(e.onDidChangeModelLanguage(()=>this.update()))}update(){this.callOnModel.clear(),!(this.editor.getOption(12)<4||this.editor.getOption(55))&&this.editor.hasModel()&&this.callOnModel.add(this.editor.onDidPaste(({range:e})=>{this.trigger(e)}))}trigger(e){const t=this.editor.getSelections();if(t===null||t.length>1)return;const i=this.editor.getModel();if(!i||!i.tokenization.isCheapToTokenize(e.getStartPosition().lineNumber))return;const n=this.editor.getOption(12),{tabSize:o,indentSize:r,insertSpaces:a}=i.getOptions(),l=[],d={shiftIndent:g=>mr.shiftIndent(g,g.length+1,o,r,a),unshiftIndent:g=>mr.unshiftIndent(g,g.length+1,o,r,a)};let c=e.startLineNumber;for(;c<=e.endLineNumber;){if(this.shouldIgnoreLine(i,c)){c++;continue}break}if(c>e.endLineNumber)return;let u=i.getLineContent(c);if(!/\S/.test(u.substring(0,e.startColumn-1))){const g=Bv(n,i,i.getLanguageId(),c,d,this._languageConfigurationService);if(g!==null){const f=Zt(u),m=lo(g,o),_=lo(f,o);if(m!==_){const v=r0(m,o,a);l.push({range:new D(c,1,c,f.length+1),text:v}),u=v+u.substr(f.length)}else{const v=RH(i,c,this._languageConfigurationService);if(v===0||v===8)return}}}const h=c;for(;c<e.endLineNumber;){if(!/\S/.test(i.getLineContent(c+1))){c++;continue}break}if(c!==e.endLineNumber){const f=Bv(n,{tokenization:{getLineTokens:m=>i.tokenization.getLineTokens(m),getLanguageId:()=>i.getLanguageId(),getLanguageIdAtPosition:(m,_)=>i.getLanguageIdAtPosition(m,_)},getLineContent:m=>m===h?u:i.getLineContent(m)},i.getLanguageId(),c+1,d,this._languageConfigurationService);if(f!==null){const m=lo(f,o),_=lo(Zt(i.getLineContent(c+1)),o);if(m!==_){const v=m-_;for(let b=c+1;b<=e.endLineNumber;b++){const C=i.getLineContent(b),w=Zt(C),x=lo(w,o)+v,L=r0(x,o,a);L!==w&&l.push({range:new D(b,1,b,w.length+1),text:L})}}}}if(l.length>0){this.editor.pushUndoStop();const g=new yLe(l,this.editor.getSelection());this.editor.executeCommand("autoIndentOnPaste",g),this.editor.pushUndoStop()}}shouldIgnoreLine(e,t){e.tokenization.forceTokenization(t);const i=e.getLineFirstNonWhitespaceColumn(t);if(i===0)return!0;const n=e.tokenization.getLineTokens(t);if(n.getCount()>0){const o=n.findTokenIndexAtOffset(i);if(o>=0&&n.getStandardTokenType(o)===1)return!0}return!1}dispose(){this.callOnDispose.dispose(),this.callOnModel.dispose()}};Fb.ID="editor.contrib.autoIndentOnPaste";Fb=bLe([CLe(1,Jt)],Fb);function SK(s,e,t,i){if(s.getLineCount()===1&&s.getLineMaxColumn(1)===1)return;let n="";for(let r=0;r<t;r++)n+=" ";const o=new RegExp(n,"gi");for(let r=1,a=s.getLineCount();r<=a;r++){let l=s.getLineFirstNonWhitespaceColumn(r);if(l===0&&(l=s.getLineMaxColumn(r)),l===1)continue;const d=new D(r,1,r,l),c=s.getValueInRange(d),u=i?c.replace(/\t/ig,n):c.replace(o,"	");e.addEditOperation(d,u)}}class LLe{constructor(e,t){this.selection=e,this.tabSize=t,this.selectionId=null}getEditOperations(e,t){this.selectionId=t.trackSelection(this.selection),SK(e,t,this.tabSize,!0)}computeCursorState(e,t){return t.getTrackedSelection(this.selectionId)}}class xLe{constructor(e,t){this.selection=e,this.tabSize=t,this.selectionId=null}getEditOperations(e,t){this.selectionId=t.trackSelection(this.selection),SK(e,t,this.tabSize,!1)}computeCursorState(e,t){return t.getTrackedSelection(this.selectionId)}}Lt(Fb.ID,Fb,2);re(zD);re(UD);re($D);re(jD);re(KD);re(qD);re(wLe);re(SLe);class yK{constructor(e,t){this.range=e,this.direction=t}}class R4{constructor(e,t,i){this.hint=e,this.anchor=t,this.provider=i,this._isResolved=!1}with(e){const t=new R4(this.hint,e.anchor,this.provider);return t._isResolved=this._isResolved,t._currentResolve=this._currentResolve,t}async resolve(e){if(typeof this.provider.resolveInlayHint=="function"){if(this._currentResolve)return await this._currentResolve,e.isCancellationRequested?void 0:this.resolve(e);this._isResolved||(this._currentResolve=this._doResolve(e).finally(()=>this._currentResolve=void 0)),await this._currentResolve}}async _doResolve(e){var t,i;try{const n=await Promise.resolve(this.provider.resolveInlayHint(this.hint,e));this.hint.tooltip=(t=n==null?void 0:n.tooltip)!==null&&t!==void 0?t:this.hint.tooltip,this.hint.label=(i=n==null?void 0:n.label)!==null&&i!==void 0?i:this.hint.label,this._isResolved=!0}catch(n){Zi(n),this._isResolved=!1}}}class Bb{static async create(e,t,i,n){const o=[],r=e.ordered(t).reverse().map(a=>i.map(async l=>{try{const d=await a.provideInlayHints(t,l,n);d!=null&&d.hints.length&&o.push([d,a])}catch(d){Zi(d)}}));if(await Promise.all(r.flat()),n.isCancellationRequested||t.isDisposed())throw new eh;return new Bb(i,o,t)}constructor(e,t,i){this._disposables=new ie,this.ranges=e,this.provider=new Set;const n=[];for(const[o,r]of t){this._disposables.add(o),this.provider.add(r);for(const a of o.hints){const l=i.validatePosition(a.position);let d="before";const c=Bb._getRangeAtPosition(i,l);let u;c.getStartPosition().isBefore(l)?(u=D.fromPositions(c.getStartPosition(),l),d="after"):(u=D.fromPositions(l,c.getEndPosition()),d="before"),n.push(new R4(a,new yK(u,d),r))}}this.items=n.sort((o,r)=>H.compare(o.hint.position,r.hint.position))}dispose(){this._disposables.dispose()}static _getRangeAtPosition(e,t){const i=t.lineNumber,n=e.getWordAtPosition(t);if(n)return new D(i,n.startColumn,i,n.endColumn);e.tokenization.tokenizeIfCheap(i);const o=e.tokenization.getLineTokens(i),r=t.column-1,a=o.findTokenIndexAtOffset(r);let l=o.getStartOffset(a),d=o.getEndOffset(a);return d-l===1&&(l===r&&a>1?(l=o.getStartOffset(a-1),d=o.getEndOffset(a-1)):d===r&&a<o.getCount()-1&&(l=o.getStartOffset(a+1),d=o.getEndOffset(a+1))),new D(i,l+1,i,d+1)}}function DLe(s){return Pe.from({scheme:it.command,path:s.id,query:s.arguments&&encodeURIComponent(JSON.stringify(s.arguments))}).toString()}async function kLe(s,e,t,i){var n;const o=s.get(io),r=s.get(Nr),a=s.get(Ei),l=s.get(We),d=s.get(Qi);if(await i.item.resolve(ct.None),!i.part.location)return;const c=i.part.location,u=[],h=new Set(Wn.getMenuItems(N.EditorContext).map(f=>sp(f)?f.command.id:xD()));for(const f of Cs.all())h.has(f.desc.id)&&u.push(new Os(f.desc.id,Xr.label(f.desc,{renderShortTitle:!0}),void 0,!0,async()=>{const m=await o.createModelReference(c.uri);try{const _=new Bm(m.object.textEditorModel,D.getStartPosition(c.range)),v=i.item.anchor.range;await l.invokeFunction(f.runEditorCommand.bind(f),e,_,v)}finally{m.dispose()}}));if(i.part.command){const{command:f}=i.part;u.push(new In),u.push(new Os(f.id,f.title,void 0,!0,async()=>{var m;try{await a.executeCommand(f.id,...(m=f.arguments)!==null&&m!==void 0?m:[])}catch(_){d.notify({severity:Rx.Error,source:i.item.provider.displayName,message:_})}}))}const g=e.getOption(126);r.showContextMenu({domForShadowRoot:g&&(n=e.getDomNode())!==null&&n!==void 0?n:void 0,getAnchor:()=>{const f=ln(t);return{x:f.left,y:f.top+f.height+8}},getActions:()=>u,onHide:()=>{e.focus()},autoSelectFirstItem:!0})}async function LK(s,e,t,i){const o=await s.get(io).createModelReference(i.uri);await t.invokeWithinContext(async r=>{const a=e.hasSideBySideModifier,l=r.get(je),d=eo.inPeekEditor.getValue(l),c=!a&&t.getOption(87)&&!d;return new VC({openToSide:a,openInPeek:c,muteMessage:!0},{title:{value:"",original:""},id:"",precondition:void 0}).run(r,new Bm(o.object.textEditorModel,D.getStartPosition(i.range)),D.lift(i.range))}),o.dispose()}var ILe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Vf=function(s,e){return function(t,i){e(t,i,s)}},lS;class CL{constructor(){this._entries=new nh(50)}get(e){const t=CL._key(e);return this._entries.get(t)}set(e,t){const i=CL._key(e);this._entries.set(i,t)}static _key(e){return`${e.uri.toString()}/${e.getVersionId()}`}}const xK=ut("IInlayHintsCache");_t(xK,CL,1);class SR{constructor(e,t){this.item=e,this.index=t}get part(){const e=this.item.hint.label;return typeof e=="string"?{label:e}:e[this.index]}}class ELe{constructor(e,t){this.part=e,this.hasTriggerModifier=t}}let Xg=lS=class{static get(e){var t;return(t=e.getContribution(lS.ID))!==null&&t!==void 0?t:void 0}constructor(e,t,i,n,o,r,a){this._editor=e,this._languageFeaturesService=t,this._inlayHintsCache=n,this._commandService=o,this._notificationService=r,this._instaService=a,this._disposables=new ie,this._sessionDisposables=new ie,this._decorationsMetadata=new Map,this._ruleFactory=new cC(this._editor),this._activeRenderMode=0,this._debounceInfo=i.for(t.inlayHintsProvider,"InlayHint",{min:25}),this._disposables.add(t.inlayHintsProvider.onDidChange(()=>this._update())),this._disposables.add(e.onDidChangeModel(()=>this._update())),this._disposables.add(e.onDidChangeModelLanguage(()=>this._update())),this._disposables.add(e.onDidChangeConfiguration(l=>{l.hasChanged(139)&&this._update()})),this._update()}dispose(){this._sessionDisposables.dispose(),this._removeAllDecorations(),this._disposables.dispose()}_update(){this._sessionDisposables.clear(),this._removeAllDecorations();const e=this._editor.getOption(139);if(e.enabled==="off")return;const t=this._editor.getModel();if(!t||!this._languageFeaturesService.inlayHintsProvider.has(t))return;const i=this._inlayHintsCache.get(t);i&&this._updateHintsDecorators([t.getFullModelRange()],i),this._sessionDisposables.add(Fe(()=>{t.isDisposed()||this._cacheHintsForFastRestore(t)}));let n;const o=new Set,r=new jt(async()=>{const a=Date.now();n==null||n.dispose(!0),n=new Yi;const l=t.onWillDispose(()=>n==null?void 0:n.cancel());try{const d=n.token,c=await Bb.create(this._languageFeaturesService.inlayHintsProvider,t,this._getHintsRanges(),d);if(r.delay=this._debounceInfo.update(t,Date.now()-a),d.isCancellationRequested){c.dispose();return}for(const u of c.provider)typeof u.onDidChangeInlayHints=="function"&&!o.has(u)&&(o.add(u),this._sessionDisposables.add(u.onDidChangeInlayHints(()=>{r.isScheduled()||r.schedule()})));this._sessionDisposables.add(c),this._updateHintsDecorators(c.ranges,c.items),this._cacheHintsForFastRestore(t)}catch(d){et(d)}finally{n.dispose(),l.dispose()}},this._debounceInfo.get(t));if(this._sessionDisposables.add(r),this._sessionDisposables.add(Fe(()=>n==null?void 0:n.dispose(!0))),r.schedule(0),this._sessionDisposables.add(this._editor.onDidScrollChange(a=>{(a.scrollTopChanged||!r.isScheduled())&&r.schedule()})),this._sessionDisposables.add(this._editor.onDidChangeModelContent(a=>{const l=Math.max(r.delay,1250);r.schedule(l)})),e.enabled==="on")this._activeRenderMode=0;else{let a,l;e.enabled==="onUnlessPressed"?(a=0,l=1):(a=1,l=0),this._activeRenderMode=a,this._sessionDisposables.add(Pd.getInstance().event(d=>{if(!this._editor.hasModel())return;const c=d.altKey&&d.ctrlKey&&!(d.shiftKey||d.metaKey)?l:a;if(c!==this._activeRenderMode){this._activeRenderMode=c;const u=this._editor.getModel(),h=this._copyInlayHintsWithCurrentAnchor(u);this._updateHintsDecorators([u.getFullModelRange()],h),r.schedule(0)}}))}this._sessionDisposables.add(this._installDblClickGesture(()=>r.schedule(0))),this._sessionDisposables.add(this._installLinkGesture()),this._sessionDisposables.add(this._installContextMenu())}_installLinkGesture(){const e=new ie,t=e.add(new mD(this._editor)),i=new ie;return e.add(i),e.add(t.onMouseMoveOrRelevantKeyDown(n=>{const[o]=n,r=this._getInlayHintLabelPart(o),a=this._editor.getModel();if(!r||!a){i.clear();return}const l=new Yi;i.add(Fe(()=>l.dispose(!0))),r.item.resolve(l.token),this._activeInlayHintPart=r.part.command||r.part.location?new ELe(r,o.hasTriggerModifier):void 0;const d=a.validatePosition(r.item.hint.position).lineNumber,c=new D(d,1,d,a.getLineMaxColumn(d)),u=this._getInlineHintsForRange(c);this._updateHintsDecorators([c],u),i.add(Fe(()=>{this._activeInlayHintPart=void 0,this._updateHintsDecorators([c],u)}))})),e.add(t.onCancel(()=>i.clear())),e.add(t.onExecute(async n=>{const o=this._getInlayHintLabelPart(n);if(o){const r=o.part;r.location?this._instaService.invokeFunction(LK,n,this._editor,r.location):QE.is(r.command)&&await this._invokeCommand(r.command,o.item)}})),e}_getInlineHintsForRange(e){const t=new Set;for(const i of this._decorationsMetadata.values())e.containsRange(i.item.anchor.range)&&t.add(i.item);return Array.from(t)}_installDblClickGesture(e){return this._editor.onMouseUp(async t=>{if(t.event.detail!==2)return;const i=this._getInlayHintLabelPart(t);if(i&&(t.event.preventDefault(),await i.item.resolve(ct.None),as(i.item.hint.textEdits))){const n=i.item.hint.textEdits.map(o=>_i.replace(D.lift(o.range),o.text));this._editor.executeEdits("inlayHint.default",n),e()}})}_installContextMenu(){return this._editor.onContextMenu(async e=>{if(!(e.event.target instanceof HTMLElement))return;const t=this._getInlayHintLabelPart(e);t&&await this._instaService.invokeFunction(kLe,this._editor,e.event.target,t)})}_getInlayHintLabelPart(e){var t;if(e.target.type!==6)return;const i=(t=e.target.detail.injectedText)===null||t===void 0?void 0:t.options;if(i instanceof Wu&&(i==null?void 0:i.attachedData)instanceof SR)return i.attachedData}async _invokeCommand(e,t){var i;try{await this._commandService.executeCommand(e.id,...(i=e.arguments)!==null&&i!==void 0?i:[])}catch(n){this._notificationService.notify({severity:Rx.Error,source:t.provider.displayName,message:n})}}_cacheHintsForFastRestore(e){const t=this._copyInlayHintsWithCurrentAnchor(e);this._inlayHintsCache.set(e,t)}_copyInlayHintsWithCurrentAnchor(e){const t=new Map;for(const[i,n]of this._decorationsMetadata){if(t.has(n.item))continue;const o=e.getDecorationRange(i);if(o){const r=new yK(o,n.item.anchor.direction),a=n.item.with({anchor:r});t.set(n.item,a)}}return Array.from(t.values())}_getHintsRanges(){const t=this._editor.getModel(),i=this._editor.getVisibleRangesPlusViewportAboveBelow(),n=[];for(const o of i.sort(D.compareRangesUsingStarts)){const r=t.validateRange(new D(o.startLineNumber-30,o.startColumn,o.endLineNumber+30,o.endColumn));n.length===0||!D.areIntersectingOrTouching(n[n.length-1],r)?n.push(r):n[n.length-1]=D.plusRange(n[n.length-1],r)}return n}_updateHintsDecorators(e,t){var i,n;const o=[],r=(m,_,v,b,C)=>{const w={content:v,inlineClassNameAffectsLetterSpacing:!0,inlineClassName:_.className,cursorStops:b,attachedData:C};o.push({item:m,classNameRef:_,decoration:{range:m.anchor.range,options:{description:"InlayHint",showIfCollapsed:m.anchor.range.isEmpty(),collapseOnReplaceEdit:!m.anchor.range.isEmpty(),stickiness:0,[m.anchor.direction]:this._activeRenderMode===0?w:void 0}}})},a=(m,_)=>{const v=this._ruleFactory.createClassNameRef({width:`${l/3|0}px`,display:"inline-block"});r(m,v," ",_?Na.Right:Na.None)},{fontSize:l,fontFamily:d,padding:c,isUniform:u}=this._getLayoutInfo(),h="--code-editorInlayHintsFontFamily";this._editor.getContainerDomNode().style.setProperty(h,d);for(const m of t){m.hint.paddingLeft&&a(m,!1);const _=typeof m.hint.label=="string"?[{label:m.hint.label}]:m.hint.label;for(let v=0;v<_.length;v++){const b=_[v],C=v===0,w=v===_.length-1,S={fontSize:`${l}px`,fontFamily:`var(${h}), ${vo.fontFamily}`,verticalAlign:u?"baseline":"middle",unicodeBidi:"isolate"};as(m.hint.textEdits)&&(S.cursor="default"),this._fillInColors(S,m.hint),(b.command||b.location)&&((i=this._activeInlayHintPart)===null||i===void 0?void 0:i.part.item)===m&&this._activeInlayHintPart.part.index===v&&(S.textDecoration="underline",this._activeInlayHintPart.hasTriggerModifier&&(S.color=Di(Mse),S.cursor="pointer")),c&&(C&&w?(S.padding=`1px ${Math.max(1,l/4)|0}px`,S.borderRadius=`${l/4|0}px`):C?(S.padding=`1px 0 1px ${Math.max(1,l/4)|0}px`,S.borderRadius=`${l/4|0}px 0 0 ${l/4|0}px`):w?(S.padding=`1px ${Math.max(1,l/4)|0}px 1px 0`,S.borderRadius=`0 ${l/4|0}px ${l/4|0}px 0`):S.padding="1px 0 1px 0"),r(m,this._ruleFactory.createClassNameRef(S),NLe(b.label),w&&!m.hint.paddingRight?Na.Right:Na.None,new SR(m,v))}if(m.hint.paddingRight&&a(m,!0),o.length>lS._MAX_DECORATORS)break}const g=[];for(const m of e)for(const{id:_}of(n=this._editor.getDecorationsInRange(m))!==null&&n!==void 0?n:[]){const v=this._decorationsMetadata.get(_);v&&(g.push(_),v.classNameRef.dispose(),this._decorationsMetadata.delete(_))}const f=$a.capture(this._editor);this._editor.changeDecorations(m=>{const _=m.deltaDecorations(g,o.map(v=>v.decoration));for(let v=0;v<_.length;v++){const b=o[v];this._decorationsMetadata.set(_[v],b)}}),f.restore(this._editor)}_fillInColors(e,t){t.kind===TS.Parameter?(e.backgroundColor=Di(Ose),e.color=Di(Pse)):t.kind===TS.Type?(e.backgroundColor=Di(Ase),e.color=Di(Rse)):(e.backgroundColor=Di(Bd),e.color=Di(Fd))}_getLayoutInfo(){const e=this._editor.getOption(139),t=e.padding,i=this._editor.getOption(52),n=this._editor.getOption(49);let o=e.fontSize;(!o||o<5||o>i)&&(o=i);const r=e.fontFamily||n;return{fontSize:o,fontFamily:r,padding:t,isUniform:!t&&r===n&&o===i}}_removeAllDecorations(){this._editor.removeDecorations(Array.from(this._decorationsMetadata.keys()));for(const e of this._decorationsMetadata.values())e.classNameRef.dispose();this._decorationsMetadata.clear()}};Xg.ID="editor.contrib.InlayHints";Xg._MAX_DECORATORS=1500;Xg=lS=ILe([Vf(1,xe),Vf(2,Er),Vf(3,xK),Vf(4,Ei),Vf(5,Qi),Vf(6,We)],Xg);function NLe(s){return s.replace(/[ \t]/g," ")}Ct.registerCommand("_executeInlayHintProvider",async(s,...e)=>{const[t,i]=e;zt(Pe.isUri(t)),zt(D.isIRange(i));const{inlayHintsProvider:n}=s.get(xe),o=await s.get(io).createModelReference(t);try{const r=await Bb.create(n,o.object.textEditorModel,[D.lift(i)],ct.None),a=r.items.map(l=>l.hint);return setTimeout(()=>r.dispose(),0),a}finally{o.dispose()}});var TLe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},J_=function(s,e){return function(t,i){e(t,i,s)}};class RB extends sS{constructor(e,t,i,n){super(10,t,e.item.anchor.range,i,n,!0),this.part=e}}let yR=class extends lL{constructor(e,t,i,n,o,r){super(e,t,i,n,r),this._resolverService=o,this.hoverOrdinal=6}suggestHoverAnchor(e){var t;if(!Xg.get(this._editor)||e.target.type!==6)return null;const n=(t=e.target.detail.injectedText)===null||t===void 0?void 0:t.options;return n instanceof Wu&&n.attachedData instanceof SR?new RB(n.attachedData,this,e.event.posx,e.event.posy):null}computeSync(){return[]}computeAsync(e,t,i){return e instanceof RB?new tn(async n=>{const{part:o}=e;if(await o.item.resolve(i),i.isCancellationRequested)return;let r;typeof o.item.hint.tooltip=="string"?r=new rs().appendText(o.item.hint.tooltip):o.item.hint.tooltip&&(r=o.item.hint.tooltip),r&&n.emitOne(new Da(this,e.range,[r],!1,0)),as(o.item.hint.textEdits)&&n.emitOne(new Da(this,e.range,[new rs().appendText(p("hint.dbl","Double-click to insert"))],!1,10001));let a;if(typeof o.part.tooltip=="string"?a=new rs().appendText(o.part.tooltip):o.part.tooltip&&(a=o.part.tooltip),a&&n.emitOne(new Da(this,e.range,[a],!1,1)),o.part.location||o.part.command){let d;const u=this._editor.getOption(77)==="altKey"?bt?p("links.navigate.kb.meta.mac","cmd + click"):p("links.navigate.kb.meta","ctrl + click"):bt?p("links.navigate.kb.alt.mac","option + click"):p("links.navigate.kb.alt","alt + click");o.part.location&&o.part.command?d=new rs().appendText(p("hint.defAndCommand","Go to Definition ({0}), right click for more",u)):o.part.location?d=new rs().appendText(p("hint.def","Go to Definition ({0})",u)):o.part.command&&(d=new rs(`[${p("hint.cmd","Execute Command")}](${DLe(o.part.command)} "${o.part.command.title}") (${u})`,{isTrusted:!0})),d&&n.emitOne(new Da(this,e.range,[d],!1,1e4))}const l=await this._resolveInlayHintLabelPartHover(o,i);for await(const d of l)n.emitOne(d)}):tn.EMPTY}async _resolveInlayHintLabelPartHover(e,t){if(!e.part.location)return tn.EMPTY;const{uri:i,range:n}=e.part.location,o=await this._resolverService.createModelReference(i);try{const r=o.object.textEditorModel;return this._languageFeaturesService.hoverProvider.has(r)?u4(this._languageFeaturesService.hoverProvider,r,new H(n.startLineNumber,n.startColumn),t).filter(a=>!Im(a.hover.contents)).map(a=>new Da(this,e.item.anchor.range,a.hover.contents,!1,2+a.ordinal)):tn.EMPTY}finally{o.dispose()}}};yR=TLe([J_(1,fi),J_(2,No),J_(3,mt),J_(4,io),J_(5,xe)],yR);Lt(Xg.ID,Xg,1);wf.register(yR);class MLe{constructor(e,t,i){this._editRange=e,this._originalSelection=t,this._text=i}getEditOperations(e,t){t.addTrackedEditOperation(this._editRange,this._text)}computeCursorState(e,t){const n=t.getInverseEditOperations()[0].range;return this._originalSelection.isEmpty()?new De(n.endLineNumber,Math.min(this._originalSelection.positionColumn,n.endColumn),n.endLineNumber,Math.min(this._originalSelection.positionColumn,n.endColumn)):new De(n.endLineNumber,n.endColumn-this._text.length,n.endLineNumber,n.endColumn)}}var RLe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},ALe=function(s,e){return function(t,i){e(t,i,s)}},dS;let Yu=dS=class{static get(e){return e.getContribution(dS.ID)}constructor(e,t){this.editor=e,this.editorWorkerService=t,this.decorations=this.editor.createDecorationsCollection()}dispose(){}run(e,t){var i;(i=this.currentRequest)===null||i===void 0||i.cancel();const n=this.editor.getSelection(),o=this.editor.getModel();if(!o||!n)return;let r=n;if(r.startLineNumber!==r.endLineNumber)return;const a=new e$(this.editor,5),l=o.uri;return this.editorWorkerService.canNavigateValueSet(l)?(this.currentRequest=gn(d=>this.editorWorkerService.navigateValueSet(l,r,t)),this.currentRequest.then(d=>{var c;if(!d||!d.range||!d.value||!a.validate(this.editor))return;const u=D.lift(d.range);let h=d.range;const g=d.value.length-(r.endColumn-r.startColumn);h={startLineNumber:h.startLineNumber,startColumn:h.startColumn,endLineNumber:h.endLineNumber,endColumn:h.startColumn+d.value.length},g>1&&(r=new De(r.startLineNumber,r.startColumn,r.endLineNumber,r.endColumn+g-1));const f=new MLe(u,r,d.value);this.editor.pushUndoStop(),this.editor.executeCommand(e,f),this.editor.pushUndoStop(),this.decorations.set([{range:h,options:dS.DECORATION}]),(c=this.decorationRemover)===null||c===void 0||c.cancel(),this.decorationRemover=Iu(350),this.decorationRemover.then(()=>this.decorations.clear()).catch(et)}).catch(et)):Promise.resolve(void 0)}};Yu.ID="editor.contrib.inPlaceReplaceController";Yu.DECORATION=tt.register({description:"in-place-replace",className:"valueSetReplacement"});Yu=dS=RLe([ALe(1,oa)],Yu);class PLe extends we{constructor(){super({id:"editor.action.inPlaceReplace.up",label:p("InPlaceReplaceAction.previous.label","Replace with Previous Value"),alias:"Replace with Previous Value",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:3159,weight:100}})}run(e,t){const i=Yu.get(t);return i?i.run(this.id,!1):Promise.resolve(void 0)}}class OLe extends we{constructor(){super({id:"editor.action.inPlaceReplace.down",label:p("InPlaceReplaceAction.next.label","Replace with Next Value"),alias:"Replace with Next Value",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:3161,weight:100}})}run(e,t){const i=Yu.get(t);return i?i.run(this.id,!0):Promise.resolve(void 0)}}Lt(Yu.ID,Yu,4);re(PLe);re(OLe);class FLe extends we{constructor(){super({id:"expandLineSelection",label:p("expandLineSelection","Expand Line Selection"),alias:"Expand Line Selection",precondition:void 0,kbOpts:{weight:0,kbExpr:T.textInputFocus,primary:2090}})}run(e,t,i){if(i=i||{},!t.hasModel())return;const n=t._getViewModel();n.model.pushStackElement(),n.setCursorStates(i.source,3,Mn.expandLineSelection(n,n.getCursorStates())),n.revealPrimaryCursor(i.source,!0)}}re(FLe);class BLe{constructor(e,t){this._selection=e,this._cursors=t,this._selectionId=null}getEditOperations(e,t){const i=WLe(e,this._cursors);for(let n=0,o=i.length;n<o;n++){const r=i[n];t.addEditOperation(r.range,r.text)}this._selectionId=t.trackSelection(this._selection)}computeCursorState(e,t){return t.getTrackedSelection(this._selectionId)}}function WLe(s,e){e.sort((r,a)=>r.lineNumber===a.lineNumber?r.column-a.column:r.lineNumber-a.lineNumber);for(let r=e.length-2;r>=0;r--)e[r].lineNumber===e[r+1].lineNumber&&e.splice(r,1);const t=[];let i=0,n=0;const o=e.length;for(let r=1,a=s.getLineCount();r<=a;r++){const l=s.getLineContent(r),d=l.length+1;let c=0;if(n<o&&e[n].lineNumber===r&&(c=e[n].column,n++,c===d)||l.length===0)continue;const u=Pa(l);let h=0;if(u===-1)h=1;else if(u!==l.length-1)h=u+2;else continue;h=Math.max(c,h),t[i++]=_i.delete(new D(r,h,r,d))}return t}class DK{constructor(e,t,i){this._selection=e,this._isCopyingDown=t,this._noop=i||!1,this._selectionDirection=0,this._selectionId=null,this._startLineNumberDelta=0,this._endLineNumberDelta=0}getEditOperations(e,t){let i=this._selection;this._startLineNumberDelta=0,this._endLineNumberDelta=0,i.startLineNumber<i.endLineNumber&&i.endColumn===1&&(this._endLineNumberDelta=1,i=i.setEndPosition(i.endLineNumber-1,e.getLineMaxColumn(i.endLineNumber-1)));const n=[];for(let r=i.startLineNumber;r<=i.endLineNumber;r++)n.push(e.getLineContent(r));const o=n.join(`
`);o===""&&this._isCopyingDown&&(this._startLineNumberDelta++,this._endLineNumberDelta++),this._noop?t.addEditOperation(new D(i.endLineNumber,e.getLineMaxColumn(i.endLineNumber),i.endLineNumber+1,1),i.endLineNumber===e.getLineCount()?"":`
`):this._isCopyingDown?t.addEditOperation(new D(i.startLineNumber,1,i.startLineNumber,1),o+`
`):t.addEditOperation(new D(i.endLineNumber,e.getLineMaxColumn(i.endLineNumber),i.endLineNumber,e.getLineMaxColumn(i.endLineNumber)),`
`+o),this._selectionId=t.trackSelection(i),this._selectionDirection=this._selection.getDirection()}computeCursorState(e,t){let i=t.getTrackedSelection(this._selectionId);if(this._startLineNumberDelta!==0||this._endLineNumberDelta!==0){let n=i.startLineNumber,o=i.startColumn,r=i.endLineNumber,a=i.endColumn;this._startLineNumberDelta!==0&&(n=n+this._startLineNumberDelta,o=1),this._endLineNumberDelta!==0&&(r=r+this._endLineNumberDelta,a=1),i=De.createWithDirection(n,o,r,a,this._selectionDirection)}return i}}var VLe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},HLe=function(s,e){return function(t,i){e(t,i,s)}};let LR=class{constructor(e,t,i,n){this._languageConfigurationService=n,this._selection=e,this._isMovingDown=t,this._autoIndent=i,this._selectionId=null,this._moveEndLineSelectionShrink=!1}getEditOperations(e,t){const i=e.getLineCount();if(this._isMovingDown&&this._selection.endLineNumber===i){this._selectionId=t.trackSelection(this._selection);return}if(!this._isMovingDown&&this._selection.startLineNumber===1){this._selectionId=t.trackSelection(this._selection);return}this._moveEndPositionDown=!1;let n=this._selection;n.startLineNumber<n.endLineNumber&&n.endColumn===1&&(this._moveEndPositionDown=!0,n=n.setEndPosition(n.endLineNumber-1,e.getLineMaxColumn(n.endLineNumber-1)));const{tabSize:o,indentSize:r,insertSpaces:a}=e.getOptions(),l=this.buildIndentConverter(o,r,a),d={tokenization:{getLineTokens:c=>e.tokenization.getLineTokens(c),getLanguageId:()=>e.getLanguageId(),getLanguageIdAtPosition:(c,u)=>e.getLanguageIdAtPosition(c,u)},getLineContent:null};if(n.startLineNumber===n.endLineNumber&&e.getLineMaxColumn(n.startLineNumber)===1){const c=n.startLineNumber,u=this._isMovingDown?c+1:c-1;e.getLineMaxColumn(u)===1?t.addEditOperation(new D(1,1,1,1),null):(t.addEditOperation(new D(c,1,c,1),e.getLineContent(u)),t.addEditOperation(new D(u,1,u,e.getLineMaxColumn(u)),null)),n=new De(u,1,u,1)}else{let c,u;if(this._isMovingDown){c=n.endLineNumber+1,u=e.getLineContent(c),t.addEditOperation(new D(c-1,e.getLineMaxColumn(c-1),c,e.getLineMaxColumn(c)),null);let h=u;if(this.shouldAutoIndent(e,n)){const g=this.matchEnterRule(e,l,o,c,n.startLineNumber-1);if(g!==null){const m=Zt(e.getLineContent(c)),_=g+lo(m,o);h=r0(_,o,a)+this.trimStart(u)}else{d.getLineContent=_=>_===n.startLineNumber?e.getLineContent(c):e.getLineContent(_);const m=Bv(this._autoIndent,d,e.getLanguageIdAtPosition(c,1),n.startLineNumber,l,this._languageConfigurationService);if(m!==null){const _=Zt(e.getLineContent(c)),v=lo(m,o),b=lo(_,o);v!==b&&(h=r0(v,o,a)+this.trimStart(u))}}t.addEditOperation(new D(n.startLineNumber,1,n.startLineNumber,1),h+`
`);const f=this.matchEnterRuleMovingDown(e,l,o,n.startLineNumber,c,h);if(f!==null)f!==0&&this.getIndentEditsOfMovingBlock(e,t,n,o,a,f);else{d.getLineContent=_=>_===n.startLineNumber?h:_>=n.startLineNumber+1&&_<=n.endLineNumber+1?e.getLineContent(_-1):e.getLineContent(_);const m=Bv(this._autoIndent,d,e.getLanguageIdAtPosition(c,1),n.startLineNumber+1,l,this._languageConfigurationService);if(m!==null){const _=Zt(e.getLineContent(n.startLineNumber)),v=lo(m,o),b=lo(_,o);if(v!==b){const C=v-b;this.getIndentEditsOfMovingBlock(e,t,n,o,a,C)}}}}else t.addEditOperation(new D(n.startLineNumber,1,n.startLineNumber,1),h+`
`)}else if(c=n.startLineNumber-1,u=e.getLineContent(c),t.addEditOperation(new D(c,1,c+1,1),null),t.addEditOperation(new D(n.endLineNumber,e.getLineMaxColumn(n.endLineNumber),n.endLineNumber,e.getLineMaxColumn(n.endLineNumber)),`
`+u),this.shouldAutoIndent(e,n)){d.getLineContent=g=>g===c?e.getLineContent(n.startLineNumber):e.getLineContent(g);const h=this.matchEnterRule(e,l,o,n.startLineNumber,n.startLineNumber-2);if(h!==null)h!==0&&this.getIndentEditsOfMovingBlock(e,t,n,o,a,h);else{const g=Bv(this._autoIndent,d,e.getLanguageIdAtPosition(n.startLineNumber,1),c,l,this._languageConfigurationService);if(g!==null){const f=Zt(e.getLineContent(n.startLineNumber)),m=lo(g,o),_=lo(f,o);if(m!==_){const v=m-_;this.getIndentEditsOfMovingBlock(e,t,n,o,a,v)}}}}}this._selectionId=t.trackSelection(n)}buildIndentConverter(e,t,i){return{shiftIndent:n=>mr.shiftIndent(n,n.length+1,e,t,i),unshiftIndent:n=>mr.unshiftIndent(n,n.length+1,e,t,i)}}parseEnterResult(e,t,i,n,o){if(o){let r=o.indentation;o.indentAction===nn.None||o.indentAction===nn.Indent?r=o.indentation+o.appendText:o.indentAction===nn.IndentOutdent?r=o.indentation:o.indentAction===nn.Outdent&&(r=t.unshiftIndent(o.indentation)+o.appendText);const a=e.getLineContent(n);if(this.trimStart(a).indexOf(this.trimStart(r))>=0){const l=Zt(e.getLineContent(n));let d=Zt(r);const c=RH(e,n,this._languageConfigurationService);c!==null&&c&2&&(d=t.unshiftIndent(d));const u=lo(d,i),h=lo(l,i);return u-h}}return null}matchEnterRuleMovingDown(e,t,i,n,o,r){if(Pa(r)>=0){const a=e.getLineMaxColumn(o),l=Hp(this._autoIndent,e,new D(o,a,o,a),this._languageConfigurationService);return this.parseEnterResult(e,t,i,n,l)}else{let a=n-1;for(;a>=1;){const c=e.getLineContent(a);if(Pa(c)>=0)break;a--}if(a<1||n>e.getLineCount())return null;const l=e.getLineMaxColumn(a),d=Hp(this._autoIndent,e,new D(a,l,a,l),this._languageConfigurationService);return this.parseEnterResult(e,t,i,n,d)}}matchEnterRule(e,t,i,n,o,r){let a=o;for(;a>=1;){let c;if(a===o&&r!==void 0?c=r:c=e.getLineContent(a),Pa(c)>=0)break;a--}if(a<1||n>e.getLineCount())return null;const l=e.getLineMaxColumn(a),d=Hp(this._autoIndent,e,new D(a,l,a,l),this._languageConfigurationService);return this.parseEnterResult(e,t,i,n,d)}trimStart(e){return e.replace(/^\s+/,"")}shouldAutoIndent(e,t){if(this._autoIndent<4||!e.tokenization.isCheapToTokenize(t.startLineNumber))return!1;const i=e.getLanguageIdAtPosition(t.startLineNumber,1),n=e.getLanguageIdAtPosition(t.endLineNumber,1);return!(i!==n||this._languageConfigurationService.getLanguageConfiguration(i).indentRulesSupport===null)}getIndentEditsOfMovingBlock(e,t,i,n,o,r){for(let a=i.startLineNumber;a<=i.endLineNumber;a++){const l=e.getLineContent(a),d=Zt(l),u=lo(d,n)+r,h=r0(u,n,o);h!==d&&(t.addEditOperation(new D(a,1,a,d.length+1),h),a===i.endLineNumber&&i.endColumn<=d.length+1&&h===""&&(this._moveEndLineSelectionShrink=!0))}}computeCursorState(e,t){let i=t.getTrackedSelection(this._selectionId);return this._moveEndPositionDown&&(i=i.setEndPosition(i.endLineNumber+1,1)),this._moveEndLineSelectionShrink&&i.startLineNumber<i.endLineNumber&&(i=i.setEndPosition(i.endLineNumber,2)),i}};LR=VLe([HLe(3,Jt)],LR);class Cu{static getCollator(){return Cu._COLLATOR||(Cu._COLLATOR=new Intl.Collator),Cu._COLLATOR}constructor(e,t){this.selection=e,this.descending=t,this.selectionId=null}getEditOperations(e,t){const i=zLe(e,this.selection,this.descending);i&&t.addEditOperation(i.range,i.text),this.selectionId=t.trackSelection(this.selection)}computeCursorState(e,t){return t.getTrackedSelection(this.selectionId)}static canRun(e,t,i){if(e===null)return!1;const n=kK(e,t,i);if(!n)return!1;for(let o=0,r=n.before.length;o<r;o++)if(n.before[o]!==n.after[o])return!0;return!1}}Cu._COLLATOR=null;function kK(s,e,t){const i=e.startLineNumber;let n=e.endLineNumber;if(e.endColumn===1&&n--,i>=n)return null;const o=[];for(let a=i;a<=n;a++)o.push(s.getLineContent(a));let r=o.slice(0);return r.sort(Cu.getCollator().compare),t===!0&&(r=r.reverse()),{startLineNumber:i,endLineNumber:n,before:o,after:r}}function zLe(s,e,t){const i=kK(s,e,t);return i?_i.replace(new D(i.startLineNumber,1,i.endLineNumber,s.getLineMaxColumn(i.endLineNumber)),i.after.join(`
`)):null}class IK extends we{constructor(e,t){super(t),this.down=e}run(e,t){if(!t.hasModel())return;const i=t.getSelections().map((r,a)=>({selection:r,index:a,ignore:!1}));i.sort((r,a)=>D.compareRangesUsingStarts(r.selection,a.selection));let n=i[0];for(let r=1;r<i.length;r++){const a=i[r];n.selection.endLineNumber===a.selection.startLineNumber&&(n.index<a.index?a.ignore=!0:(n.ignore=!0,n=a))}const o=[];for(const r of i)o.push(new DK(r.selection,this.down,r.ignore));t.pushUndoStop(),t.executeCommands(this.id,o),t.pushUndoStop()}}class ULe extends IK{constructor(){super(!1,{id:"editor.action.copyLinesUpAction",label:p("lines.copyUp","Copy Line Up"),alias:"Copy Line Up",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:1552,linux:{primary:3600},weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"2_line",title:p({key:"miCopyLinesUp",comment:["&& denotes a mnemonic"]},"&&Copy Line Up"),order:1}})}}class $Le extends IK{constructor(){super(!0,{id:"editor.action.copyLinesDownAction",label:p("lines.copyDown","Copy Line Down"),alias:"Copy Line Down",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:1554,linux:{primary:3602},weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"2_line",title:p({key:"miCopyLinesDown",comment:["&& denotes a mnemonic"]},"Co&&py Line Down"),order:2}})}}class jLe extends we{constructor(){super({id:"editor.action.duplicateSelection",label:p("duplicateSelection","Duplicate Selection"),alias:"Duplicate Selection",precondition:T.writable,menuOpts:{menuId:N.MenubarSelectionMenu,group:"2_line",title:p({key:"miDuplicateSelection",comment:["&& denotes a mnemonic"]},"&&Duplicate Selection"),order:5}})}run(e,t,i){if(!t.hasModel())return;const n=[],o=t.getSelections(),r=t.getModel();for(const a of o)if(a.isEmpty())n.push(new DK(a,!0));else{const l=new De(a.endLineNumber,a.endColumn,a.endLineNumber,a.endColumn);n.push(new iae(l,r.getValueInRange(a)))}t.pushUndoStop(),t.executeCommands(this.id,n),t.pushUndoStop()}}class EK extends we{constructor(e,t){super(t),this.down=e}run(e,t){const i=e.get(Jt),n=[],o=t.getSelections()||[],r=t.getOption(12);for(const a of o)n.push(new LR(a,this.down,r,i));t.pushUndoStop(),t.executeCommands(this.id,n),t.pushUndoStop()}}class KLe extends EK{constructor(){super(!1,{id:"editor.action.moveLinesUpAction",label:p("lines.moveUp","Move Line Up"),alias:"Move Line Up",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:528,linux:{primary:528},weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"2_line",title:p({key:"miMoveLinesUp",comment:["&& denotes a mnemonic"]},"Mo&&ve Line Up"),order:3}})}}class qLe extends EK{constructor(){super(!0,{id:"editor.action.moveLinesDownAction",label:p("lines.moveDown","Move Line Down"),alias:"Move Line Down",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:530,linux:{primary:530},weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"2_line",title:p({key:"miMoveLinesDown",comment:["&& denotes a mnemonic"]},"Move &&Line Down"),order:4}})}}class NK extends we{constructor(e,t){super(t),this.descending=e}run(e,t){const i=t.getSelections()||[];for(const o of i)if(!Cu.canRun(t.getModel(),o,this.descending))return;const n=[];for(let o=0,r=i.length;o<r;o++)n[o]=new Cu(i[o],this.descending);t.pushUndoStop(),t.executeCommands(this.id,n),t.pushUndoStop()}}class GLe extends NK{constructor(){super(!1,{id:"editor.action.sortLinesAscending",label:p("lines.sortAscending","Sort Lines Ascending"),alias:"Sort Lines Ascending",precondition:T.writable})}}class ZLe extends NK{constructor(){super(!0,{id:"editor.action.sortLinesDescending",label:p("lines.sortDescending","Sort Lines Descending"),alias:"Sort Lines Descending",precondition:T.writable})}}class YLe extends we{constructor(){super({id:"editor.action.removeDuplicateLines",label:p("lines.deleteDuplicates","Delete Duplicate Lines"),alias:"Delete Duplicate Lines",precondition:T.writable})}run(e,t){if(!t.hasModel())return;const i=t.getModel();if(i.getLineCount()===1&&i.getLineMaxColumn(1)===1)return;const n=[],o=[];let r=0;for(const a of t.getSelections()){const l=new Set,d=[];for(let g=a.startLineNumber;g<=a.endLineNumber;g++){const f=i.getLineContent(g);l.has(f)||(d.push(f),l.add(f))}const c=new De(a.startLineNumber,1,a.endLineNumber,i.getLineMaxColumn(a.endLineNumber)),u=a.startLineNumber-r,h=new De(u,1,u+d.length-1,d[d.length-1].length);n.push(_i.replace(c,d.join(`
`))),o.push(h),r+=a.endLineNumber-a.startLineNumber+1-d.length}t.pushUndoStop(),t.executeEdits(this.id,n,o),t.pushUndoStop()}}class GD extends we{constructor(){super({id:GD.ID,label:p("lines.trimTrailingWhitespace","Trim Trailing Whitespace"),alias:"Trim Trailing Whitespace",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:dn(2089,2102),weight:100}})}run(e,t,i){let n=[];i.reason==="auto-save"&&(n=(t.getSelections()||[]).map(a=>new H(a.positionLineNumber,a.positionColumn)));const o=t.getSelection();if(o===null)return;const r=new BLe(o,n);t.pushUndoStop(),t.executeCommands(this.id,[r]),t.pushUndoStop()}}GD.ID="editor.action.trimTrailingWhitespace";class XLe extends we{constructor(){super({id:"editor.action.deleteLines",label:p("lines.delete","Delete Line"),alias:"Delete Line",precondition:T.writable,kbOpts:{kbExpr:T.textInputFocus,primary:3113,weight:100}})}run(e,t){if(!t.hasModel())return;const i=this._getLinesToRemove(t),n=t.getModel();if(n.getLineCount()===1&&n.getLineMaxColumn(1)===1)return;let o=0;const r=[],a=[];for(let l=0,d=i.length;l<d;l++){const c=i[l];let u=c.startLineNumber,h=c.endLineNumber,g=1,f=n.getLineMaxColumn(h);h<n.getLineCount()?(h+=1,f=1):u>1&&(u-=1,g=n.getLineMaxColumn(u)),r.push(_i.replace(new De(u,g,h,f),"")),a.push(new De(u-o,c.positionColumn,u-o,c.positionColumn)),o+=c.endLineNumber-c.startLineNumber+1}t.pushUndoStop(),t.executeEdits(this.id,r,a),t.pushUndoStop()}_getLinesToRemove(e){const t=e.getSelections().map(o=>{let r=o.endLineNumber;return o.startLineNumber<o.endLineNumber&&o.endColumn===1&&(r-=1),{startLineNumber:o.startLineNumber,selectionStartColumn:o.selectionStartColumn,endLineNumber:r,positionColumn:o.positionColumn}});t.sort((o,r)=>o.startLineNumber===r.startLineNumber?o.endLineNumber-r.endLineNumber:o.startLineNumber-r.startLineNumber);const i=[];let n=t[0];for(let o=1;o<t.length;o++)n.endLineNumber+1>=t[o].startLineNumber?n.endLineNumber=t[o].endLineNumber:(i.push(n),n=t[o]);return i.push(n),i}}class QLe extends we{constructor(){super({id:"editor.action.indentLines",label:p("lines.indent","Indent Line"),alias:"Indent Line",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:2142,weight:100}})}run(e,t){const i=t._getViewModel();i&&(t.pushUndoStop(),t.executeCommands(this.id,bi.indent(i.cursorConfig,t.getModel(),t.getSelections())),t.pushUndoStop())}}class JLe extends we{constructor(){super({id:"editor.action.outdentLines",label:p("lines.outdent","Outdent Line"),alias:"Outdent Line",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:2140,weight:100}})}run(e,t){zp.Outdent.runEditorCommand(e,t,null)}}class exe extends we{constructor(){super({id:"editor.action.insertLineBefore",label:p("lines.insertBefore","Insert Line Above"),alias:"Insert Line Above",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:3075,weight:100}})}run(e,t){const i=t._getViewModel();i&&(t.pushUndoStop(),t.executeCommands(this.id,bi.lineInsertBefore(i.cursorConfig,t.getModel(),t.getSelections())))}}class txe extends we{constructor(){super({id:"editor.action.insertLineAfter",label:p("lines.insertAfter","Insert Line Below"),alias:"Insert Line Below",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:2051,weight:100}})}run(e,t){const i=t._getViewModel();i&&(t.pushUndoStop(),t.executeCommands(this.id,bi.lineInsertAfter(i.cursorConfig,t.getModel(),t.getSelections())))}}class TK extends we{run(e,t){if(!t.hasModel())return;const i=t.getSelection(),n=this._getRangesToDelete(t),o=[];for(let l=0,d=n.length-1;l<d;l++){const c=n[l],u=n[l+1];D.intersectRanges(c,u)===null?o.push(c):n[l+1]=D.plusRange(c,u)}o.push(n[n.length-1]);const r=this._getEndCursorState(i,o),a=o.map(l=>_i.replace(l,""));t.pushUndoStop(),t.executeEdits(this.id,a,r),t.pushUndoStop()}}class ixe extends TK{constructor(){super({id:"deleteAllLeft",label:p("lines.deleteAllLeft","Delete All Left"),alias:"Delete All Left",precondition:T.writable,kbOpts:{kbExpr:T.textInputFocus,primary:0,mac:{primary:2049},weight:100}})}_getEndCursorState(e,t){let i=null;const n=[];let o=0;return t.forEach(r=>{let a;if(r.endColumn===1&&o>0){const l=r.startLineNumber-o;a=new De(l,r.startColumn,l,r.startColumn)}else a=new De(r.startLineNumber,r.startColumn,r.startLineNumber,r.startColumn);o+=r.endLineNumber-r.startLineNumber,r.intersectRanges(e)?i=a:n.push(a)}),i&&n.unshift(i),n}_getRangesToDelete(e){const t=e.getSelections();if(t===null)return[];let i=t;const n=e.getModel();return n===null?[]:(i.sort(D.compareRangesUsingStarts),i=i.map(o=>{if(o.isEmpty())if(o.startColumn===1){const r=Math.max(1,o.startLineNumber-1),a=o.startLineNumber===1?1:n.getLineLength(r)+1;return new D(r,a,o.startLineNumber,1)}else return new D(o.startLineNumber,1,o.startLineNumber,o.startColumn);else return new D(o.startLineNumber,1,o.endLineNumber,o.endColumn)}),i)}}class nxe extends TK{constructor(){super({id:"deleteAllRight",label:p("lines.deleteAllRight","Delete All Right"),alias:"Delete All Right",precondition:T.writable,kbOpts:{kbExpr:T.textInputFocus,primary:0,mac:{primary:297,secondary:[2068]},weight:100}})}_getEndCursorState(e,t){let i=null;const n=[];for(let o=0,r=t.length,a=0;o<r;o++){const l=t[o],d=new De(l.startLineNumber-a,l.startColumn,l.startLineNumber-a,l.startColumn);l.intersectRanges(e)?i=d:n.push(d)}return i&&n.unshift(i),n}_getRangesToDelete(e){const t=e.getModel();if(t===null)return[];const i=e.getSelections();if(i===null)return[];const n=i.map(o=>{if(o.isEmpty()){const r=t.getLineMaxColumn(o.startLineNumber);return o.startColumn===r?new D(o.startLineNumber,o.startColumn,o.startLineNumber+1,1):new D(o.startLineNumber,o.startColumn,o.startLineNumber,r)}return o});return n.sort(D.compareRangesUsingStarts),n}}class sxe extends we{constructor(){super({id:"editor.action.joinLines",label:p("lines.joinLines","Join Lines"),alias:"Join Lines",precondition:T.writable,kbOpts:{kbExpr:T.editorTextFocus,primary:0,mac:{primary:296},weight:100}})}run(e,t){const i=t.getSelections();if(i===null)return;let n=t.getSelection();if(n===null)return;i.sort(D.compareRangesUsingStarts);const o=[],r=i.reduce((h,g)=>h.isEmpty()?h.endLineNumber===g.startLineNumber?(n.equalsSelection(h)&&(n=g),g):g.startLineNumber>h.endLineNumber+1?(o.push(h),g):new De(h.startLineNumber,h.startColumn,g.endLineNumber,g.endColumn):g.startLineNumber>h.endLineNumber?(o.push(h),g):new De(h.startLineNumber,h.startColumn,g.endLineNumber,g.endColumn));o.push(r);const a=t.getModel();if(a===null)return;const l=[],d=[];let c=n,u=0;for(let h=0,g=o.length;h<g;h++){const f=o[h],m=f.startLineNumber,_=1;let v=0,b,C;const w=a.getLineLength(f.endLineNumber)-f.endColumn;if(f.isEmpty()||f.startLineNumber===f.endLineNumber){const L=f.getStartPosition();L.lineNumber<a.getLineCount()?(b=m+1,C=a.getLineMaxColumn(b)):(b=L.lineNumber,C=a.getLineMaxColumn(L.lineNumber))}else b=f.endLineNumber,C=a.getLineMaxColumn(b);let S=a.getLineContent(m);for(let L=m+1;L<=b;L++){const k=a.getLineContent(L),I=a.getLineFirstNonWhitespaceColumn(L);if(I>=1){let P=!0;S===""&&(P=!1),P&&(S.charAt(S.length-1)===" "||S.charAt(S.length-1)==="	")&&(P=!1,S=S.replace(/[\s\uFEFF\xA0]+$/g," "));const $=k.substr(I-1);S+=(P?" ":"")+$,P?v=$.length+1:v=$.length}else v=0}const x=new D(m,_,b,C);if(!x.isEmpty()){let L;f.isEmpty()?(l.push(_i.replace(x,S)),L=new De(x.startLineNumber-u,S.length-v+1,m-u,S.length-v+1)):f.startLineNumber===f.endLineNumber?(l.push(_i.replace(x,S)),L=new De(f.startLineNumber-u,f.startColumn,f.endLineNumber-u,f.endColumn)):(l.push(_i.replace(x,S)),L=new De(f.startLineNumber-u,f.startColumn,f.startLineNumber-u,S.length-w)),D.intersectRanges(x,n)!==null?c=L:d.push(L)}u+=x.endLineNumber-x.startLineNumber}d.unshift(c),t.pushUndoStop(),t.executeEdits(this.id,l,d),t.pushUndoStop()}}class oxe extends we{constructor(){super({id:"editor.action.transpose",label:p("editor.transpose","Transpose Characters around the Cursor"),alias:"Transpose Characters around the Cursor",precondition:T.writable})}run(e,t){const i=t.getSelections();if(i===null)return;const n=t.getModel();if(n===null)return;const o=[];for(let r=0,a=i.length;r<a;r++){const l=i[r];if(!l.isEmpty())continue;const d=l.getStartPosition(),c=n.getLineMaxColumn(d.lineNumber);if(d.column>=c){if(d.lineNumber===n.getLineCount())continue;const u=new D(d.lineNumber,Math.max(1,d.column-1),d.lineNumber+1,1),h=n.getValueInRange(u).split("").reverse().join("");o.push(new Kn(new De(d.lineNumber,Math.max(1,d.column-1),d.lineNumber+1,1),h))}else{const u=new D(d.lineNumber,Math.max(1,d.column-1),d.lineNumber,d.column+1),h=n.getValueInRange(u).split("").reverse().join("");o.push(new EP(u,h,new De(d.lineNumber,d.column+1,d.lineNumber,d.column+1)))}}t.pushUndoStop(),t.executeCommands(this.id,o),t.pushUndoStop()}}class C_ extends we{run(e,t){const i=t.getSelections();if(i===null)return;const n=t.getModel();if(n===null)return;const o=t.getOption(129),r=[];for(const a of i)if(a.isEmpty()){const l=a.getStartPosition(),d=t.getConfiguredWordAtPosition(l);if(!d)continue;const c=new D(l.lineNumber,d.startColumn,l.lineNumber,d.endColumn),u=n.getValueInRange(c);r.push(_i.replace(c,this._modifyText(u,o)))}else{const l=n.getValueInRange(a);r.push(_i.replace(a,this._modifyText(l,o)))}t.pushUndoStop(),t.executeEdits(this.id,r),t.pushUndoStop()}}class rxe extends C_{constructor(){super({id:"editor.action.transformToUppercase",label:p("editor.transformToUppercase","Transform to Uppercase"),alias:"Transform to Uppercase",precondition:T.writable})}_modifyText(e,t){return e.toLocaleUpperCase()}}class axe extends C_{constructor(){super({id:"editor.action.transformToLowercase",label:p("editor.transformToLowercase","Transform to Lowercase"),alias:"Transform to Lowercase",precondition:T.writable})}_modifyText(e,t){return e.toLocaleLowerCase()}}class Sf{constructor(e,t){this._pattern=e,this._flags=t,this._actual=null,this._evaluated=!1}get(){if(!this._evaluated){this._evaluated=!0;try{this._actual=new RegExp(this._pattern,this._flags)}catch{}}return this._actual}isSupported(){return this.get()!==null}}class Wb extends C_{constructor(){super({id:"editor.action.transformToTitlecase",label:p("editor.transformToTitlecase","Transform to Title Case"),alias:"Transform to Title Case",precondition:T.writable})}_modifyText(e,t){const i=Wb.titleBoundary.get();return i?e.toLocaleLowerCase().replace(i,n=>n.toLocaleUpperCase()):e}}Wb.titleBoundary=new Sf("(^|[^\\p{L}\\p{N}']|((^|\\P{L})'))\\p{L}","gmu");class wu extends C_{constructor(){super({id:"editor.action.transformToSnakecase",label:p("editor.transformToSnakecase","Transform to Snake Case"),alias:"Transform to Snake Case",precondition:T.writable})}_modifyText(e,t){const i=wu.caseBoundary.get(),n=wu.singleLetters.get();return!i||!n?e:e.replace(i,"$1_$2").replace(n,"$1_$2$3").toLocaleLowerCase()}}wu.caseBoundary=new Sf("(\\p{Ll})(\\p{Lu})","gmu");wu.singleLetters=new Sf("(\\p{Lu}|\\p{N})(\\p{Lu})(\\p{Ll})","gmu");class Vb extends C_{constructor(){super({id:"editor.action.transformToCamelcase",label:p("editor.transformToCamelcase","Transform to Camel Case"),alias:"Transform to Camel Case",precondition:T.writable})}_modifyText(e,t){const i=Vb.wordBoundary.get();if(!i)return e;const n=e.split(i);return n.shift()+n.map(r=>r.substring(0,1).toLocaleUpperCase()+r.substring(1)).join("")}}Vb.wordBoundary=new Sf("[_\\s-]","gm");class Xd extends C_{static isSupported(){return[this.caseBoundary,this.singleLetters,this.underscoreBoundary].every(t=>t.isSupported())}constructor(){super({id:"editor.action.transformToKebabcase",label:p("editor.transformToKebabcase","Transform to Kebab Case"),alias:"Transform to Kebab Case",precondition:T.writable})}_modifyText(e,t){const i=Xd.caseBoundary.get(),n=Xd.singleLetters.get(),o=Xd.underscoreBoundary.get();return!i||!n||!o?e:e.replace(o,"$1-$3").replace(i,"$1-$2").replace(n,"$1-$2").toLocaleLowerCase()}}Xd.caseBoundary=new Sf("(\\p{Ll})(\\p{Lu})","gmu");Xd.singleLetters=new Sf("(\\p{Lu}|\\p{N})(\\p{Lu}\\p{Ll})","gmu");Xd.underscoreBoundary=new Sf("(\\S)(_)(\\S)","gm");re(ULe);re($Le);re(jLe);re(KLe);re(qLe);re(GLe);re(ZLe);re(YLe);re(GD);re(XLe);re(QLe);re(JLe);re(exe);re(txe);re(ixe);re(nxe);re(sxe);re(oxe);re(rxe);re(axe);wu.caseBoundary.isSupported()&&wu.singleLetters.isSupported()&&re(wu);Vb.wordBoundary.isSupported()&&re(Vb);Wb.titleBoundary.isSupported()&&re(Wb);Xd.isSupported()&&re(Xd);var lxe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},_w=function(s,e){return function(t,i){e(t,i,s)}},cS;const MK=new me("LinkedEditingInputVisible",!1),dxe="linked-editing-decoration";let Xu=cS=class extends j{static get(e){return e.getContribution(cS.ID)}constructor(e,t,i,n,o){super(),this.languageConfigurationService=n,this._syncRangesToken=0,this._localToDispose=this._register(new ie),this._editor=e,this._providers=i.linkedEditingRangeProvider,this._enabled=!1,this._visibleContextKey=MK.bindTo(t),this._debounceInformation=o.for(this._providers,"Linked Editing",{max:200}),this._currentDecorations=this._editor.createDecorationsCollection(),this._languageWordPattern=null,this._currentWordPattern=null,this._ignoreChangeEvent=!1,this._localToDispose=this._register(new ie),this._rangeUpdateTriggerPromise=null,this._rangeSyncTriggerPromise=null,this._currentRequest=null,this._currentRequestPosition=null,this._currentRequestModelVersion=null,this._register(this._editor.onDidChangeModel(()=>this.reinitialize(!0))),this._register(this._editor.onDidChangeConfiguration(r=>{(r.hasChanged(69)||r.hasChanged(92))&&this.reinitialize(!1)})),this._register(this._providers.onDidChange(()=>this.reinitialize(!1))),this._register(this._editor.onDidChangeModelLanguage(()=>this.reinitialize(!0))),this.reinitialize(!0)}reinitialize(e){const t=this._editor.getModel(),i=t!==null&&(this._editor.getOption(69)||this._editor.getOption(92))&&this._providers.has(t);if(i===this._enabled&&!e||(this._enabled=i,this.clearRanges(),this._localToDispose.clear(),!i||t===null))return;this._localToDispose.add(ge.runAndSubscribe(t.onDidChangeLanguageConfiguration,()=>{this._languageWordPattern=this.languageConfigurationService.getLanguageConfiguration(t.getLanguageId()).getWordDefinition()}));const n=new Qr(this._debounceInformation.get(t)),o=()=>{var l;this._rangeUpdateTriggerPromise=n.trigger(()=>this.updateRanges(),(l=this._debounceDuration)!==null&&l!==void 0?l:this._debounceInformation.get(t))},r=new Qr(0),a=l=>{this._rangeSyncTriggerPromise=r.trigger(()=>this._syncRanges(l))};this._localToDispose.add(this._editor.onDidChangeCursorPosition(()=>{o()})),this._localToDispose.add(this._editor.onDidChangeModelContent(l=>{if(!this._ignoreChangeEvent&&this._currentDecorations.length>0){const d=this._currentDecorations.getRange(0);if(d&&l.changes.every(c=>d.intersectRanges(c.range))){a(this._syncRangesToken);return}}o()})),this._localToDispose.add({dispose:()=>{n.dispose(),r.dispose()}}),this.updateRanges()}_syncRanges(e){if(!this._editor.hasModel()||e!==this._syncRangesToken||this._currentDecorations.length===0)return;const t=this._editor.getModel(),i=this._currentDecorations.getRange(0);if(!i||i.startLineNumber!==i.endLineNumber)return this.clearRanges();const n=t.getValueInRange(i);if(this._currentWordPattern){const r=n.match(this._currentWordPattern);if((r?r[0].length:0)!==n.length)return this.clearRanges()}const o=[];for(let r=1,a=this._currentDecorations.length;r<a;r++){const l=this._currentDecorations.getRange(r);if(l)if(l.startLineNumber!==l.endLineNumber)o.push({range:l,text:n});else{let d=t.getValueInRange(l),c=n,u=l.startColumn,h=l.endColumn;const g=Dg(d,c);u+=g,d=d.substr(g),c=c.substr(g);const f=RS(d,c);h-=f,d=d.substr(0,d.length-f),c=c.substr(0,c.length-f),(u!==h||c.length!==0)&&o.push({range:new D(l.startLineNumber,u,l.endLineNumber,h),text:c})}}if(o.length!==0)try{this._editor.popUndoStop(),this._ignoreChangeEvent=!0;const r=this._editor._getViewModel().getPrevEditOperationType();this._editor.executeEdits("linkedEditing",o),this._editor._getViewModel().setPrevEditOperationType(r)}finally{this._ignoreChangeEvent=!1}}dispose(){this.clearRanges(),super.dispose()}clearRanges(){this._visibleContextKey.set(!1),this._currentDecorations.clear(),this._currentRequest&&(this._currentRequest.cancel(),this._currentRequest=null,this._currentRequestPosition=null)}async updateRanges(e=!1){if(!this._editor.hasModel()){this.clearRanges();return}const t=this._editor.getPosition();if(!this._enabled&&!e||this._editor.getSelections().length>1){this.clearRanges();return}const i=this._editor.getModel(),n=i.getVersionId();if(this._currentRequestPosition&&this._currentRequestModelVersion===n){if(t.equals(this._currentRequestPosition))return;if(this._currentDecorations.length>0){const r=this._currentDecorations.getRange(0);if(r&&r.containsPosition(t))return}}this.clearRanges(),this._currentRequestPosition=t,this._currentRequestModelVersion=n;const o=gn(async r=>{try{const a=new cs(!1),l=await RK(this._providers,i,t,r);if(this._debounceInformation.update(i,a.elapsed()),o!==this._currentRequest||(this._currentRequest=null,n!==i.getVersionId()))return;let d=[];l!=null&&l.ranges&&(d=l.ranges),this._currentWordPattern=(l==null?void 0:l.wordPattern)||this._languageWordPattern;let c=!1;for(let h=0,g=d.length;h<g;h++)if(D.containsPosition(d[h],t)){if(c=!0,h!==0){const f=d[h];d.splice(h,1),d.unshift(f)}break}if(!c){this.clearRanges();return}const u=d.map(h=>({range:h,options:cS.DECORATION}));this._visibleContextKey.set(!0),this._currentDecorations.set(u),this._syncRangesToken++}catch(a){Ka(a)||et(a),(this._currentRequest===o||!this._currentRequest)&&this.clearRanges()}});return this._currentRequest=o,o}};Xu.ID="editor.contrib.linkedEditing";Xu.DECORATION=tt.register({description:"linked-editing",stickiness:0,className:dxe});Xu=cS=lxe([_w(1,je),_w(2,xe),_w(3,Jt),_w(4,Er)],Xu);class cxe extends we{constructor(){super({id:"editor.action.linkedEditing",label:p("linkedEditing.label","Start Linked Editing"),alias:"Start Linked Editing",precondition:ee.and(T.writable,T.hasRenameProvider),kbOpts:{kbExpr:T.editorTextFocus,primary:3132,weight:100}})}runCommand(e,t){const i=e.get(It),[n,o]=Array.isArray(t)&&t||[void 0,void 0];return Pe.isUri(n)&&H.isIPosition(o)?i.openCodeEditor({resource:n},i.getActiveCodeEditor()).then(r=>{r&&(r.setPosition(o),r.invokeWithinContext(a=>(this.reportTelemetry(a,r),this.run(a,r))))},et):super.runCommand(e,t)}run(e,t){const i=Xu.get(t);return i?Promise.resolve(i.updateRanges(!0)):Promise.resolve()}}const uxe=Nn.bindToContribution(Xu.get);ue(new uxe({id:"cancelLinkedEditingInput",precondition:MK,handler:s=>s.clearRanges(),kbOpts:{kbExpr:T.editorTextFocus,weight:199,primary:9,secondary:[1033]}}));function RK(s,e,t,i){const n=s.ordered(e);return GA(n.map(o=>async()=>{try{return await o.provideLinkedEditingRanges(e,t,i)}catch(r){Zi(r);return}}),o=>!!o&&as(o==null?void 0:o.ranges))}R("editor.linkedEditingBackground",{dark:G.fromHex("#f00").transparent(.3),light:G.fromHex("#f00").transparent(.3),hcDark:G.fromHex("#f00").transparent(.3),hcLight:G.white},p("editorLinkedEditingBackground","Background color when the editor auto renames on type."));od("_executeLinkedEditingProvider",(s,e,t)=>{const{linkedEditingRangeProvider:i}=s.get(xe);return RK(i,e,t,ct.None)});Lt(Xu.ID,Xu,1);re(cxe);let hxe=class{constructor(e,t){this._link=e,this._provider=t}toJSON(){return{range:this.range,url:this.url,tooltip:this.tooltip}}get range(){return this._link.range}get url(){return this._link.url}get tooltip(){return this._link.tooltip}async resolve(e){return this._link.url?this._link.url:typeof this._provider.resolveLink=="function"?Promise.resolve(this._provider.resolveLink(this._link,e)).then(t=>(this._link=t||this._link,this._link.url?this.resolve(e):Promise.reject(new Error("missing")))):Promise.reject(new Error("missing"))}};class wL{constructor(e){this._disposables=new ie;let t=[];for(const[i,n]of e){const o=i.links.map(r=>new hxe(r,n));t=wL._union(t,o),EA(i)&&this._disposables.add(i)}this.links=t}dispose(){this._disposables.dispose(),this.links.length=0}static _union(e,t){const i=[];let n,o,r,a;for(n=0,r=0,o=e.length,a=t.length;n<o&&r<a;){const l=e[n],d=t[r];if(D.areIntersectingOrTouching(l.range,d.range)){n++;continue}D.compareRangesUsingStarts(l.range,d.range)<0?(i.push(l),n++):(i.push(d),r++)}for(;n<o;n++)i.push(e[n]);for(;r<a;r++)i.push(t[r]);return i}}function AK(s,e,t){const i=[],n=s.ordered(e).reverse().map((o,r)=>Promise.resolve(o.provideLinks(e,t)).then(a=>{a&&(i[r]=[a,o])},Zi));return Promise.all(n).then(()=>{const o=new wL(Ba(i));return t.isCancellationRequested?(o.dispose(),new wL([])):o})}Ct.registerCommand("_executeLinkProvider",async(s,...e)=>{let[t,i]=e;zt(t instanceof Pe),typeof i!="number"&&(i=0);const{linkProvider:n}=s.get(xe),o=s.get(vi).getModel(t);if(!o)return[];const r=await AK(n,o,ct.None);if(!r)return[];for(let l=0;l<Math.min(i,r.links.length);l++)await r.links[l].resolve(ct.None);const a=r.links.slice(0);return r.dispose(),a});var gxe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},vw=function(s,e){return function(t,i){e(t,i,s)}},xR;let jm=xR=class extends j{static get(e){return e.getContribution(xR.ID)}constructor(e,t,i,n,o){super(),this.editor=e,this.openerService=t,this.notificationService=i,this.languageFeaturesService=n,this.providers=this.languageFeaturesService.linkProvider,this.debounceInformation=o.for(this.providers,"Links",{min:1e3,max:4e3}),this.computeLinks=this._register(new jt(()=>this.computeLinksNow(),1e3)),this.computePromise=null,this.activeLinksList=null,this.currentOccurrences={},this.activeLinkDecorationId=null;const r=this._register(new mD(e));this._register(r.onMouseMoveOrRelevantKeyDown(([a,l])=>{this._onEditorMouseMove(a,l)})),this._register(r.onExecute(a=>{this.onEditorMouseUp(a)})),this._register(r.onCancel(a=>{this.cleanUpActiveLinkDecoration()})),this._register(e.onDidChangeConfiguration(a=>{a.hasChanged(70)&&(this.updateDecorations([]),this.stop(),this.computeLinks.schedule(0))})),this._register(e.onDidChangeModelContent(a=>{this.editor.hasModel()&&this.computeLinks.schedule(this.debounceInformation.get(this.editor.getModel()))})),this._register(e.onDidChangeModel(a=>{this.currentOccurrences={},this.activeLinkDecorationId=null,this.stop(),this.computeLinks.schedule(0)})),this._register(e.onDidChangeModelLanguage(a=>{this.stop(),this.computeLinks.schedule(0)})),this._register(this.providers.onDidChange(a=>{this.stop(),this.computeLinks.schedule(0)})),this.computeLinks.schedule(0)}async computeLinksNow(){if(!this.editor.hasModel()||!this.editor.getOption(70))return;const e=this.editor.getModel();if(!e.isTooLargeForSyncing()&&this.providers.has(e)){this.activeLinksList&&(this.activeLinksList.dispose(),this.activeLinksList=null),this.computePromise=gn(t=>AK(this.providers,e,t));try{const t=new cs(!1);if(this.activeLinksList=await this.computePromise,this.debounceInformation.update(e,t.elapsed()),e.isDisposed())return;this.updateDecorations(this.activeLinksList.links)}catch(t){et(t)}finally{this.computePromise=null}}}updateDecorations(e){const t=this.editor.getOption(77)==="altKey",i=[],n=Object.keys(this.currentOccurrences);for(const r of n){const a=this.currentOccurrences[r];i.push(a.decorationId)}const o=[];if(e)for(const r of e)o.push(em.decoration(r,t));this.editor.changeDecorations(r=>{const a=r.deltaDecorations(i,o);this.currentOccurrences={},this.activeLinkDecorationId=null;for(let l=0,d=a.length;l<d;l++){const c=new em(e[l],a[l]);this.currentOccurrences[c.decorationId]=c}})}_onEditorMouseMove(e,t){const i=this.editor.getOption(77)==="altKey";if(this.isEnabled(e,t)){this.cleanUpActiveLinkDecoration();const n=this.getLinkOccurrence(e.target.position);n&&this.editor.changeDecorations(o=>{n.activate(o,i),this.activeLinkDecorationId=n.decorationId})}else this.cleanUpActiveLinkDecoration()}cleanUpActiveLinkDecoration(){const e=this.editor.getOption(77)==="altKey";if(this.activeLinkDecorationId){const t=this.currentOccurrences[this.activeLinkDecorationId];t&&this.editor.changeDecorations(i=>{t.deactivate(i,e)}),this.activeLinkDecorationId=null}}onEditorMouseUp(e){if(!this.isEnabled(e))return;const t=this.getLinkOccurrence(e.target.position);t&&this.openLinkOccurrence(t,e.hasSideBySideModifier,!0)}openLinkOccurrence(e,t,i=!1){if(!this.openerService)return;const{link:n}=e;n.resolve(ct.None).then(o=>{if(typeof o=="string"&&this.editor.hasModel()){const r=this.editor.getModel().uri;if(r.scheme===it.file&&o.startsWith(`${it.file}:`)){const a=Pe.parse(o);if(a.scheme===it.file){const l=rl(a);let d=null;l.startsWith("/./")?d=`.${l.substr(1)}`:l.startsWith("//./")&&(d=`.${l.substr(2)}`),d&&(o=Ole(r,d))}}}return this.openerService.open(o,{openToSide:t,fromUserGesture:i,allowContributedOpeners:!0,allowCommands:!0,fromWorkspace:!0})},o=>{const r=o instanceof Error?o.message:o;r==="invalid"?this.notificationService.warn(p("invalid.url","Failed to open this link because it is not well-formed: {0}",n.url.toString())):r==="missing"?this.notificationService.warn(p("missing.url","Failed to open this link because its target is missing.")):et(o)})}getLinkOccurrence(e){if(!this.editor.hasModel()||!e)return null;const t=this.editor.getModel().getDecorationsInRange({startLineNumber:e.lineNumber,startColumn:e.column,endLineNumber:e.lineNumber,endColumn:e.column},0,!0);for(const i of t){const n=this.currentOccurrences[i.id];if(n)return n}return null}isEnabled(e,t){return!!(e.target.type===6&&(e.hasTriggerModifier||t&&t.keyCodeIsTriggerKey))}stop(){var e;this.computeLinks.cancel(),this.activeLinksList&&((e=this.activeLinksList)===null||e===void 0||e.dispose(),this.activeLinksList=null),this.computePromise&&(this.computePromise.cancel(),this.computePromise=null)}dispose(){super.dispose(),this.stop()}};jm.ID="editor.linkDetector";jm=xR=gxe([vw(1,No),vw(2,Qi),vw(3,xe),vw(4,Er)],jm);const AB={general:tt.register({description:"detected-link",stickiness:1,collapseOnReplaceEdit:!0,inlineClassName:"detected-link"}),active:tt.register({description:"detected-link-active",stickiness:1,collapseOnReplaceEdit:!0,inlineClassName:"detected-link-active"})};class em{static decoration(e,t){return{range:e.range,options:em._getOptions(e,t,!1)}}static _getOptions(e,t,i){const n={...i?AB.active:AB.general};return n.hoverMessage=fxe(e,t),n}constructor(e,t){this.link=e,this.decorationId=t}activate(e,t){e.changeDecorationOptions(this.decorationId,em._getOptions(this.link,t,!0))}deactivate(e,t){e.changeDecorationOptions(this.decorationId,em._getOptions(this.link,t,!1))}}function fxe(s,e){const t=s.url&&/^command:/i.test(s.url.toString()),i=s.tooltip?s.tooltip:t?p("links.navigate.executeCmd","Execute command"):p("links.navigate.follow","Follow link"),n=e?bt?p("links.navigate.kb.meta.mac","cmd + click"):p("links.navigate.kb.meta","ctrl + click"):bt?p("links.navigate.kb.alt.mac","option + click"):p("links.navigate.kb.alt","alt + click");if(s.url){let o="";if(/^command:/i.test(s.url.toString())){const a=s.url.toString().match(/^command:([^?#]+)/);if(a){const l=a[1];o=p("tooltip.explanation","Execute command {0}",l)}}return new rs("",!0).appendLink(s.url.toString(!0).replace(/ /g,"%20"),i,o).appendMarkdown(` (${n})`)}else return new rs().appendText(`${i} (${n})`)}class pxe extends we{constructor(){super({id:"editor.action.openLink",label:p("label","Open Link"),alias:"Open Link",precondition:void 0})}run(e,t){const i=jm.get(t);if(!i||!t.hasModel())return;const n=t.getSelections();for(const o of n){const r=i.getLinkOccurrence(o.getEndPosition());r&&i.openLinkOccurrence(r,!1)}}}Lt(jm.ID,jm,1);re(pxe);class DR extends j{constructor(e){super(),this._editor=e,this._register(this._editor.onMouseDown(t=>{const i=this._editor.getOption(116);i>=0&&t.target.type===6&&t.target.position.column>=i&&this._editor.updateOptions({stopRenderingLineAfter:-1})}))}}DR.ID="editor.contrib.longLinesHelper";Lt(DR.ID,DR,2);const bw=R("editor.wordHighlightBackground",{dark:"#575757B8",light:"#57575740",hcDark:null,hcLight:null},p("wordHighlight","Background color of a symbol during read-access, like reading a variable. The color must not be opaque so as not to hide underlying decorations."),!0);R("editor.wordHighlightStrongBackground",{dark:"#004972B8",light:"#0e639c40",hcDark:null,hcLight:null},p("wordHighlightStrong","Background color of a symbol during write-access, like writing to a variable. The color must not be opaque so as not to hide underlying decorations."),!0);R("editor.wordHighlightTextBackground",{light:bw,dark:bw,hcDark:bw,hcLight:bw},p("wordHighlightText","Background color of a textual occurrence for a symbol. The color must not be opaque so as not to hide underlying decorations."),!0);const Cw=R("editor.wordHighlightBorder",{light:null,dark:null,hcDark:ai,hcLight:ai},p("wordHighlightBorder","Border color of a symbol during read-access, like reading a variable."));R("editor.wordHighlightStrongBorder",{light:null,dark:null,hcDark:ai,hcLight:ai},p("wordHighlightStrongBorder","Border color of a symbol during write-access, like writing to a variable."));R("editor.wordHighlightTextBorder",{light:Cw,dark:Cw,hcDark:Cw,hcLight:Cw},p("wordHighlightTextBorder","Border color of a textual occurrence for a symbol."));const mxe=R("editorOverviewRuler.wordHighlightForeground",{dark:"#A0A0A0CC",light:"#A0A0A0CC",hcDark:"#A0A0A0CC",hcLight:"#A0A0A0CC"},p("overviewRulerWordHighlightForeground","Overview ruler marker color for symbol highlights. The color must not be opaque so as not to hide underlying decorations."),!0),_xe=R("editorOverviewRuler.wordHighlightStrongForeground",{dark:"#C0A0C0CC",light:"#C0A0C0CC",hcDark:"#C0A0C0CC",hcLight:"#C0A0C0CC"},p("overviewRulerWordHighlightStrongForeground","Overview ruler marker color for write-access symbol highlights. The color must not be opaque so as not to hide underlying decorations."),!0),vxe=R("editorOverviewRuler.wordHighlightTextForeground",{dark:gv,light:gv,hcDark:gv,hcLight:gv},p("overviewRulerWordHighlightTextForeground","Overview ruler marker color of a textual occurrence for a symbol. The color must not be opaque so as not to hide underlying decorations."),!0),bxe=tt.register({description:"word-highlight-strong",stickiness:1,className:"wordHighlightStrong",overviewRuler:{color:Di(_xe),position:nr.Center},minimap:{color:Di(wx),position:bo.Inline}}),Cxe=tt.register({description:"word-highlight-text",stickiness:1,className:"wordHighlightText",overviewRuler:{color:Di(vxe),position:nr.Center},minimap:{color:Di(wx),position:bo.Inline}}),wxe=tt.register({description:"selection-highlight-overview",stickiness:1,className:"selectionHighlight",overviewRuler:{color:Di(gv),position:nr.Center},minimap:{color:Di(wx),position:bo.Inline}}),Sxe=tt.register({description:"selection-highlight",stickiness:1,className:"selectionHighlight"}),yxe=tt.register({description:"word-highlight",stickiness:1,className:"wordHighlight",overviewRuler:{color:Di(mxe),position:nr.Center},minimap:{color:Di(wx),position:bo.Inline}});function Lxe(s){return s===L0.Write?bxe:s===L0.Text?Cxe:yxe}function xxe(s){return s?Sxe:wxe}ia((s,e)=>{const t=s.getColor(wP);t&&e.addRule(`.monaco-editor .selectionHighlight { background-color: ${t.transparent(.5)}; }`)});var Dxe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},kxe=function(s,e){return function(t,i){e(t,i,s)}},kR;function dh(s,e){const t=e.filter(i=>!s.find(n=>n.equals(i)));if(t.length>=1){const i=t.map(o=>`line ${o.viewState.position.lineNumber} column ${o.viewState.position.column}`).join(", "),n=t.length===1?p("cursorAdded","Cursor added: {0}",i):p("cursorsAdded","Cursors added: {0}",i);Au(n)}}class Ixe extends we{constructor(){super({id:"editor.action.insertCursorAbove",label:p("mutlicursor.insertAbove","Add Cursor Above"),alias:"Add Cursor Above",precondition:void 0,kbOpts:{kbExpr:T.editorTextFocus,primary:2576,linux:{primary:1552,secondary:[3088]},weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"3_multi",title:p({key:"miInsertCursorAbove",comment:["&& denotes a mnemonic"]},"&&Add Cursor Above"),order:2}})}run(e,t,i){if(!t.hasModel())return;let n=!0;i&&i.logicalLine===!1&&(n=!1);const o=t._getViewModel();if(o.cursorConfig.readOnly)return;o.model.pushStackElement();const r=o.getCursorStates();o.setCursorStates(i.source,3,Mn.addCursorUp(o,r,n)),o.revealTopMostCursor(i.source),dh(r,o.getCursorStates())}}class Exe extends we{constructor(){super({id:"editor.action.insertCursorBelow",label:p("mutlicursor.insertBelow","Add Cursor Below"),alias:"Add Cursor Below",precondition:void 0,kbOpts:{kbExpr:T.editorTextFocus,primary:2578,linux:{primary:1554,secondary:[3090]},weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"3_multi",title:p({key:"miInsertCursorBelow",comment:["&& denotes a mnemonic"]},"A&&dd Cursor Below"),order:3}})}run(e,t,i){if(!t.hasModel())return;let n=!0;i&&i.logicalLine===!1&&(n=!1);const o=t._getViewModel();if(o.cursorConfig.readOnly)return;o.model.pushStackElement();const r=o.getCursorStates();o.setCursorStates(i.source,3,Mn.addCursorDown(o,r,n)),o.revealBottomMostCursor(i.source),dh(r,o.getCursorStates())}}class Nxe extends we{constructor(){super({id:"editor.action.insertCursorAtEndOfEachLineSelected",label:p("mutlicursor.insertAtEndOfEachLineSelected","Add Cursors to Line Ends"),alias:"Add Cursors to Line Ends",precondition:void 0,kbOpts:{kbExpr:T.editorTextFocus,primary:1575,weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"3_multi",title:p({key:"miInsertCursorAtEndOfEachLineSelected",comment:["&& denotes a mnemonic"]},"Add C&&ursors to Line Ends"),order:4}})}getCursorsForSelection(e,t,i){if(!e.isEmpty()){for(let n=e.startLineNumber;n<e.endLineNumber;n++){const o=t.getLineMaxColumn(n);i.push(new De(n,o,n,o))}e.endColumn>1&&i.push(new De(e.endLineNumber,e.endColumn,e.endLineNumber,e.endColumn))}}run(e,t){if(!t.hasModel())return;const i=t.getModel(),n=t.getSelections(),o=t._getViewModel(),r=o.getCursorStates(),a=[];n.forEach(l=>this.getCursorsForSelection(l,i,a)),a.length>0&&t.setSelections(a),dh(r,o.getCursorStates())}}class Txe extends we{constructor(){super({id:"editor.action.addCursorsToBottom",label:p("mutlicursor.addCursorsToBottom","Add Cursors To Bottom"),alias:"Add Cursors To Bottom",precondition:void 0})}run(e,t){if(!t.hasModel())return;const i=t.getSelections(),n=t.getModel().getLineCount(),o=[];for(let l=i[0].startLineNumber;l<=n;l++)o.push(new De(l,i[0].startColumn,l,i[0].endColumn));const r=t._getViewModel(),a=r.getCursorStates();o.length>0&&t.setSelections(o),dh(a,r.getCursorStates())}}class Mxe extends we{constructor(){super({id:"editor.action.addCursorsToTop",label:p("mutlicursor.addCursorsToTop","Add Cursors To Top"),alias:"Add Cursors To Top",precondition:void 0})}run(e,t){if(!t.hasModel())return;const i=t.getSelections(),n=[];for(let a=i[0].startLineNumber;a>=1;a--)n.push(new De(a,i[0].startColumn,a,i[0].endColumn));const o=t._getViewModel(),r=o.getCursorStates();n.length>0&&t.setSelections(n),dh(r,o.getCursorStates())}}class ww{constructor(e,t,i){this.selections=e,this.revealRange=t,this.revealScrollType=i}}class Hb{static create(e,t){if(!e.hasModel())return null;const i=t.getState();if(!e.hasTextFocus()&&i.isRevealed&&i.searchString.length>0)return new Hb(e,t,!1,i.searchString,i.wholeWord,i.matchCase,null);let n=!1,o,r;const a=e.getSelections();a.length===1&&a[0].isEmpty()?(n=!0,o=!0,r=!0):(o=i.wholeWord,r=i.matchCase);const l=e.getSelection();let d,c=null;if(l.isEmpty()){const u=e.getConfiguredWordAtPosition(l.getStartPosition());if(!u)return null;d=u.word,c=new De(l.startLineNumber,u.startColumn,l.startLineNumber,u.endColumn)}else d=e.getModel().getValueInRange(l).replace(/\r\n/g,`
`);return new Hb(e,t,n,d,o,r,c)}constructor(e,t,i,n,o,r,a){this._editor=e,this.findController=t,this.isDisconnectedFromFindController=i,this.searchText=n,this.wholeWord=o,this.matchCase=r,this.currentMatch=a}addSelectionToNextFindMatch(){if(!this._editor.hasModel())return null;const e=this._getNextMatch();if(!e)return null;const t=this._editor.getSelections();return new ww(t.concat(e),e,0)}moveSelectionToNextFindMatch(){if(!this._editor.hasModel())return null;const e=this._getNextMatch();if(!e)return null;const t=this._editor.getSelections();return new ww(t.slice(0,t.length-1).concat(e),e,0)}_getNextMatch(){if(!this._editor.hasModel())return null;if(this.currentMatch){const n=this.currentMatch;return this.currentMatch=null,n}this.findController.highlightFindOptions();const e=this._editor.getSelections(),t=e[e.length-1],i=this._editor.getModel().findNextMatch(this.searchText,t.getEndPosition(),!1,this.matchCase,this.wholeWord?this._editor.getOption(129):null,!1);return i?new De(i.range.startLineNumber,i.range.startColumn,i.range.endLineNumber,i.range.endColumn):null}addSelectionToPreviousFindMatch(){if(!this._editor.hasModel())return null;const e=this._getPreviousMatch();if(!e)return null;const t=this._editor.getSelections();return new ww(t.concat(e),e,0)}moveSelectionToPreviousFindMatch(){if(!this._editor.hasModel())return null;const e=this._getPreviousMatch();if(!e)return null;const t=this._editor.getSelections();return new ww(t.slice(0,t.length-1).concat(e),e,0)}_getPreviousMatch(){if(!this._editor.hasModel())return null;if(this.currentMatch){const n=this.currentMatch;return this.currentMatch=null,n}this.findController.highlightFindOptions();const e=this._editor.getSelections(),t=e[e.length-1],i=this._editor.getModel().findPreviousMatch(this.searchText,t.getStartPosition(),!1,this.matchCase,this.wholeWord?this._editor.getOption(129):null,!1);return i?new De(i.range.startLineNumber,i.range.startColumn,i.range.endLineNumber,i.range.endColumn):null}selectAll(e){if(!this._editor.hasModel())return[];this.findController.highlightFindOptions();const t=this._editor.getModel();return e?t.findMatches(this.searchText,e,!1,this.matchCase,this.wholeWord?this._editor.getOption(129):null,!1,1073741824):t.findMatches(this.searchText,!0,!1,this.matchCase,this.wholeWord?this._editor.getOption(129):null,!1,1073741824)}}class Qg extends j{static get(e){return e.getContribution(Qg.ID)}constructor(e){super(),this._sessionDispose=this._register(new ie),this._editor=e,this._ignoreSelectionChange=!1,this._session=null}dispose(){this._endSession(),super.dispose()}_beginSessionIfNeeded(e){if(!this._session){const t=Hb.create(this._editor,e);if(!t)return;this._session=t;const i={searchString:this._session.searchText};this._session.isDisconnectedFromFindController&&(i.wholeWordOverride=1,i.matchCaseOverride=1,i.isRegexOverride=2),e.getState().change(i,!1),this._sessionDispose.add(this._editor.onDidChangeCursorSelection(n=>{this._ignoreSelectionChange||this._endSession()})),this._sessionDispose.add(this._editor.onDidBlurEditorText(()=>{this._endSession()})),this._sessionDispose.add(e.getState().onFindReplaceStateChange(n=>{(n.matchCase||n.wholeWord)&&this._endSession()}))}}_endSession(){if(this._sessionDispose.clear(),this._session&&this._session.isDisconnectedFromFindController){const e={wholeWordOverride:0,matchCaseOverride:0,isRegexOverride:0};this._session.findController.getState().change(e,!1)}this._session=null}_setSelections(e){this._ignoreSelectionChange=!0,this._editor.setSelections(e),this._ignoreSelectionChange=!1}_expandEmptyToWord(e,t){if(!t.isEmpty())return t;const i=this._editor.getConfiguredWordAtPosition(t.getStartPosition());return i?new De(t.startLineNumber,i.startColumn,t.startLineNumber,i.endColumn):t}_applySessionResult(e){e&&(this._setSelections(e.selections),e.revealRange&&this._editor.revealRangeInCenterIfOutsideViewport(e.revealRange,e.revealScrollType))}getSession(e){return this._session}addSelectionToNextFindMatch(e){if(this._editor.hasModel()){if(!this._session){const t=this._editor.getSelections();if(t.length>1){const n=e.getState().matchCase;if(!PK(this._editor.getModel(),t,n)){const r=this._editor.getModel(),a=[];for(let l=0,d=t.length;l<d;l++)a[l]=this._expandEmptyToWord(r,t[l]);this._editor.setSelections(a);return}}}this._beginSessionIfNeeded(e),this._session&&this._applySessionResult(this._session.addSelectionToNextFindMatch())}}addSelectionToPreviousFindMatch(e){this._beginSessionIfNeeded(e),this._session&&this._applySessionResult(this._session.addSelectionToPreviousFindMatch())}moveSelectionToNextFindMatch(e){this._beginSessionIfNeeded(e),this._session&&this._applySessionResult(this._session.moveSelectionToNextFindMatch())}moveSelectionToPreviousFindMatch(e){this._beginSessionIfNeeded(e),this._session&&this._applySessionResult(this._session.moveSelectionToPreviousFindMatch())}selectAll(e){if(!this._editor.hasModel())return;let t=null;const i=e.getState();if(i.isRevealed&&i.searchString.length>0&&i.isRegex){const n=this._editor.getModel();i.searchScope?t=n.findMatches(i.searchString,i.searchScope,i.isRegex,i.matchCase,i.wholeWord?this._editor.getOption(129):null,!1,1073741824):t=n.findMatches(i.searchString,!0,i.isRegex,i.matchCase,i.wholeWord?this._editor.getOption(129):null,!1,1073741824)}else{if(this._beginSessionIfNeeded(e),!this._session)return;t=this._session.selectAll(i.searchScope)}if(t.length>0){const n=this._editor.getSelection();for(let o=0,r=t.length;o<r;o++){const a=t[o];if(a.range.intersectRanges(n)){t[o]=t[0],t[0]=a;break}}this._setSelections(t.map(o=>new De(o.range.startLineNumber,o.range.startColumn,o.range.endLineNumber,o.range.endColumn)))}}}Qg.ID="editor.contrib.multiCursorController";class w_ extends we{run(e,t){const i=Qg.get(t);if(!i)return;const n=t._getViewModel();if(n){const o=n.getCursorStates(),r=Ws.get(t);if(r)this._run(i,r);else{const a=e.get(We).createInstance(Ws,t);this._run(i,a),a.dispose()}dh(o,n.getCursorStates())}}}class Rxe extends w_{constructor(){super({id:"editor.action.addSelectionToNextFindMatch",label:p("addSelectionToNextFindMatch","Add Selection To Next Find Match"),alias:"Add Selection To Next Find Match",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:2082,weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"3_multi",title:p({key:"miAddSelectionToNextFindMatch",comment:["&& denotes a mnemonic"]},"Add &&Next Occurrence"),order:5}})}_run(e,t){e.addSelectionToNextFindMatch(t)}}class Axe extends w_{constructor(){super({id:"editor.action.addSelectionToPreviousFindMatch",label:p("addSelectionToPreviousFindMatch","Add Selection To Previous Find Match"),alias:"Add Selection To Previous Find Match",precondition:void 0,menuOpts:{menuId:N.MenubarSelectionMenu,group:"3_multi",title:p({key:"miAddSelectionToPreviousFindMatch",comment:["&& denotes a mnemonic"]},"Add P&&revious Occurrence"),order:6}})}_run(e,t){e.addSelectionToPreviousFindMatch(t)}}class Pxe extends w_{constructor(){super({id:"editor.action.moveSelectionToNextFindMatch",label:p("moveSelectionToNextFindMatch","Move Last Selection To Next Find Match"),alias:"Move Last Selection To Next Find Match",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:dn(2089,2082),weight:100}})}_run(e,t){e.moveSelectionToNextFindMatch(t)}}class Oxe extends w_{constructor(){super({id:"editor.action.moveSelectionToPreviousFindMatch",label:p("moveSelectionToPreviousFindMatch","Move Last Selection To Previous Find Match"),alias:"Move Last Selection To Previous Find Match",precondition:void 0})}_run(e,t){e.moveSelectionToPreviousFindMatch(t)}}class Fxe extends w_{constructor(){super({id:"editor.action.selectHighlights",label:p("selectAllOccurrencesOfFindMatch","Select All Occurrences of Find Match"),alias:"Select All Occurrences of Find Match",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:3114,weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"3_multi",title:p({key:"miSelectHighlights",comment:["&& denotes a mnemonic"]},"Select All &&Occurrences"),order:7}})}_run(e,t){e.selectAll(t)}}class Bxe extends w_{constructor(){super({id:"editor.action.changeAll",label:p("changeAll.label","Change All Occurrences"),alias:"Change All Occurrences",precondition:ee.and(T.writable,T.editorTextFocus),kbOpts:{kbExpr:T.editorTextFocus,primary:2108,weight:100},contextMenuOpts:{group:"1_modification",order:1.2}})}_run(e,t){e.selectAll(t)}}class Wxe{constructor(e,t,i,n,o){this._model=e,this._searchText=t,this._matchCase=i,this._wordSeparators=n,this._modelVersionId=this._model.getVersionId(),this._cachedFindMatches=null,o&&this._model===o._model&&this._searchText===o._searchText&&this._matchCase===o._matchCase&&this._wordSeparators===o._wordSeparators&&this._modelVersionId===o._modelVersionId&&(this._cachedFindMatches=o._cachedFindMatches)}findMatches(){return this._cachedFindMatches===null&&(this._cachedFindMatches=this._model.findMatches(this._searchText,!0,!1,this._matchCase,this._wordSeparators,!1).map(e=>e.range),this._cachedFindMatches.sort(D.compareRangesUsingStarts)),this._cachedFindMatches}}let zb=kR=class extends j{constructor(e,t){super(),this._languageFeaturesService=t,this.editor=e,this._isEnabled=e.getOption(107),this._decorations=e.createDecorationsCollection(),this.updateSoon=this._register(new jt(()=>this._update(),300)),this.state=null,this._register(e.onDidChangeConfiguration(n=>{this._isEnabled=e.getOption(107)})),this._register(e.onDidChangeCursorSelection(n=>{this._isEnabled&&(n.selection.isEmpty()?n.reason===3?(this.state&&this._setState(null),this.updateSoon.schedule()):this._setState(null):this._update())})),this._register(e.onDidChangeModel(n=>{this._setState(null)})),this._register(e.onDidChangeModelContent(n=>{this._isEnabled&&this.updateSoon.schedule()}));const i=Ws.get(e);i&&this._register(i.getState().onFindReplaceStateChange(n=>{this._update()})),this.updateSoon.schedule()}_update(){this._setState(kR._createState(this.state,this._isEnabled,this.editor))}static _createState(e,t,i){if(!t||!i.hasModel())return null;const n=i.getSelection();if(n.startLineNumber!==n.endLineNumber)return null;const o=Qg.get(i);if(!o)return null;const r=Ws.get(i);if(!r)return null;let a=o.getSession(r);if(!a){const c=i.getSelections();if(c.length>1){const h=r.getState().matchCase;if(!PK(i.getModel(),c,h))return null}a=Hb.create(i,r)}if(!a||a.currentMatch||/^[ \t]+$/.test(a.searchText)||a.searchText.length>200)return null;const l=r.getState(),d=l.matchCase;if(l.isRevealed){let c=l.searchString;d||(c=c.toLowerCase());let u=a.searchText;if(d||(u=u.toLowerCase()),c===u&&a.matchCase===l.matchCase&&a.wholeWord===l.wholeWord&&!l.isRegex)return null}return new Wxe(i.getModel(),a.searchText,a.matchCase,a.wholeWord?i.getOption(129):null,e)}_setState(e){if(this.state=e,!this.state){this._decorations.clear();return}if(!this.editor.hasModel())return;const t=this.editor.getModel();if(t.isTooLargeForTokenization())return;const i=this.state.findMatches(),n=this.editor.getSelections();n.sort(D.compareRangesUsingStarts);const o=[];for(let d=0,c=0,u=i.length,h=n.length;d<u;){const g=i[d];if(c>=h)o.push(g),d++;else{const f=D.compareRangesUsingStarts(g,n[c]);f<0?((n[c].isEmpty()||!D.areIntersecting(g,n[c]))&&o.push(g),d++):(f>0||d++,c++)}}const r=this.editor.getOption(80)!=="off",a=this._languageFeaturesService.documentHighlightProvider.has(t)&&r,l=o.map(d=>({range:d,options:xxe(a)}));this._decorations.set(l)}dispose(){this._setState(null),super.dispose()}};zb.ID="editor.contrib.selectionHighlighter";zb=kR=Dxe([kxe(1,xe)],zb);function PK(s,e,t){const i=PB(s,e[0],!t);for(let n=1,o=e.length;n<o;n++){const r=e[n];if(r.isEmpty())return!1;const a=PB(s,r,!t);if(i!==a)return!1}return!0}function PB(s,e,t){const i=s.getValueInRange(e);return t?i.toLowerCase():i}class Vxe extends we{constructor(){super({id:"editor.action.focusNextCursor",label:p("mutlicursor.focusNextCursor","Focus Next Cursor"),metadata:{description:p("mutlicursor.focusNextCursor.description","Focuses the next cursor"),args:[]},alias:"Focus Next Cursor",precondition:void 0})}run(e,t,i){if(!t.hasModel())return;const n=t._getViewModel();if(n.cursorConfig.readOnly)return;n.model.pushStackElement();const o=Array.from(n.getCursorStates()),r=o.shift();r&&(o.push(r),n.setCursorStates(i.source,3,o),n.revealPrimaryCursor(i.source,!0),dh(o,n.getCursorStates()))}}class Hxe extends we{constructor(){super({id:"editor.action.focusPreviousCursor",label:p("mutlicursor.focusPreviousCursor","Focus Previous Cursor"),metadata:{description:p("mutlicursor.focusPreviousCursor.description","Focuses the previous cursor"),args:[]},alias:"Focus Previous Cursor",precondition:void 0})}run(e,t,i){if(!t.hasModel())return;const n=t._getViewModel();if(n.cursorConfig.readOnly)return;n.model.pushStackElement();const o=Array.from(n.getCursorStates()),r=o.pop();r&&(o.unshift(r),n.setCursorStates(i.source,3,o),n.revealPrimaryCursor(i.source,!0),dh(o,n.getCursorStates()))}}Lt(Qg.ID,Qg,4);Lt(zb.ID,zb,1);re(Ixe);re(Exe);re(Nxe);re(Rxe);re(Axe);re(Pxe);re(Oxe);re(Fxe);re(Bxe);re(Txe);re(Mxe);re(Vxe);re(Hxe);const Jg={Visible:new me("parameterHintsVisible",!1),MultipleSignatures:new me("parameterHintsMultipleSignatures",!1)};async function OK(s,e,t,i,n){const o=s.ordered(e);for(const r of o)try{const a=await r.provideSignatureHelp(e,t,n,i);if(a)return a}catch(a){Zi(a)}}Ct.registerCommand("_executeSignatureHelpProvider",async(s,...e)=>{const[t,i,n]=e;zt(Pe.isUri(t)),zt(H.isIPosition(i)),zt(typeof n=="string"||!n);const o=s.get(xe),r=await s.get(io).createModelReference(t);try{const a=await OK(o.signatureHelpProvider,r.object.textEditorModel,H.lift(i),{triggerKind:Bl.Invoke,isRetrigger:!1,triggerCharacter:n},ct.None);return a?(setTimeout(()=>a.dispose(),0),a.value):void 0}finally{r.dispose()}});var Rc;(function(s){s.Default={type:0};class e{constructor(n,o){this.request=n,this.previouslyActiveHints=o,this.type=2}}s.Pending=e;class t{constructor(n){this.hints=n,this.type=1}}s.Active=t})(Rc||(Rc={}));class ZD extends j{constructor(e,t,i=ZD.DEFAULT_DELAY){super(),this._onChangedHints=this._register(new W),this.onChangedHints=this._onChangedHints.event,this.triggerOnType=!1,this._state=Rc.Default,this._pendingTriggers=[],this._lastSignatureHelpResult=this._register(new En),this.triggerChars=new US,this.retriggerChars=new US,this.triggerId=0,this.editor=e,this.providers=t,this.throttledDelayer=new Qr(i),this._register(this.editor.onDidBlurEditorWidget(()=>this.cancel())),this._register(this.editor.onDidChangeConfiguration(()=>this.onEditorConfigurationChange())),this._register(this.editor.onDidChangeModel(n=>this.onModelChanged())),this._register(this.editor.onDidChangeModelLanguage(n=>this.onModelChanged())),this._register(this.editor.onDidChangeCursorSelection(n=>this.onCursorChange(n))),this._register(this.editor.onDidChangeModelContent(n=>this.onModelContentChange())),this._register(this.providers.onDidChange(this.onModelChanged,this)),this._register(this.editor.onDidType(n=>this.onDidType(n))),this.onEditorConfigurationChange(),this.onModelChanged()}get state(){return this._state}set state(e){this._state.type===2&&this._state.request.cancel(),this._state=e}cancel(e=!1){this.state=Rc.Default,this.throttledDelayer.cancel(),e||this._onChangedHints.fire(void 0)}trigger(e,t){const i=this.editor.getModel();if(!i||!this.providers.has(i))return;const n=++this.triggerId;this._pendingTriggers.push(e),this.throttledDelayer.trigger(()=>this.doTrigger(n),t).catch(et)}next(){if(this.state.type!==1)return;const e=this.state.hints.signatures.length,t=this.state.hints.activeSignature,i=t%e===e-1,n=this.editor.getOption(85).cycle;if((e<2||i)&&!n){this.cancel();return}this.updateActiveSignature(i&&n?0:t+1)}previous(){if(this.state.type!==1)return;const e=this.state.hints.signatures.length,t=this.state.hints.activeSignature,i=t===0,n=this.editor.getOption(85).cycle;if((e<2||i)&&!n){this.cancel();return}this.updateActiveSignature(i&&n?e-1:t-1)}updateActiveSignature(e){this.state.type===1&&(this.state=new Rc.Active({...this.state.hints,activeSignature:e}),this._onChangedHints.fire(this.state.hints))}async doTrigger(e){const t=this.state.type===1||this.state.type===2,i=this.getLastActiveHints();if(this.cancel(!0),this._pendingTriggers.length===0)return!1;const n=this._pendingTriggers.reduce(zxe);this._pendingTriggers=[];const o={triggerKind:n.triggerKind,triggerCharacter:n.triggerCharacter,isRetrigger:t,activeSignatureHelp:i};if(!this.editor.hasModel())return!1;const r=this.editor.getModel(),a=this.editor.getPosition();this.state=new Rc.Pending(gn(l=>OK(this.providers,r,a,o,l)),i);try{const l=await this.state.request;return e!==this.triggerId?(l==null||l.dispose(),!1):!l||!l.value.signatures||l.value.signatures.length===0?(l==null||l.dispose(),this._lastSignatureHelpResult.clear(),this.cancel(),!1):(this.state=new Rc.Active(l.value),this._lastSignatureHelpResult.value=l,this._onChangedHints.fire(this.state.hints),!0)}catch(l){return e===this.triggerId&&(this.state=Rc.Default),et(l),!1}}getLastActiveHints(){switch(this.state.type){case 1:return this.state.hints;case 2:return this.state.previouslyActiveHints;default:return}}get isTriggered(){return this.state.type===1||this.state.type===2||this.throttledDelayer.isTriggered()}onModelChanged(){this.cancel(),this.triggerChars.clear(),this.retriggerChars.clear();const e=this.editor.getModel();if(e)for(const t of this.providers.ordered(e)){for(const i of t.signatureHelpTriggerCharacters||[])if(i.length){const n=i.charCodeAt(0);this.triggerChars.add(n),this.retriggerChars.add(n)}for(const i of t.signatureHelpRetriggerCharacters||[])i.length&&this.retriggerChars.add(i.charCodeAt(0))}}onDidType(e){if(!this.triggerOnType)return;const t=e.length-1,i=e.charCodeAt(t);(this.triggerChars.has(i)||this.isTriggered&&this.retriggerChars.has(i))&&this.trigger({triggerKind:Bl.TriggerCharacter,triggerCharacter:e.charAt(t)})}onCursorChange(e){e.source==="mouse"?this.cancel():this.isTriggered&&this.trigger({triggerKind:Bl.ContentChange})}onModelContentChange(){this.isTriggered&&this.trigger({triggerKind:Bl.ContentChange})}onEditorConfigurationChange(){this.triggerOnType=this.editor.getOption(85).enabled,this.triggerOnType||this.cancel()}dispose(){this.cancel(!0),super.dispose()}}ZD.DEFAULT_DELAY=120;function zxe(s,e){switch(e.triggerKind){case Bl.Invoke:return e;case Bl.ContentChange:return s;case Bl.TriggerCharacter:default:return e}}var Uxe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},CE=function(s,e){return function(t,i){e(t,i,s)}},IR;const Mo=se,$xe=Ui("parameter-hints-next",le.chevronDown,p("parameterHintsNextIcon","Icon for show next parameter hint.")),jxe=Ui("parameter-hints-previous",le.chevronUp,p("parameterHintsPreviousIcon","Icon for show previous parameter hint."));let SL=IR=class extends j{constructor(e,t,i,n,o){super(),this.editor=e,this.model=t,this.renderDisposeables=this._register(new ie),this.visible=!1,this.announcedLabel=null,this.allowEditorOverflow=!0,this.markdownRenderer=this._register(new ic({editor:e},o,n)),this.keyVisible=Jg.Visible.bindTo(i),this.keyMultipleSignatures=Jg.MultipleSignatures.bindTo(i)}createParameterHintDOMNodes(){const e=Mo(".editor-widget.parameter-hints-widget"),t=te(e,Mo(".phwrapper"));t.tabIndex=-1;const i=te(t,Mo(".controls")),n=te(i,Mo(".button"+Oe.asCSSSelector(jxe))),o=te(i,Mo(".overloads")),r=te(i,Mo(".button"+Oe.asCSSSelector($xe)));this._register(Y(n,"click",h=>{ot.stop(h),this.previous()})),this._register(Y(r,"click",h=>{ot.stop(h),this.next()}));const a=Mo(".body"),l=new hC(a,{alwaysConsumeMouseWheel:!0});this._register(l),t.appendChild(l.getDomNode());const d=te(a,Mo(".signature")),c=te(a,Mo(".docs"));e.style.userSelect="text",this.domNodes={element:e,signature:d,overloads:o,docs:c,scrollbar:l},this.editor.addContentWidget(this),this.hide(),this._register(this.editor.onDidChangeCursorSelection(h=>{this.visible&&this.editor.layoutContentWidget(this)}));const u=()=>{if(!this.domNodes)return;const h=this.editor.getOption(50);this.domNodes.element.style.fontSize=`${h.fontSize}px`,this.domNodes.element.style.lineHeight=`${h.lineHeight/h.fontSize}`};u(),this._register(ge.chain(this.editor.onDidChangeConfiguration.bind(this.editor),h=>h.filter(g=>g.hasChanged(50)))(u)),this._register(this.editor.onDidLayoutChange(h=>this.updateMaxHeight())),this.updateMaxHeight()}show(){this.visible||(this.domNodes||this.createParameterHintDOMNodes(),this.keyVisible.set(!0),this.visible=!0,setTimeout(()=>{var e;(e=this.domNodes)===null||e===void 0||e.element.classList.add("visible")},100),this.editor.layoutContentWidget(this))}hide(){var e;this.renderDisposeables.clear(),this.visible&&(this.keyVisible.reset(),this.visible=!1,this.announcedLabel=null,(e=this.domNodes)===null||e===void 0||e.element.classList.remove("visible"),this.editor.layoutContentWidget(this))}getPosition(){return this.visible?{position:this.editor.getPosition(),preference:[1,2]}:null}render(e){var t;if(this.renderDisposeables.clear(),!this.domNodes)return;const i=e.signatures.length>1;this.domNodes.element.classList.toggle("multiple",i),this.keyMultipleSignatures.set(i),this.domNodes.signature.innerText="",this.domNodes.docs.innerText="";const n=e.signatures[e.activeSignature];if(!n)return;const o=te(this.domNodes.signature,Mo(".code")),r=this.editor.getOption(50);o.style.fontSize=`${r.fontSize}px`,o.style.fontFamily=r.fontFamily;const a=n.parameters.length>0,l=(t=n.activeParameter)!==null&&t!==void 0?t:e.activeParameter;if(a)this.renderParameters(o,n,l);else{const u=te(o,Mo("span"));u.textContent=n.label}const d=n.parameters[l];if(d!=null&&d.documentation){const u=Mo("span.documentation");if(typeof d.documentation=="string")u.textContent=d.documentation;else{const h=this.renderMarkdownDocs(d.documentation);u.appendChild(h.element)}te(this.domNodes.docs,Mo("p",{},u))}if(n.documentation!==void 0)if(typeof n.documentation=="string")te(this.domNodes.docs,Mo("p",{},n.documentation));else{const u=this.renderMarkdownDocs(n.documentation);te(this.domNodes.docs,u.element)}const c=this.hasDocs(n,d);if(this.domNodes.signature.classList.toggle("has-docs",c),this.domNodes.docs.classList.toggle("empty",!c),this.domNodes.overloads.textContent=String(e.activeSignature+1).padStart(e.signatures.length.toString().length,"0")+"/"+e.signatures.length,d){let u="";const h=n.parameters[l];Array.isArray(h.label)?u=n.label.substring(h.label[0],h.label[1]):u=h.label,h.documentation&&(u+=typeof h.documentation=="string"?`, ${h.documentation}`:`, ${h.documentation.value}`),n.documentation&&(u+=typeof n.documentation=="string"?`, ${n.documentation}`:`, ${n.documentation.value}`),this.announcedLabel!==u&&(Lo(p("hint","{0}, hint",u)),this.announcedLabel=u)}this.editor.layoutContentWidget(this),this.domNodes.scrollbar.scanDomNode()}renderMarkdownDocs(e){const t=this.renderDisposeables.add(this.markdownRenderer.render(e,{asyncRenderCallback:()=>{var i;(i=this.domNodes)===null||i===void 0||i.scrollbar.scanDomNode()}}));return t.element.classList.add("markdown-docs"),t}hasDocs(e,t){return!!(t&&typeof t.documentation=="string"&&Vc(t.documentation).length>0||t&&typeof t.documentation=="object"&&Vc(t.documentation).value.length>0||e.documentation&&typeof e.documentation=="string"&&Vc(e.documentation).length>0||e.documentation&&typeof e.documentation=="object"&&Vc(e.documentation.value).length>0)}renderParameters(e,t,i){const[n,o]=this.getParameterLabelOffsets(t,i),r=document.createElement("span");r.textContent=t.label.substring(0,n);const a=document.createElement("span");a.textContent=t.label.substring(n,o),a.className="parameter active";const l=document.createElement("span");l.textContent=t.label.substring(o),te(e,r,a,l)}getParameterLabelOffsets(e,t){const i=e.parameters[t];if(i){if(Array.isArray(i.label))return i.label;if(i.label.length){const n=new RegExp(`(\\W|^)${ir(i.label)}(?=\\W|$)`,"g");n.test(e.label);const o=n.lastIndex-i.label.length;return o>=0?[o,n.lastIndex]:[0,0]}else return[0,0]}else return[0,0]}next(){this.editor.focus(),this.model.next()}previous(){this.editor.focus(),this.model.previous()}getDomNode(){return this.domNodes||this.createParameterHintDOMNodes(),this.domNodes.element}getId(){return IR.ID}updateMaxHeight(){if(!this.domNodes)return;const t=`${Math.max(this.editor.getLayoutInfo().height/4,250)}px`;this.domNodes.element.style.maxHeight=t;const i=this.domNodes.element.getElementsByClassName("phwrapper");i.length&&(i[0].style.maxHeight=t)}};SL.ID="editor.widget.parameterHintsWidget";SL=IR=Uxe([CE(2,je),CE(3,No),CE(4,fi)],SL);R("editorHoverWidget.highlightForeground",{dark:jr,light:jr,hcDark:jr,hcLight:jr},p("editorHoverWidgetHighlightForeground","Foreground color of the active item in the parameter hint."));var Kxe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},OB=function(s,e){return function(t,i){e(t,i,s)}},ER;let ef=ER=class extends j{static get(e){return e.getContribution(ER.ID)}constructor(e,t,i){super(),this.editor=e,this.model=this._register(new ZD(e,i.signatureHelpProvider)),this._register(this.model.onChangedHints(n=>{var o;n?(this.widget.value.show(),this.widget.value.render(n)):(o=this.widget.rawValue)===null||o===void 0||o.hide()})),this.widget=new ih(()=>this._register(t.createInstance(SL,this.editor,this.model)))}cancel(){this.model.cancel()}previous(){var e;(e=this.widget.rawValue)===null||e===void 0||e.previous()}next(){var e;(e=this.widget.rawValue)===null||e===void 0||e.next()}trigger(e){this.model.trigger(e,0)}};ef.ID="editor.controller.parameterHints";ef=ER=Kxe([OB(1,We),OB(2,xe)],ef);class qxe extends we{constructor(){super({id:"editor.action.triggerParameterHints",label:p("parameterHints.trigger.label","Trigger Parameter Hints"),alias:"Trigger Parameter Hints",precondition:T.hasSignatureHelpProvider,kbOpts:{kbExpr:T.editorTextFocus,primary:3082,weight:100}})}run(e,t){const i=ef.get(t);i==null||i.trigger({triggerKind:Bl.Invoke})}}Lt(ef.ID,ef,2);re(qxe);const A4=175,P4=Nn.bindToContribution(ef.get);ue(new P4({id:"closeParameterHints",precondition:Jg.Visible,handler:s=>s.cancel(),kbOpts:{weight:A4,kbExpr:T.focus,primary:9,secondary:[1033]}}));ue(new P4({id:"showPrevParameterHint",precondition:ee.and(Jg.Visible,Jg.MultipleSignatures),handler:s=>s.previous(),kbOpts:{weight:A4,kbExpr:T.focus,primary:16,secondary:[528],mac:{primary:16,secondary:[528,302]}}}));ue(new P4({id:"showNextParameterHint",precondition:ee.and(Jg.Visible,Jg.MultipleSignatures),handler:s=>s.next(),kbOpts:{weight:A4,kbExpr:T.focus,primary:18,secondary:[530],mac:{primary:18,secondary:[530,300]}}}));var Gxe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},wE=function(s,e){return function(t,i){e(t,i,s)}};const YD=new me("renameInputVisible",!1,p("renameInputVisible","Whether the rename input widget is visible"));let NR=class{constructor(e,t,i,n,o){this._editor=e,this._acceptKeybindings=t,this._themeService=i,this._keybindingService=n,this._disposables=new ie,this.allowEditorOverflow=!0,this._visibleContextKey=YD.bindTo(o),this._editor.addContentWidget(this),this._disposables.add(this._editor.onDidChangeConfiguration(r=>{r.hasChanged(50)&&this._updateFont()})),this._disposables.add(i.onDidColorThemeChange(this._updateStyles,this))}dispose(){this._disposables.dispose(),this._editor.removeContentWidget(this)}getId(){return"__renameInputWidget"}getDomNode(){return this._domNode||(this._domNode=document.createElement("div"),this._domNode.className="monaco-editor rename-box",this._input=document.createElement("input"),this._input.className="rename-input",this._input.type="text",this._input.setAttribute("aria-label",p("renameAriaLabel","Rename input. Type new name and press Enter to commit.")),this._domNode.appendChild(this._input),this._label=document.createElement("div"),this._label.className="rename-label",this._domNode.appendChild(this._label),this._updateFont(),this._updateStyles(this._themeService.getColorTheme())),this._domNode}_updateStyles(e){var t,i,n,o;if(!this._input||!this._domNode)return;const r=e.getColor(Il),a=e.getColor(vP);this._domNode.style.backgroundColor=String((t=e.getColor(Ri))!==null&&t!==void 0?t:""),this._domNode.style.boxShadow=r?` 0 0 8px 2px ${r}`:"",this._domNode.style.border=a?`1px solid ${a}`:"",this._domNode.style.color=String((i=e.getColor(rH))!==null&&i!==void 0?i:""),this._input.style.backgroundColor=String((n=e.getColor(oH))!==null&&n!==void 0?n:"");const l=e.getColor(aH);this._input.style.borderWidth=l?"1px":"0px",this._input.style.borderStyle=l?"solid":"none",this._input.style.borderColor=(o=l==null?void 0:l.toString())!==null&&o!==void 0?o:"none"}_updateFont(){if(!this._input||!this._label)return;const e=this._editor.getOption(50);this._input.style.fontFamily=e.fontFamily,this._input.style.fontWeight=e.fontWeight,this._input.style.fontSize=`${e.fontSize}px`,this._label.style.fontSize=`${e.fontSize*.8}px`}getPosition(){return this._visible?{position:this._position,preference:[2,1]}:null}beforeRender(){var e,t;const[i,n]=this._acceptKeybindings;return this._label.innerText=p({key:"label",comment:['placeholders are keybindings, e.g "F2 to Rename, Shift+F2 to Preview"']},"{0} to Rename, {1} to Preview",(e=this._keybindingService.lookupKeybinding(i))===null||e===void 0?void 0:e.getLabel(),(t=this._keybindingService.lookupKeybinding(n))===null||t===void 0?void 0:t.getLabel()),null}afterRender(e){e||this.cancelInput(!0)}acceptInput(e){var t;(t=this._currentAcceptInput)===null||t===void 0||t.call(this,e)}cancelInput(e){var t;(t=this._currentCancelInput)===null||t===void 0||t.call(this,e)}getInput(e,t,i,n,o,r){this._domNode.classList.toggle("preview",o),this._position=new H(e.startLineNumber,e.startColumn),this._input.value=t,this._input.setAttribute("selectionStart",i.toString()),this._input.setAttribute("selectionEnd",n.toString()),this._input.size=Math.max((e.endColumn-e.startColumn)*1.1,20);const a=new ie;return new Promise(l=>{this._currentCancelInput=d=>(this._currentAcceptInput=void 0,this._currentCancelInput=void 0,l(d),!0),this._currentAcceptInput=d=>{if(this._input.value.trim().length===0||this._input.value===t){this.cancelInput(!0);return}this._currentAcceptInput=void 0,this._currentCancelInput=void 0,l({newName:this._input.value,wantsPreview:o&&d})},a.add(r.onCancellationRequested(()=>this.cancelInput(!0))),a.add(this._editor.onDidBlurEditorWidget(()=>{var d;return this.cancelInput(!(!((d=this._domNode)===null||d===void 0)&&d.ownerDocument.hasFocus()))})),this._show()}).finally(()=>{a.dispose(),this._hide()})}_show(){this._editor.revealLineInCenterIfOutsideViewport(this._position.lineNumber,0),this._visible=!0,this._visibleContextKey.set(!0),this._editor.layoutContentWidget(this),setTimeout(()=>{this._input.focus(),this._input.setSelectionRange(parseInt(this._input.getAttribute("selectionStart")),parseInt(this._input.getAttribute("selectionEnd")))},100)}_hide(){this._visible=!1,this._visibleContextKey.reset(),this._editor.layoutContentWidget(this)}};NR=Gxe([wE(2,Cn),wE(3,qt),wE(4,je)],NR);var Zxe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Eh=function(s,e){return function(t,i){e(t,i,s)}},TR;class O4{constructor(e,t,i){this.model=e,this.position=t,this._providerRenameIdx=0,this._providers=i.ordered(e)}hasProvider(){return this._providers.length>0}async resolveRenameLocation(e){const t=[];for(this._providerRenameIdx=0;this._providerRenameIdx<this._providers.length;this._providerRenameIdx++){const n=this._providers[this._providerRenameIdx];if(!n.resolveRenameLocation)break;const o=await n.resolveRenameLocation(this.model,this.position,e);if(o){if(o.rejectReason){t.push(o.rejectReason);continue}return o}}this._providerRenameIdx=0;const i=this.model.getWordAtPosition(this.position);return i?{range:new D(this.position.lineNumber,i.startColumn,this.position.lineNumber,i.endColumn),text:i.word,rejectReason:t.length>0?t.join(`
`):void 0}:{range:D.fromPositions(this.position),text:"",rejectReason:t.length>0?t.join(`
`):void 0}}async provideRenameEdits(e,t){return this._provideRenameEdits(e,this._providerRenameIdx,[],t)}async _provideRenameEdits(e,t,i,n){const o=this._providers[t];if(!o)return{edits:[],rejectReason:i.join(`
`)};const r=await o.provideRenameEdits(this.model,this.position,e,n);if(r){if(r.rejectReason)return this._provideRenameEdits(e,t+1,i.concat(r.rejectReason),n)}else return this._provideRenameEdits(e,t+1,i.concat(p("no result","No result.")),n);return r}}async function Yxe(s,e,t,i){const n=new O4(e,t,s),o=await n.resolveRenameLocation(ct.None);return o!=null&&o.rejectReason?{edits:[],rejectReason:o.rejectReason}:n.provideRenameEdits(i,ct.None)}let tf=TR=class{static get(e){return e.getContribution(TR.ID)}constructor(e,t,i,n,o,r,a,l){this.editor=e,this._instaService=t,this._notificationService=i,this._bulkEditService=n,this._progressService=o,this._logService=r,this._configService=a,this._languageFeaturesService=l,this._disposableStore=new ie,this._cts=new Yi,this._renameInputField=this._disposableStore.add(this._instaService.createInstance(NR,this.editor,["acceptRenameInput","acceptRenameInputWithPreview"]))}dispose(){this._disposableStore.dispose(),this._cts.dispose(!0)}async run(){var e,t;if(this._cts.dispose(!0),this._cts=new Yi,!this.editor.hasModel())return;const i=this.editor.getPosition(),n=new O4(this.editor.getModel(),i,this._languageFeaturesService.renameProvider);if(!n.hasProvider())return;const o=new Hu(this.editor,5,void 0,this._cts.token);let r;try{const f=n.resolveRenameLocation(o.token);this._progressService.showWhile(f,250),r=await f}catch(f){(e=Co.get(this.editor))===null||e===void 0||e.showMessage(f||p("resolveRenameLocationFailed","An unknown error occurred while resolving rename location"),i);return}finally{o.dispose()}if(!r)return;if(r.rejectReason){(t=Co.get(this.editor))===null||t===void 0||t.showMessage(r.rejectReason,i);return}if(o.token.isCancellationRequested)return;const a=new Hu(this.editor,5,r.range,this._cts.token),l=this.editor.getSelection();let d=0,c=r.text.length;!D.isEmpty(l)&&!D.spansMultipleLines(l)&&D.containsRange(r.range,l)&&(d=Math.max(0,l.startColumn-r.range.startColumn),c=Math.min(r.range.endColumn,l.endColumn)-r.range.startColumn);const u=this._bulkEditService.hasPreviewHandler()&&this._configService.getValue(this.editor.getModel().uri,"editor.rename.enablePreview"),h=await this._renameInputField.getInput(r.range,r.text,d,c,u,a.token);if(typeof h=="boolean"){h&&this.editor.focus(),a.dispose();return}this.editor.focus();const g=sx(n.provideRenameEdits(h.newName,a.token),a.token).then(async f=>{if(!(!f||!this.editor.hasModel())){if(f.rejectReason){this._notificationService.info(f.rejectReason);return}this.editor.setSelection(D.fromPositions(this.editor.getSelection().getPosition())),this._bulkEditService.apply(f,{editor:this.editor,showPreview:h.wantsPreview,label:p("label","Renaming '{0}' to '{1}'",r==null?void 0:r.text,h.newName),code:"undoredo.rename",quotableLabel:p("quotableLabel","Renaming {0} to {1}",r==null?void 0:r.text,h.newName),respectAutoSaveConfig:!0}).then(m=>{m.ariaSummary&&Lo(p("aria","Successfully renamed '{0}' to '{1}'. Summary: {2}",r.text,h.newName,m.ariaSummary))}).catch(m=>{this._notificationService.error(p("rename.failedApply","Rename failed to apply edits")),this._logService.error(m)})}},f=>{this._notificationService.error(p("rename.failed","Rename failed to compute edits")),this._logService.error(f)}).finally(()=>{a.dispose()});return this._progressService.showWhile(g,250),g}acceptRenameInput(e){this._renameInputField.acceptInput(e)}cancelRenameInput(){this._renameInputField.cancelInput(!0)}};tf.ID="editor.contrib.renameController";tf=TR=Zxe([Eh(1,We),Eh(2,Qi),Eh(3,bC),Eh(4,rh),Eh(5,ko),Eh(6,cP),Eh(7,xe)],tf);class Xxe extends we{constructor(){super({id:"editor.action.rename",label:p("rename.label","Rename Symbol"),alias:"Rename Symbol",precondition:ee.and(T.writable,T.hasRenameProvider),kbOpts:{kbExpr:T.editorTextFocus,primary:60,weight:100},contextMenuOpts:{group:"1_modification",order:1.1}})}runCommand(e,t){const i=e.get(It),[n,o]=Array.isArray(t)&&t||[void 0,void 0];return Pe.isUri(n)&&H.isIPosition(o)?i.openCodeEditor({resource:n},i.getActiveCodeEditor()).then(r=>{r&&(r.setPosition(o),r.invokeWithinContext(a=>(this.reportTelemetry(a,r),this.run(a,r))))},et):super.runCommand(e,t)}run(e,t){const i=tf.get(t);return i?i.run():Promise.resolve()}}Lt(tf.ID,tf,4);re(Xxe);const F4=Nn.bindToContribution(tf.get);ue(new F4({id:"acceptRenameInput",precondition:YD,handler:s=>s.acceptRenameInput(!1),kbOpts:{weight:199,kbExpr:ee.and(T.focus,ee.not("isComposing")),primary:3}}));ue(new F4({id:"acceptRenameInputWithPreview",precondition:ee.and(YD,ee.has("config.editor.rename.enablePreview")),handler:s=>s.acceptRenameInput(!0),kbOpts:{weight:199,kbExpr:ee.and(T.focus,ee.not("isComposing")),primary:1027}}));ue(new F4({id:"cancelRenameInput",precondition:YD,handler:s=>s.cancelRenameInput(),kbOpts:{weight:199,kbExpr:T.focus,primary:9,secondary:[1033]}}));od("_executeDocumentRenameProvider",function(s,e,t,...i){const[n]=i;zt(typeof n=="string");const{renameProvider:o}=s.get(xe);return Yxe(o,e,t,n)});od("_executePrepareRename",async function(s,e,t){const{renameProvider:i}=s.get(xe),o=await new O4(e,t,i).resolveRenameLocation(ct.None);if(o!=null&&o.rejectReason)throw new Error(o.rejectReason);return o});Si.as(Za.Configuration).registerConfiguration({id:"editor",properties:{"editor.rename.enablePreview":{scope:5,description:p("enablePreview","Enable/disable the ability to preview changes before renaming"),default:!0,type:"boolean"}}});function Qxe(s){for(let e=0,t=s.length;e<t;e+=4){const i=s[e+0],n=s[e+1],o=s[e+2],r=s[e+3];s[e+0]=r,s[e+1]=o,s[e+2]=n,s[e+3]=i}}function Jxe(s){const e=new Uint8Array(s.buffer,s.byteOffset,s.length*4);return bW()||Qxe(e),gx.wrap(e)}function FK(s){const e=new Uint32Array(eDe(s));let t=0;if(e[t++]=s.id,s.type==="full")e[t++]=1,e[t++]=s.data.length,e.set(s.data,t),t+=s.data.length;else{e[t++]=2,e[t++]=s.deltas.length;for(const i of s.deltas)e[t++]=i.start,e[t++]=i.deleteCount,i.data?(e[t++]=i.data.length,e.set(i.data,t),t+=i.data.length):e[t++]=0}return Jxe(e)}function eDe(s){let e=0;if(e+=2,s.type==="full")e+=1+s.data.length;else{e+=1,e+=3*s.deltas.length;for(const t of s.deltas)t.data&&(e+=t.data.length)}return e}function XD(s){return s&&!!s.data}function BK(s){return s&&Array.isArray(s.edits)}class tDe{constructor(e,t,i){this.provider=e,this.tokens=t,this.error=i}}function WK(s,e){return s.has(e)}function iDe(s,e){const t=s.orderedGroups(e);return t.length>0?t[0]:[]}async function VK(s,e,t,i,n){const o=iDe(s,e),r=await Promise.all(o.map(async a=>{let l,d=null;try{l=await a.provideDocumentSemanticTokens(e,a===t?i:null,n)}catch(c){d=c,l=null}return(!l||!XD(l)&&!BK(l))&&(l=null),new tDe(a,l,d)}));for(const a of r){if(a.error)throw a.error;if(a.tokens)return a}return r.length>0?r[0]:null}function nDe(s,e){const t=s.orderedGroups(e);return t.length>0?t[0]:null}class sDe{constructor(e,t){this.provider=e,this.tokens=t}}function oDe(s,e){return s.has(e)}function HK(s,e){const t=s.orderedGroups(e);return t.length>0?t[0]:[]}async function B4(s,e,t,i){const n=HK(s,e),o=await Promise.all(n.map(async r=>{let a;try{a=await r.provideDocumentRangeSemanticTokens(e,t,i)}catch(l){Zi(l),a=null}return(!a||!XD(a))&&(a=null),new sDe(r,a)}));for(const r of o)if(r.tokens)return r;return o.length>0?o[0]:null}Ct.registerCommand("_provideDocumentSemanticTokensLegend",async(s,...e)=>{const[t]=e;zt(t instanceof Pe);const i=s.get(vi).getModel(t);if(!i)return;const{documentSemanticTokensProvider:n}=s.get(xe),o=nDe(n,i);return o?o[0].getLegend():s.get(Ei).executeCommand("_provideDocumentRangeSemanticTokensLegend",t)});Ct.registerCommand("_provideDocumentSemanticTokens",async(s,...e)=>{const[t]=e;zt(t instanceof Pe);const i=s.get(vi).getModel(t);if(!i)return;const{documentSemanticTokensProvider:n}=s.get(xe);if(!WK(n,i))return s.get(Ei).executeCommand("_provideDocumentRangeSemanticTokens",t,i.getFullModelRange());const o=await VK(n,i,null,null,ct.None);if(!o)return;const{provider:r,tokens:a}=o;if(!a||!XD(a))return;const l=FK({id:0,type:"full",data:a.data});return a.resultId&&r.releaseDocumentSemanticTokens(a.resultId),l});Ct.registerCommand("_provideDocumentRangeSemanticTokensLegend",async(s,...e)=>{const[t,i]=e;zt(t instanceof Pe);const n=s.get(vi).getModel(t);if(!n)return;const{documentRangeSemanticTokensProvider:o}=s.get(xe),r=HK(o,n);if(r.length===0)return;if(r.length===1)return r[0].getLegend();if(!i||!D.isIRange(i))return console.warn("provideDocumentRangeSemanticTokensLegend might be out-of-sync with provideDocumentRangeSemanticTokens unless a range argument is passed in"),r[0].getLegend();const a=await B4(o,n,D.lift(i),ct.None);if(a)return a.provider.getLegend()});Ct.registerCommand("_provideDocumentRangeSemanticTokens",async(s,...e)=>{const[t,i]=e;zt(t instanceof Pe),zt(D.isIRange(i));const n=s.get(vi).getModel(t);if(!n)return;const{documentRangeSemanticTokensProvider:o}=s.get(xe),r=await B4(o,n,D.lift(i),ct.None);if(!(!r||!r.tokens))return FK({id:0,type:"full",data:r.tokens.data})});const W4="editor.semanticHighlighting";function MR(s,e,t){var i;const n=(i=t.getValue(W4,{overrideIdentifier:s.getLanguageId(),resource:s.uri}))===null||i===void 0?void 0:i.enabled;return typeof n=="boolean"?n:e.getColorTheme().semanticHighlighting}var zK=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},pl=function(s,e){return function(t,i){e(t,i,s)}},kc;let RR=class extends j{constructor(e,t,i,n,o,r){super(),this._watchers=Object.create(null);const a=c=>{this._watchers[c.uri.toString()]=new Ub(c,e,i,o,r)},l=(c,u)=>{u.dispose(),delete this._watchers[c.uri.toString()]},d=()=>{for(const c of t.getModels()){const u=this._watchers[c.uri.toString()];MR(c,i,n)?u||a(c):u&&l(c,u)}};this._register(t.onModelAdded(c=>{MR(c,i,n)&&a(c)})),this._register(t.onModelRemoved(c=>{const u=this._watchers[c.uri.toString()];u&&l(c,u)})),this._register(n.onDidChangeConfiguration(c=>{c.affectsConfiguration(W4)&&d()})),this._register(i.onDidColorThemeChange(d))}dispose(){for(const e of Object.values(this._watchers))e.dispose();super.dispose()}};RR=zK([pl(0,Ax),pl(1,vi),pl(2,Cn),pl(3,mt),pl(4,Er),pl(5,xe)],RR);let Ub=kc=class extends j{constructor(e,t,i,n,o){super(),this._semanticTokensStylingService=t,this._isDisposed=!1,this._model=e,this._provider=o.documentSemanticTokensProvider,this._debounceInformation=n.for(this._provider,"DocumentSemanticTokens",{min:kc.REQUEST_MIN_DELAY,max:kc.REQUEST_MAX_DELAY}),this._fetchDocumentSemanticTokens=this._register(new jt(()=>this._fetchDocumentSemanticTokensNow(),kc.REQUEST_MIN_DELAY)),this._currentDocumentResponse=null,this._currentDocumentRequestCancellationTokenSource=null,this._documentProvidersChangeListeners=[],this._providersChangedDuringRequest=!1,this._register(this._model.onDidChangeContent(()=>{this._fetchDocumentSemanticTokens.isScheduled()||this._fetchDocumentSemanticTokens.schedule(this._debounceInformation.get(this._model))})),this._register(this._model.onDidChangeAttached(()=>{this._fetchDocumentSemanticTokens.isScheduled()||this._fetchDocumentSemanticTokens.schedule(this._debounceInformation.get(this._model))})),this._register(this._model.onDidChangeLanguage(()=>{this._currentDocumentResponse&&(this._currentDocumentResponse.dispose(),this._currentDocumentResponse=null),this._currentDocumentRequestCancellationTokenSource&&(this._currentDocumentRequestCancellationTokenSource.cancel(),this._currentDocumentRequestCancellationTokenSource=null),this._setDocumentSemanticTokens(null,null,null,[]),this._fetchDocumentSemanticTokens.schedule(0)}));const r=()=>{Bt(this._documentProvidersChangeListeners),this._documentProvidersChangeListeners=[];for(const a of this._provider.all(e))typeof a.onDidChange=="function"&&this._documentProvidersChangeListeners.push(a.onDidChange(()=>{if(this._currentDocumentRequestCancellationTokenSource){this._providersChangedDuringRequest=!0;return}this._fetchDocumentSemanticTokens.schedule(0)}))};r(),this._register(this._provider.onDidChange(()=>{r(),this._fetchDocumentSemanticTokens.schedule(this._debounceInformation.get(this._model))})),this._register(i.onDidColorThemeChange(a=>{this._setDocumentSemanticTokens(null,null,null,[]),this._fetchDocumentSemanticTokens.schedule(this._debounceInformation.get(this._model))})),this._fetchDocumentSemanticTokens.schedule(0)}dispose(){this._currentDocumentResponse&&(this._currentDocumentResponse.dispose(),this._currentDocumentResponse=null),this._currentDocumentRequestCancellationTokenSource&&(this._currentDocumentRequestCancellationTokenSource.cancel(),this._currentDocumentRequestCancellationTokenSource=null),Bt(this._documentProvidersChangeListeners),this._documentProvidersChangeListeners=[],this._setDocumentSemanticTokens(null,null,null,[]),this._isDisposed=!0,super.dispose()}_fetchDocumentSemanticTokensNow(){if(this._currentDocumentRequestCancellationTokenSource)return;if(!WK(this._provider,this._model)){this._currentDocumentResponse&&this._model.tokenization.setSemanticTokens(null,!1);return}if(!this._model.isAttachedToEditor())return;const e=new Yi,t=this._currentDocumentResponse?this._currentDocumentResponse.provider:null,i=this._currentDocumentResponse&&this._currentDocumentResponse.resultId||null,n=VK(this._provider,this._model,t,i,e.token);this._currentDocumentRequestCancellationTokenSource=e,this._providersChangedDuringRequest=!1;const o=[],r=this._model.onDidChangeContent(l=>{o.push(l)}),a=new cs(!1);n.then(l=>{if(this._debounceInformation.update(this._model,a.elapsed()),this._currentDocumentRequestCancellationTokenSource=null,r.dispose(),!l)this._setDocumentSemanticTokens(null,null,null,o);else{const{provider:d,tokens:c}=l,u=this._semanticTokensStylingService.getStyling(d);this._setDocumentSemanticTokens(d,c||null,u,o)}},l=>{l&&(Ka(l)||typeof l.message=="string"&&l.message.indexOf("busy")!==-1)||et(l),this._currentDocumentRequestCancellationTokenSource=null,r.dispose(),(o.length>0||this._providersChangedDuringRequest)&&(this._fetchDocumentSemanticTokens.isScheduled()||this._fetchDocumentSemanticTokens.schedule(this._debounceInformation.get(this._model)))})}static _copy(e,t,i,n,o){o=Math.min(o,i.length-n,e.length-t);for(let r=0;r<o;r++)i[n+r]=e[t+r]}_setDocumentSemanticTokens(e,t,i,n){const o=this._currentDocumentResponse,r=()=>{(n.length>0||this._providersChangedDuringRequest)&&!this._fetchDocumentSemanticTokens.isScheduled()&&this._fetchDocumentSemanticTokens.schedule(this._debounceInformation.get(this._model))};if(this._currentDocumentResponse&&(this._currentDocumentResponse.dispose(),this._currentDocumentResponse=null),this._isDisposed){e&&t&&e.releaseDocumentSemanticTokens(t.resultId);return}if(!e||!i){this._model.tokenization.setSemanticTokens(null,!1);return}if(!t){this._model.tokenization.setSemanticTokens(null,!0),r();return}if(BK(t)){if(!o){this._model.tokenization.setSemanticTokens(null,!0);return}if(t.edits.length===0)t={resultId:t.resultId,data:o.data};else{let a=0;for(const h of t.edits)a+=(h.data?h.data.length:0)-h.deleteCount;const l=o.data,d=new Uint32Array(l.length+a);let c=l.length,u=d.length;for(let h=t.edits.length-1;h>=0;h--){const g=t.edits[h];if(g.start>l.length){i.warnInvalidEditStart(o.resultId,t.resultId,h,g.start,l.length),this._model.tokenization.setSemanticTokens(null,!0);return}const f=c-(g.start+g.deleteCount);f>0&&(kc._copy(l,c-f,d,u-f,f),u-=f),g.data&&(kc._copy(g.data,0,d,u-g.data.length,g.data.length),u-=g.data.length),c=g.start}c>0&&kc._copy(l,0,d,0,c),t={resultId:t.resultId,data:d}}}if(XD(t)){this._currentDocumentResponse=new rDe(e,t.resultId,t.data);const a=wz(t,i,this._model.getLanguageId());if(n.length>0)for(const l of n)for(const d of a)for(const c of l.changes)d.applyEdit(c.range,c.text);this._model.tokenization.setSemanticTokens(a,!0)}else this._model.tokenization.setSemanticTokens(null,!0);r()}};Ub.REQUEST_MIN_DELAY=300;Ub.REQUEST_MAX_DELAY=2e3;Ub=kc=zK([pl(1,Ax),pl(2,Cn),pl(3,Er),pl(4,xe)],Ub);class rDe{constructor(e,t,i){this.provider=e,this.resultId=t,this.data=i}dispose(){this.provider.releaseDocumentSemanticTokens(this.resultId)}}tD(RR);var aDe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},ev=function(s,e){return function(t,i){e(t,i,s)}};let $b=class extends j{constructor(e,t,i,n,o,r){super(),this._semanticTokensStylingService=t,this._themeService=i,this._configurationService=n,this._editor=e,this._provider=r.documentRangeSemanticTokensProvider,this._debounceInformation=o.for(this._provider,"DocumentRangeSemanticTokens",{min:100,max:500}),this._tokenizeViewport=this._register(new jt(()=>this._tokenizeViewportNow(),100)),this._outstandingRequests=[];const a=()=>{this._editor.hasModel()&&this._tokenizeViewport.schedule(this._debounceInformation.get(this._editor.getModel()))};this._register(this._editor.onDidScrollChange(()=>{a()})),this._register(this._editor.onDidChangeModel(()=>{this._cancelAll(),a()})),this._register(this._editor.onDidChangeModelContent(l=>{this._cancelAll(),a()})),this._register(this._provider.onDidChange(()=>{this._cancelAll(),a()})),this._register(this._configurationService.onDidChangeConfiguration(l=>{l.affectsConfiguration(W4)&&(this._cancelAll(),a())})),this._register(this._themeService.onDidColorThemeChange(()=>{this._cancelAll(),a()})),a()}_cancelAll(){for(const e of this._outstandingRequests)e.cancel();this._outstandingRequests=[]}_removeOutstandingRequest(e){for(let t=0,i=this._outstandingRequests.length;t<i;t++)if(this._outstandingRequests[t]===e){this._outstandingRequests.splice(t,1);return}}_tokenizeViewportNow(){if(!this._editor.hasModel())return;const e=this._editor.getModel();if(e.tokenization.hasCompleteSemanticTokens())return;if(!MR(e,this._themeService,this._configurationService)){e.tokenization.hasSomeSemanticTokens()&&e.tokenization.setSemanticTokens(null,!1);return}if(!oDe(this._provider,e)){e.tokenization.hasSomeSemanticTokens()&&e.tokenization.setSemanticTokens(null,!1);return}const t=this._editor.getVisibleRangesPlusViewportAboveBelow();this._outstandingRequests=this._outstandingRequests.concat(t.map(i=>this._requestRange(e,i)))}_requestRange(e,t){const i=e.getVersionId(),n=gn(r=>Promise.resolve(B4(this._provider,e,t,r))),o=new cs(!1);return n.then(r=>{if(this._debounceInformation.update(e,o.elapsed()),!r||!r.tokens||e.isDisposed()||e.getVersionId()!==i)return;const{provider:a,tokens:l}=r,d=this._semanticTokensStylingService.getStyling(a);e.tokenization.setPartialSemanticTokens(t,wz(l,d,e.getLanguageId()))}).then(()=>this._removeOutstandingRequest(n),()=>this._removeOutstandingRequest(n)),n}};$b.ID="editor.contrib.viewportSemanticTokens";$b=aDe([ev(1,Ax),ev(2,Cn),ev(3,mt),ev(4,Er),ev(5,xe)],$b);Lt($b.ID,$b,1);class lDe{constructor(e=!0){this.selectSubwords=e}provideSelectionRanges(e,t){const i=[];for(const n of t){const o=[];i.push(o),this.selectSubwords&&this._addInWordRanges(o,e,n),this._addWordRanges(o,e,n),this._addWhitespaceLine(o,e,n),o.push({range:e.getFullModelRange()})}return i}_addInWordRanges(e,t,i){const n=t.getWordAtPosition(i);if(!n)return;const{word:o,startColumn:r}=n,a=i.column-r;let l=a,d=a,c=0;for(;l>=0;l--){const u=o.charCodeAt(l);if(l!==a&&(u===95||u===45))break;if(Hc(u)&&ul(c))break;c=u}for(l+=1;d<o.length;d++){const u=o.charCodeAt(d);if(ul(u)&&Hc(c))break;if(u===95||u===45)break;c=u}l<d&&e.push({range:new D(i.lineNumber,r+l,i.lineNumber,r+d)})}_addWordRanges(e,t,i){const n=t.getWordAtPosition(i);n&&e.push({range:new D(i.lineNumber,n.startColumn,i.lineNumber,n.endColumn)})}_addWhitespaceLine(e,t,i){t.getLineLength(i.lineNumber)>0&&t.getLineFirstNonWhitespaceColumn(i.lineNumber)===0&&t.getLineLastNonWhitespaceColumn(i.lineNumber)===0&&e.push({range:new D(i.lineNumber,1,i.lineNumber,t.getLineMaxColumn(i.lineNumber))})}}var dDe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},cDe=function(s,e){return function(t,i){e(t,i,s)}},AR;class V4{constructor(e,t){this.index=e,this.ranges=t}mov(e){const t=this.index+(e?1:-1);if(t<0||t>=this.ranges.length)return this;const i=new V4(t,this.ranges);return i.ranges[t].equalsRange(this.ranges[this.index])?i.mov(e):i}}let Km=AR=class{static get(e){return e.getContribution(AR.ID)}constructor(e,t){this._editor=e,this._languageFeaturesService=t,this._ignoreSelection=!1}dispose(){var e;(e=this._selectionListener)===null||e===void 0||e.dispose()}async run(e){if(!this._editor.hasModel())return;const t=this._editor.getSelections(),i=this._editor.getModel();if(this._state||await $K(this._languageFeaturesService.selectionRangeProvider,i,t.map(o=>o.getPosition()),this._editor.getOption(112),ct.None).then(o=>{var r;if(!(!as(o)||o.length!==t.length)&&!(!this._editor.hasModel()||!Ai(this._editor.getSelections(),t,(a,l)=>a.equalsSelection(l)))){for(let a=0;a<o.length;a++)o[a]=o[a].filter(l=>l.containsPosition(t[a].getStartPosition())&&l.containsPosition(t[a].getEndPosition())),o[a].unshift(t[a]);this._state=o.map(a=>new V4(0,a)),(r=this._selectionListener)===null||r===void 0||r.dispose(),this._selectionListener=this._editor.onDidChangeCursorPosition(()=>{var a;this._ignoreSelection||((a=this._selectionListener)===null||a===void 0||a.dispose(),this._state=void 0)})}}),!this._state)return;this._state=this._state.map(o=>o.mov(e));const n=this._state.map(o=>De.fromPositions(o.ranges[o.index].getStartPosition(),o.ranges[o.index].getEndPosition()));this._ignoreSelection=!0;try{this._editor.setSelections(n)}finally{this._ignoreSelection=!1}}};Km.ID="editor.contrib.smartSelectController";Km=AR=dDe([cDe(1,xe)],Km);class UK extends we{constructor(e,t){super(t),this._forward=e}async run(e,t){const i=Km.get(t);i&&await i.run(this._forward)}}class uDe extends UK{constructor(){super(!0,{id:"editor.action.smartSelect.expand",label:p("smartSelect.expand","Expand Selection"),alias:"Expand Selection",precondition:void 0,kbOpts:{kbExpr:T.editorTextFocus,primary:1553,mac:{primary:3345,secondary:[1297]},weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"1_basic",title:p({key:"miSmartSelectGrow",comment:["&& denotes a mnemonic"]},"&&Expand Selection"),order:2}})}}Ct.registerCommandAlias("editor.action.smartSelect.grow","editor.action.smartSelect.expand");class hDe extends UK{constructor(){super(!1,{id:"editor.action.smartSelect.shrink",label:p("smartSelect.shrink","Shrink Selection"),alias:"Shrink Selection",precondition:void 0,kbOpts:{kbExpr:T.editorTextFocus,primary:1551,mac:{primary:3343,secondary:[1295]},weight:100},menuOpts:{menuId:N.MenubarSelectionMenu,group:"1_basic",title:p({key:"miSmartSelectShrink",comment:["&& denotes a mnemonic"]},"&&Shrink Selection"),order:3}})}}Lt(Km.ID,Km,4);re(uDe);re(hDe);async function $K(s,e,t,i,n){const o=s.all(e).concat(new lDe(i.selectSubwords));o.length===1&&o.unshift(new Wo);const r=[],a=[];for(const l of o)r.push(Promise.resolve(l.provideSelectionRanges(e,t,n)).then(d=>{if(as(d)&&d.length===t.length)for(let c=0;c<t.length;c++){a[c]||(a[c]=[]);for(const u of d[c])D.isIRange(u.range)&&D.containsPosition(u.range,t[c])&&a[c].push(D.lift(u.range))}},Zi));return await Promise.all(r),a.map(l=>{if(l.length===0)return[];l.sort((h,g)=>H.isBefore(h.getStartPosition(),g.getStartPosition())?1:H.isBefore(g.getStartPosition(),h.getStartPosition())||H.isBefore(h.getEndPosition(),g.getEndPosition())?-1:H.isBefore(g.getEndPosition(),h.getEndPosition())?1:0);const d=[];let c;for(const h of l)(!c||D.containsRange(h,c)&&!D.equalsRange(h,c))&&(d.push(h),c=h);if(!i.selectLeadingAndTrailingWhitespace)return d;const u=[d[0]];for(let h=1;h<d.length;h++){const g=d[h-1],f=d[h];if(f.startLineNumber!==g.startLineNumber||f.endLineNumber!==g.endLineNumber){const m=new D(g.startLineNumber,e.getLineFirstNonWhitespaceColumn(g.startLineNumber),g.endLineNumber,e.getLineLastNonWhitespaceColumn(g.endLineNumber));m.containsRange(g)&&!m.equalsRange(g)&&f.containsRange(m)&&!f.equalsRange(m)&&u.push(m);const _=new D(g.startLineNumber,1,g.endLineNumber,e.getLineMaxColumn(g.endLineNumber));_.containsRange(g)&&!_.equalsRange(m)&&f.containsRange(_)&&!f.equalsRange(_)&&u.push(_)}u.push(f)}return u})}Ct.registerCommand("_executeSelectionRangeProvider",async function(s,...e){const[t,i]=e;zt(Pe.isUri(t));const n=s.get(xe).selectionRangeProvider,o=await s.get(io).createModelReference(t);try{return $K(n,o.object.textEditorModel,i,{selectLeadingAndTrailingWhitespace:!0,selectSubwords:!0},ct.None)}finally{o.dispose()}});const gDe=Object.freeze({View:{value:p("view","View"),original:"View"},Help:{value:p("help","Help"),original:"Help"},Test:{value:p("test","Test"),original:"Test"},File:{value:p("file","File"),original:"File"},Preferences:{value:p("preferences","Preferences"),original:"Preferences"},Developer:{value:p({key:"developer",comment:["A developer on Code itself or someone diagnosing issues in Code"]},"Developer"),original:"Developer"}});class FB{constructor(e,t,i,n=null){this.startLineNumbers=e,this.endLineNumbers=t,this.lastLineRelativePosition=i,this.showEndForLine=n}equals(e){return!!e&&this.lastLineRelativePosition===e.lastLineRelativePosition&&this.showEndForLine===e.showEndForLine&&Ai(this.startLineNumbers,e.startLineNumbers)&&Ai(this.endLineNumbers,e.endLineNumbers)}}const BB=oc("stickyScrollViewLayer",{createHTML:s=>s}),SE="data-sticky-line-index",WB="data-sticky-is-line",fDe="data-sticky-is-line-number",VB="data-sticky-is-folding-icon";class pDe extends j{constructor(e){super(),this._editor=e,this._foldingIconStore=new ie,this._rootDomNode=document.createElement("div"),this._lineNumbersDomNode=document.createElement("div"),this._linesDomNodeScrollable=document.createElement("div"),this._linesDomNode=document.createElement("div"),this._lineHeight=this._editor.getOption(66),this._stickyLines=[],this._lineNumbers=[],this._lastLineRelativePosition=0,this._minContentWidthInPx=0,this._isOnGlyphMargin=!1,this._lineNumbersDomNode.className="sticky-widget-line-numbers",this._lineNumbersDomNode.setAttribute("role","none"),this._linesDomNode.className="sticky-widget-lines",this._linesDomNode.setAttribute("role","list"),this._linesDomNodeScrollable.className="sticky-widget-lines-scrollable",this._linesDomNodeScrollable.appendChild(this._linesDomNode),this._rootDomNode.className="sticky-widget",this._rootDomNode.classList.toggle("peek",e instanceof $u),this._rootDomNode.appendChild(this._lineNumbersDomNode),this._rootDomNode.appendChild(this._linesDomNodeScrollable);const t=()=>{this._linesDomNode.style.left=this._editor.getOption(114).scrollWithEditor?`-${this._editor.getScrollLeft()}px`:"0px"};this._register(this._editor.onDidChangeConfiguration(i=>{i.hasChanged(114)&&t(),i.hasChanged(66)&&(this._lineHeight=this._editor.getOption(66))})),this._register(this._editor.onDidScrollChange(i=>{i.scrollLeftChanged&&t(),i.scrollWidthChanged&&this._updateWidgetWidth()})),this._register(this._editor.onDidChangeModel(()=>{t(),this._updateWidgetWidth()})),this._register(this._foldingIconStore),t(),this._register(this._editor.onDidLayoutChange(i=>{this._updateWidgetWidth()})),this._updateWidgetWidth()}get lineNumbers(){return this._lineNumbers}get lineNumberCount(){return this._lineNumbers.length}getStickyLineForLine(e){return this._stickyLines.find(t=>t.lineNumber===e)}getCurrentLines(){return this._lineNumbers}setState(e,t,i=1/0){if((!this._previousState&&!e||this._previousState&&this._previousState.equals(e))&&i===1/0)return;this._previousState=e;const n=this._stickyLines;if(this._clearStickyWidget(),!e||!this._editor._getViewModel())return;if(e.startLineNumbers.length*this._lineHeight+e.lastLineRelativePosition>0){this._lastLineRelativePosition=e.lastLineRelativePosition;const r=[...e.startLineNumbers];e.showEndForLine!==null&&(r[e.showEndForLine]=e.endLineNumbers[e.showEndForLine]),this._lineNumbers=r}else this._lastLineRelativePosition=0,this._lineNumbers=[];this._renderRootNode(n,t,i)}_updateWidgetWidth(){const e=this._editor.getLayoutInfo(),t=e.contentLeft;this._lineNumbersDomNode.style.width=`${t}px`,this._linesDomNodeScrollable.style.setProperty("--vscode-editorStickyScroll-scrollableWidth",`${this._editor.getScrollWidth()-e.verticalScrollbarWidth}px`),this._rootDomNode.style.width=`${e.width-e.verticalScrollbarWidth}px`}_clearStickyWidget(){this._stickyLines=[],this._foldingIconStore.clear(),Vn(this._lineNumbersDomNode),Vn(this._linesDomNode),this._rootDomNode.style.display="none"}_useFoldingOpacityTransition(e){this._lineNumbersDomNode.style.setProperty("--vscode-editorStickyScroll-foldingOpacityTransition",`opacity ${e?.5:0}s`)}_setFoldingIconsVisibility(e){for(const t of this._stickyLines){const i=t.foldingIcon;i&&i.setVisible(e?!0:i.isCollapsed)}}async _renderRootNode(e,t,i=1/0){const n=this._editor.getLayoutInfo();for(const[r,a]of this._lineNumbers.entries()){const l=e[r],d=a>=i||(l==null?void 0:l.lineNumber)!==a?this._renderChildNode(r,a,t,n):this._updateTopAndZIndexOfStickyLine(l);d&&(this._linesDomNode.appendChild(d.lineDomNode),this._lineNumbersDomNode.appendChild(d.lineNumberDomNode),this._stickyLines.push(d))}t&&(this._setFoldingHoverListeners(),this._useFoldingOpacityTransition(!this._isOnGlyphMargin));const o=this._lineNumbers.length*this._lineHeight+this._lastLineRelativePosition;if(o===0){this._clearStickyWidget();return}this._rootDomNode.style.display="block",this._lineNumbersDomNode.style.height=`${o}px`,this._linesDomNodeScrollable.style.height=`${o}px`,this._rootDomNode.style.height=`${o}px`,this._rootDomNode.style.marginLeft="0px",this._updateMinContentWidth(),this._editor.layoutOverlayWidget(this)}_setFoldingHoverListeners(){this._editor.getOption(109)==="mouseover"&&(this._foldingIconStore.add(Y(this._lineNumbersDomNode,he.MOUSE_ENTER,t=>{this._isOnGlyphMargin=!0,this._setFoldingIconsVisibility(!0)})),this._foldingIconStore.add(Y(this._lineNumbersDomNode,he.MOUSE_LEAVE,()=>{this._isOnGlyphMargin=!1,this._useFoldingOpacityTransition(!0),this._setFoldingIconsVisibility(!1)})))}_renderChildNode(e,t,i,n){const o=this._editor._getViewModel();if(!o)return;const r=o.coordinatesConverter.convertModelPositionToViewPosition(new H(t,1)).lineNumber,a=o.getViewLineRenderingData(r),l=this._editor.getOption(67);let d;try{d=mo.filter(a.inlineDecorations,r,a.minColumn,a.maxColumn)}catch{d=[]}const c=new sh(!0,!0,a.content,a.continuesWithWrappedLine,a.isBasicASCII,a.containsRTL,0,a.tokens,d,a.tabSize,a.startVisibleColumn,1,1,1,500,"none",!0,!0,null),u=new s_(2e3),h=lC(c,u);let g;BB?g=BB.createHTML(u.build()):g=u.build();const f=document.createElement("span");f.setAttribute(SE,String(e)),f.setAttribute(WB,""),f.setAttribute("role","listitem"),f.tabIndex=0,f.className="sticky-line-content",f.classList.add(`stickyLine${t}`),f.style.lineHeight=`${this._lineHeight}px`,f.innerHTML=g;const m=document.createElement("span");m.setAttribute(SE,String(e)),m.setAttribute(fDe,""),m.className="sticky-line-number",m.style.lineHeight=`${this._lineHeight}px`;const _=n.contentLeft;m.style.width=`${_}px`;const v=document.createElement("span");l.renderType===1||l.renderType===3&&t%10===0?v.innerText=t.toString():l.renderType===2&&(v.innerText=Math.abs(t-this._editor.getPosition().lineNumber).toString()),v.className="sticky-line-number-inner",v.style.lineHeight=`${this._lineHeight}px`,v.style.width=`${n.lineNumbersWidth}px`,v.style.paddingLeft=`${n.lineNumbersLeft}px`,m.appendChild(v);const b=this._renderFoldingIconForLine(i,t);b&&m.appendChild(b.domNode),this._editor.applyFontInfo(f),this._editor.applyFontInfo(v),m.style.lineHeight=`${this._lineHeight}px`,f.style.lineHeight=`${this._lineHeight}px`,m.style.height=`${this._lineHeight}px`,f.style.height=`${this._lineHeight}px`;const C=new mDe(e,t,f,m,b,h.characterMapping);return this._updateTopAndZIndexOfStickyLine(C)}_updateTopAndZIndexOfStickyLine(e){var t;const i=e.index,n=e.lineDomNode,o=e.lineNumberDomNode,r=i===this._lineNumbers.length-1,a="0",l="1";n.style.zIndex=r?a:l,o.style.zIndex=r?a:l;const d=`${i*this._lineHeight+this._lastLineRelativePosition+(!((t=e.foldingIcon)===null||t===void 0)&&t.isCollapsed?1:0)}px`,c=`${i*this._lineHeight}px`;return n.style.top=r?d:c,o.style.top=r?d:c,e}_renderFoldingIconForLine(e,t){const i=this._editor.getOption(109);if(!e||i==="never")return;const n=e.regions,o=n.findRange(t),r=n.getStartLineNumber(o);if(!(t===r))return;const l=n.isCollapsed(o),d=new _De(l,r,n.getEndLineNumber(o),this._lineHeight);return d.setVisible(this._isOnGlyphMargin?!0:l||i==="always"),d.domNode.setAttribute(VB,""),d}_updateMinContentWidth(){this._minContentWidthInPx=0;for(const e of this._stickyLines)e.lineDomNode.scrollWidth>this._minContentWidthInPx&&(this._minContentWidthInPx=e.lineDomNode.scrollWidth);this._minContentWidthInPx+=this._editor.getLayoutInfo().verticalScrollbarWidth}getId(){return"editor.contrib.stickyScrollWidget"}getDomNode(){return this._rootDomNode}getPosition(){return{preference:null}}getMinContentWidthInPx(){return this._minContentWidthInPx}focusLineWithIndex(e){0<=e&&e<this._stickyLines.length&&this._stickyLines[e].lineDomNode.focus()}getEditorPositionFromNode(e){if(!e||e.children.length>0)return null;const t=this._getRenderedStickyLineFromChildDomNode(e);if(!t)return null;const i=xP(t.characterMapping,e,0);return new H(t.lineNumber,i)}getLineNumberFromChildDomNode(e){var t,i;return(i=(t=this._getRenderedStickyLineFromChildDomNode(e))===null||t===void 0?void 0:t.lineNumber)!==null&&i!==void 0?i:null}_getRenderedStickyLineFromChildDomNode(e){const t=this.getLineIndexFromChildDomNode(e);return t===null||t<0||t>=this._stickyLines.length?null:this._stickyLines[t]}getLineIndexFromChildDomNode(e){const t=this._getAttributeValue(e,SE);return t?parseInt(t,10):null}isInStickyLine(e){return this._getAttributeValue(e,WB)!==void 0}isInFoldingIconDomNode(e){return this._getAttributeValue(e,VB)!==void 0}_getAttributeValue(e,t){for(;e&&e!==this._rootDomNode;){const i=e.getAttribute(t);if(i!==null)return i;e=e.parentElement}}}class mDe{constructor(e,t,i,n,o,r){this.index=e,this.lineNumber=t,this.lineDomNode=i,this.lineNumberDomNode=n,this.foldingIcon=o,this.characterMapping=r}}class _De{constructor(e,t,i,n){this.isCollapsed=e,this.foldingStartLine=t,this.foldingEndLine=i,this.dimension=n,this.domNode=document.createElement("div"),this.domNode.style.width=`${n}px`,this.domNode.style.height=`${n}px`,this.domNode.className=Oe.asClassName(e?MD:TD)}setVisible(e){this.domNode.style.cursor=e?"pointer":"default",this.domNode.style.opacity=e?"1":"0"}}class a0{constructor(e,t){this.startLineNumber=e,this.endLineNumber=t}}class yL{constructor(e,t,i){this.range=e,this.children=t,this.parent=i}}class jK{constructor(e,t,i,n){this.uri=e,this.version=t,this.element=i,this.outlineProviderId=n}}var QD=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},jb=function(s,e){return function(t,i){e(t,i,s)}},l0;(function(s){s.OUTLINE_MODEL="outlineModel",s.FOLDING_PROVIDER_MODEL="foldingProviderModel",s.INDENTATION_MODEL="indentationModel"})(l0||(l0={}));var eu;(function(s){s[s.VALID=0]="VALID",s[s.INVALID=1]="INVALID",s[s.CANCELED=2]="CANCELED"})(eu||(eu={}));let PR=class extends j{constructor(e,t,i,n){super(),this._editor=e,this._languageConfigurationService=t,this._languageFeaturesService=i,this._modelProviders=[],this._modelPromise=null,this._updateScheduler=this._register(new Qr(300)),this._updateOperation=this._register(new ie);const o=new OR(i),r=new BR(this._editor,i),a=new FR(this._editor,t);switch(n){case l0.OUTLINE_MODEL:this._modelProviders.push(o),this._modelProviders.push(r),this._modelProviders.push(a);break;case l0.FOLDING_PROVIDER_MODEL:this._modelProviders.push(r),this._modelProviders.push(a);break;case l0.INDENTATION_MODEL:this._modelProviders.push(a);break}}_cancelModelPromise(){this._modelPromise&&(this._modelPromise.cancel(),this._modelPromise=null)}async update(e,t,i){return this._updateOperation.clear(),this._updateOperation.add({dispose:()=>{this._cancelModelPromise(),this._updateScheduler.cancel()}}),this._cancelModelPromise(),await this._updateScheduler.trigger(async()=>{for(const n of this._modelProviders){const{statusPromise:o,modelPromise:r}=n.computeStickyModel(e,t,i);this._modelPromise=r;const a=await o;if(this._modelPromise!==r)return null;switch(a){case eu.CANCELED:return this._updateOperation.clear(),null;case eu.VALID:return n.stickyModel}}return null}).catch(n=>(et(n),null))}};PR=QD([jb(1,Jt),jb(2,xe)],PR);class KK{constructor(){this._stickyModel=null}get stickyModel(){return this._stickyModel}_invalid(){return this._stickyModel=null,eu.INVALID}computeStickyModel(e,t,i){if(i.isCancellationRequested||!this.isProviderValid(e))return{statusPromise:this._invalid(),modelPromise:null};const n=gn(o=>this.createModelFromProvider(e,t,o));return{statusPromise:n.then(o=>this.isModelValid(o)?i.isCancellationRequested?eu.CANCELED:(this._stickyModel=this.createStickyModel(e,t,i,o),eu.VALID):this._invalid()).then(void 0,o=>(et(o),eu.CANCELED)),modelPromise:n}}isModelValid(e){return!0}isProviderValid(e){return!0}}let OR=class extends KK{constructor(e){super(),this._languageFeaturesService=e}createModelFromProvider(e,t,i){return kd.create(this._languageFeaturesService.documentSymbolProvider,e,i)}createStickyModel(e,t,i,n){var o;const{stickyOutlineElement:r,providerID:a}=this._stickyModelFromOutlineModel(n,(o=this._stickyModel)===null||o===void 0?void 0:o.outlineProviderId);return new jK(e.uri,t,r,a)}isModelValid(e){return e&&e.children.size>0}_stickyModelFromOutlineModel(e,t){let i;if(ht.first(e.children.values())instanceof _K){const a=ht.find(e.children.values(),l=>l.id===t);if(a)i=a.children;else{let l="",d=-1,c;for(const[u,h]of e.children.entries()){const g=this._findSumOfRangesOfGroup(h);g>d&&(c=h,d=g,l=h.id)}t=l,i=c.children}}else i=e.children;const n=[],o=Array.from(i.values()).sort((a,l)=>{const d=new a0(a.symbol.range.startLineNumber,a.symbol.range.endLineNumber),c=new a0(l.symbol.range.startLineNumber,l.symbol.range.endLineNumber);return this._comparator(d,c)});for(const a of o)n.push(this._stickyModelFromOutlineElement(a,a.symbol.selectionRange.startLineNumber));return{stickyOutlineElement:new yL(void 0,n,void 0),providerID:t}}_stickyModelFromOutlineElement(e,t){const i=[];for(const o of e.children.values())if(o.symbol.selectionRange.startLineNumber!==o.symbol.range.endLineNumber)if(o.symbol.selectionRange.startLineNumber!==t)i.push(this._stickyModelFromOutlineElement(o,o.symbol.selectionRange.startLineNumber));else for(const r of o.children.values())i.push(this._stickyModelFromOutlineElement(r,o.symbol.selectionRange.startLineNumber));i.sort((o,r)=>this._comparator(o.range,r.range));const n=new a0(e.symbol.selectionRange.startLineNumber,e.symbol.range.endLineNumber);return new yL(n,i,void 0)}_comparator(e,t){return e.startLineNumber!==t.startLineNumber?e.startLineNumber-t.startLineNumber:t.endLineNumber-e.endLineNumber}_findSumOfRangesOfGroup(e){let t=0;for(const i of e.children.values())t+=this._findSumOfRangesOfGroup(i);return e instanceof sR?t+e.symbol.range.endLineNumber-e.symbol.selectionRange.startLineNumber:t}};OR=QD([jb(0,xe)],OR);class qK extends KK{constructor(e){super(),this._foldingLimitReporter=new fK(e)}createStickyModel(e,t,i,n){const o=this._fromFoldingRegions(n);return new jK(e.uri,t,o,void 0)}isModelValid(e){return e!==null}_fromFoldingRegions(e){const t=e.length,i=[],n=new yL(void 0,[],void 0);for(let o=0;o<t;o++){const r=e.getParentIndex(o);let a;r!==-1?a=i[r]:a=n;const l=new yL(new a0(e.getStartLineNumber(o),e.getEndLineNumber(o)+1),[],a);a.children.push(l),i.push(l)}return n}}let FR=class extends qK{constructor(e,t){super(e),this._languageConfigurationService=t}createModelFromProvider(e,t,i){return new y4(e,this._languageConfigurationService,this._foldingLimitReporter).compute(i)}};FR=QD([jb(1,Jt)],FR);let BR=class extends qK{constructor(e,t){super(e),this._languageFeaturesService=t}isProviderValid(e){return id.getFoldingRangeProviders(this._languageFeaturesService,e).length>0}createModelFromProvider(e,t,i){const n=id.getFoldingRangeProviders(this._languageFeaturesService,e);return new x4(e,n,()=>this.createModelFromProvider(e,t,i),this._foldingLimitReporter,void 0).compute(i)}};BR=QD([jb(1,xe)],BR);var vDe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},HB=function(s,e){return function(t,i){e(t,i,s)}};class bDe{constructor(e,t,i){this.startLineNumber=e,this.endLineNumber=t,this.nestingDepth=i}}let WR=class extends j{constructor(e,t,i){super(),this._languageFeaturesService=t,this._languageConfigurationService=i,this._onDidChangeStickyScroll=this._register(new W),this.onDidChangeStickyScroll=this._onDidChangeStickyScroll.event,this._options=null,this._model=null,this._cts=null,this._stickyModelProvider=null,this._editor=e,this._sessionStore=this._register(new ie),this._updateSoon=this._register(new jt(()=>this.update(),50)),this._register(this._editor.onDidChangeConfiguration(n=>{n.hasChanged(114)&&this.readConfiguration()})),this.readConfiguration()}readConfiguration(){this._stickyModelProvider=null,this._sessionStore.clear(),this._options=this._editor.getOption(114),this._options.enabled&&(this._stickyModelProvider=this._sessionStore.add(new PR(this._editor,this._languageConfigurationService,this._languageFeaturesService,this._options.defaultModel)),this._sessionStore.add(this._editor.onDidChangeModel(()=>{this._model=null,this._onDidChangeStickyScroll.fire(),this.update()})),this._sessionStore.add(this._editor.onDidChangeHiddenAreas(()=>this.update())),this._sessionStore.add(this._editor.onDidChangeModelContent(()=>this._updateSoon.schedule())),this._sessionStore.add(this._languageFeaturesService.documentSymbolProvider.onDidChange(()=>this.update())),this.update())}getVersionId(){var e;return(e=this._model)===null||e===void 0?void 0:e.version}async update(){var e;(e=this._cts)===null||e===void 0||e.dispose(!0),this._cts=new Yi,await this.updateStickyModel(this._cts.token),this._onDidChangeStickyScroll.fire()}async updateStickyModel(e){if(!this._editor.hasModel()||!this._stickyModelProvider||this._editor.getModel().isTooLargeForTokenization()){this._model=null;return}const t=this._editor.getModel(),i=t.getVersionId(),n=await this._stickyModelProvider.update(t,i,e);e.isCancellationRequested||(this._model=n)}updateIndex(e){return e===-1?e=0:e<0&&(e=-e-2),e}getCandidateStickyLinesIntersectingFromStickyModel(e,t,i,n,o){if(t.children.length===0)return;let r=o;const a=[];for(let c=0;c<t.children.length;c++){const u=t.children[c];u.range&&a.push(u.range.startLineNumber)}const l=this.updateIndex(_0(a,e.startLineNumber,(c,u)=>c-u)),d=this.updateIndex(_0(a,e.startLineNumber+n,(c,u)=>c-u));for(let c=l;c<=d;c++){const u=t.children[c];if(!u)return;if(u.range){const h=u.range.startLineNumber,g=u.range.endLineNumber;e.startLineNumber<=g+1&&h-1<=e.endLineNumber&&h!==r&&(r=h,i.push(new bDe(h,g-1,n+1)),this.getCandidateStickyLinesIntersectingFromStickyModel(e,u,i,n+1,h))}else this.getCandidateStickyLinesIntersectingFromStickyModel(e,u,i,n,o)}}getCandidateStickyLinesIntersecting(e){var t,i;if(!(!((t=this._model)===null||t===void 0)&&t.element))return[];let n=[];this.getCandidateStickyLinesIntersectingFromStickyModel(e,this._model.element,n,0,-1);const o=(i=this._editor._getViewModel())===null||i===void 0?void 0:i.getHiddenAreas();if(o)for(const r of o)n=n.filter(a=>!(a.startLineNumber>=r.startLineNumber&&a.endLineNumber<=r.endLineNumber+1));return n}};WR=vDe([HB(1,xe),HB(2,Jt)],WR);var CDe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Hf=function(s,e){return function(t,i){e(t,i,s)}},VR;let nd=VR=class extends j{constructor(e,t,i,n,o,r,a){super(),this._editor=e,this._contextMenuService=t,this._languageFeaturesService=i,this._instaService=n,this._contextKeyService=a,this._sessionStore=new ie,this._foldingModel=null,this._maxStickyLines=Number.MAX_SAFE_INTEGER,this._candidateDefinitionsLength=-1,this._focusedStickyElementIndex=-1,this._enabled=!1,this._focused=!1,this._positionRevealed=!1,this._onMouseDown=!1,this._endLineNumbers=[],this._showEndForLine=null,this._stickyScrollWidget=new pDe(this._editor),this._stickyLineCandidateProvider=new WR(this._editor,i,o),this._register(this._stickyScrollWidget),this._register(this._stickyLineCandidateProvider),this._widgetState=new FB([],[],0),this._readConfiguration();const l=this._stickyScrollWidget.getDomNode();this._register(this._editor.onDidChangeConfiguration(c=>{(c.hasChanged(114)||c.hasChanged(72)||c.hasChanged(66)||c.hasChanged(109))&&this._readConfiguration()})),this._register(Y(l,he.CONTEXT_MENU,async c=>{this._onContextMenu(Xe(l),c)})),this._stickyScrollFocusedContextKey=T.stickyScrollFocused.bindTo(this._contextKeyService),this._stickyScrollVisibleContextKey=T.stickyScrollVisible.bindTo(this._contextKeyService);const d=this._register(ql(l));this._register(d.onDidBlur(c=>{this._positionRevealed===!1&&l.clientHeight===0?(this._focusedStickyElementIndex=-1,this.focus()):this._disposeFocusStickyScrollStore()})),this._register(d.onDidFocus(c=>{this.focus()})),this._registerMouseListeners(),this._register(Y(l,he.MOUSE_DOWN,c=>{this._onMouseDown=!0}))}static get(e){return e.getContribution(VR.ID)}_disposeFocusStickyScrollStore(){var e;this._stickyScrollFocusedContextKey.set(!1),(e=this._focusDisposableStore)===null||e===void 0||e.dispose(),this._focused=!1,this._positionRevealed=!1,this._onMouseDown=!1}focus(){if(this._onMouseDown){this._onMouseDown=!1,this._editor.focus();return}this._stickyScrollFocusedContextKey.get()!==!0&&(this._focused=!0,this._focusDisposableStore=new ie,this._stickyScrollFocusedContextKey.set(!0),this._focusedStickyElementIndex=this._stickyScrollWidget.lineNumbers.length-1,this._stickyScrollWidget.focusLineWithIndex(this._focusedStickyElementIndex))}focusNext(){this._focusedStickyElementIndex<this._stickyScrollWidget.lineNumberCount-1&&this._focusNav(!0)}focusPrevious(){this._focusedStickyElementIndex>0&&this._focusNav(!1)}selectEditor(){this._editor.focus()}_focusNav(e){this._focusedStickyElementIndex=e?this._focusedStickyElementIndex+1:this._focusedStickyElementIndex-1,this._stickyScrollWidget.focusLineWithIndex(this._focusedStickyElementIndex)}goToFocused(){const e=this._stickyScrollWidget.lineNumbers;this._disposeFocusStickyScrollStore(),this._revealPosition({lineNumber:e[this._focusedStickyElementIndex],column:1})}_revealPosition(e){this._reveaInEditor(e,()=>this._editor.revealPosition(e))}_revealLineInCenterIfOutsideViewport(e){this._reveaInEditor(e,()=>this._editor.revealLineInCenterIfOutsideViewport(e.lineNumber,0))}_reveaInEditor(e,t){this._focused&&this._disposeFocusStickyScrollStore(),this._positionRevealed=!0,t(),this._editor.setSelection(D.fromPositions(e)),this._editor.focus()}_registerMouseListeners(){const e=this._register(new ie),t=this._register(new mD(this._editor,{extractLineNumberFromMouseEvent:o=>{const r=this._stickyScrollWidget.getEditorPositionFromNode(o.target.element);return r?r.lineNumber:0}})),i=o=>{if(!this._editor.hasModel()||o.target.type!==12||o.target.detail!==this._stickyScrollWidget.getId())return null;const r=o.target.element;if(!r||r.innerText!==r.innerHTML)return null;const a=this._stickyScrollWidget.getEditorPositionFromNode(r);return a?{range:new D(a.lineNumber,a.column,a.lineNumber,a.column+r.innerText.length),textElement:r}:null},n=this._stickyScrollWidget.getDomNode();this._register(Pi(n,he.CLICK,o=>{if(o.ctrlKey||o.altKey||o.metaKey||!o.leftButton)return;if(o.shiftKey){const d=this._stickyScrollWidget.getLineIndexFromChildDomNode(o.target);if(d===null)return;const c=new H(this._endLineNumbers[d],1);this._revealLineInCenterIfOutsideViewport(c);return}if(this._stickyScrollWidget.isInFoldingIconDomNode(o.target)){const d=this._stickyScrollWidget.getLineNumberFromChildDomNode(o.target);this._toggleFoldingRegionForLine(d);return}if(!this._stickyScrollWidget.isInStickyLine(o.target))return;let l=this._stickyScrollWidget.getEditorPositionFromNode(o.target);if(!l){const d=this._stickyScrollWidget.getLineNumberFromChildDomNode(o.target);if(d===null)return;l=new H(d,1)}this._revealPosition(l)})),this._register(Pi(n,he.MOUSE_MOVE,o=>{if(o.shiftKey){const r=this._stickyScrollWidget.getLineIndexFromChildDomNode(o.target);if(r===null||this._showEndForLine!==null&&this._showEndForLine===r)return;this._showEndForLine=r,this._renderStickyScroll();return}this._showEndForLine!==null&&(this._showEndForLine=null,this._renderStickyScroll())})),this._register(Y(n,he.MOUSE_LEAVE,o=>{this._showEndForLine!==null&&(this._showEndForLine=null,this._renderStickyScroll())})),this._register(t.onMouseMoveOrRelevantKeyDown(([o,r])=>{const a=i(o);if(!a||!o.hasTriggerModifier||!this._editor.hasModel()){e.clear();return}const{range:l,textElement:d}=a;if(!l.equalsRange(this._stickyRangeProjectedOnEditor))this._stickyRangeProjectedOnEditor=l,e.clear();else if(d.style.textDecoration==="underline")return;const c=new Yi;e.add(Fe(()=>c.dispose(!0)));let u;SD(this._languageFeaturesService.definitionProvider,this._editor.getModel(),new H(l.startLineNumber,l.startColumn+1),c.token).then(h=>{if(!c.token.isCancellationRequested)if(h.length!==0){this._candidateDefinitionsLength=h.length;const g=d;u!==g?(e.clear(),u=g,u.style.textDecoration="underline",e.add(Fe(()=>{u.style.textDecoration="none"}))):u||(u=g,u.style.textDecoration="underline",e.add(Fe(()=>{u.style.textDecoration="none"})))}else e.clear()})})),this._register(t.onCancel(()=>{e.clear()})),this._register(t.onExecute(async o=>{if(o.target.type!==12||o.target.detail!==this._stickyScrollWidget.getId())return;const r=this._stickyScrollWidget.getEditorPositionFromNode(o.target.element);r&&(this._candidateDefinitionsLength>1&&(this._focused&&this._disposeFocusStickyScrollStore(),this._revealPosition({lineNumber:r.lineNumber,column:1})),this._instaService.invokeFunction(LK,o,this._editor,{uri:this._editor.getModel().uri,range:this._stickyRangeProjectedOnEditor}))}))}_onContextMenu(e,t){const i=new zr(e,t);this._contextMenuService.showContextMenu({menuId:N.StickyScrollContext,getAnchor:()=>i})}_toggleFoldingRegionForLine(e){if(!this._foldingModel||e===null)return;const t=this._stickyScrollWidget.getStickyLineForLine(e),i=t==null?void 0:t.foldingIcon;if(!i)return;dK(this._foldingModel,Number.MAX_VALUE,[e]),i.isCollapsed=!i.isCollapsed;const n=(i.isCollapsed?this._editor.getTopForLineNumber(i.foldingEndLine):this._editor.getTopForLineNumber(i.foldingStartLine))-this._editor.getOption(66)*t.index+1;this._editor.setScrollTop(n),this._renderStickyScroll(e)}_readConfiguration(){const e=this._editor.getOption(114);if(e.enabled===!1){this._editor.removeOverlayWidget(this._stickyScrollWidget),this._sessionStore.clear(),this._enabled=!1;return}else e.enabled&&!this._enabled&&(this._editor.addOverlayWidget(this._stickyScrollWidget),this._sessionStore.add(this._editor.onDidScrollChange(i=>{i.scrollTopChanged&&(this._showEndForLine=null,this._renderStickyScroll())})),this._sessionStore.add(this._editor.onDidLayoutChange(()=>this._onDidResize())),this._sessionStore.add(this._editor.onDidChangeModelTokens(i=>this._onTokensChange(i))),this._sessionStore.add(this._stickyLineCandidateProvider.onDidChangeStickyScroll(()=>{this._showEndForLine=null,this._renderStickyScroll()})),this._enabled=!0);this._editor.getOption(67).renderType===2&&this._sessionStore.add(this._editor.onDidChangeCursorPosition(()=>{this._showEndForLine=null,this._renderStickyScroll(-1)}))}_needsUpdate(e){const t=this._stickyScrollWidget.getCurrentLines();for(const i of t)for(const n of e.ranges)if(i>=n.fromLineNumber&&i<=n.toLineNumber)return!0;return!1}_onTokensChange(e){this._needsUpdate(e)&&this._renderStickyScroll(-1)}_onDidResize(){const t=this._editor.getLayoutInfo().height/this._editor.getOption(66);this._maxStickyLines=Math.round(t*.25)}async _renderStickyScroll(e=1/0){var t,i;const n=this._editor.getModel();if(!n||n.isTooLargeForTokenization()){this._foldingModel=null,this._stickyScrollWidget.setState(void 0,null,e);return}const o=this._stickyLineCandidateProvider.getVersionId();if(o===void 0||o===n.getVersionId())if(this._foldingModel=(i=await((t=id.get(this._editor))===null||t===void 0?void 0:t.getFoldingModel()))!==null&&i!==void 0?i:null,this._widgetState=this.findScrollWidgetState(),this._stickyScrollVisibleContextKey.set(this._widgetState.startLineNumbers.length!==0),!this._focused)this._stickyScrollWidget.setState(this._widgetState,this._foldingModel,e);else if(this._focusedStickyElementIndex===-1)this._stickyScrollWidget.setState(this._widgetState,this._foldingModel,e),this._focusedStickyElementIndex=this._stickyScrollWidget.lineNumberCount-1,this._focusedStickyElementIndex!==-1&&this._stickyScrollWidget.focusLineWithIndex(this._focusedStickyElementIndex);else{const r=this._stickyScrollWidget.lineNumbers[this._focusedStickyElementIndex];this._stickyScrollWidget.setState(this._widgetState,this._foldingModel,e),this._stickyScrollWidget.lineNumberCount===0?this._focusedStickyElementIndex=-1:(this._stickyScrollWidget.lineNumbers.includes(r)||(this._focusedStickyElementIndex=this._stickyScrollWidget.lineNumberCount-1),this._stickyScrollWidget.focusLineWithIndex(this._focusedStickyElementIndex))}}findScrollWidgetState(){const e=this._editor.getOption(66),t=Math.min(this._maxStickyLines,this._editor.getOption(114).maxLineCount),i=this._editor.getScrollTop();let n=0;const o=[],r=[],a=this._editor.getVisibleRanges();if(a.length!==0){const l=new a0(a[0].startLineNumber,a[a.length-1].endLineNumber),d=this._stickyLineCandidateProvider.getCandidateStickyLinesIntersecting(l);for(const c of d){const u=c.startLineNumber,h=c.endLineNumber,g=c.nestingDepth;if(h-u>0){const f=(g-1)*e,m=g*e,_=this._editor.getBottomForLineNumber(u)-i,v=this._editor.getTopForLineNumber(h)-i,b=this._editor.getBottomForLineNumber(h)-i;if(f>v&&f<=b){o.push(u),r.push(h+1),n=b-m;break}else m>_&&m<=b&&(o.push(u),r.push(h+1));if(o.length===t)break}}}return this._endLineNumbers=r,new FB(o,r,n,this._showEndForLine)}dispose(){super.dispose(),this._sessionStore.dispose()}};nd.ID="store.contrib.stickyScrollController";nd=VR=CDe([Hf(1,Nr),Hf(2,xe),Hf(3,We),Hf(4,Jt),Hf(5,Er),Hf(6,je)],nd);class wDe extends ar{constructor(){super({id:"editor.action.toggleStickyScroll",title:{value:p("toggleStickyScroll","Toggle Sticky Scroll"),mnemonicTitle:p({key:"mitoggleStickyScroll",comment:["&& denotes a mnemonic"]},"&&Toggle Sticky Scroll"),original:"Toggle Sticky Scroll"},category:gDe.View,toggled:{condition:ee.equals("config.editor.stickyScroll.enabled",!0),title:p("stickyScroll","Sticky Scroll"),mnemonicTitle:p({key:"miStickyScroll",comment:["&& denotes a mnemonic"]},"&&Sticky Scroll")},menu:[{id:N.CommandPalette},{id:N.MenubarAppearanceMenu,group:"4_editor",order:3},{id:N.StickyScrollContext}]})}async run(e){const t=e.get(mt),i=!t.getValue("editor.stickyScroll.enabled");return t.updateValue("editor.stickyScroll.enabled",i)}}const JD=100;class SDe extends Ga{constructor(){super({id:"editor.action.focusStickyScroll",title:{value:p("focusStickyScroll","Focus Sticky Scroll"),mnemonicTitle:p({key:"mifocusStickyScroll",comment:["&& denotes a mnemonic"]},"&&Focus Sticky Scroll"),original:"Focus Sticky Scroll"},precondition:ee.and(ee.has("config.editor.stickyScroll.enabled"),T.stickyScrollVisible),menu:[{id:N.CommandPalette}]})}runEditorCommand(e,t){var i;(i=nd.get(t))===null||i===void 0||i.focus()}}class yDe extends Ga{constructor(){super({id:"editor.action.selectNextStickyScrollLine",title:{value:p("selectNextStickyScrollLine.title","Select next sticky scroll line"),original:"Select next sticky scroll line"},precondition:T.stickyScrollFocused.isEqualTo(!0),keybinding:{weight:JD,primary:18}})}runEditorCommand(e,t){var i;(i=nd.get(t))===null||i===void 0||i.focusNext()}}class LDe extends Ga{constructor(){super({id:"editor.action.selectPreviousStickyScrollLine",title:{value:p("selectPreviousStickyScrollLine.title","Select previous sticky scroll line"),original:"Select previous sticky scroll line"},precondition:T.stickyScrollFocused.isEqualTo(!0),keybinding:{weight:JD,primary:16}})}runEditorCommand(e,t){var i;(i=nd.get(t))===null||i===void 0||i.focusPrevious()}}class xDe extends Ga{constructor(){super({id:"editor.action.goToFocusedStickyScrollLine",title:{value:p("goToFocusedStickyScrollLine.title","Go to focused sticky scroll line"),original:"Go to focused sticky scroll line"},precondition:T.stickyScrollFocused.isEqualTo(!0),keybinding:{weight:JD,primary:3}})}runEditorCommand(e,t){var i;(i=nd.get(t))===null||i===void 0||i.goToFocused()}}class DDe extends Ga{constructor(){super({id:"editor.action.selectEditor",title:{value:p("selectEditor.title","Select Editor"),original:"Select Editor"},precondition:T.stickyScrollFocused.isEqualTo(!0),keybinding:{weight:JD,primary:9}})}runEditorCommand(e,t){var i;(i=nd.get(t))===null||i===void 0||i.selectEditor()}}Lt(nd.ID,nd,1);di(wDe);di(SDe);di(LDe);di(yDe);di(xDe);di(DDe);var H4=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},yg=function(s,e){return function(t,i){e(t,i,s)}},Fh;class kDe{constructor(e,t,i,n,o,r){this.range=e,this.insertText=t,this.filterText=i,this.additionalTextEdits=n,this.command=o,this.completion=r}}let HR=class extends mQ{constructor(e,t,i,n,o,r){super(o.disposable),this.model=e,this.line=t,this.word=i,this.completionModel=n,this._suggestMemoryService=r}canBeReused(e,t,i){return this.model===e&&this.line===t&&this.word.word.length>0&&this.word.startColumn===i.startColumn&&this.word.endColumn<i.endColumn&&this.completionModel.getIncompleteProvider().size===0}get items(){var e;const t=[],{items:i}=this.completionModel,n=this._suggestMemoryService.select(this.model,{lineNumber:this.line,column:this.word.endColumn+this.completionModel.lineContext.characterCountDelta},i),o=ht.slice(i,n),r=ht.slice(i,0,n);let a=5;for(const l of ht.concat(o,r)){if(l.score===Fa.Default)continue;const d=new D(l.editStart.lineNumber,l.editStart.column,l.editInsertEnd.lineNumber,l.editInsertEnd.column+this.completionModel.lineContext.characterCountDelta),c=l.completion.insertTextRules&&l.completion.insertTextRules&4?{snippet:l.completion.insertText}:l.completion.insertText;t.push(new kDe(d,c,(e=l.filterTextLow)!==null&&e!==void 0?e:l.labelLow,l.completion.additionalTextEdits,l.completion.command,l)),a-->=0&&l.resolve(ct.None)}return t}};HR=H4([yg(5,OD)],HR);let zR=class{constructor(e,t,i,n){this._getEditorOption=e,this._languageFeatureService=t,this._clipboardService=i,this._suggestMemoryService=n}async provideInlineCompletions(e,t,i,n){var o;if(i.selectedSuggestionInfo)return;const r=this._getEditorOption(88,e);if(xp.isAllOff(r))return;e.tokenization.tokenizeIfCheap(t.lineNumber);const a=e.tokenization.getLineTokens(t.lineNumber),l=a.getStandardTokenType(a.findTokenIndexAtOffset(Math.max(t.column-1-1,0)));if(xp.valueFor(r,l)!=="inline")return;let d=e.getWordAtPosition(t),c;if(d!=null&&d.word||(c=this._getTriggerCharacterInfo(e,t)),!(d!=null&&d.word)&&!c||(d||(d=e.getWordUntilPosition(t)),d.endColumn!==t.column))return;let u;const h=e.getValueInRange(new D(t.lineNumber,1,t.lineNumber,t.column));if(!c&&(!((o=this._lastResult)===null||o===void 0)&&o.canBeReused(e,t.lineNumber,d))){const g=new MB(h,t.column-this._lastResult.word.endColumn);this._lastResult.completionModel.lineContext=g,this._lastResult.acquire(),u=this._lastResult}else{const g=await k4(this._languageFeatureService.completionProvider,e,t,new Rb(void 0,void 0,c==null?void 0:c.providers),c&&{triggerKind:1,triggerCharacter:c.ch},n);let f;g.needsClipboard&&(f=await this._clipboardService.readText());const m=new Wc(g.items,t.column,new MB(h,0),ya.None,this._getEditorOption(117,e),this._getEditorOption(111,e),{boostFullMatch:!1,firstMatchCanBeWeak:!1},f);u=new HR(e,t.lineNumber,d,m,g,this._suggestMemoryService)}return this._lastResult=u,u}handleItemDidShow(e,t){t.completion.resolve(ct.None)}freeInlineCompletions(e){e.release()}_getTriggerCharacterInfo(e,t){var i;const n=e.getValueInRange(D.fromPositions({lineNumber:t.lineNumber,column:t.column-1},t)),o=new Set;for(const r of this._languageFeatureService.completionProvider.all(e))!((i=r.triggerCharacters)===null||i===void 0)&&i.includes(n)&&o.add(r);if(o.size!==0)return{providers:o,ch:n}}};zR=H4([yg(1,xe),yg(2,dc),yg(3,OD)],zR);let LL=Fh=class{constructor(e,t,i,n){if(++Fh._counter===1){const o=n.createInstance(zR,(r,a)=>{var l;return((l=i.listCodeEditors().find(c=>c.getModel()===a))!==null&&l!==void 0?l:e).getOption(r)});Fh._disposable=t.inlineCompletionsProvider.register("*",o)}}dispose(){var e;--Fh._counter===0&&((e=Fh._disposable)===null||e===void 0||e.dispose(),Fh._disposable=void 0)}};LL._counter=0;LL=Fh=H4([yg(1,xe),yg(2,It),yg(3,We)],LL);Lt("suggest.inlineCompletionsProvider",LL,0);class IDe extends we{constructor(){super({id:"editor.action.forceRetokenize",label:p("forceRetokenize","Developer: Force Retokenize"),alias:"Developer: Force Retokenize",precondition:void 0})}run(e,t){if(!t.hasModel())return;const i=t.getModel();i.tokenization.resetTokenization();const n=new cs;i.tokenization.forceTokenization(i.getLineCount()),n.stop(),console.log(`tokenization took ${n.elapsed()}`)}}re(IDe);class ek extends ar{constructor(){super({id:ek.ID,title:{value:p({key:"toggle.tabMovesFocus",comment:["Turn on/off use of tab key for moving focus around VS Code"]},"Toggle Tab Key Moves Focus"),original:"Toggle Tab Key Moves Focus"},precondition:void 0,keybinding:{primary:2091,mac:{primary:1323},weight:100},f1:!0})}run(){const t=!mm.getTabFocusMode();mm.setTabFocusMode(t),Lo(t?p("toggle.tabMovesFocus.on","Pressing Tab will now move focus to the next focusable element"):p("toggle.tabMovesFocus.off","Pressing Tab will now insert the tab character"))}}ek.ID="editor.action.toggleTabFocusMode";di(ek);var EDe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},NDe=function(s,e){return function(t,i){e(t,i,s)}};let UR=class extends j{get enabled(){return this._enabled}set enabled(e){e?(this.el.setAttribute("aria-disabled","false"),this.el.tabIndex=0,this.el.style.pointerEvents="auto",this.el.style.opacity="1",this.el.style.cursor="pointer",this._enabled=!1):(this.el.setAttribute("aria-disabled","true"),this.el.tabIndex=-1,this.el.style.pointerEvents="none",this.el.style.opacity="0.4",this.el.style.cursor="default",this._enabled=!0),this._enabled=e}constructor(e,t,i={},n){var o;super(),this._link=t,this._enabled=!0,this.el=te(e,se("a.monaco-link",{tabIndex:(o=t.tabIndex)!==null&&o!==void 0?o:0,href:t.href,title:t.title},t.label)),this.el.setAttribute("role","button");const r=this._register(new gt(this.el,"click")),a=this._register(new gt(this.el,"keypress")),l=ge.chain(a.event,u=>u.map(h=>new ri(h)).filter(h=>h.keyCode===3)),d=this._register(new gt(this.el,Qt.Tap)).event;this._register(Xt.addTarget(this.el));const c=ge.any(r.event,l,d);this._register(c(u=>{this.enabled&&(ot.stop(u,!0),i!=null&&i.opener?i.opener(this._link.href):n.open(this._link.href,{allowCommands:!0}))})),this.enabled=!0}};UR=EDe([NDe(3,No)],UR);var GK=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},ZK=function(s,e){return function(t,i){e(t,i,s)}};const TDe=26;let $R=class extends j{constructor(e,t){super(),this._editor=e,this.instantiationService=t,this.banner=this._register(this.instantiationService.createInstance(jR))}hide(){this._editor.setBanner(null,0),this.banner.clear()}show(e){this.banner.show({...e,onClose:()=>{var t;this.hide(),(t=e.onClose)===null||t===void 0||t.call(e)}}),this._editor.setBanner(this.banner.element,TDe)}};$R=GK([ZK(1,We)],$R);let jR=class extends j{constructor(e){super(),this.instantiationService=e,this.markdownRenderer=this.instantiationService.createInstance(ic,{}),this.element=se("div.editor-banner"),this.element.tabIndex=0}getAriaLabel(e){if(e.ariaLabel)return e.ariaLabel;if(typeof e.message=="string")return e.message}getBannerMessage(e){if(typeof e=="string"){const t=se("span");return t.innerText=e,t}return this.markdownRenderer.render(e).element}clear(){Vn(this.element)}show(e){Vn(this.element);const t=this.getAriaLabel(e);t&&this.element.setAttribute("aria-label",t);const i=te(this.element,se("div.icon-container"));i.setAttribute("aria-hidden","true"),e.icon&&i.appendChild(se(`div${Oe.asCSSSelector(e.icon)}`));const n=te(this.element,se("div.message-container"));if(n.setAttribute("aria-hidden","true"),n.appendChild(this.getBannerMessage(e.message)),this.messageActionsContainer=te(this.element,se("div.message-actions-container")),e.actions)for(const r of e.actions)this._register(this.instantiationService.createInstance(UR,this.messageActionsContainer,{...r,tabIndex:-1},{}));const o=te(this.element,se("div.action-container"));this.actionBar=this._register(new Ir(o)),this.actionBar.push(this._register(new Os("banner.close","Close Banner",Oe.asClassName(EU),!0,()=>{typeof e.onClose=="function"&&e.onClose()})),{icon:!0,label:!1}),this.actionBar.setFocusable(!1)}};jR=GK([ZK(0,We)],jR);var z4=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},tm=function(s,e){return function(t,i){e(t,i,s)}};const MDe=Ui("extensions-warning-message",le.warning,p("warningIcon","Icon shown with a warning message in the extensions editor."));let qm=class extends j{constructor(e,t,i,n){super(),this._editor=e,this._editorWorkerService=t,this._workspaceTrustService=i,this._highlighter=null,this._bannerClosed=!1,this._updateState=o=>{if(o&&o.hasMore){if(this._bannerClosed)return;const r=Math.max(o.ambiguousCharacterCount,o.nonBasicAsciiCharacterCount,o.invisibleCharacterCount);let a;if(o.nonBasicAsciiCharacterCount>=r)a={message:p("unicodeHighlighting.thisDocumentHasManyNonBasicAsciiUnicodeCharacters","This document contains many non-basic ASCII unicode characters"),command:new y_};else if(o.ambiguousCharacterCount>=r)a={message:p("unicodeHighlighting.thisDocumentHasManyAmbiguousUnicodeCharacters","This document contains many ambiguous unicode characters"),command:new ch};else if(o.invisibleCharacterCount>=r)a={message:p("unicodeHighlighting.thisDocumentHasManyInvisibleUnicodeCharacters","This document contains many invisible unicode characters"),command:new S_};else throw new Error("Unreachable");this._bannerController.show({id:"unicodeHighlightBanner",message:a.message,icon:MDe,actions:[{label:a.command.shortLabel,href:`command:${a.command.id}`}],onClose:()=>{this._bannerClosed=!0}})}else this._bannerController.hide()},this._bannerController=this._register(n.createInstance($R,e)),this._register(this._editor.onDidChangeModel(()=>{this._bannerClosed=!1,this._updateHighlighter()})),this._options=e.getOption(124),this._register(i.onDidChangeTrust(o=>{this._updateHighlighter()})),this._register(e.onDidChangeConfiguration(o=>{o.hasChanged(124)&&(this._options=e.getOption(124),this._updateHighlighter())})),this._updateHighlighter()}dispose(){this._highlighter&&(this._highlighter.dispose(),this._highlighter=null),super.dispose()}_updateHighlighter(){if(this._updateState(null),this._highlighter&&(this._highlighter.dispose(),this._highlighter=null),!this._editor.hasModel())return;const e=RDe(this._workspaceTrustService.isWorkspaceTrusted(),this._options);if([e.nonBasicASCII,e.ambiguousCharacters,e.invisibleCharacters].every(i=>i===!1))return;const t={nonBasicASCII:e.nonBasicASCII,ambiguousCharacters:e.ambiguousCharacters,invisibleCharacters:e.invisibleCharacters,includeComments:e.includeComments,includeStrings:e.includeStrings,allowedCodePoints:Object.keys(e.allowedCharacters).map(i=>i.codePointAt(0)),allowedLocales:Object.keys(e.allowedLocales).map(i=>i==="_os"?new Intl.NumberFormat().resolvedOptions().locale:i==="_vscode"?vX:i)};this._editorWorkerService.canComputeUnicodeHighlights(this._editor.getModel().uri)?this._highlighter=new KR(this._editor,t,this._updateState,this._editorWorkerService):this._highlighter=new ADe(this._editor,t,this._updateState)}getDecorationInfo(e){return this._highlighter?this._highlighter.getDecorationInfo(e):null}};qm.ID="editor.contrib.unicodeHighlighter";qm=z4([tm(1,oa),tm(2,Ez),tm(3,We)],qm);function RDe(s,e){return{nonBasicASCII:e.nonBasicASCII===Oo?!s:e.nonBasicASCII,ambiguousCharacters:e.ambiguousCharacters,invisibleCharacters:e.invisibleCharacters,includeComments:e.includeComments===Oo?!s:e.includeComments,includeStrings:e.includeStrings===Oo?!s:e.includeStrings,allowedCharacters:e.allowedCharacters,allowedLocales:e.allowedLocales}}let KR=class extends j{constructor(e,t,i,n){super(),this._editor=e,this._options=t,this._updateState=i,this._editorWorkerService=n,this._model=this._editor.getModel(),this._decorations=this._editor.createDecorationsCollection(),this._updateSoon=this._register(new jt(()=>this._update(),250)),this._register(this._editor.onDidChangeModelContent(()=>{this._updateSoon.schedule()})),this._updateSoon.schedule()}dispose(){this._decorations.clear(),super.dispose()}_update(){if(this._model.isDisposed())return;if(!this._model.mightContainNonBasicASCII()){this._decorations.clear();return}const e=this._model.getVersionId();this._editorWorkerService.computedUnicodeHighlights(this._model.uri,this._options).then(t=>{if(this._model.isDisposed()||this._model.getVersionId()!==e)return;this._updateState(t);const i=[];if(!t.hasMore)for(const n of t.ranges)i.push({range:n,options:xL.instance.getDecorationFromOptions(this._options)});this._decorations.set(i)})}getDecorationInfo(e){if(!this._decorations.has(e))return null;const t=this._editor.getModel();if(!$P(t,e))return null;const i=t.getValueInRange(e.range);return{reason:YK(i,this._options),inComment:jP(t,e),inString:KP(t,e)}}};KR=z4([tm(3,oa)],KR);class ADe extends j{constructor(e,t,i){super(),this._editor=e,this._options=t,this._updateState=i,this._model=this._editor.getModel(),this._decorations=this._editor.createDecorationsCollection(),this._updateSoon=this._register(new jt(()=>this._update(),250)),this._register(this._editor.onDidLayoutChange(()=>{this._updateSoon.schedule()})),this._register(this._editor.onDidScrollChange(()=>{this._updateSoon.schedule()})),this._register(this._editor.onDidChangeHiddenAreas(()=>{this._updateSoon.schedule()})),this._register(this._editor.onDidChangeModelContent(()=>{this._updateSoon.schedule()})),this._updateSoon.schedule()}dispose(){this._decorations.clear(),super.dispose()}_update(){if(this._model.isDisposed())return;if(!this._model.mightContainNonBasicASCII()){this._decorations.clear();return}const e=this._editor.getVisibleRanges(),t=[],i={ranges:[],ambiguousCharacterCount:0,invisibleCharacterCount:0,nonBasicAsciiCharacterCount:0,hasMore:!1};for(const n of e){const o=oP.computeUnicodeHighlights(this._model,this._options,n);for(const r of o.ranges)i.ranges.push(r);i.ambiguousCharacterCount+=i.ambiguousCharacterCount,i.invisibleCharacterCount+=i.invisibleCharacterCount,i.nonBasicAsciiCharacterCount+=i.nonBasicAsciiCharacterCount,i.hasMore=i.hasMore||o.hasMore}if(!i.hasMore)for(const n of i.ranges)t.push({range:n,options:xL.instance.getDecorationFromOptions(this._options)});this._updateState(i),this._decorations.set(t)}getDecorationInfo(e){if(!this._decorations.has(e))return null;const t=this._editor.getModel(),i=t.getValueInRange(e.range);return $P(t,e)?{reason:YK(i,this._options),inComment:jP(t,e),inString:KP(t,e)}:null}}let qR=class{constructor(e,t,i){this._editor=e,this._languageService=t,this._openerService=i,this.hoverOrdinal=5}computeSync(e,t){if(!this._editor.hasModel()||e.type!==1)return[];const i=this._editor.getModel(),n=this._editor.getContribution(qm.ID);if(!n)return[];const o=[],r=new Set;let a=300;for(const l of t){const d=n.getDecorationInfo(l);if(!d)continue;const u=i.getValueInRange(l.range).codePointAt(0),h=yE(u);let g;switch(d.reason.kind){case 0:{sC(d.reason.confusableWith)?g=p("unicodeHighlight.characterIsAmbiguousASCII","The character {0} could be confused with the ASCII character {1}, which is more common in source code.",h,yE(d.reason.confusableWith.codePointAt(0))):g=p("unicodeHighlight.characterIsAmbiguous","The character {0} could be confused with the character {1}, which is more common in source code.",h,yE(d.reason.confusableWith.codePointAt(0)));break}case 1:g=p("unicodeHighlight.characterIsInvisible","The character {0} is invisible.",h);break;case 2:g=p("unicodeHighlight.characterIsNonBasicAscii","The character {0} is not a basic ASCII character.",h);break}if(r.has(g))continue;r.add(g);const f={codePoint:u,reason:d.reason,inComment:d.inComment,inString:d.inString},m=p("unicodeHighlight.adjustSettings","Adjust settings"),_=`command:${UC.ID}?${encodeURIComponent(JSON.stringify(f))}`,v=new rs("",!0).appendMarkdown(g).appendText(" ").appendLink(_,m);o.push(new Da(this,l.range,[v],!1,a++))}return o}renderHoverParts(e,t){return Nj(e,t,this._editor,this._languageService,this._openerService)}};qR=z4([tm(1,fi),tm(2,No)],qR);function GR(s){return`U+${s.toString(16).padStart(4,"0")}`}function yE(s){let e=`\`${GR(s)}\``;return Vl.isInvisibleCharacter(s)||(e+=` "${`${PDe(s)}`}"`),e}function PDe(s){return s===96?"`` ` ``":"`"+String.fromCodePoint(s)+"`"}function YK(s,e){return oP.computeUnicodeHighlightReason(s,e)}class xL{constructor(){this.map=new Map}getDecorationFromOptions(e){return this.getDecoration(!e.includeComments,!e.includeStrings)}getDecoration(e,t){const i=`${e}${t}`;let n=this.map.get(i);return n||(n=tt.createDynamic({description:"unicode-highlight",stickiness:1,className:"unicode-highlight",showIfCollapsed:!0,overviewRuler:null,minimap:null,hideInCommentTokens:e,hideInStringTokens:t}),this.map.set(i,n)),n}}xL.instance=new xL;class ODe extends we{constructor(){super({id:ch.ID,label:p("action.unicodeHighlight.disableHighlightingInComments","Disable highlighting of characters in comments"),alias:"Disable highlighting of characters in comments",precondition:void 0}),this.shortLabel=p("unicodeHighlight.disableHighlightingInComments.shortLabel","Disable Highlight In Comments")}async run(e,t,i){const n=e==null?void 0:e.get(mt);n&&this.runAction(n)}async runAction(e){await e.updateValue(qs.includeComments,!1,2)}}class FDe extends we{constructor(){super({id:ch.ID,label:p("action.unicodeHighlight.disableHighlightingInStrings","Disable highlighting of characters in strings"),alias:"Disable highlighting of characters in strings",precondition:void 0}),this.shortLabel=p("unicodeHighlight.disableHighlightingInStrings.shortLabel","Disable Highlight In Strings")}async run(e,t,i){const n=e==null?void 0:e.get(mt);n&&this.runAction(n)}async runAction(e){await e.updateValue(qs.includeStrings,!1,2)}}class ch extends we{constructor(){super({id:ch.ID,label:p("action.unicodeHighlight.disableHighlightingOfAmbiguousCharacters","Disable highlighting of ambiguous characters"),alias:"Disable highlighting of ambiguous characters",precondition:void 0}),this.shortLabel=p("unicodeHighlight.disableHighlightingOfAmbiguousCharacters.shortLabel","Disable Ambiguous Highlight")}async run(e,t,i){const n=e==null?void 0:e.get(mt);n&&this.runAction(n)}async runAction(e){await e.updateValue(qs.ambiguousCharacters,!1,2)}}ch.ID="editor.action.unicodeHighlight.disableHighlightingOfAmbiguousCharacters";class S_ extends we{constructor(){super({id:S_.ID,label:p("action.unicodeHighlight.disableHighlightingOfInvisibleCharacters","Disable highlighting of invisible characters"),alias:"Disable highlighting of invisible characters",precondition:void 0}),this.shortLabel=p("unicodeHighlight.disableHighlightingOfInvisibleCharacters.shortLabel","Disable Invisible Highlight")}async run(e,t,i){const n=e==null?void 0:e.get(mt);n&&this.runAction(n)}async runAction(e){await e.updateValue(qs.invisibleCharacters,!1,2)}}S_.ID="editor.action.unicodeHighlight.disableHighlightingOfInvisibleCharacters";class y_ extends we{constructor(){super({id:y_.ID,label:p("action.unicodeHighlight.disableHighlightingOfNonBasicAsciiCharacters","Disable highlighting of non basic ASCII characters"),alias:"Disable highlighting of non basic ASCII characters",precondition:void 0}),this.shortLabel=p("unicodeHighlight.disableHighlightingOfNonBasicAsciiCharacters.shortLabel","Disable Non ASCII Highlight")}async run(e,t,i){const n=e==null?void 0:e.get(mt);n&&this.runAction(n)}async runAction(e){await e.updateValue(qs.nonBasicASCII,!1,2)}}y_.ID="editor.action.unicodeHighlight.disableHighlightingOfNonBasicAsciiCharacters";class UC extends we{constructor(){super({id:UC.ID,label:p("action.unicodeHighlight.showExcludeOptions","Show Exclude Options"),alias:"Show Exclude Options",precondition:void 0})}async run(e,t,i){const{codePoint:n,reason:o,inString:r,inComment:a}=i,l=String.fromCodePoint(n),d=e.get(Ya),c=e.get(mt);function u(f){return Vl.isInvisibleCharacter(f)?p("unicodeHighlight.excludeInvisibleCharFromBeingHighlighted","Exclude {0} (invisible character) from being highlighted",GR(f)):p("unicodeHighlight.excludeCharFromBeingHighlighted","Exclude {0} from being highlighted",`${GR(f)} "${l}"`)}const h=[];if(o.kind===0)for(const f of o.notAmbiguousInLocales)h.push({label:p("unicodeHighlight.allowCommonCharactersInLanguage",'Allow unicode characters that are more common in the language "{0}".',f),run:async()=>{WDe(c,[f])}});if(h.push({label:u(n),run:()=>BDe(c,[n])}),a){const f=new ODe;h.push({label:f.label,run:async()=>f.runAction(c)})}else if(r){const f=new FDe;h.push({label:f.label,run:async()=>f.runAction(c)})}if(o.kind===0){const f=new ch;h.push({label:f.label,run:async()=>f.runAction(c)})}else if(o.kind===1){const f=new S_;h.push({label:f.label,run:async()=>f.runAction(c)})}else if(o.kind===2){const f=new y_;h.push({label:f.label,run:async()=>f.runAction(c)})}else VDe(o);const g=await d.pick(h,{title:p("unicodeHighlight.configureUnicodeHighlightOptions","Configure Unicode Highlight Options")});g&&await g.run()}}UC.ID="editor.action.unicodeHighlight.showExcludeOptions";async function BDe(s,e){const t=s.getValue(qs.allowedCharacters);let i;typeof t=="object"&&t?i=t:i={};for(const n of e)i[String.fromCodePoint(n)]=!0;await s.updateValue(qs.allowedCharacters,i,2)}async function WDe(s,e){var t;const i=(t=s.inspect(qs.allowedLocales).user)===null||t===void 0?void 0:t.value;let n;typeof i=="object"&&i?n=Object.assign({},i):n={};for(const o of e)n[o]=!0;await s.updateValue(qs.allowedLocales,n,2)}function VDe(s){throw new Error(`Unexpected value: ${s}`)}re(ch);re(S_);re(y_);re(UC);Lt(qm.ID,qm,1);wf.register(qR);var HDe=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},zB=function(s,e){return function(t,i){e(t,i,s)}};const XK="ignoreUnusualLineTerminators";function zDe(s,e,t){s.setModelProperty(e.uri,XK,t)}function UDe(s,e){return s.getModelProperty(e.uri,XK)}let Kb=class extends j{constructor(e,t,i){super(),this._editor=e,this._dialogService=t,this._codeEditorService=i,this._isPresentingDialog=!1,this._config=this._editor.getOption(125),this._register(this._editor.onDidChangeConfiguration(n=>{n.hasChanged(125)&&(this._config=this._editor.getOption(125),this._checkForUnusualLineTerminators())})),this._register(this._editor.onDidChangeModel(()=>{this._checkForUnusualLineTerminators()})),this._register(this._editor.onDidChangeModelContent(n=>{n.isUndoing||this._checkForUnusualLineTerminators()})),this._checkForUnusualLineTerminators()}async _checkForUnusualLineTerminators(){if(this._config==="off"||!this._editor.hasModel())return;const e=this._editor.getModel();if(!e.mightContainUnusualLineTerminators()||UDe(this._codeEditorService,e)===!0||this._editor.getOption(90))return;if(this._config==="auto"){e.removeUnusualLineTerminators(this._editor.getSelections());return}if(this._isPresentingDialog)return;let i;try{this._isPresentingDialog=!0,i=await this._dialogService.confirm({title:p("unusualLineTerminators.title","Unusual Line Terminators"),message:p("unusualLineTerminators.message","Detected unusual line terminators"),detail:p("unusualLineTerminators.detail","The file '{0}' contains one or more unusual line terminator characters, like Line Separator (LS) or Paragraph Separator (PS).\n\nIt is recommended to remove them from the file. This can be configured via `editor.unusualLineTerminators`.",kr(e.uri)),primaryButton:p({key:"unusualLineTerminators.fix",comment:["&& denotes a mnemonic"]},"&&Remove Unusual Line Terminators"),cancelButton:p("unusualLineTerminators.ignore","Ignore")})}finally{this._isPresentingDialog=!1}if(!i.confirmed){zDe(this._codeEditorService,e,!0);return}e.removeUnusualLineTerminators(this._editor.getSelections())}};Kb.ID="editor.contrib.unusualLineTerminatorsDetector";Kb=HDe([zB(1,vC),zB(2,It)],Kb);Lt(Kb.ID,Kb,1);var QK=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},uS=function(s,e){return function(t,i){e(t,i,s)}},qi,ZR;const tk=new me("hasWordHighlights",!1);function JK(s,e,t,i){const n=s.ordered(e);return GA(n.map(o=>()=>Promise.resolve(o.provideDocumentHighlights(e,t,i)).then(void 0,Zi)),as).then(o=>{if(o){const r=new zi;return r.set(e.uri,o),r}return new zi})}function $De(s,e,t,i,n,o){const r=s.ordered(e);return GA(r.map(a=>()=>{const l=o.filter(d=>QP(a.selector,d.uri,d.getLanguageId(),!0,void 0,void 0)>0);return Promise.resolve(a.provideMultiDocumentHighlights(e,t,l,n)).then(void 0,Zi)}),a=>a instanceof zi&&a.size>0)}class U4{constructor(e,t,i){this._model=e,this._selection=t,this._wordSeparators=i,this._wordRange=this._getCurrentWordRange(e,t),this._result=null}get result(){return this._result||(this._result=gn(e=>this._compute(this._model,this._selection,this._wordSeparators,e))),this._result}_getCurrentWordRange(e,t){const i=e.getWordAtPosition(t.getPosition());return i?new D(t.startLineNumber,i.startColumn,t.startLineNumber,i.endColumn):null}isValid(e,t,i){const n=t.startLineNumber,o=t.startColumn,r=t.endColumn,a=this._getCurrentWordRange(e,t);let l=!!(this._wordRange&&this._wordRange.equalsRange(a));for(let d=0,c=i.length;!l&&d<c;d++){const u=i.getRange(d);u&&u.startLineNumber===n&&u.startColumn<=o&&u.endColumn>=r&&(l=!0)}return l}cancel(){this.result.cancel()}}class jDe extends U4{constructor(e,t,i,n){super(e,t,i),this._providers=n}_compute(e,t,i,n){return JK(this._providers,e,t.getPosition(),n).then(o=>o||new zi)}}class KDe extends U4{constructor(e,t,i,n,o){super(e,t,i),this._providers=n,this._otherModels=o}_compute(e,t,i,n){return $De(this._providers,e,t.getPosition(),i,n,this._otherModels).then(o=>o||new zi)}}class eq extends U4{constructor(e,t,i,n,o){super(e,t,n),this._otherModels=o,this._selectionIsEmpty=t.isEmpty(),this._word=i}_compute(e,t,i,n){return Iu(250,n).then(()=>{const o=new zi;let r;if(this._word?r=this._word:r=e.getWordAtPosition(t.getPosition()),!r)return new zi;const a=[e,...this._otherModels];for(const l of a){if(l.isDisposed())continue;const c=l.findMatches(r.word,!0,!1,!0,i,!1).map(u=>({range:u.range,kind:L0.Text}));c&&o.set(l.uri,c)}return o})}isValid(e,t,i){const n=t.isEmpty();return this._selectionIsEmpty!==n?!1:super.isValid(e,t,i)}}function qDe(s,e,t,i,n){return s.has(e)?new jDe(e,t,n,s):new eq(e,t,i,n,[])}function GDe(s,e,t,i,n,o){return s.has(e)?new KDe(e,t,n,s,o):new eq(e,t,i,n,o)}od("_executeDocumentHighlights",async(s,e,t)=>{const i=s.get(xe),n=await JK(i.documentHighlightProvider,e,t,ct.None);return n==null?void 0:n.get(e.uri)});let qb=qi=class{constructor(e,t,i,n,o){this.toUnhook=new ie,this.workerRequestTokenId=0,this.workerRequestCompleted=!1,this.workerRequestValue=new zi,this.lastCursorPositionChangeTime=0,this.renderDecorationsTimer=-1,this.editor=e,this.providers=t,this.multiDocumentProviders=i,this.codeEditorService=o,this._hasWordHighlights=tk.bindTo(n),this._ignorePositionChangeEvent=!1,this.occurrencesHighlight=this.editor.getOption(80),this.model=this.editor.getModel(),this.toUnhook.add(e.onDidChangeCursorPosition(r=>{this._ignorePositionChangeEvent||this.occurrencesHighlight!=="off"&&this._onPositionChanged(r)})),this.toUnhook.add(e.onDidChangeModelContent(r=>{this._stopAll()})),this.toUnhook.add(e.onDidChangeModel(r=>{!r.newModelUrl&&r.oldModelUrl?this._stopSingular():qi.query&&this._run()})),this.toUnhook.add(e.onDidChangeConfiguration(r=>{const a=this.editor.getOption(80);this.occurrencesHighlight!==a&&(this.occurrencesHighlight=a,this._stopAll())})),this.decorations=this.editor.createDecorationsCollection(),this.workerRequestTokenId=0,this.workerRequest=null,this.workerRequestCompleted=!1,this.lastCursorPositionChangeTime=0,this.renderDecorationsTimer=-1,qi.query&&this._run()}hasDecorations(){return this.decorations.length>0}restore(){this.occurrencesHighlight!=="off"&&this._run()}_getSortedHighlights(){return this.decorations.getRanges().sort(D.compareRangesUsingStarts)}moveNext(){const e=this._getSortedHighlights(),i=(e.findIndex(o=>o.containsPosition(this.editor.getPosition()))+1)%e.length,n=e[i];try{this._ignorePositionChangeEvent=!0,this.editor.setPosition(n.getStartPosition()),this.editor.revealRangeInCenterIfOutsideViewport(n);const o=this._getWord();if(o){const r=this.editor.getModel().getLineContent(n.startLineNumber);Lo(`${r}, ${i+1} of ${e.length} for '${o.word}'`)}}finally{this._ignorePositionChangeEvent=!1}}moveBack(){const e=this._getSortedHighlights(),i=(e.findIndex(o=>o.containsPosition(this.editor.getPosition()))-1+e.length)%e.length,n=e[i];try{this._ignorePositionChangeEvent=!0,this.editor.setPosition(n.getStartPosition()),this.editor.revealRangeInCenterIfOutsideViewport(n);const o=this._getWord();if(o){const r=this.editor.getModel().getLineContent(n.startLineNumber);Lo(`${r}, ${i+1} of ${e.length} for '${o.word}'`)}}finally{this._ignorePositionChangeEvent=!1}}_removeSingleDecorations(){if(!this.editor.hasModel())return;const e=qi.storedDecorations.get(this.editor.getModel().uri);e&&(this.editor.removeDecorations(e),qi.storedDecorations.delete(this.editor.getModel().uri),this.decorations.length>0&&(this.decorations.clear(),this._hasWordHighlights.set(!1)))}_removeAllDecorations(){const e=this.codeEditorService.listCodeEditors();for(const t of e){if(!t.hasModel())continue;const i=qi.storedDecorations.get(t.getModel().uri);if(!i)continue;t.removeDecorations(i),qi.storedDecorations.delete(t.getModel().uri);const n=nc.get(t);n!=null&&n.wordHighlighter&&n.wordHighlighter.decorations.length>0&&(n.wordHighlighter.decorations.clear(),n.wordHighlighter._hasWordHighlights.set(!1))}}_stopSingular(){var e,t,i,n;this._removeSingleDecorations(),this.editor.hasWidgetFocus()&&(((e=this.editor.getModel())===null||e===void 0?void 0:e.uri.scheme)!==it.vscodeNotebookCell&&((i=(t=qi.query)===null||t===void 0?void 0:t.modelInfo)===null||i===void 0?void 0:i.model.uri.scheme)!==it.vscodeNotebookCell?(qi.query=null,this._run()):!((n=qi.query)===null||n===void 0)&&n.modelInfo&&(qi.query.modelInfo=null)),this.renderDecorationsTimer!==-1&&(clearTimeout(this.renderDecorationsTimer),this.renderDecorationsTimer=-1),this.workerRequest!==null&&(this.workerRequest.cancel(),this.workerRequest=null),this.workerRequestCompleted||(this.workerRequestTokenId++,this.workerRequestCompleted=!0)}_stopAll(){this._removeAllDecorations(),this.renderDecorationsTimer!==-1&&(clearTimeout(this.renderDecorationsTimer),this.renderDecorationsTimer=-1),this.workerRequest!==null&&(this.workerRequest.cancel(),this.workerRequest=null),this.workerRequestCompleted||(this.workerRequestTokenId++,this.workerRequestCompleted=!0)}_onPositionChanged(e){var t;if(this.occurrencesHighlight==="off"){this._stopAll();return}if(e.reason!==3&&((t=this.editor.getModel())===null||t===void 0?void 0:t.uri.scheme)!==it.vscodeNotebookCell){this._stopAll();return}this._run()}_getWord(){const e=this.editor.getSelection(),t=e.startLineNumber,i=e.startColumn;return this.model.isDisposed()?null:this.model.getWordAtPosition({lineNumber:t,column:i})}getOtherModelsToHighlight(e){if(!e)return[];if(e.uri.scheme===it.vscodeNotebookCell){const o=[],r=this.codeEditorService.listCodeEditors();for(const a of r){const l=a.getModel();l&&l!==e&&l.uri.scheme===it.vscodeNotebookCell&&o.push(l)}return o}const i=[],n=this.codeEditorService.listCodeEditors();for(const o of n){if(!ZO(o))continue;const r=o.getModel();r&&e===r.modified&&i.push(r.modified)}if(i.length)return i;if(this.occurrencesHighlight==="singleFile")return[];for(const o of n){const r=o.getModel();r&&r!==e&&i.push(r)}return i}_run(){var e,t;let i;if(this.editor.hasWidgetFocus()){const n=this.editor.getSelection();if(!n||n.startLineNumber!==n.endLineNumber){this._stopAll();return}const o=n.startColumn,r=n.endColumn,a=this._getWord();if(!a||a.startColumn>o||a.endColumn<r){qi.query=null,this._stopAll();return}i=this.workerRequest&&this.workerRequest.isValid(this.model,n,this.decorations),qi.query={modelInfo:{model:this.model,selection:n},word:a}}else if(qi.query===null)return;if(this.lastCursorPositionChangeTime=new Date().getTime(),i)this.workerRequestCompleted&&this.renderDecorationsTimer!==-1&&(clearTimeout(this.renderDecorationsTimer),this.renderDecorationsTimer=-1,this._beginRenderDecorations());else{this._stopAll();const n=++this.workerRequestTokenId;this.workerRequestCompleted=!1;const o=this.getOtherModelsToHighlight(this.editor.getModel()),r=!!(!qi.query.modelInfo&&qi.query.word||((e=qi.query.modelInfo)===null||e===void 0?void 0:e.model.uri)!==this.model.uri);!qi.query.modelInfo||qi.query.modelInfo.model.uri!==this.model.uri?this.workerRequest=this.computeWithModel(this.model,this.editor.getSelection(),r?qi.query.word:null,o):this.workerRequest=this.computeWithModel(qi.query.modelInfo.model,qi.query.modelInfo.selection,qi.query.word,o),(t=this.workerRequest)===null||t===void 0||t.result.then(a=>{n===this.workerRequestTokenId&&(this.workerRequestCompleted=!0,this.workerRequestValue=a||[],this._beginRenderDecorations())},et)}}computeWithModel(e,t,i,n){return n.length?GDe(this.multiDocumentProviders,e,t,i,this.editor.getOption(129),n):qDe(this.providers,e,t,i,this.editor.getOption(129))}_beginRenderDecorations(){const e=new Date().getTime(),t=this.lastCursorPositionChangeTime+250;e>=t?(this.renderDecorationsTimer=-1,this.renderDecorations()):this.renderDecorationsTimer=setTimeout(()=>{this.renderDecorations()},t-e)}renderDecorations(){var e,t,i;this.renderDecorationsTimer=-1;const n=this.codeEditorService.listCodeEditors();for(const o of n){const r=nc.get(o);if(!r)continue;const a=[],l=(e=o.getModel())===null||e===void 0?void 0:e.uri;if(l&&this.workerRequestValue.has(l)){const d=qi.storedDecorations.get(l),c=this.workerRequestValue.get(l);if(c)for(const h of c)a.push({range:h.range,options:Lxe(h.kind)});let u=[];o.changeDecorations(h=>{u=h.deltaDecorations(d??[],a)}),qi.storedDecorations=qi.storedDecorations.set(l,u),a.length>0&&((t=r.wordHighlighter)===null||t===void 0||t.decorations.set(a),(i=r.wordHighlighter)===null||i===void 0||i._hasWordHighlights.set(!0))}}}dispose(){this._stopSingular(),this.toUnhook.dispose()}};qb.storedDecorations=new zi;qb.query=null;qb=qi=QK([uS(4,It)],qb);let nc=ZR=class extends j{static get(e){return e.getContribution(ZR.ID)}constructor(e,t,i,n){super(),this._wordHighlighter=null;const o=()=>{e.hasModel()&&!e.getModel().isTooLargeForTokenization()&&(this._wordHighlighter=new qb(e,i.documentHighlightProvider,i.multiDocumentHighlightProvider,t,n))};this._register(e.onDidChangeModel(r=>{this._wordHighlighter&&(this._wordHighlighter.dispose(),this._wordHighlighter=null),o()})),o()}get wordHighlighter(){return this._wordHighlighter}saveViewState(){return!!(this._wordHighlighter&&this._wordHighlighter.hasDecorations())}moveNext(){var e;(e=this._wordHighlighter)===null||e===void 0||e.moveNext()}moveBack(){var e;(e=this._wordHighlighter)===null||e===void 0||e.moveBack()}restoreViewState(e){this._wordHighlighter&&e&&this._wordHighlighter.restore()}dispose(){this._wordHighlighter&&(this._wordHighlighter.dispose(),this._wordHighlighter=null),super.dispose()}};nc.ID="editor.contrib.wordHighlighter";nc=ZR=QK([uS(1,je),uS(2,xe),uS(3,It)],nc);class tq extends we{constructor(e,t){super(t),this._isNext=e}run(e,t){const i=nc.get(t);i&&(this._isNext?i.moveNext():i.moveBack())}}class ZDe extends tq{constructor(){super(!0,{id:"editor.action.wordHighlight.next",label:p("wordHighlight.next.label","Go to Next Symbol Highlight"),alias:"Go to Next Symbol Highlight",precondition:tk,kbOpts:{kbExpr:T.editorTextFocus,primary:65,weight:100}})}}class YDe extends tq{constructor(){super(!1,{id:"editor.action.wordHighlight.prev",label:p("wordHighlight.previous.label","Go to Previous Symbol Highlight"),alias:"Go to Previous Symbol Highlight",precondition:tk,kbOpts:{kbExpr:T.editorTextFocus,primary:1089,weight:100}})}}class XDe extends we{constructor(){super({id:"editor.action.wordHighlight.trigger",label:p("wordHighlight.trigger.label","Trigger Symbol Highlight"),alias:"Trigger Symbol Highlight",precondition:tk.toNegated(),kbOpts:{kbExpr:T.editorTextFocus,primary:0,weight:100}})}run(e,t,i){const n=nc.get(t);n&&n.restoreViewState(!0)}}Lt(nc.ID,nc,0);re(ZDe);re(YDe);re(XDe);class ik extends Nn{constructor(e){super(e),this._inSelectionMode=e.inSelectionMode,this._wordNavigationType=e.wordNavigationType}runEditorCommand(e,t,i){if(!t.hasModel())return;const n=xr(t.getOption(129)),o=t.getModel(),a=t.getSelections().map(l=>{const d=new H(l.positionLineNumber,l.positionColumn),c=this._move(n,o,d,this._wordNavigationType);return this._moveTo(l,c,this._inSelectionMode)});if(o.pushStackElement(),t._getViewModel().setCursorStates("moveWordCommand",3,a.map(l=>yt.fromModelSelection(l))),a.length===1){const l=new H(a[0].positionLineNumber,a[0].positionColumn);t.revealPosition(l,0)}}_moveTo(e,t,i){return i?new De(e.selectionStartLineNumber,e.selectionStartColumn,t.lineNumber,t.column):new De(t.lineNumber,t.column,t.lineNumber,t.column)}}class uh extends ik{_move(e,t,i,n){return Nt.moveWordLeft(e,t,i,n)}}class hh extends ik{_move(e,t,i,n){return Nt.moveWordRight(e,t,i,n)}}class QDe extends uh{constructor(){super({inSelectionMode:!1,wordNavigationType:0,id:"cursorWordStartLeft",precondition:void 0})}}class JDe extends uh{constructor(){super({inSelectionMode:!1,wordNavigationType:2,id:"cursorWordEndLeft",precondition:void 0})}}class eke extends uh{constructor(){var e;super({inSelectionMode:!1,wordNavigationType:1,id:"cursorWordLeft",precondition:void 0,kbOpts:{kbExpr:ee.and(T.textInputFocus,(e=ee.and(dC,jx))===null||e===void 0?void 0:e.negate()),primary:2063,mac:{primary:527},weight:100}})}}class tke extends uh{constructor(){super({inSelectionMode:!0,wordNavigationType:0,id:"cursorWordStartLeftSelect",precondition:void 0})}}class ike extends uh{constructor(){super({inSelectionMode:!0,wordNavigationType:2,id:"cursorWordEndLeftSelect",precondition:void 0})}}class nke extends uh{constructor(){var e;super({inSelectionMode:!0,wordNavigationType:1,id:"cursorWordLeftSelect",precondition:void 0,kbOpts:{kbExpr:ee.and(T.textInputFocus,(e=ee.and(dC,jx))===null||e===void 0?void 0:e.negate()),primary:3087,mac:{primary:1551},weight:100}})}}class ske extends uh{constructor(){super({inSelectionMode:!1,wordNavigationType:3,id:"cursorWordAccessibilityLeft",precondition:void 0})}_move(e,t,i,n){return super._move(xr(ja.wordSeparators.defaultValue),t,i,n)}}class oke extends uh{constructor(){super({inSelectionMode:!0,wordNavigationType:3,id:"cursorWordAccessibilityLeftSelect",precondition:void 0})}_move(e,t,i,n){return super._move(xr(ja.wordSeparators.defaultValue),t,i,n)}}class rke extends hh{constructor(){super({inSelectionMode:!1,wordNavigationType:0,id:"cursorWordStartRight",precondition:void 0})}}class ake extends hh{constructor(){var e;super({inSelectionMode:!1,wordNavigationType:2,id:"cursorWordEndRight",precondition:void 0,kbOpts:{kbExpr:ee.and(T.textInputFocus,(e=ee.and(dC,jx))===null||e===void 0?void 0:e.negate()),primary:2065,mac:{primary:529},weight:100}})}}class lke extends hh{constructor(){super({inSelectionMode:!1,wordNavigationType:2,id:"cursorWordRight",precondition:void 0})}}class dke extends hh{constructor(){super({inSelectionMode:!0,wordNavigationType:0,id:"cursorWordStartRightSelect",precondition:void 0})}}class cke extends hh{constructor(){var e;super({inSelectionMode:!0,wordNavigationType:2,id:"cursorWordEndRightSelect",precondition:void 0,kbOpts:{kbExpr:ee.and(T.textInputFocus,(e=ee.and(dC,jx))===null||e===void 0?void 0:e.negate()),primary:3089,mac:{primary:1553},weight:100}})}}class uke extends hh{constructor(){super({inSelectionMode:!0,wordNavigationType:2,id:"cursorWordRightSelect",precondition:void 0})}}class hke extends hh{constructor(){super({inSelectionMode:!1,wordNavigationType:3,id:"cursorWordAccessibilityRight",precondition:void 0})}_move(e,t,i,n){return super._move(xr(ja.wordSeparators.defaultValue),t,i,n)}}class gke extends hh{constructor(){super({inSelectionMode:!0,wordNavigationType:3,id:"cursorWordAccessibilityRightSelect",precondition:void 0})}_move(e,t,i,n){return super._move(xr(ja.wordSeparators.defaultValue),t,i,n)}}class nk extends Nn{constructor(e){super(e),this._whitespaceHeuristics=e.whitespaceHeuristics,this._wordNavigationType=e.wordNavigationType}runEditorCommand(e,t,i){const n=e.get(Jt);if(!t.hasModel())return;const o=xr(t.getOption(129)),r=t.getModel(),a=t.getSelections(),l=t.getOption(6),d=t.getOption(11),c=n.getLanguageConfiguration(r.getLanguageId()).getAutoClosingPairs(),u=t._getViewModel(),h=a.map(g=>{const f=this._delete({wordSeparators:o,model:r,selection:g,whitespaceHeuristics:this._whitespaceHeuristics,autoClosingDelete:t.getOption(9),autoClosingBrackets:l,autoClosingQuotes:d,autoClosingPairs:c,autoClosedCharacters:u.getCursorAutoClosedCharacters()},this._wordNavigationType);return new Kn(f,"")});t.pushUndoStop(),t.executeCommands(this.id,h),t.pushUndoStop()}}class $4 extends nk{_delete(e,t){const i=Nt.deleteWordLeft(e,t);return i||new D(1,1,1,1)}}class j4 extends nk{_delete(e,t){const i=Nt.deleteWordRight(e,t);if(i)return i;const n=e.model.getLineCount(),o=e.model.getLineMaxColumn(n);return new D(n,o,n,o)}}class fke extends $4{constructor(){super({whitespaceHeuristics:!1,wordNavigationType:0,id:"deleteWordStartLeft",precondition:T.writable})}}class pke extends $4{constructor(){super({whitespaceHeuristics:!1,wordNavigationType:2,id:"deleteWordEndLeft",precondition:T.writable})}}class mke extends $4{constructor(){super({whitespaceHeuristics:!0,wordNavigationType:0,id:"deleteWordLeft",precondition:T.writable,kbOpts:{kbExpr:T.textInputFocus,primary:2049,mac:{primary:513},weight:100}})}}class _ke extends j4{constructor(){super({whitespaceHeuristics:!1,wordNavigationType:0,id:"deleteWordStartRight",precondition:T.writable})}}class vke extends j4{constructor(){super({whitespaceHeuristics:!1,wordNavigationType:2,id:"deleteWordEndRight",precondition:T.writable})}}class bke extends j4{constructor(){super({whitespaceHeuristics:!0,wordNavigationType:2,id:"deleteWordRight",precondition:T.writable,kbOpts:{kbExpr:T.textInputFocus,primary:2068,mac:{primary:532},weight:100}})}}class Cke extends we{constructor(){super({id:"deleteInsideWord",precondition:T.writable,label:p("deleteInsideWord","Delete Word"),alias:"Delete Word"})}run(e,t,i){if(!t.hasModel())return;const n=xr(t.getOption(129)),o=t.getModel(),a=t.getSelections().map(l=>{const d=Nt.deleteInsideWord(n,o,l);return new Kn(d,"")});t.pushUndoStop(),t.executeCommands(this.id,a),t.pushUndoStop()}}ue(new QDe);ue(new JDe);ue(new eke);ue(new tke);ue(new ike);ue(new nke);ue(new rke);ue(new ake);ue(new lke);ue(new dke);ue(new cke);ue(new uke);ue(new ske);ue(new oke);ue(new hke);ue(new gke);ue(new fke);ue(new pke);ue(new mke);ue(new _ke);ue(new vke);ue(new bke);re(Cke);class wke extends nk{constructor(){super({whitespaceHeuristics:!0,wordNavigationType:0,id:"deleteWordPartLeft",precondition:T.writable,kbOpts:{kbExpr:T.textInputFocus,primary:0,mac:{primary:769},weight:100}})}_delete(e,t){const i=Dx.deleteWordPartLeft(e);return i||new D(1,1,1,1)}}class Ske extends nk{constructor(){super({whitespaceHeuristics:!0,wordNavigationType:2,id:"deleteWordPartRight",precondition:T.writable,kbOpts:{kbExpr:T.textInputFocus,primary:0,mac:{primary:788},weight:100}})}_delete(e,t){const i=Dx.deleteWordPartRight(e);if(i)return i;const n=e.model.getLineCount(),o=e.model.getLineMaxColumn(n);return new D(n,o,n,o)}}class iq extends ik{_move(e,t,i,n){return Dx.moveWordPartLeft(e,t,i)}}class yke extends iq{constructor(){super({inSelectionMode:!1,wordNavigationType:0,id:"cursorWordPartLeft",precondition:void 0,kbOpts:{kbExpr:T.textInputFocus,primary:0,mac:{primary:783},weight:100}})}}Ct.registerCommandAlias("cursorWordPartStartLeft","cursorWordPartLeft");class Lke extends iq{constructor(){super({inSelectionMode:!0,wordNavigationType:0,id:"cursorWordPartLeftSelect",precondition:void 0,kbOpts:{kbExpr:T.textInputFocus,primary:0,mac:{primary:1807},weight:100}})}}Ct.registerCommandAlias("cursorWordPartStartLeftSelect","cursorWordPartLeftSelect");class nq extends ik{_move(e,t,i,n){return Dx.moveWordPartRight(e,t,i)}}class xke extends nq{constructor(){super({inSelectionMode:!1,wordNavigationType:2,id:"cursorWordPartRight",precondition:void 0,kbOpts:{kbExpr:T.textInputFocus,primary:0,mac:{primary:785},weight:100}})}}class Dke extends nq{constructor(){super({inSelectionMode:!0,wordNavigationType:2,id:"cursorWordPartRightSelect",precondition:void 0,kbOpts:{kbExpr:T.textInputFocus,primary:0,mac:{primary:1809},weight:100}})}}ue(new wke);ue(new Ske);ue(new yke);ue(new Lke);ue(new xke);ue(new Dke);class YR extends j{constructor(e){super(),this.editor=e,this._register(this.editor.onDidAttemptReadOnlyEdit(()=>this._onDidAttemptReadOnlyEdit()))}_onDidAttemptReadOnlyEdit(){const e=Co.get(this.editor);if(e&&this.editor.hasModel()){let t=this.editor.getOptions().get(91);t||(this.editor.isSimpleWidget?t=new rs(p("editor.simple.readonly","Cannot edit in read-only input")):t=new rs(p("editor.readonly","Cannot edit in read-only editor"))),e.showMessage(t,this.editor.getPosition())}}}YR.ID="editor.contrib.readOnlyMessageController";Lt(YR.ID,YR,2);class XR extends j{constructor(e){super(),this.editor=e,this.widget=null,Wa&&(this._register(e.onDidChangeConfiguration(()=>this.update())),this.update())}update(){const e=!this.editor.getOption(90);!this.widget&&e?this.widget=new sk(this.editor):this.widget&&!e&&(this.widget.dispose(),this.widget=null)}dispose(){super.dispose(),this.widget&&(this.widget.dispose(),this.widget=null)}}XR.ID="editor.contrib.iPadShowKeyboard";class sk extends j{constructor(e){super(),this.editor=e,this._domNode=document.createElement("textarea"),this._domNode.className="iPadShowKeyboard",this._register(Y(this._domNode,"touchstart",t=>{this.editor.focus()})),this._register(Y(this._domNode,"focus",t=>{this.editor.focus()})),this.editor.addOverlayWidget(this)}dispose(){this.editor.removeOverlayWidget(this),super.dispose()}getId(){return sk.ID}getDomNode(){return this._domNode}getPosition(){return{preference:1}}}sk.ID="editor.contrib.ShowKeyboardWidget";Lt(XR.ID,XR,3);var kke=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},UB=function(s,e){return function(t,i){e(t,i,s)}},QR;let Gm=QR=class extends j{static get(e){return e.getContribution(QR.ID)}constructor(e,t,i){super(),this._editor=e,this._languageService=i,this._widget=null,this._register(this._editor.onDidChangeModel(n=>this.stop())),this._register(this._editor.onDidChangeModelLanguage(n=>this.stop())),this._register(xi.onDidChange(n=>this.stop())),this._register(this._editor.onKeyUp(n=>n.keyCode===9&&this.stop()))}dispose(){this.stop(),super.dispose()}launch(){this._widget||this._editor.hasModel()&&(this._widget=new ok(this._editor,this._languageService))}stop(){this._widget&&(this._widget.dispose(),this._widget=null)}};Gm.ID="editor.contrib.inspectTokens";Gm=QR=kke([UB(1,lr),UB(2,fi)],Gm);class Ike extends we{constructor(){super({id:"editor.action.inspectTokens",label:YT.inspectTokensAction,alias:"Developer: Inspect Tokens",precondition:void 0})}run(e,t){const i=Gm.get(t);i==null||i.launch()}}function Eke(s){let e="";for(let t=0,i=s.length;t<i;t++){const n=s.charCodeAt(t);switch(n){case 9:e+="→";break;case 32:e+="·";break;default:e+=String.fromCharCode(n)}}return e}function Nke(s,e){const t=xi.get(e);if(t)return t;const i=s.encodeLanguageId(e);return{getInitialState:()=>pm,tokenize:(n,o,r)=>hP(e,r),tokenizeEncoded:(n,o,r)=>_x(i,r)}}class ok extends j{constructor(e,t){super(),this.allowEditorOverflow=!0,this._editor=e,this._languageService=t,this._model=this._editor.getModel(),this._domNode=document.createElement("div"),this._domNode.className="tokens-inspect-widget",this._tokenizationSupport=Nke(this._languageService.languageIdCodec,this._model.getLanguageId()),this._compute(this._editor.getPosition()),this._register(this._editor.onDidChangeCursorPosition(i=>this._compute(this._editor.getPosition()))),this._editor.addContentWidget(this)}dispose(){this._editor.removeContentWidget(this),super.dispose()}getId(){return ok._ID}_compute(e){const t=this._getTokensAtLine(e.lineNumber);let i=0;for(let l=t.tokens1.length-1;l>=0;l--){const d=t.tokens1[l];if(e.column-1>=d.offset){i=l;break}}let n=0;for(let l=t.tokens2.length>>>1;l>=0;l--)if(e.column-1>=t.tokens2[l<<1]){n=l;break}const o=this._model.getLineContent(e.lineNumber);let r="";if(i<t.tokens1.length){const l=t.tokens1[i].offset,d=i+1<t.tokens1.length?t.tokens1[i+1].offset:o.length;r=o.substring(l,d)}Qn(this._domNode,se("h2.tm-token",void 0,Eke(r),se("span.tm-token-length",void 0,`${r.length} ${r.length===1?"char":"chars"}`))),te(this._domNode,se("hr.tokens-inspect-separator",{style:"clear:both"}));const a=(n<<1)+1<t.tokens2.length?this._decodeMetadata(t.tokens2[(n<<1)+1]):null;te(this._domNode,se("table.tm-metadata-table",void 0,se("tbody",void 0,se("tr",void 0,se("td.tm-metadata-key",void 0,"language"),se("td.tm-metadata-value",void 0,`${a?a.languageId:"-?-"}`)),se("tr",void 0,se("td.tm-metadata-key",void 0,"token type"),se("td.tm-metadata-value",void 0,`${a?this._tokenTypeToString(a.tokenType):"-?-"}`)),se("tr",void 0,se("td.tm-metadata-key",void 0,"font style"),se("td.tm-metadata-value",void 0,`${a?this._fontStyleToString(a.fontStyle):"-?-"}`)),se("tr",void 0,se("td.tm-metadata-key",void 0,"foreground"),se("td.tm-metadata-value",void 0,`${a?G.Format.CSS.formatHex(a.foreground):"-?-"}`)),se("tr",void 0,se("td.tm-metadata-key",void 0,"background"),se("td.tm-metadata-value",void 0,`${a?G.Format.CSS.formatHex(a.background):"-?-"}`))))),te(this._domNode,se("hr.tokens-inspect-separator")),i<t.tokens1.length&&te(this._domNode,se("span.tm-token-type",void 0,t.tokens1[i].type)),this._editor.layoutContentWidget(this)}_decodeMetadata(e){const t=xi.getColorMap(),i=Zn.getLanguageId(e),n=Zn.getTokenType(e),o=Zn.getFontStyle(e),r=Zn.getForeground(e),a=Zn.getBackground(e);return{languageId:this._languageService.languageIdCodec.decodeLanguageId(i),tokenType:n,fontStyle:o,foreground:t[r],background:t[a]}}_tokenTypeToString(e){switch(e){case 0:return"Other";case 1:return"Comment";case 2:return"String";case 3:return"RegEx";default:return"??"}}_fontStyleToString(e){let t="";return e&1&&(t+="italic "),e&2&&(t+="bold "),e&4&&(t+="underline "),e&8&&(t+="strikethrough "),t.length===0&&(t="---"),t}_getTokensAtLine(e){const t=this._getStateBeforeLine(e),i=this._tokenizationSupport.tokenize(this._model.getLineContent(e),!0,t),n=this._tokenizationSupport.tokenizeEncoded(this._model.getLineContent(e),!0,t);return{startState:t,tokens1:i.tokens,tokens2:n.tokens,endState:i.endState}}_getStateBeforeLine(e){let t=this._tokenizationSupport.getInitialState();for(let i=1;i<e;i++)t=this._tokenizationSupport.tokenize(this._model.getLineContent(i),!0,t).endState;return t}getDomNode(){return this._domNode}getPosition(){return{position:this._editor.getPosition(),preference:[2,1]}}}ok._ID="editor.contrib.inspectTokensWidget";Lt(Gm.ID,Gm,4);re(Ike);var Tke=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},$B=function(s,e){return function(t,i){e(t,i,s)}},Dv;let DL=Dv=class{constructor(e,t){this.quickInputService=e,this.keybindingService=t,this.registry=Si.as(pf.Quickaccess)}provide(e){const t=new ie;return t.add(e.onDidAccept(()=>{const[i]=e.selectedItems;i&&this.quickInputService.quickAccess.show(i.prefix,{preserveValue:!0})})),t.add(e.onDidChangeValue(i=>{const n=this.registry.getQuickAccessProvider(i.substr(Dv.PREFIX.length));n&&n.prefix&&n.prefix!==Dv.PREFIX&&this.quickInputService.quickAccess.show(n.prefix,{preserveValue:!0})})),e.items=this.getQuickAccessProviders().filter(i=>i.prefix!==Dv.PREFIX),t}getQuickAccessProviders(){return this.registry.getQuickAccessProviders().sort((t,i)=>t.prefix.localeCompare(i.prefix)).flatMap(t=>this.createPicks(t))}createPicks(e){return e.helpEntries.map(t=>{const i=t.prefix||e.prefix,n=i||"…";return{prefix:i,label:n,keybinding:t.commandId?this.keybindingService.lookupKeybinding(t.commandId):void 0,ariaLabel:p("helpPickAriaLabel","{0}, {1}",n,t.description),description:t.description}})}};DL.PREFIX="?";DL=Dv=Tke([$B(0,Ya),$B(1,qt)],DL);Si.as(pf.Quickaccess).registerQuickAccessProvider({ctor:DL,prefix:"",helpEntries:[{description:XT.helpQuickAccessActionLabel}]});class sq{constructor(e){this.options=e,this.rangeHighlightDecorationId=void 0}provide(e,t){var i;const n=new ie;e.canAcceptInBackground=!!(!((i=this.options)===null||i===void 0)&&i.canAcceptInBackground),e.matchOnLabel=e.matchOnDescription=e.matchOnDetail=e.sortByLabel=!1;const o=n.add(new En);return o.value=this.doProvide(e,t),n.add(this.onDidActiveTextEditorControlChange(()=>{o.value=void 0,o.value=this.doProvide(e,t)})),n}doProvide(e,t){var i;const n=new ie,o=this.activeTextEditorControl;if(o&&this.canProvideWithTextEditor(o)){const r={editor:o},a=t$(o);if(a){let l=(i=o.saveViewState())!==null&&i!==void 0?i:void 0;n.add(a.onDidChangeCursorPosition(()=>{var d;l=(d=o.saveViewState())!==null&&d!==void 0?d:void 0})),r.restoreViewState=()=>{l&&o===this.activeTextEditorControl&&o.restoreViewState(l)},n.add(Du(t.onCancellationRequested)(()=>{var d;return(d=r.restoreViewState)===null||d===void 0?void 0:d.call(r)}))}n.add(Fe(()=>this.clearDecorations(o))),n.add(this.provideWithTextEditor(r,e,t))}else n.add(this.provideWithoutTextEditor(e,t));return n}canProvideWithTextEditor(e){return!0}gotoLocation({editor:e},t){e.setSelection(t.range),e.revealRangeInCenter(t.range,0),t.preserveFocus||e.focus();const i=e.getModel();i&&"getLineContent"in i&&Au(`${i.getLineContent(t.range.startLineNumber)}`)}getModel(e){var t;return ZO(e)?(t=e.getModel())===null||t===void 0?void 0:t.modified:e.getModel()}addDecorations(e,t){e.changeDecorations(i=>{const n=[];this.rangeHighlightDecorationId&&(n.push(this.rangeHighlightDecorationId.overviewRulerDecorationId),n.push(this.rangeHighlightDecorationId.rangeHighlightId),this.rangeHighlightDecorationId=void 0);const o=[{range:t,options:{description:"quick-access-range-highlight",className:"rangeHighlight",isWholeLine:!0}},{range:t,options:{description:"quick-access-range-highlight-overview",overviewRuler:{color:Di(xH),position:nr.Full}}}],[r,a]=i.deltaDecorations(n,o);this.rangeHighlightDecorationId={rangeHighlightId:r,overviewRulerDecorationId:a}})}clearDecorations(e){const t=this.rangeHighlightDecorationId;t&&(e.changeDecorations(i=>{i.deltaDecorations([t.overviewRulerDecorationId,t.rangeHighlightId],[])}),this.rangeHighlightDecorationId=void 0)}}class rk extends sq{constructor(){super({canAcceptInBackground:!0})}provideWithoutTextEditor(e){const t=p("cannotRunGotoLine","Open a text editor first to go to a line.");return e.items=[{label:t}],e.ariaLabel=t,j.None}provideWithTextEditor(e,t,i){const n=e.editor,o=new ie;o.add(t.onDidAccept(l=>{const[d]=t.selectedItems;if(d){if(!this.isValidLineNumber(n,d.lineNumber))return;this.gotoLocation(e,{range:this.toRange(d.lineNumber,d.column),keyMods:t.keyMods,preserveFocus:l.inBackground}),l.inBackground||t.hide()}}));const r=()=>{const l=this.parsePosition(n,t.value.trim().substr(rk.PREFIX.length)),d=this.getPickLabel(n,l.lineNumber,l.column);if(t.items=[{lineNumber:l.lineNumber,column:l.column,label:d}],t.ariaLabel=d,!this.isValidLineNumber(n,l.lineNumber)){this.clearDecorations(n);return}const c=this.toRange(l.lineNumber,l.column);n.revealRangeInCenter(c,0),this.addDecorations(n,c)};r(),o.add(t.onDidChangeValue(()=>r()));const a=t$(n);return a&&a.getOptions().get(67).renderType===2&&(a.updateOptions({lineNumbers:"on"}),o.add(Fe(()=>a.updateOptions({lineNumbers:"relative"})))),o}toRange(e=1,t=1){return{startLineNumber:e,startColumn:t,endLineNumber:e,endColumn:t}}parsePosition(e,t){const i=t.split(/,|:|#/).map(o=>parseInt(o,10)).filter(o=>!isNaN(o)),n=this.lineCount(e)+1;return{lineNumber:i[0]>0?i[0]:n+i[0],column:i[1]}}getPickLabel(e,t,i){if(this.isValidLineNumber(e,t))return this.isValidColumn(e,t,i)?p("gotoLineColumnLabel","Go to line {0} and character {1}.",t,i):p("gotoLineLabel","Go to line {0}.",t);const n=e.getPosition()||{lineNumber:1,column:1},o=this.lineCount(e);return o>1?p("gotoLineLabelEmptyWithLimit","Current Line: {0}, Character: {1}. Type a line number between 1 and {2} to navigate to.",n.lineNumber,n.column,o):p("gotoLineLabelEmpty","Current Line: {0}, Character: {1}. Type a line number to navigate to.",n.lineNumber,n.column)}isValidLineNumber(e,t){return!t||typeof t!="number"?!1:t>0&&t<=this.lineCount(e)}isValidColumn(e,t,i){if(!i||typeof i!="number")return!1;const n=this.getModel(e);if(!n)return!1;const o={lineNumber:t,column:i};return n.validatePosition(o).equals(o)}lineCount(e){var t,i;return(i=(t=this.getModel(e))===null||t===void 0?void 0:t.getLineCount())!==null&&i!==void 0?i:0}}rk.PREFIX=":";var Mke=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Rke=function(s,e){return function(t,i){e(t,i,s)}};let Gb=class extends rk{constructor(e){super(),this.editorService=e,this.onDidActiveTextEditorControlChange=ge.None}get activeTextEditorControl(){var e;return(e=this.editorService.getFocusedCodeEditor())!==null&&e!==void 0?e:void 0}};Gb=Mke([Rke(0,It)],Gb);let K4=class oq extends we{constructor(){super({id:oq.ID,label:vy.gotoLineActionLabel,alias:"Go to Line/Column...",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:2085,mac:{primary:293},weight:100}})}run(e){e.get(Ya).quickAccess.show(Gb.PREFIX)}};K4.ID="editor.action.gotoLine";re(K4);Si.as(pf.Quickaccess).registerQuickAccessProvider({ctor:Gb,prefix:Gb.PREFIX,helpEntries:[{description:vy.gotoLineActionLabel,commandId:K4.ID}]});const rq=[void 0,[]];function LE(s,e,t=0,i=0){const n=e;return n.values&&n.values.length>1?Ake(s,n.values,t,i):aq(s,e,t,i)}function Ake(s,e,t,i){let n=0;const o=[];for(const r of e){const[a,l]=aq(s,r,t,i);if(typeof a!="number")return rq;n+=a,o.push(...l)}return[n,Pke(o)]}function aq(s,e,t,i){const n=Pg(e.original,e.originalLowercase,t,s,s.toLowerCase(),i,{firstMatchCanBeWeak:!0,boostFullMatch:!0});return n?[n[0],CC(n)]:rq}function Pke(s){const e=s.sort((n,o)=>n.start-o.start),t=[];let i;for(const n of e)!i||!Oke(i,n)?(i=n,t.push(n)):(i.start=Math.min(i.start,n.start),i.end=Math.max(i.end,n.end));return t}function Oke(s,e){return!(s.end<e.start||e.end<s.start)}function jB(s){return s.startsWith('"')&&s.endsWith('"')}const lq=" ";function JR(s){typeof s!="string"&&(s="");const e=s.toLowerCase(),{pathNormalized:t,normalized:i,normalizedLowercase:n}=KB(s),o=t.indexOf(Aa)>=0,r=jB(s);let a;const l=s.split(lq);if(l.length>1)for(const d of l){const c=jB(d),{pathNormalized:u,normalized:h,normalizedLowercase:g}=KB(d);h&&(a||(a=[]),a.push({original:d,originalLowercase:d.toLowerCase(),pathNormalized:u,normalized:h,normalizedLowercase:g,expectContiguousMatch:c}))}return{original:s,originalLowercase:e,pathNormalized:t,normalized:i,normalizedLowercase:n,values:a,containsPathSeparator:o,expectContiguousMatch:r}}function KB(s){let e;es?e=s.replace(/\//g,Aa):e=s.replace(/\\/g,Aa);const t=nJ(e).replace(/\s|"/g,"");return{pathNormalized:e,normalized:t,normalizedLowercase:t.toLowerCase()}}function qB(s){return Array.isArray(s)?JR(s.map(e=>e.original).join(lq)):JR(s.original)}var Fke=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},GB=function(s,e){return function(t,i){e(t,i,s)}},im;let Ul=im=class extends sq{constructor(e,t,i=Object.create(null)){super(i),this._languageFeaturesService=e,this._outlineModelService=t,this.options=i,this.options.canAcceptInBackground=!0}provideWithoutTextEditor(e){return this.provideLabelPick(e,p("cannotRunGotoSymbolWithoutEditor","To go to a symbol, first open a text editor with symbol information.")),j.None}provideWithTextEditor(e,t,i){const n=e.editor,o=this.getModel(n);return o?this._languageFeaturesService.documentSymbolProvider.has(o)?this.doProvideWithEditorSymbols(e,o,t,i):this.doProvideWithoutEditorSymbols(e,o,t,i):j.None}doProvideWithoutEditorSymbols(e,t,i,n){const o=new ie;return this.provideLabelPick(i,p("cannotRunGotoSymbolWithoutSymbolProvider","The active text editor does not provide symbol information.")),(async()=>!await this.waitForLanguageSymbolRegistry(t,o)||n.isCancellationRequested||o.add(this.doProvideWithEditorSymbols(e,t,i,n)))(),o}provideLabelPick(e,t){e.items=[{label:t,index:0,kind:14}],e.ariaLabel=t}async waitForLanguageSymbolRegistry(e,t){if(this._languageFeaturesService.documentSymbolProvider.has(e))return!0;const i=new ox,n=t.add(this._languageFeaturesService.documentSymbolProvider.onDidChange(()=>{this._languageFeaturesService.documentSymbolProvider.has(e)&&(n.dispose(),i.complete(!0))}));return t.add(Fe(()=>i.complete(!1))),i.p}doProvideWithEditorSymbols(e,t,i,n){var o;const r=e.editor,a=new ie;a.add(i.onDidAccept(u=>{const[h]=i.selectedItems;h&&h.range&&(this.gotoLocation(e,{range:h.range.selection,keyMods:i.keyMods,preserveFocus:u.inBackground}),u.inBackground||i.hide())})),a.add(i.onDidTriggerItemButton(({item:u})=>{u&&u.range&&(this.gotoLocation(e,{range:u.range.selection,keyMods:i.keyMods,forceSideBySide:!0}),i.hide())}));const l=this.getDocumentSymbols(t,n);let d;const c=async u=>{d==null||d.dispose(!0),i.busy=!1,d=new Yi(n),i.busy=!0;try{const h=JR(i.value.substr(im.PREFIX.length).trim()),g=await this.doGetSymbolPicks(l,h,void 0,d.token);if(n.isCancellationRequested)return;if(g.length>0){if(i.items=g,u&&h.original.length===0){const f=R0(g,m=>!!(m.type!=="separator"&&m.range&&D.containsPosition(m.range.decoration,u)));f&&(i.activeItems=[f])}}else h.original.length>0?this.provideLabelPick(i,p("noMatchingSymbolResults","No matching editor symbols")):this.provideLabelPick(i,p("noSymbolResults","No editor symbols"))}finally{n.isCancellationRequested||(i.busy=!1)}};return a.add(i.onDidChangeValue(()=>c(void 0))),c((o=r.getSelection())===null||o===void 0?void 0:o.getPosition()),a.add(i.onDidChangeActive(()=>{const[u]=i.activeItems;u&&u.range&&(r.revealRangeInCenter(u.range.selection,0),this.addDecorations(r,u.range.decoration))})),a}async doGetSymbolPicks(e,t,i,n){var o,r;const a=await e;if(n.isCancellationRequested)return[];const l=t.original.indexOf(im.SCOPE_PREFIX)===0,d=l?1:0;let c,u;t.values&&t.values.length>1?(c=qB(t.values[0]),u=qB(t.values.slice(1))):c=t;let h;const g=(r=(o=this.options)===null||o===void 0?void 0:o.openSideBySideDirection)===null||r===void 0?void 0:r.call(o);g&&(h=[{iconClass:g==="right"?Oe.asClassName(le.splitHorizontal):Oe.asClassName(le.splitVertical),tooltip:g==="right"?p("openToSide","Open to the Side"):p("openToBottom","Open to the Bottom")}]);const f=[];for(let v=0;v<a.length;v++){const b=a[v],C=tJ(b.name),w=`$(${NS.toIcon(b.kind).id}) ${C}`,S=w.length-C.length;let x=b.containerName;i!=null&&i.extraContainerLabel&&(x?x=`${i.extraContainerLabel} • ${x}`:x=i.extraContainerLabel);let L,k,I,P;if(t.original.length>d){let A=!1;if(c!==t&&([L,k]=LE(w,{...t,values:void 0},d,S),typeof L=="number"&&(A=!0)),typeof L!="number"&&([L,k]=LE(w,c,d,S),typeof L!="number"))continue;if(!A&&u){if(x&&u.original.length>0&&([I,P]=LE(x,u)),typeof I!="number")continue;typeof L=="number"&&(L+=I)}}const $=b.tags&&b.tags.indexOf(1)>=0;f.push({index:v,kind:b.kind,score:L,label:w,ariaLabel:YQ(b.name,b.kind),description:x,highlights:$?void 0:{label:k,description:P},range:{selection:D.collapseToStart(b.selectionRange),decoration:b.range},strikethrough:$,buttons:h})}const m=f.sort((v,b)=>l?this.compareByKindAndScore(v,b):this.compareByScore(v,b));let _=[];if(l){let w=function(){b&&typeof v=="number"&&C>0&&(b.label=xg(DE[v]||xE,C))},v,b,C=0;for(const S of m)v!==S.kind?(w(),v=S.kind,C=1,b={type:"separator"},_.push(b)):C++,_.push(S);w()}else m.length>0&&(_=[{label:p("symbols","symbols ({0})",f.length),type:"separator"},...m]);return _}compareByScore(e,t){if(typeof e.score!="number"&&typeof t.score=="number")return 1;if(typeof e.score=="number"&&typeof t.score!="number")return-1;if(typeof e.score=="number"&&typeof t.score=="number"){if(e.score>t.score)return-1;if(e.score<t.score)return 1}return e.index<t.index?-1:e.index>t.index?1:0}compareByKindAndScore(e,t){const i=DE[e.kind]||xE,n=DE[t.kind]||xE,o=i.localeCompare(n);return o===0?this.compareByScore(e,t):o}async getDocumentSymbols(e,t){const i=await this._outlineModelService.getOrCreate(e,t);return t.isCancellationRequested?[]:i.asListOfDocumentSymbols()}};Ul.PREFIX="@";Ul.SCOPE_PREFIX=":";Ul.PREFIX_BY_CATEGORY=`${im.PREFIX}${im.SCOPE_PREFIX}`;Ul=im=Fke([GB(0,xe),GB(1,RD)],Ul);const xE=p("property","properties ({0})"),DE={5:p("method","methods ({0})"),11:p("function","functions ({0})"),8:p("_constructor","constructors ({0})"),12:p("variable","variables ({0})"),4:p("class","classes ({0})"),22:p("struct","structs ({0})"),23:p("event","events ({0})"),24:p("operator","operators ({0})"),10:p("interface","interfaces ({0})"),2:p("namespace","namespaces ({0})"),3:p("package","packages ({0})"),25:p("typeParameter","type parameters ({0})"),1:p("modules","modules ({0})"),6:p("property","properties ({0})"),9:p("enum","enumerations ({0})"),21:p("enumMember","enumeration members ({0})"),14:p("string","strings ({0})"),0:p("file","files ({0})"),17:p("array","arrays ({0})"),15:p("number","numbers ({0})"),16:p("boolean","booleans ({0})"),18:p("object","objects ({0})"),19:p("key","keys ({0})"),7:p("field","fields ({0})"),13:p("constant","constants ({0})")};var Bke=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},kE=function(s,e){return function(t,i){e(t,i,s)}};let eA=class extends Ul{constructor(e,t,i){super(t,i),this.editorService=e,this.onDidActiveTextEditorControlChange=ge.None}get activeTextEditorControl(){var e;return(e=this.editorService.getFocusedCodeEditor())!==null&&e!==void 0?e:void 0}};eA=Bke([kE(0,It),kE(1,xe),kE(2,RD)],eA);class $C extends we{constructor(){super({id:$C.ID,label:sb.quickOutlineActionLabel,alias:"Go to Symbol...",precondition:T.hasDocumentSymbolProvider,kbOpts:{kbExpr:T.focus,primary:3117,weight:100},contextMenuOpts:{group:"navigation",order:3}})}run(e){e.get(Ya).quickAccess.show(Ul.PREFIX,{itemActivation:ma.NONE})}}$C.ID="editor.action.quickOutline";re($C);Si.as(pf.Quickaccess).registerQuickAccessProvider({ctor:eA,prefix:Ul.PREFIX,helpEntries:[{description:sb.quickOutlineActionLabel,prefix:Ul.PREFIX,commandId:$C.ID},{description:sb.quickOutlineByCategoryActionLabel,prefix:Ul.PREFIX_BY_CATEGORY}]});function IE(s,e){return e&&(s.stack||s.stacktrace)?p("stackTrace.format","{0}: {1}",YB(s),ZB(s.stack)||ZB(s.stacktrace)):YB(s)}function ZB(s){return Array.isArray(s)?s.join(`
`):s}function YB(s){return s.code==="ERR_UNC_HOST_NOT_ALLOWED"?`${s.message}. Please update the 'security.allowedUNCHosts' setting if you want to allow this host.`:typeof s.code=="string"&&typeof s.errno=="number"&&typeof s.syscall=="string"?p("nodeExceptionMessage","A system error occurred ({0})",s.message):s.message||p("error.defaultMessage","An unknown error occurred. Please consult the log for more details.")}function dq(s=null,e=!1){if(!s)return p("error.defaultMessage","An unknown error occurred. Please consult the log for more details.");if(Array.isArray(s)){const t=Ba(s),i=dq(t[0],e);return t.length>1?p("error.moreErrors","{0} ({1} errors in total)",i,t.length):i}if(Ps(s))return s;if(s.detail){const t=s.detail;if(t.error)return IE(t.error,e);if(t.exception)return IE(t.exception,e)}return s.stack?IE(s,e):s.message?s.message:p("error.defaultMessage","An unknown error occurred. Please consult the log for more details.")}function Wke(s){var e;const t=new Map;for(const i of s)t.set(i,((e=t.get(i))!==null&&e!==void 0?e:0)+1);return t}class d0{constructor(){this.chunkCount=0,this.chunkOccurrences=new Map,this.documents=new Map}calculateScores(e,t){const i=this.computeEmbedding(e),n=new Map,o=[];for(const[r,a]of this.documents){if(t.isCancellationRequested)return[];for(const l of a.chunks){const d=this.computeSimilarityScore(l,i,n);d>0&&o.push({key:r,score:d})}}return o}static termFrequencies(e){return Wke(d0.splitTerms(e))}static*splitTerms(e){const t=i=>i.toLowerCase();for(const[i]of e.matchAll(new RegExp("\\b\\p{Letter}[\\p{Letter}\\d]{2,}\\b","gu"))){yield t(i);const n=i.replace(/([a-z])([A-Z])/g,"$1 $2").split(/\s+/g);if(n.length>1)for(const o of n)o.length>2&&new RegExp("\\p{Letter}{3,}","gu").test(o)&&(yield t(o))}}updateDocuments(e){var t;for(const{key:i}of e)this.deleteDocument(i);for(const i of e){const n=[];for(const o of i.textChunks){const r=d0.termFrequencies(o);for(const a of r.keys())this.chunkOccurrences.set(a,((t=this.chunkOccurrences.get(a))!==null&&t!==void 0?t:0)+1);n.push({text:o,tf:r})}this.chunkCount+=n.length,this.documents.set(i.key,{chunks:n})}return this}deleteDocument(e){const t=this.documents.get(e);if(t){this.documents.delete(e),this.chunkCount-=t.chunks.length;for(const i of t.chunks)for(const n of i.tf.keys()){const o=this.chunkOccurrences.get(n);if(typeof o=="number"){const r=o-1;r<=0?this.chunkOccurrences.delete(n):this.chunkOccurrences.set(n,r)}}}}computeSimilarityScore(e,t,i){let n=0;for(const[o,r]of Object.entries(t)){const a=e.tf.get(o);if(!a)continue;let l=i.get(o);typeof l!="number"&&(l=this.computeIdf(o),i.set(o,l));const d=a*l;n+=d*r}return n}computeEmbedding(e){const t=d0.termFrequencies(e);return this.computeTfidf(t)}computeIdf(e){var t;const i=(t=this.chunkOccurrences.get(e))!==null&&t!==void 0?t:0;return i>0?Math.log((this.chunkCount+1)/i):0}computeTfidf(e){const t=Object.create(null);for(const[i,n]of e){const o=this.computeIdf(i);o>0&&(t[i]=n*o)}return t}}function Vke(s){var e,t;const i=s.slice(0);i.sort((o,r)=>r.score-o.score);const n=(t=(e=i[0])===null||e===void 0?void 0:e.score)!==null&&t!==void 0?t:0;if(n>0)for(const o of i)o.score/=n;return i}var Dp;(function(s){s[s.NO_ACTION=0]="NO_ACTION",s[s.CLOSE_PICKER=1]="CLOSE_PICKER",s[s.REFRESH_PICKER=2]="REFRESH_PICKER",s[s.REMOVE_ITEM=3]="REMOVE_ITEM"})(Dp||(Dp={}));function EE(s){const e=s;return Array.isArray(e.items)}function XB(s){const e=s;return!!e.picks&&e.additionalPicks instanceof Promise}class Hke extends j{constructor(e,t){super(),this.prefix=e,this.options=t}provide(e,t,i){var n;const o=new ie;e.canAcceptInBackground=!!(!((n=this.options)===null||n===void 0)&&n.canAcceptInBackground),e.matchOnLabel=e.matchOnDescription=e.matchOnDetail=e.sortByLabel=!1;let r;const a=o.add(new En),l=async()=>{const d=a.value=new ie;r==null||r.dispose(!0),e.busy=!1,r=new Yi(t);const c=r.token,u=e.value.substr(this.prefix.length).trim(),h=this._getPicks(u,d,c,i),g=(m,_)=>{var v;let b,C;if(EE(m)?(b=m.items,C=m.active):b=m,b.length===0){if(_)return!1;(u.length>0||e.hideInput)&&(!((v=this.options)===null||v===void 0)&&v.noResultsPick)&&(C0(this.options.noResultsPick)?b=[this.options.noResultsPick(u)]:b=[this.options.noResultsPick])}return e.items=b,C&&(e.activeItems=[C]),!0},f=async m=>{let _=!1,v=!1;await Promise.all([(async()=>{typeof m.mergeDelay=="number"&&(await Iu(m.mergeDelay),c.isCancellationRequested)||v||(_=g(m.picks,!0))})(),(async()=>{e.busy=!0;try{const b=await m.additionalPicks;if(c.isCancellationRequested)return;let C,w;EE(m.picks)?(C=m.picks.items,w=m.picks.active):C=m.picks;let S,x;if(EE(b)?(S=b.items,x=b.active):S=b,S.length>0||!_){let L;if(!w&&!x){const k=e.activeItems[0];k&&C.indexOf(k)!==-1&&(L=k)}g({items:[...C,...S],active:w||x||L})}}finally{c.isCancellationRequested||(e.busy=!1),v=!0}})()])};if(h!==null)if(XB(h))await f(h);else if(!(h instanceof Promise))g(h);else{e.busy=!0;try{const m=await h;if(c.isCancellationRequested)return;XB(m)?await f(m):g(m)}finally{c.isCancellationRequested||(e.busy=!1)}}};return o.add(e.onDidChangeValue(()=>l())),l(),o.add(e.onDidAccept(d=>{const[c]=e.selectedItems;typeof(c==null?void 0:c.accept)=="function"&&(d.inBackground||e.hide(),c.accept(e.keyMods,d))})),o.add(e.onDidTriggerItemButton(async({button:d,item:c})=>{var u,h;if(typeof c.trigger=="function"){const g=(h=(u=c.buttons)===null||u===void 0?void 0:u.indexOf(d))!==null&&h!==void 0?h:-1;if(g>=0){const f=c.trigger(g,e.keyMods),m=typeof f=="number"?f:await f;if(t.isCancellationRequested)return;switch(m){case Dp.NO_ACTION:break;case Dp.CLOSE_PICKER:e.hide();break;case Dp.REFRESH_PICKER:l();break;case Dp.REMOVE_ITEM:{const _=e.items.indexOf(c);if(_!==-1){const v=e.items.slice(),b=v.splice(_,1),C=e.activeItems.filter(S=>S!==b[0]),w=e.keepScrollPosition;e.keepScrollPosition=!0,e.items=v,C&&(e.activeItems=C),e.keepScrollPosition=w}break}}}}})),o}}var cq=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Yh=function(s,e){return function(t,i){e(t,i,s)}},Bh,sn;let nf=Bh=class extends Hke{constructor(e,t,i,n,o,r){super(Bh.PREFIX,e),this.instantiationService=t,this.keybindingService=i,this.commandService=n,this.telemetryService=o,this.dialogService=r,this.commandsHistory=this._register(this.instantiationService.createInstance(Qu)),this.options=e}async _getPicks(e,t,i,n){var o,r,a,l;const d=await this.getCommandPicks(i);if(i.isCancellationRequested)return[];const c=Du(()=>{const v=new d0;v.updateDocuments(d.map(C=>({key:C.commandId,textChunks:[this.getTfIdfChunk(C)]})));const b=v.calculateScores(e,i);return Vke(b).filter(C=>C.score>Bh.TFIDF_THRESHOLD).slice(0,Bh.TFIDF_MAX_RESULTS)}),u=[];for(const v of d){const b=(o=Bh.WORD_FILTER(e,v.label))!==null&&o!==void 0?o:void 0,C=v.commandAlias&&(r=Bh.WORD_FILTER(e,v.commandAlias))!==null&&r!==void 0?r:void 0;if(b||C)v.highlights={label:b,detail:this.options.showAlias?C:void 0},u.push(v);else if(e===v.commandId)u.push(v);else if(e.length>=3){const w=c();if(i.isCancellationRequested)return[];const S=w.find(x=>x.key===v.commandId);S&&(v.tfIdfScore=S.score,u.push(v))}}const h=new Map;for(const v of u){const b=h.get(v.label);b?(v.description=v.commandId,b.description=b.commandId):h.set(v.label,v)}u.sort((v,b)=>{if(v.tfIdfScore&&b.tfIdfScore)return v.tfIdfScore===b.tfIdfScore?v.label.localeCompare(b.label):b.tfIdfScore-v.tfIdfScore;if(v.tfIdfScore)return 1;if(b.tfIdfScore)return-1;const C=this.commandsHistory.peek(v.commandId),w=this.commandsHistory.peek(b.commandId);if(C&&w)return C>w?-1:1;if(C)return-1;if(w)return 1;if(this.options.suggestedCommandIds){const S=this.options.suggestedCommandIds.has(v.commandId),x=this.options.suggestedCommandIds.has(b.commandId);if(S&&x)return 0;if(S)return-1;if(x)return 1}return v.label.localeCompare(b.label)});const g=[];let f=!1,m=!0,_=!!this.options.suggestedCommandIds;for(let v=0;v<u.length;v++){const b=u[v];v===0&&this.commandsHistory.peek(b.commandId)&&(g.push({type:"separator",label:p("recentlyUsed","recently used")}),f=!0),m&&b.tfIdfScore!==void 0&&(g.push({type:"separator",label:p("suggested","similar commands")}),m=!1),_&&b.tfIdfScore===void 0&&!this.commandsHistory.peek(b.commandId)&&(!((a=this.options.suggestedCommandIds)===null||a===void 0)&&a.has(b.commandId))&&(g.push({type:"separator",label:p("commonlyUsed","commonly used")}),f=!0,_=!1),f&&b.tfIdfScore===void 0&&!this.commandsHistory.peek(b.commandId)&&!(!((l=this.options.suggestedCommandIds)===null||l===void 0)&&l.has(b.commandId))&&(g.push({type:"separator",label:p("morecCommands","other commands")}),f=!1),g.push(this.toCommandPick(b,n))}return this.hasAdditionalCommandPicks(e,i)?{picks:g,additionalPicks:(async()=>{var v;const b=await this.getAdditionalCommandPicks(d,u,e,i);if(i.isCancellationRequested)return[];const C=b.map(w=>this.toCommandPick(w,n));return m&&((v=C[0])===null||v===void 0?void 0:v.type)!=="separator"&&C.unshift({type:"separator",label:p("suggested","similar commands")}),C})()}:g}toCommandPick(e,t){if(e.type==="separator")return e;const i=this.keybindingService.lookupKeybinding(e.commandId),n=i?p("commandPickAriaLabelWithKeybinding","{0}, {1}",e.label,i.getAriaLabel()):e.label;return{...e,ariaLabel:n,detail:this.options.showAlias&&e.commandAlias!==e.label?e.commandAlias:void 0,keybinding:i,accept:async()=>{var o,r;this.commandsHistory.push(e.commandId),this.telemetryService.publicLog2("workbenchActionExecuted",{id:e.commandId,from:(o=t==null?void 0:t.from)!==null&&o!==void 0?o:"quick open"});try{!((r=e.args)===null||r===void 0)&&r.length?await this.commandService.executeCommand(e.commandId,...e.args):await this.commandService.executeCommand(e.commandId)}catch(a){Ka(a)||this.dialogService.error(p("canNotRun","Command '{0}' resulted in an error",e.label),dq(a))}}}}getTfIdfChunk({label:e,commandAlias:t,commandDescription:i}){let n=e;return t&&t!==e&&(n+=` - ${t}`),i&&i.value!==e&&(n+=` - ${i.value===i.original?i.value:`${i.value} (${i.original})`}`),n}};nf.PREFIX=">";nf.TFIDF_THRESHOLD=.5;nf.TFIDF_MAX_RESULTS=5;nf.WORD_FILTER=iO(lb,che,Mz);nf=Bh=cq([Yh(1,We),Yh(2,qt),Yh(3,Ei),Yh(4,Do),Yh(5,vC)],nf);let Qu=sn=class extends j{constructor(e,t){super(),this.storageService=e,this.configurationService=t,this.configuredCommandsHistoryLength=0,this.updateConfiguration(),this.load(),this.registerListeners()}registerListeners(){this._register(this.configurationService.onDidChangeConfiguration(e=>this.updateConfiguration(e))),this._register(this.storageService.onWillSaveState(e=>{e.reason===db.SHUTDOWN&&this.saveState()}))}updateConfiguration(e){e&&!e.affectsConfiguration("workbench.commandPalette.history")||(this.configuredCommandsHistoryLength=sn.getConfiguredCommandHistoryLength(this.configurationService),sn.cache&&sn.cache.limit!==this.configuredCommandsHistoryLength&&(sn.cache.limit=this.configuredCommandsHistoryLength,sn.hasChanges=!0))}load(){const e=this.storageService.get(sn.PREF_KEY_CACHE,0);let t;if(e)try{t=JSON.parse(e)}catch{}const i=sn.cache=new nh(this.configuredCommandsHistoryLength,1);if(t){let n;t.usesLRU?n=t.entries:n=t.entries.sort((o,r)=>o.value-r.value),n.forEach(o=>i.set(o.key,o.value))}sn.counter=this.storageService.getNumber(sn.PREF_KEY_COUNTER,0,sn.counter)}push(e){sn.cache&&(sn.cache.set(e,sn.counter++),sn.hasChanges=!0)}peek(e){var t;return(t=sn.cache)===null||t===void 0?void 0:t.peek(e)}saveState(){if(!sn.cache||!sn.hasChanges)return;const e={usesLRU:!0,entries:[]};sn.cache.forEach((t,i)=>e.entries.push({key:i,value:t})),this.storageService.store(sn.PREF_KEY_CACHE,JSON.stringify(e),0,0),this.storageService.store(sn.PREF_KEY_COUNTER,sn.counter,0,0),sn.hasChanges=!1}static getConfiguredCommandHistoryLength(e){var t,i;const o=(i=(t=e.getValue().workbench)===null||t===void 0?void 0:t.commandPalette)===null||i===void 0?void 0:i.history;return typeof o=="number"?o:sn.DEFAULT_COMMANDS_HISTORY_LENGTH}};Qu.DEFAULT_COMMANDS_HISTORY_LENGTH=50;Qu.PREF_KEY_CACHE="commandPalette.mru.cache";Qu.PREF_KEY_COUNTER="commandPalette.mru.counter";Qu.counter=1;Qu.hasChanges=!1;Qu=sn=cq([Yh(0,sa),Yh(1,mt)],Qu);class zke extends nf{constructor(e,t,i,n,o,r){super(e,t,i,n,o,r)}getCodeEditorCommandPicks(){const e=this.activeTextEditorControl;if(!e)return[];const t=[];for(const i of e.getSupportedActions())t.push({commandId:i.id,commandAlias:i.alias,label:lO(i.label)||i.id});return t}}var Uke=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},zf=function(s,e){return function(t,i){e(t,i,s)}};let Zb=class extends zke{get activeTextEditorControl(){var e;return(e=this.codeEditorService.getFocusedCodeEditor())!==null&&e!==void 0?e:void 0}constructor(e,t,i,n,o,r){super({showAlias:!1},e,i,n,o,r),this.codeEditorService=t}async getCommandPicks(){return this.getCodeEditorCommandPicks()}hasAdditionalCommandPicks(){return!1}async getAdditionalCommandPicks(){return[]}};Zb=Uke([zf(0,We),zf(1,It),zf(2,qt),zf(3,Ei),zf(4,Do),zf(5,vC)],Zb);class jC extends we{constructor(){super({id:jC.ID,label:by.quickCommandActionLabel,alias:"Command Palette",precondition:void 0,kbOpts:{kbExpr:T.focus,primary:59,weight:100},contextMenuOpts:{group:"z_commands",order:1}})}run(e){e.get(Ya).quickAccess.show(Zb.PREFIX)}}jC.ID="editor.action.quickCommand";re(jC);Si.as(pf.Quickaccess).registerQuickAccessProvider({ctor:Zb,prefix:Zb.PREFIX,helpEntries:[{description:by.quickCommandHelp,commandId:jC.ID}]});var $ke=function(s,e,t,i){var n=arguments.length,o=n<3?e:i===null?i=Object.getOwnPropertyDescriptor(e,t):i,r;if(typeof Reflect=="object"&&typeof Reflect.decorate=="function")o=Reflect.decorate(s,e,t,i);else for(var a=s.length-1;a>=0;a--)(r=s[a])&&(o=(n<3?r(o):n>3?r(e,t,o):r(e,t))||o);return n>3&&o&&Object.defineProperty(e,t,o),o},Uf=function(s,e){return function(t,i){e(t,i,s)}};let tA=class extends Ku{constructor(e,t,i,n,o,r,a){super(!0,e,t,i,n,o,r,a)}};tA=$ke([Uf(1,je),Uf(2,It),Uf(3,Qi),Uf(4,We),Uf(5,sa),Uf(6,mt)],tA);Lt(Ku.ID,tA,4);class jke extends we{constructor(){super({id:"editor.action.toggleHighContrast",label:QT.toggleHighContrast,alias:"Toggle High Contrast Theme",precondition:void 0}),this._originalThemeName=null}run(e,t){const i=e.get(lr),n=i.getColorTheme();Oa(n.type)?(i.setTheme(this._originalThemeName||(bm(n.type)?Qp:Rd)),this._originalThemeName=null):(i.setTheme(bm(n.type)?bg:Cg),this._originalThemeName=n.themeName)}}re(jke);const uq=Object.freeze(Object.defineProperty({__proto__:null,CancellationTokenSource:o$,Emitter:r$,KeyCode:a$,KeyMod:l$,MarkerSeverity:g$,MarkerTag:f$,Position:d$,Range:c$,Selection:u$,SelectionDirection:h$,Token:m$,Uri:p$,editor:_$,languages:v$},Symbol.toStringTag,{value:"Module"}));function Kke(s){return new Worker("/assets/editor.worker-weymZOpQ.js",{name:s==null?void 0:s.name})}function qke(s){return new Worker("/assets/json.worker-c6IXuO26.js",{name:s==null?void 0:s.name})}function Gke(s){return new Worker("/assets/css.worker-_3MqMzan.js",{name:s==null?void 0:s.name})}function Zke(s){return new Worker("/assets/html.worker-qTNNCz_y.js",{name:s==null?void 0:s.name})}function Yke(s){return new Worker("/assets/ts.worker-COXDPV9x.js",{name:s==null?void 0:s.name})}self.MonacoEnvironment={getWorker(s,e){return e==="json"?new qke:e==="css"||e==="scss"||e==="less"?new Gke:e==="html"||e==="handlebars"||e==="razor"?new Zke:e==="typescript"||e==="javascript"?new Yke:new Kke}};gS.config({monaco:uq});var Xke=!1;/*!
 * pinia v2.1.7
 * (c) 2023 Eduardo San Martin Morote
 * @license MIT
 */let hq;const ak=s=>hq=s,gq=Symbol();function iA(s){return s&&typeof s=="object"&&Object.prototype.toString.call(s)==="[object Object]"&&typeof s.toJSON!="function"}var c0;(function(s){s.direct="direct",s.patchObject="patch object",s.patchFunction="patch function"})(c0||(c0={}));function Qke(){const s=h6(!0),e=s.run(()=>_o({}));let t=[],i=[];const n=PL({install(o){ak(n),n._a=o,o.provide(gq,n),o.config.globalProperties.$pinia=n,i.forEach(r=>t.push(r)),i=[]},use(o){return!this._a&&!Xke?i.push(o):t.push(o),this},_p:t,_a:null,_e:s,_s:new Map,state:e});return n}const fq=()=>{};function QB(s,e,t,i=fq){s.push(e);const n=()=>{const o=s.indexOf(e);o>-1&&(s.splice(o,1),i())};return!t&&g6()&&wG(n),n}function $f(s,...e){s.slice().forEach(t=>{t(...e)})}const Jke=s=>s();function nA(s,e){s instanceof Map&&e instanceof Map&&e.forEach((t,i)=>s.set(i,t)),s instanceof Set&&e instanceof Set&&e.forEach(s.add,s);for(const t in e){if(!e.hasOwnProperty(t))continue;const i=e[t],n=s[t];iA(n)&&iA(i)&&s.hasOwnProperty(t)&&!ds(i)&&!nu(i)?s[t]=nA(n,i):s[t]=i}return s}const eIe=Symbol();function tIe(s){return!iA(s)||!s.hasOwnProperty(eIe)}const{assign:Ic}=Object;function iIe(s){return!!(ds(s)&&s.effect)}function nIe(s,e,t,i){const{state:n,actions:o,getters:r}=e,a=t.state.value[s];let l;function d(){a||(t.state.value[s]=n?n():{});const c=KG(t.state.value[s]);return Ic(c,o,Object.keys(r||{}).reduce((u,h)=>(u[h]=PL(An(()=>{ak(t);const g=t._s.get(s);return r[h].call(g,g)})),u),{}))}return l=pq(s,d,e,t,i,!0),l}function pq(s,e,t={},i,n,o){let r;const a=Ic({actions:{}},t),l={deep:!0};let d,c,u=[],h=[],g;const f=i.state.value[s];!o&&!f&&(i.state.value[s]={}),_o({});let m;function _(k){let I;d=c=!1,typeof k=="function"?(k(i.state.value[s]),I={type:c0.patchFunction,storeId:s,events:g}):(nA(i.state.value[s],k),I={type:c0.patchObject,payload:k,storeId:s,events:g});const P=m=Symbol();Xb().then(()=>{m===P&&(d=!0)}),c=!0,$f(u,I,i.state.value[s])}const v=o?function(){const{state:I}=t,P=I?I():{};this.$patch($=>{Ic($,P)})}:fq;function b(){r.stop(),u=[],h=[],i._s.delete(s)}function C(k,I){return function(){ak(i);const P=Array.from(arguments),$=[],A=[];function z(ne){$.push(ne)}function K(ne){A.push(ne)}$f(h,{args:P,name:k,store:S,after:z,onError:K});let Q;try{Q=I.apply(this&&this.$id===s?this:S,P)}catch(ne){throw $f(A,ne),ne}return Q instanceof Promise?Q.then(ne=>($f($,ne),ne)).catch(ne=>($f(A,ne),Promise.reject(ne))):($f($,Q),Q)}}const w={_p:i,$id:s,$onAction:QB.bind(null,h),$patch:_,$reset:v,$subscribe(k,I={}){const P=QB(u,k,I.detached,()=>$()),$=r.run(()=>mn(()=>i.state.value[s],A=>{(I.flush==="sync"?c:d)&&k({storeId:s,type:c0.direct,events:g},A)},Ic({},l,I)));return P},$dispose:b},S=AL(w);i._s.set(s,S);const L=(i._a&&i._a.runWithContext||Jke)(()=>i._e.run(()=>(r=h6()).run(e)));for(const k in L){const I=L[k];if(ds(I)&&!iIe(I)||nu(I))o||(f&&tIe(I)&&(ds(I)?I.value=f[k]:nA(I,f[k])),i.state.value[s][k]=I);else if(typeof I=="function"){const P=C(k,I);L[k]=P,a.actions[k]=I}}return Ic(S,L),Ic(gi(S),L),Object.defineProperty(S,"$state",{get:()=>i.state.value[s],set:k=>{_(I=>{Ic(I,k)})}}),i._p.forEach(k=>{Ic(S,r.run(()=>k({store:S,app:i._a,pinia:i,options:a})))}),f&&o&&t.hydrate&&t.hydrate(S.$state,f),d=!0,c=!0,S}function lk(s,e,t){let i,n;const o=typeof e=="function";typeof s=="string"?(i=s,n=o?t:e):(n=s,i=s.id);function r(a,l){const d=MZ();return a=a||(d?Ev(gq,null):null),a&&ak(a),a=hq,a._s.has(i)||(o?pq(i,e,n,a):nIe(i,n,a)),a._s.get(i)}return r.$id=i,r}const q4="/python-logo.svg",sIe=Ce("span",{class:"font-bold text-blue-400"},[Ce("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4"},[Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M17.25 6.75 22.5 12l-5.25 5.25m-10.5 0L1.5 12l5.25-5.25m7.5-3-4.5 16.5"})])],-1),oIe={class:"text-sm flex-1 truncate"},rIe=Ce("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4"},[Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M6 18 18 6M6 6l12 12"})],-1),aIe=[rIe],lIe=Qm({__name:"Tab",props:{title:String,icon:String,active:Boolean},emits:["close","click"],setup(s,{emit:e}){const t=s,i=e;return _o(t.icon),(n,o)=>(xt(),Vt("button",{onClick:o[1]||(o[1]=r=>i("click")),class:Ho([s.active?"border-t border-b-base-100 border-t-primary bg-base-100 text-base-content":"","flex group h-8 gap-2 items-center h-full px-2 text-neutral-content/80 border-r border-b border-neutral/80 cursor-pointer hover:bg-base-100"])},[sIe,Ce("span",oIe,jn(s.title),1),Ce("span",{onClick:o[0]||(o[0]=r=>i("close")),class:"invisible group-hover:visible p-1 rounded-lg hover:bg-neutral-500/50"},aIe)],2))}}),mq=(s,e)=>{const t=s.__vccOpts||s;for(const[i,n]of e)t[i]=n;return t},dIe={},cIe={title:"Source code",class:"flex items-center justify-center p-2 border-l border-primary text-base-content/50 hover:text-base-content/100 font-bold"};function uIe(s,e){return xt(),Vt("button",cIe,[VL(s.$slots,"default")])}const JB=mq(dIe,[["render",uIe]]),hIe=["id"],gIe={key:0,class:"absolute bg-base-100 rounded-lg border border-neutral flex flex-col p-4 px-1 *:px-8 gap-2 min-w-64 *:text-left"},jf=Qm({__name:"Menu",props:{title:{},group:{},id:{}},setup(s){const e=s,t=An(()=>"id-"+e.group+"-"+e.id),i=_o(!1),n=o=>{console.log(o.target),o.target.closest(`#${t.value}`)||(i.value=!1)};return mn(i,o=>{o?window.addEventListener("click",n):window.removeEventListener("click",n)}),(o,r)=>(xt(),Vt("div",{class:"relative group",id:t.value},[Ce("button",{onClick:r[0]||(r[0]=a=>i.value=!i.value),class:Ho([{"bg-neutral":i.value},"text-sm p-2 group-hover:bg-neutral/80 active:bg-neutral rounded-lg"])},jn(o.title),3),i.value?(xt(),Vt("div",gIe,[VL(o.$slots,"default")])):_s("",!0)],8,hIe))}}),G4=lk("info",()=>{const s=_o([]);return{messages:s,addMessage:t=>{const i=new Date().toLocaleTimeString();s.value.push({...t,time:i})}}}),Z4=lk("codes",()=>{const s=G4(),e=_o([]),t=_o([]),i=_o(null),n=An(()=>i.value?e.value.find(I=>I.id===i.value):null),o=An({get:()=>n.value?n.value.content:"",set:I=>{n.value&&(n.value.content=I)}}),r=An(()=>e.value.find(I=>I.id==="src")!==void 0),a=An(()=>e.value.find(I=>I.id==="src")),l=An(()=>e.value.find(I=>I.id==="test")!==void 0),d=An(()=>e.value.find(I=>I.id==="test"));function c(I){if(r.value){a.value.content=I||"",v();return}e.value.push({id:"src",name:"src.py",content:I||"",language:"python",diff:void 0})}function u(I){if(l.value){d.value.content=I||"",v();return}e.value.push({id:"test",name:"test.py",content:I||"",language:"python",diff:void 0})}function h(I){t.value.includes(I.id)||t.value.push(I.id),g(I.id)}function g(I){i.value=I}function f(I){if(i.value==I){i.value=null;const P=t.value.filter($=>$!==I);P.length>0&&g(P[0]),t.value=P}else t.value=t.value.filter(P=>P!==I)}function m(I){return e.value.find(P=>P.id===I)}const _=An(()=>e.value.filter(I=>!!I.diff));function v(){e.value=[...e.value]}function b(I,P,$){var z,K;let A=m(I);A||(A={id:I,name:I,content:P,language:"python",diff:$||((z=a.value)==null?void 0:z.content)},e.value.push(A)),A.content=P,A.diff=$||((K=a.value)==null?void 0:K.content),v()}async function C(){var $;const P=await(await fetch("/parse",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({program:($=a.value)==null?void 0:$.content})})).json();a.value.content=P.parsed,v()}async function w(){var $;s.addMessage({message:"Generating mutants...",type:"info",paths:[]}),e.value=e.value.filter(A=>!A.diff);const P=(await fetch("/mutate",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({program:($=a.value)==null?void 0:$.content})})).body.pipeThrough(new TextDecoderStream).getReader();for(;;){const{value:A,done:z}=await P.read();if(z)break;const K=A.trim().split(`

`);for(const Q of K){let ne;try{ne=JSON.parse(Q.trim())}catch{console.log(Q);continue}if(console.log(ne),ne.error){s.addMessage({message:ne.error.join(`
`),type:"error",paths:[ne.id]});continue}b(ne.id,ne.mutant,ne.original)}}s.addMessage({message:`${_.value.length} Mutants generated`,type:"success",paths:[]})}const S=An(()=>{const I=[];return _.value.forEach(P=>{const $=P.id.split("/");let A=I;for(let z=0;z<$.length;z++){const K=$[z];if(z===$.length-1){A.push({name:K,content:P});break}let Q=A.find(ne=>ne.name===K);Q||(Q={name:K,children:[]},A.push(Q)),A=Q.children}}),I});function x(I,P){let $;return(...A)=>{clearTimeout($),$=setTimeout(()=>{I(...A)},P)}}function L(){localStorage.setItem("src",a.value.content),localStorage.setItem("test",d.value.content)}function k(){const I=localStorage.getItem("src"),P=localStorage.getItem("test");I&&c(I),P&&u(P)}return mn(a,x(L,5e3)),mn(d,x(L,5e3)),{codes:e,createSrc:c,createTest:u,hasSrc:r,hasTest:l,codeTabs:t,addToTabs:h,setActiveTab:g,closeTab:f,activeTab:n,activeTabCode:o,getSrc:a,getTest:d,getCode:m,parseCode:C,getMutants:w,mutants:_,mutantHierarchy:S,loadFromLocalStorage:k,saveToLocalStorage:L}}),_q=lk("tester",()=>{const s=Z4(),e=G4(),t=_o([]),i=_o([]),n=An(()=>i.value.filter(_=>_.id!=="src")),o=An(()=>n.value.filter(_=>!_.success)),r=An(()=>n.value.filter(_=>_.success)),a=An(()=>o.value.length/n.value.length),l=An(()=>{const _=a.value;return _>=.85?"A":_>=.65?"B":_>=.35?"C":_>=.15?"D":"E"}),d=An(()=>{const _=a.value;return _>=.85?"Excellent":_>=.65?"Good":_>=.35?"Average":_>=.15?"Poor":"Very Poor"});function c(){if(!s.hasTest){alert("No test found");return}if(!s.activeTabCode){alert("No code found");return}u([s.activeTab.id])}async function u(_){e.addMessage({message:"Initiating test run",type:"info",paths:[]});const v=_.map(w=>{const S=s.getCode(w);return t.value.push(S.id),{id:S.id,program:S.content}}),C=(await fetch("/test",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({programs:v,test:s.getTest.content})})).body.pipeThrough(new TextDecoderStream).getReader();for(;;){const{value:w,done:S}=await C.read();if(S)break;const x=w.trim().split(`

`);for(const L of x){let k;try{k=JSON.parse(L.trim()),i.value.push(k),t.value=t.value.filter(I=>I!==k.id),k.error?e.addMessage({message:k.error.join(`
`),type:"error",paths:[k.id]}):k.id==="src"?e.addMessage({message:k.success?"Test passed":" Test failed at "+k.output.join(", "),type:k.success?"success":"error",paths:["test",k.id]}):e.addMessage({message:`Mutant analysis completed: Mutant did ${k.success?"":"not"} survive the test run.`,type:k.success?"error":"success",paths:[k.id]})}catch{console.log(L);continue}console.log(k)}}e.addMessage({message:`${v.length} Tests completed`,type:"info",paths:[]})}function h(_){return i.value.find(v=>v.id===_)}function g(_){return t.value.includes(_)}function f(_){u([_])}function m(){i.value=[],u(s.codes.map(_=>_.id).filter(_=>_!=="test"))}return{runActiveTab:c,activeTesting:t,testResults:i,getResult:h,testIsRunning:g,runTestFor:f,runAllTests:m,mutantsResult:n,killedMutants:o,aliveMutants:r,mutatationScore:a,mutationGrade:l,mutationComment:d}}),fIe=["onClick"],pIe=Ce("img",{src:q4,class:"w-4 h-",alt:"python icon"},null,-1),mIe={class:"text-neutral-content/80"},_Ie={class:"flex gap-1 ml-auto"},vIe={key:0,class:"flex"},bIe={key:0,xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4 text-error"},CIe=Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M6 18 18 6M6 6l12 12"},null,-1),wIe=[CIe],SIe={key:1,xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4 text-success"},yIe=Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"m4.5 12.75 6 6 9-13.5"},null,-1),LIe=[yIe],xIe={key:1},DIe=Ce("svg",{class:"w-5 h-5 mr-3 -ml-1 text-white animate-spin",xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"},[Ce("circle",{class:"opacity-25",cx:"12",cy:"12",r:"10",stroke:"currentColor","stroke-width":"4"}),Ce("path",{class:"opacity-75",fill:"currentColor",d:"M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"})],-1),kIe=[DIe],IIe={key:1,open:""},EIe=Ce("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4"},[Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M2.25 12.75V12A2.25 2.25 0 014.5 9.75h15A2.25 2.25 0 0121.75 12v.75m-8.69-6.44l-2.12-2.12a1.5 1.5 0 00-1.061-.44H4.5A2.25 2.25 0 002.25 6v12a2.25 2.25 0 002.25 2.25h15A2.25 2.25 0 0021.75 18V9a2.25 2.25 0 00-2.25-2.25h-5.379a1.5 1.5 0 01-1.06-.44z"})],-1),NIe=Qm({__name:"FileHierarchy",props:{folders:{},activeId:{},subs:{type:Boolean}},emits:["click"],setup(s,{emit:e}){const t=_q(),i=e;return(n,o)=>{const r=PE("file-hierarchy",!0);return xt(),Vt("ul",{class:Ho({"menu menu-xs w-full flex-nowrap overflow-auto":!n.subs})},[(xt(!0),Vt(Ds,null,iv(n.folders,(a,l)=>(xt(),Vt("li",{key:a.name},[a.content?(xt(),Vt("div",{key:0,onClick:d=>i("click",a.content),class:Ho([{"bg-neutral/80":n.activeId==a.content.id},"flex items-center gap-1 p-1 px-4 hover:bg-neutral/80"])},[pIe,Ce("p",mIe,jn(a.name),1),Ce("div",_Ie,[Ue(t).getResult(a.content.id)?(xt(),Vt("span",vIe,[Ue(t).getResult(a.content.id).success?(xt(),Vt("svg",bIe,wIe)):(xt(),Vt("svg",SIe,LIe))])):_s("",!0),Ue(t).testIsRunning(a.content.id)?(xt(),Vt("span",xIe,kIe)):_s("",!0)])],10,fIe)):_s("",!0),a.children?(xt(),Vt("details",IIe,[Ce("summary",null,[EIe,Vh(" "+jn(a.name),1)]),Yt(r,{folders:a.children,subs:"",activeId:n.activeId,onClick:o[0]||(o[0]=d=>i("click",d))},null,8,["folders","activeId"])])):_s("",!0)]))),128))],2)}}}),TIe={},MIe={class:"hover:bg-accent/50 hover:text-accent-content p-1 rounded-lg"};function RIe(s,e){return xt(),Vt("button",MIe,[VL(s.$slots,"default")])}const Sw=mq(TIe,[["render",RIe]]),NE={name:"splitpanes",emits:["ready","resize","resized","pane-click","pane-maximize","pane-add","pane-remove","splitter-click"],props:{horizontal:{type:Boolean},pushOtherPanes:{type:Boolean,default:!0},dblClickSplitter:{type:Boolean,default:!0},rtl:{type:Boolean,default:!1},firstSplitter:{type:Boolean}},provide(){return{requestUpdate:this.requestUpdate,onPaneAdd:this.onPaneAdd,onPaneRemove:this.onPaneRemove,onPaneClick:this.onPaneClick}},data:()=>({container:null,ready:!1,panes:[],touch:{mouseDown:!1,dragging:!1,activeSplitter:null},splitterTaps:{splitter:null,timeoutId:null}}),computed:{panesCount(){return this.panes.length},indexedPanes(){return this.panes.reduce((s,e)=>(s[e.id]=e)&&s,{})}},methods:{updatePaneComponents(){this.panes.forEach(s=>{s.update&&s.update({[this.horizontal?"height":"width"]:`${this.indexedPanes[s.id].size}%`})})},bindEvents(){document.addEventListener("mousemove",this.onMouseMove,{passive:!1}),document.addEventListener("mouseup",this.onMouseUp),"ontouchstart"in window&&(document.addEventListener("touchmove",this.onMouseMove,{passive:!1}),document.addEventListener("touchend",this.onMouseUp))},unbindEvents(){document.removeEventListener("mousemove",this.onMouseMove,{passive:!1}),document.removeEventListener("mouseup",this.onMouseUp),"ontouchstart"in window&&(document.removeEventListener("touchmove",this.onMouseMove,{passive:!1}),document.removeEventListener("touchend",this.onMouseUp))},onMouseDown(s,e){this.bindEvents(),this.touch.mouseDown=!0,this.touch.activeSplitter=e},onMouseMove(s){this.touch.mouseDown&&(s.preventDefault(),this.touch.dragging=!0,this.calculatePanesSize(this.getCurrentMouseDrag(s)),this.$emit("resize",this.panes.map(e=>({min:e.min,max:e.max,size:e.size}))))},onMouseUp(){this.touch.dragging&&this.$emit("resized",this.panes.map(s=>({min:s.min,max:s.max,size:s.size}))),this.touch.mouseDown=!1,setTimeout(()=>{this.touch.dragging=!1,this.unbindEvents()},100)},onSplitterClick(s,e){"ontouchstart"in window&&(s.preventDefault(),this.dblClickSplitter&&(this.splitterTaps.splitter===e?(clearTimeout(this.splitterTaps.timeoutId),this.splitterTaps.timeoutId=null,this.onSplitterDblClick(s,e),this.splitterTaps.splitter=null):(this.splitterTaps.splitter=e,this.splitterTaps.timeoutId=setTimeout(()=>{this.splitterTaps.splitter=null},500)))),this.touch.dragging||this.$emit("splitter-click",this.panes[e])},onSplitterDblClick(s,e){let t=0;this.panes=this.panes.map((i,n)=>(i.size=n===e?i.max:i.min,n!==e&&(t+=i.min),i)),this.panes[e].size-=t,this.$emit("pane-maximize",this.panes[e]),this.$emit("resized",this.panes.map(i=>({min:i.min,max:i.max,size:i.size})))},onPaneClick(s,e){this.$emit("pane-click",this.indexedPanes[e])},getCurrentMouseDrag(s){const e=this.container.getBoundingClientRect(),{clientX:t,clientY:i}="ontouchstart"in window&&s.touches?s.touches[0]:s;return{x:t-e.left,y:i-e.top}},getCurrentDragPercentage(s){s=s[this.horizontal?"y":"x"];const e=this.container[this.horizontal?"clientHeight":"clientWidth"];return this.rtl&&!this.horizontal&&(s=e-s),s*100/e},calculatePanesSize(s){const e=this.touch.activeSplitter;let t={prevPanesSize:this.sumPrevPanesSize(e),nextPanesSize:this.sumNextPanesSize(e),prevReachedMinPanes:0,nextReachedMinPanes:0};const i=0+(this.pushOtherPanes?0:t.prevPanesSize),n=100-(this.pushOtherPanes?0:t.nextPanesSize),o=Math.max(Math.min(this.getCurrentDragPercentage(s),n),i);let r=[e,e+1],a=this.panes[r[0]]||null,l=this.panes[r[1]]||null;const d=a.max<100&&o>=a.max+t.prevPanesSize,c=l.max<100&&o<=100-(l.max+this.sumNextPanesSize(e+1));if(d||c){d?(a.size=a.max,l.size=Math.max(100-a.max-t.prevPanesSize-t.nextPanesSize,0)):(a.size=Math.max(100-l.max-t.prevPanesSize-this.sumNextPanesSize(e+1),0),l.size=l.max);return}if(this.pushOtherPanes){const u=this.doPushOtherPanes(t,o);if(!u)return;({sums:t,panesToResize:r}=u),a=this.panes[r[0]]||null,l=this.panes[r[1]]||null}a!==null&&(a.size=Math.min(Math.max(o-t.prevPanesSize-t.prevReachedMinPanes,a.min),a.max)),l!==null&&(l.size=Math.min(Math.max(100-o-t.nextPanesSize-t.nextReachedMinPanes,l.min),l.max))},doPushOtherPanes(s,e){const t=this.touch.activeSplitter,i=[t,t+1];return e<s.prevPanesSize+this.panes[i[0]].min&&(i[0]=this.findPrevExpandedPane(t).index,s.prevReachedMinPanes=0,i[0]<t&&this.panes.forEach((n,o)=>{o>i[0]&&o<=t&&(n.size=n.min,s.prevReachedMinPanes+=n.min)}),s.prevPanesSize=this.sumPrevPanesSize(i[0]),i[0]===void 0)?(s.prevReachedMinPanes=0,this.panes[0].size=this.panes[0].min,this.panes.forEach((n,o)=>{o>0&&o<=t&&(n.size=n.min,s.prevReachedMinPanes+=n.min)}),this.panes[i[1]].size=100-s.prevReachedMinPanes-this.panes[0].min-s.prevPanesSize-s.nextPanesSize,null):e>100-s.nextPanesSize-this.panes[i[1]].min&&(i[1]=this.findNextExpandedPane(t).index,s.nextReachedMinPanes=0,i[1]>t+1&&this.panes.forEach((n,o)=>{o>t&&o<i[1]&&(n.size=n.min,s.nextReachedMinPanes+=n.min)}),s.nextPanesSize=this.sumNextPanesSize(i[1]-1),i[1]===void 0)?(s.nextReachedMinPanes=0,this.panes[this.panesCount-1].size=this.panes[this.panesCount-1].min,this.panes.forEach((n,o)=>{o<this.panesCount-1&&o>=t+1&&(n.size=n.min,s.nextReachedMinPanes+=n.min)}),this.panes[i[0]].size=100-s.prevPanesSize-s.nextReachedMinPanes-this.panes[this.panesCount-1].min-s.nextPanesSize,null):{sums:s,panesToResize:i}},sumPrevPanesSize(s){return this.panes.reduce((e,t,i)=>e+(i<s?t.size:0),0)},sumNextPanesSize(s){return this.panes.reduce((e,t,i)=>e+(i>s+1?t.size:0),0)},findPrevExpandedPane(s){return[...this.panes].reverse().find(e=>e.index<s&&e.size>e.min)||{}},findNextExpandedPane(s){return this.panes.find(e=>e.index>s+1&&e.size>e.min)||{}},checkSplitpanesNodes(){Array.from(this.container.children).forEach(s=>{const e=s.classList.contains("splitpanes__pane"),t=s.classList.contains("splitpanes__splitter");!e&&!t&&(s.parentNode.removeChild(s),console.warn("Splitpanes: Only <pane> elements are allowed at the root of <splitpanes>. One of your DOM nodes was removed."))})},addSplitter(s,e,t=!1){const i=s-1,n=document.createElement("div");n.classList.add("splitpanes__splitter"),t||(n.onmousedown=o=>this.onMouseDown(o,i),typeof window<"u"&&"ontouchstart"in window&&(n.ontouchstart=o=>this.onMouseDown(o,i)),n.onclick=o=>this.onSplitterClick(o,i+1)),this.dblClickSplitter&&(n.ondblclick=o=>this.onSplitterDblClick(o,i+1)),e.parentNode.insertBefore(n,e)},removeSplitter(s){s.onmousedown=void 0,s.onclick=void 0,s.ondblclick=void 0,s.parentNode.removeChild(s)},redoSplitters(){const s=Array.from(this.container.children);s.forEach(t=>{t.className.includes("splitpanes__splitter")&&this.removeSplitter(t)});let e=0;s.forEach(t=>{t.className.includes("splitpanes__pane")&&(!e&&this.firstSplitter?this.addSplitter(e,t,!0):e&&this.addSplitter(e,t),e++)})},requestUpdate({target:s,...e}){const t=this.indexedPanes[s._.uid];Object.entries(e).forEach(([i,n])=>t[i]=n)},onPaneAdd(s){let e=-1;Array.from(s.$el.parentNode.children).some(n=>(n.className.includes("splitpanes__pane")&&e++,n===s.$el));const t=parseFloat(s.minSize),i=parseFloat(s.maxSize);this.panes.splice(e,0,{id:s._.uid,index:e,min:isNaN(t)?0:t,max:isNaN(i)?100:i,size:s.size===null?null:parseFloat(s.size),givenSize:s.size,update:s.update}),this.panes.forEach((n,o)=>n.index=o),this.ready&&this.$nextTick(()=>{this.redoSplitters(),this.resetPaneSizes({addedPane:this.panes[e]}),this.$emit("pane-add",{index:e,panes:this.panes.map(n=>({min:n.min,max:n.max,size:n.size}))})})},onPaneRemove(s){const e=this.panes.findIndex(i=>i.id===s._.uid),t=this.panes.splice(e,1)[0];this.panes.forEach((i,n)=>i.index=n),this.$nextTick(()=>{this.redoSplitters(),this.resetPaneSizes({removedPane:{...t,index:e}}),this.$emit("pane-remove",{removed:t,panes:this.panes.map(i=>({min:i.min,max:i.max,size:i.size}))})})},resetPaneSizes(s={}){!s.addedPane&&!s.removedPane?this.initialPanesSizing():this.panes.some(e=>e.givenSize!==null||e.min||e.max<100)?this.equalizeAfterAddOrRemove(s):this.equalize(),this.ready&&this.$emit("resized",this.panes.map(e=>({min:e.min,max:e.max,size:e.size})))},equalize(){const s=100/this.panesCount;let e=0;const t=[],i=[];this.panes.forEach(n=>{n.size=Math.max(Math.min(s,n.max),n.min),e-=n.size,n.size>=n.max&&t.push(n.id),n.size<=n.min&&i.push(n.id)}),e>.1&&this.readjustSizes(e,t,i)},initialPanesSizing(){let s=100;const e=[],t=[];let i=0;this.panes.forEach(o=>{s-=o.size,o.size!==null&&i++,o.size>=o.max&&e.push(o.id),o.size<=o.min&&t.push(o.id)});let n=100;s>.1&&(this.panes.forEach(o=>{o.size===null&&(o.size=Math.max(Math.min(s/(this.panesCount-i),o.max),o.min)),n-=o.size}),n>.1&&this.readjustSizes(s,e,t))},equalizeAfterAddOrRemove({addedPane:s,removedPane:e}={}){let t=100/this.panesCount,i=0;const n=[],o=[];s&&s.givenSize!==null&&(t=(100-s.givenSize)/(this.panesCount-1)),this.panes.forEach(r=>{i-=r.size,r.size>=r.max&&n.push(r.id),r.size<=r.min&&o.push(r.id)}),!(Math.abs(i)<.1)&&(this.panes.forEach(r=>{s&&s.givenSize!==null&&s.id===r.id||(r.size=Math.max(Math.min(t,r.max),r.min)),i-=r.size,r.size>=r.max&&n.push(r.id),r.size<=r.min&&o.push(r.id)}),i>.1&&this.readjustSizes(i,n,o))},readjustSizes(s,e,t){let i;s>0?i=s/(this.panesCount-e.length):i=s/(this.panesCount-t.length),this.panes.forEach((n,o)=>{if(s>0&&!e.includes(n.id)){const r=Math.max(Math.min(n.size+i,n.max),n.min),a=r-n.size;s-=a,n.size=r}else if(!t.includes(n.id)){const r=Math.max(Math.min(n.size+i,n.max),n.min),a=r-n.size;s-=a,n.size=r}n.update({[this.horizontal?"height":"width"]:`${this.indexedPanes[n.id].size}%`})}),Math.abs(s)>.1&&this.$nextTick(()=>{this.ready&&console.warn("Splitpanes: Could not resize panes correctly due to their constraints.")})}},watch:{panes:{deep:!0,immediate:!1,handler(){this.updatePaneComponents()}},horizontal(){this.updatePaneComponents()},firstSplitter(){this.redoSplitters()},dblClickSplitter(s){[...this.container.querySelectorAll(".splitpanes__splitter")].forEach((e,t)=>{e.ondblclick=s?i=>this.onSplitterDblClick(i,t):void 0})}},beforeUnmount(){this.ready=!1},mounted(){this.container=this.$refs.container,this.checkSplitpanesNodes(),this.redoSplitters(),this.resetPaneSizes(),this.$emit("ready"),this.ready=!0},render(){return cg("div",{ref:"container",class:["splitpanes",`splitpanes--${this.horizontal?"horizontal":"vertical"}`,{"splitpanes--dragging":this.touch.dragging}]},this.$slots.default())}},AIe=(s,e)=>{const t=s.__vccOpts||s;for(const[i,n]of e)t[i]=n;return t},PIe={name:"pane",inject:["requestUpdate","onPaneAdd","onPaneRemove","onPaneClick"],props:{size:{type:[Number,String],default:null},minSize:{type:[Number,String],default:0},maxSize:{type:[Number,String],default:100}},data:()=>({style:{}}),mounted(){this.onPaneAdd(this)},beforeUnmount(){this.onPaneRemove(this)},methods:{update(s){this.style=s}},computed:{sizeNumber(){return this.size||this.size===0?parseFloat(this.size):null},minSizeNumber(){return parseFloat(this.minSize)},maxSizeNumber(){return parseFloat(this.maxSize)}},watch:{sizeNumber(s){this.requestUpdate({target:this,size:s})},minSizeNumber(s){this.requestUpdate({target:this,min:s})},maxSizeNumber(s){this.requestUpdate({target:this,max:s})}}};function OIe(s,e,t,i,n,o){return xt(),Vt("div",{class:"splitpanes__pane",onClick:e[0]||(e[0]=r=>o.onPaneClick(r,s._.uid)),style:ML(s.style)},[VL(s.$slots,"default")],4)}const Kf=AIe(PIe,[["render",OIe]]),FIe=lk("samples",()=>{const s={calculator:{name:"Calculator",description:"A simple calculator",src:`def add(a, b):
    return a + b


def subtract(a, b):
    return a - b


def multiply(a, b):
    return a * b


def divide(a, b):
    return a / b


if __name__ == "__main__":
    print(add(1, 2))
    print(subtract(1, 2))
    print(multiply(1, 2))
    print(divide(1, 2))`,test:`from src import add, subtract, multiply, divide


def test_add():
    assert add(1, 2) == 3


def test_subtract():
    assert subtract(1, 2) == -1


def test_multiply():
    assert multiply(1, 2) == 2


def test_divide():
    assert divide(1, 2) == 0.5`,language:"python"}},e=Z4();function t(i){if(!confirm("This will overwrite your current code. Are you sure?"))return;const n=s[i];e.createSrc(n.src),e.createTest(n.test)}return{loadSample:t}}),BIe={class:"relative flex flex-col w-screen h-screen overflow-hidden bg-base-300"},WIe={class:"z-10 flex items-center h-12 gap-4 p-2 border-b border-neutral/80"},VIe=Ce("h1",null,"MuPy",-1),HIe={class:"ml-auto"},zIe=Ce("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4"},[Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M5.25 5.653c0-.856.917-1.398 1.667-.986l11.54 6.347a1.125 1.125 0 0 1 0 1.972l-11.54 6.347a1.125 1.125 0 0 1-1.667-.986V5.653Z"})],-1),UIe={class:"flex flex-1 w-full overflow-hidden defaul-theme"},$Ie={"max-size":"3rem","min-size":"3rem",class:"flex flex-col border-r border-neutral/80"},jIe=Ce("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-6 h-6"},[Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M15.75 17.25v3.375c0 .621-.504 1.125-1.125 1.125h-9.75a1.125 1.125 0 0 1-1.125-1.125V7.875c0-.621.504-1.125 1.125-1.125H6.75a9.06 9.06 0 0 1 1.5.124m7.5 10.376h3.375c.621 0 1.125-.504 1.125-1.125V11.25c0-4.46-3.243-8.161-7.5-8.876a9.06 9.06 0 0 0-1.5-.124H9.375c-.621 0-1.125.504-1.125 1.125v3.5m7.5 10.375H9.375a1.125 1.125 0 0 1-1.125-1.125v-9.25m12 6.625v-1.875a3.375 3.375 0 0 0-3.375-3.375h-1.5a1.125 1.125 0 0 1-1.125-1.125v-1.5a3.375 3.375 0 0 0-3.375-3.375H9.75"})],-1),KIe=Ce("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-6 h-6"},[Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M12 12.75c1.148 0 2.278.08 3.383.237 1.037.146 1.866.966 1.866 2.013 0 3.728-2.35 6.75-5.25 6.75S6.75 18.728 6.75 15c0-1.046.83-1.867 1.866-2.013A24.204 24.204 0 0 1 12 12.75Zm0 0c2.883 0 5.647.508 8.207 1.44a23.91 23.91 0 0 1-1.152 6.06M12 12.75c-2.883 0-5.647.508-8.208 1.44.125 2.104.52 4.136 1.153 6.06M12 12.75a2.25 2.25 0 0 0 2.248-2.354M12 12.75a2.25 2.25 0 0 1-2.248-2.354M12 8.25c.995 0 1.971-.08 2.922-.236.403-.066.74-.358.795-.762a3.778 3.778 0 0 0-.399-2.25M12 8.25c-.995 0-1.97-.08-2.922-.236-.402-.066-.74-.358-.795-.762a3.734 3.734 0 0 1 .4-2.253M12 8.25a2.25 2.25 0 0 0-2.248 2.146M12 8.25a2.25 2.25 0 0 1 2.248 2.146M8.683 5a6.032 6.032 0 0 1-1.155-1.002c.07-.63.27-1.222.574-1.747m.581 2.749A3.75 3.75 0 0 1 15.318 5m0 0c.427-.283.815-.62 1.155-.999a4.471 4.471 0 0 0-.575-1.752M4.921 6a24.048 24.048 0 0 0-.392 3.314c1.668.546 3.416.914 5.223 1.082M19.08 6c.205 1.08.337 2.187.392 3.314a23.882 23.882 0 0 1-5.223 1.082"})],-1),qIe=Ce("p",{class:"hidden p-4 text-sm uppercase"},"EXPLORER",-1),GIe=Ce("div",{class:"flex items-center justify-between"},[Ce("p",{class:"p-4 text-xs font-bold tracking-wide uppercase"},"Source Code"),Ce("button",{title:"Add new source code",class:"hidden btn btn-sm btn-circle"},[Ce("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4"},[Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M12 4.5v15m7.5-7.5h-15"})])])],-1),ZIe={class:"flex flex-col flex-1 gap-4"},YIe=Ce("img",{src:q4,class:"w-4 h-",alt:"python icon"},null,-1),XIe={class:"text-neutral-content/80"},QIe={class:"flex gap-1 ml-auto"},JIe={key:0,class:"flex"},eEe={key:0,xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4 text-error"},tEe=Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M6 18 18 6M6 6l12 12"},null,-1),iEe=[tEe],nEe={key:1,xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4 text-success"},sEe=Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"m4.5 12.75 6 6 9-13.5"},null,-1),oEe=[sEe],rEe={key:1},aEe=Ce("svg",{class:"w-5 h-5 mr-3 -ml-1 text-white animate-spin",xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"},[Ce("circle",{class:"opacity-25",cx:"12",cy:"12",r:"10",stroke:"currentColor","stroke-width":"4"}),Ce("path",{class:"opacity-75",fill:"currentColor",d:"M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"})],-1),lEe=[aEe],dEe=Ce("img",{src:q4,class:"w-4 h-",alt:"python icon"},null,-1),cEe={class:"text-neutral-content/80"},uEe={key:0,class:"flex flex-col items-center justify-center"},hEe=Ce("p",{class:"text-neutral-content/80"},"No source code found",-1),gEe=[hEe],fEe={class:"flex items-center gap-2"},pEe={class:"p-4 text-xs font-bold tracking-wide uppercase"},mEe=Ce("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4"},[Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M12 12.75c1.148 0 2.278.08 3.383.237 1.037.146 1.866.966 1.866 2.013 0 3.728-2.35 6.75-5.25 6.75S6.75 18.728 6.75 15c0-1.046.83-1.867 1.866-2.013A24.204 24.204 0 0 1 12 12.75Zm0 0c2.883 0 5.647.508 8.207 1.44a23.91 23.91 0 0 1-1.152 6.06M12 12.75c-2.883 0-5.647.508-8.208 1.44.125 2.104.52 4.136 1.153 6.06M12 12.75a2.25 2.25 0 0 0 2.248-2.354M12 12.75a2.25 2.25 0 0 1-2.248-2.354M12 8.25c.995 0 1.971-.08 2.922-.236.403-.066.74-.358.795-.762a3.778 3.778 0 0 0-.399-2.25M12 8.25c-.995 0-1.97-.08-2.922-.236-.402-.066-.74-.358-.795-.762a3.734 3.734 0 0 1 .4-2.253M12 8.25a2.25 2.25 0 0 0-2.248 2.146M12 8.25a2.25 2.25 0 0 1 2.248 2.146M8.683 5a6.032 6.032 0 0 1-1.155-1.002c.07-.63.27-1.222.574-1.747m.581 2.749A3.75 3.75 0 0 1 15.318 5m0 0c.427-.283.815-.62 1.155-.999a4.471 4.471 0 0 0-.575-1.752M4.921 6a24.048 24.048 0 0 0-.392 3.314c1.668.546 3.416.914 5.223 1.082M19.08 6c.205 1.08.337 2.187.392 3.314a23.882 23.882 0 0 1-5.223 1.082"})],-1),_Ee=[mEe],vEe=Ce("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24","stroke-width":"1.5",stroke:"currentColor",class:"w-4 h-4"},[Ce("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M3 8.689c0-.864.933-1.406 1.683-.977l7.108 4.061a1.125 1.125 0 0 1 0 1.954l-7.108 4.061A1.125 1.125 0 0 1 3 16.811V8.69ZM12.75 8.689c0-.864.933-1.406 1.683-.977l7.108 4.061a1.125 1.125 0 0 1 0 1.954l-7.108 4.061a1.125 1.125 0 0 1-1.683-.977V8.69Z"})],-1),bEe=[vEe],CEe={key:0,class:"flex flex-col items-center justify-center flex-1 gap-4"},wEe=Ce("p",{class:"text-neutral-content/80"},"No mutants found",-1),SEe={class:"border-b-0 flex border-neutral/80 h-8 overflow-x-hidden overflow-y-visible w-full hover:overflow-x-auto flex-shrink-0 *:flex-shrink-0 tiny-scroll"},yEe=Ce("div",{class:"flex-1 h-full border-b border-neutral/80"},null,-1),LEe={class:"flex flex-col h-full overflow-hidden"},xEe={class:"flex h-8 gap-2 border-b border-neutral/80"},DEe={class:"flex flex-col flex-1 overflow-auto"},kEe={key:0,class:"h-full p-4 overflow-auto"},IEe=Ce("ul",{class:"form-control"},[Ce("h2",{class:"text-center"},"Mutant Generation Configuration"),Ce("p",{class:"mt-1 text-sm text-center"},"Please select your preffered mutation operators"),Ce("li",{class:"border-b border-neutral/80"},[Ce("label",{class:"flex items-center gap-4 py-4 cursor-pointer"},[Ce("input",{type:"checkbox",class:"checkbox checkbox-sm"}),Ce("span",{class:"label-text"},"Arithmetique Operators")])]),Ce("li",{class:"border-b border-neutral/80"},[Ce("label",{class:"flex items-center gap-4 py-4 cursor-pointer"},[Ce("input",{type:"checkbox",class:"checkbox checkbox-sm"}),Ce("span",{class:"label-text"},"Boolean Operators")])]),Ce("li",{class:"border-b border-neutral/80"},[Ce("label",{class:"flex items-center gap-4 py-4 cursor-pointer"},[Ce("input",{type:"checkbox",class:"checkbox checkbox-sm"}),Ce("span",{class:"label-text"},"Constant Operators")])]),Ce("li",{class:"border-b border-neutral/80"},[Ce("label",{class:"flex items-center gap-4 py-4 cursor-pointer"},[Ce("input",{type:"checkbox",class:"checkbox checkbox-sm"}),Ce("span",{class:"label-text"},"Comparison Operators")])])],-1),EEe=[IEe],NEe={key:1,class:"p-4 font-mono"},TEe={key:0},MEe=Ce("li",null,"No Mutants Analysed",-1),REe={key:1},AEe={class:"mt-4"},PEe={key:2,class:"p-4 font-mono"},OEe={key:0},FEe=Ce("span",{class:"font-mono text-red-500 uppercase"},"[NOT Killed]",-1),BEe=["onClick"],WEe={key:3,class:"p-4 font-mono"},VEe={class:"text-base-content/50"},HEe={class:"mx-2 whitespace-pre"},zEe={key:0,class:"text-base-content/50"},UEe=["onClick"],$Ee=Ce("h1",{class:"text-sm font-bold tracking-wide text-center uppercase"},"Notification",-1),jEe=Ce("div",{class:"py-8 text-sm"},[Ce("p",null,"Notification Content")],-1),KEe=Qm({__name:"App",setup(s){const e=_o(void 0),t=_o(""),i=Z4(),n=FIe(),o=G4(),r=_q();function a(){console.log("ready"),e.value="20rem"}const l={automaticLayout:!0,formatOnType:!0,formatOnPaste:!0};_o("// some code...");const d=Xm(),c=g=>d.value=g;async function u(){var g;(g=d.value)==null||g.getAction("editor.action.formatDocument").run(),await i.parseCode()}function h(){window.alert("Hello")}return Qb(()=>{i.createSrc("#Add your source code here"),i.createTest("#Add your test code here"),i.addToTabs(i.getTest),i.addToTabs(i.getSrc),o.addMessage({type:"info",message:"Welcome to MuPy",paths:[]}),i.loadFromLocalStorage(),window.addEventListener("keydown",function(g){g.ctrlKey&&g.key==="s"&&(g.preventDefault(),i.saveToLocalStorage())}),window.addEventListener("keydown",function(g){g.ctrlKey&&g.key==="g"&&(g.preventDefault(),i.getMutants())})}),(g,f)=>{const m=PE("vue-monaco-diff-editor"),_=PE("vue-monaco-editor");return xt(),Vt(Ds,null,[Ce("main",BIe,[Ce("nav",WIe,[VIe,Yt(jf,{title:"File",group:"1",id:"1"},{default:ts(()=>[Yt(Sw,{onClick:f[0]||(f[0]=v=>Ue(i).saveToLocalStorage())},{default:ts(()=>[Vh("Save")]),_:1}),Yt(Sw,{onClick:f[1]||(f[1]=v=>Ue(i).getMutants())},{default:ts(()=>[Vh("Generate Mutant")]),_:1})]),_:1}),Yt(jf,{title:"Edit",group:"1",id:"2"},{default:ts(()=>[Yt(Sw,{onClick:u},{default:ts(()=>[Vh("Format Code")]),_:1})]),_:1}),Yt(jf,{title:"View",group:"1",id:"3"}),Yt(jf,{title:"Generate",group:"1",id:"4"}),Yt(jf,{title:"Samples",group:"1",id:"5"},{default:ts(()=>[Yt(Sw,{onClick:f[2]||(f[2]=v=>Ue(n).loadSample("calculator"))},{default:ts(()=>[Vh("Simple Calculator")]),_:1})]),_:1}),Yt(jf,{title:"Help",group:"1",id:"6"}),Ce("div",HIe,[Ue(i).activeTab&&Ue(i).activeTab.id!="test"?(xt(),Vt("button",{key:0,onClick:f[3]||(f[3]=(...v)=>Ue(r).runActiveTab&&Ue(r).runActiveTab(...v)),title:"Run Test",class:"btn btn-xs btn-accent"},[zIe,Vh(" Test Current Code ")])):_s("",!0)])]),Ce("div",UIe,[Ce("aside",$Ie,[Yt(JB,null,{default:ts(()=>[jIe]),_:1}),Yt(JB,null,{default:ts(()=>[KIe]),_:1})]),Yt(Ue(NE),{onReady:a},{default:ts(()=>[Yt(Ue(Kf),{"max-size":e.value?void 0:"12rem",size:e.value,class:"flex flex-col h-full"},{default:ts(()=>[qIe,Yt(Ue(NE),{horizontal:"",class:"flex flex-col flex-1"},{default:ts(()=>[Yt(Ue(Kf),{size:"30 flex flex-col"},{default:ts(()=>{var v,b,C,w;return[GIe,Ce("div",ZIe,[Ce("ul",null,[Ue(i).hasSrc?(xt(),Vt("li",{key:0,onClick:f[4]||(f[4]=S=>Ue(i).addToTabs(Ue(i).getSrc)),class:Ho([{"bg-neutral/80":((v=Ue(i).activeTab)==null?void 0:v.id)==((b=Ue(i).getSrc)==null?void 0:b.id)},"flex items-center gap-1 p-1 px-4 cursor-pointer hover:bg-neutral/80"])},[YIe,Ce("p",XIe,jn(Ue(i).getSrc.name),1),Ce("div",QIe,[Ue(r).getResult("src")?(xt(),Vt("span",JIe,[Ue(r).getResult("src").success?(xt(),Vt("svg",nEe,oEe)):(xt(),Vt("svg",eEe,iEe))])):_s("",!0),Ue(r).testIsRunning("src")?(xt(),Vt("span",rEe,lEe)):_s("",!0)])],2)):_s("",!0),Ue(i).hasTest?(xt(),Vt("li",{key:1,onClick:f[5]||(f[5]=S=>Ue(i).addToTabs(Ue(i).getTest)),class:Ho([{"bg-neutral/80":((C=Ue(i).activeTab)==null?void 0:C.id)==((w=Ue(i).getTest)==null?void 0:w.id)},"flex items-center gap-1 p-1 px-4 hover:bg-neutral/80"])},[dEe,Ce("p",cEe,jn(Ue(i).getTest.name),1)],2)):_s("",!0)]),!Ue(i).hasSrc||!Ue(i).hasTest?(xt(),Vt("div",uEe,gEe)):_s("",!0)])]}),_:1}),Yt(Ue(Kf),{size:"70",class:"flex flex-col overflow-auto"},{default:ts(()=>{var v;return[Ce("div",fEe,[Ce("p",pEe,"Mutants "+jn(Ue(i).mutants.length?`(${Ue(i).mutants.length})`:""),1),Ce("button",{onClick:f[6]||(f[6]=b=>Ue(i).getMutants()),title:"Run mutant generation",class:"ml-auto btn btn-sm btn-circle"},_Ee),Ce("button",{onClick:f[7]||(f[7]=b=>Ue(r).runAllTests()),title:"Analyse all mutant",class:"btn btn-xs btn-circle btn-square"},bEe)]),Ue(i).mutants.length?(xt(),ep(NIe,{key:1,class:"",folders:Ue(i).mutantHierarchy,activeId:(v=Ue(i).activeTab)==null?void 0:v.id,onClick:f[9]||(f[9]=b=>Ue(i).addToTabs(b))},null,8,["folders","activeId"])):(xt(),Vt("div",CEe,[wEe,Ce("button",{class:"btn btn-sm btn-primary",onClick:f[8]||(f[8]=b=>Ue(i).getMutants())},"Run Mutant Generation")]))]}),_:1})]),_:1})]),_:1},8,["max-size","size"]),Yt(Ue(Kf),{class:"flex flex-col flex-1 overflow-hidden"},{default:ts(()=>[Ce("nav",SEe,[(xt(!0),Vt(Ds,null,iv(Ue(i).codeTabs,(v,b)=>{var C,w;return xt(),ep(lIe,{title:((C=Ue(i).getCode(v))==null?void 0:C.name)||"No title",onClick:S=>Ue(i).setActiveTab(v),key:v,active:v==((w=Ue(i).activeTab)==null?void 0:w.id),onClose:S=>Ue(i).closeTab(v)},null,8,["title","onClick","active","onClose"])}),128)),yEe]),Yt(Ue(NE),{horizontal:"",class:"flex flex-col flex-1 overflow-hidden"},{default:ts(()=>[Yt(Ue(Kf),{size:"70",class:"bg-base-100"},{default:ts(()=>{var v,b,C;return[Ue(i).activeTab?(xt(),Vt("div",{class:"w-full h-full overflow-clip",key:(v=Ue(i).activeTab)==null?void 0:v.id},[Ue(i).activeTab.diff?(xt(),ep(m,{key:0,theme:"vs-dark",original:((b=Ue(i).activeTab)==null?void 0:b.diff)||"// the original code",modified:((C=Ue(i).activeTab)==null?void 0:C.content)||"// the modified code",language:"python",options:{...l,readOnly:!0},onMount:c},null,8,["original","modified","options"])):(xt(),ep(_,{key:1,value:Ue(i).activeTabCode,"onUpdate:value":f[10]||(f[10]=w=>Ue(i).activeTabCode=w),theme:"vs-dark",options:l,class:"h-full",language:"python"},null,8,["value"]))])):_s("",!0)]}),_:1}),Yt(Ue(Kf),{size:"30",class:""},{default:ts(()=>[Ce("div",LEe,[Ce("nav",xEe,[Ce("button",{onClick:f[11]||(f[11]=v=>t.value="output"),class:Ho([{"border-b border-primary text-base-content/100":t.value=="output"},"p-2 text-xs font-bold tracking-wide uppercase text-base-content/50 hover:text-base-content"])},"Output",2),Ce("button",{onClick:f[12]||(f[12]=v=>t.value="problems"),class:Ho([{"border-b border-primary text-base-content/100":t.value=="problems"},"p-2 text-xs font-bold tracking-wide uppercase text-base-content/50 hover:text-base-content"])},"Problems "+jn(Ue(r).aliveMutants.length?`(${Ue(r).aliveMutants.length})`:""),3),Ce("button",{onClick:f[13]||(f[13]=v=>t.value="results"),class:Ho([{"border-b border-primary text-base-content/100":t.value=="results"},"p-2 text-xs font-bold tracking-wide uppercase text-base-content/50 hover:text-base-content"])},"Test Results",2),Ce("button",{onClick:f[14]||(f[14]=v=>t.value="config"),class:Ho([{"border-b border-primary text-base-content/100":t.value=="config"},"p-2 text-xs font-bold tracking-wide uppercase text-base-content/50 hover:text-base-content"])},"Mutation Config",2)]),Ce("div",DEe,[t.value=="config"?(xt(),Vt("div",kEe,EEe)):_s("",!0),t.value=="results"?(xt(),Vt("div",NEe,[Ue(r).mutantsResult.length?(xt(),Vt("ul",REe,[Ce("li",null,jn(Ue(r).mutantsResult.length)+" Mutants Executed",1),Ce("li",null,"Killed : "+jn(Ue(r).killedMutants.length),1),Ce("li",null,"Survived : "+jn(Ue(r).mutantsResult.length-Ue(r).killedMutants.length),1),Ce("li",AEe," Mutation Score: "+jn(Ue(r).mutatationScore*100)+"%",1),Ce("li",null," Mutation Grade: "+jn(Ue(r).mutationGrade),1),Ce("li",null,"Observation: "+jn(Ue(r).mutationComment),1)])):(xt(),Vt("ul",TEe,[MEe,Ce("li",null,[Ce("button",{class:"mt-4 btn",onClick:f[15]||(f[15]=(...v)=>Ue(r).runAllTests&&Ue(r).runAllTests(...v))},"Run Analysis")])]))])):_s("",!0),t.value=="problems"?(xt(),Vt("div",PEe,[Ce("ul",null,[Ue(r).aliveMutants.length?_s("",!0):(xt(),Vt("li",OEe,"No problems found")),(xt(!0),Vt(Ds,null,iv(Ue(r).aliveMutants,(v,b)=>(xt(),Vt("li",{key:v.id},[FEe,Ce("span",{onClick:C=>Ue(i).setActiveTab(v.id),class:"btn btn-link"},jn(v.id),9,BEe)]))),128))])])):_s("",!0),t.value=="output"?(xt(),Vt("div",WEe,[Ce("ul",null,[(xt(!0),Vt(Ds,null,iv(Ue(o).messages,(v,b)=>(xt(),Vt("li",{key:b,class:"flex gap-2"},[Ce("span",VEe,jn(v.time),1),Ce("span",{class:Ho([{"text-blue-500":v.type=="info","text-green-500":v.type=="success","text-yellow-500":v.type=="warning","text-red-500":v.type=="error"},"uppercase"])}," ["+jn(v.type)+"] ",3),Ce("span",HEe,jn(v.message),1),v.paths.length?(xt(),Vt("ul",zEe,[(xt(!0),Vt(Ds,null,iv(v.paths,(C,w)=>(xt(),Vt("li",{class:"cursor-pointer hover:text-base-content",onClick:S=>Ue(i).addToTabs(Ue(i).getCode(C)),key:w},jn(C)+" "+jn(w==v.paths.length-1?"":", "),9,UEe))),128))])):_s("",!0)]))),128))])])):_s("",!0)])])]),_:1})]),_:1})]),_:1})]),_:1})])]),Ce("div",{class:"fixed inset-0 flex items-center justify-center hidden"},[Ce("div",{class:"fixed inset-0 bg-neutral/80",onClick:h}),Ce("div",{class:"relative w-full max-w-lg p-4 border rounded-lg bg-base-300 text-base-content border-neutral/80"},[$Ee,jEe,Ce("div",{class:"flex justify-end"},[Ce("button",{class:"btn btn-sm btn-primary",onClick:h},"Close")])])])],64)}}}),Y4=DY(KEe);Y4.use(Qke());Y4.use(YY,{monaco:uq});Y4.mount("#app");export{MC as m,P$ as t};
function __vite__mapDeps(indexes) {
  if (!__vite__mapDeps.viteFileDeps) {
    __vite__mapDeps.viteFileDeps = ["assets/javascript-V_ZQIUoq.js","assets/typescript-BRZxGkNK.js"]
  }
  return indexes.map((i) => __vite__mapDeps.viteFileDeps[i])
}
